(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    249175,       7629]*)
(*NotebookOutlinePosition[    250432,       7668]*)
(*  CellTagsIndexPosition[    250388,       7664]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
The recalculation of the two-wire simple model with blades - V3.0- LOS values\
\
\>", "Section"],

Cell[CellGroupData[{

Cell["Switches, version numbers, paths etc", "Subsection"],

Cell["\<\
Switches to enable loading of previously saved results instead of \
recalculating from scratch\
\>", "Text"],

Cell["\<\
useprecomputed = False; (* set to True to use saved results from precomputed \
subdirectory *)
If[useprecomputed,
\texceptdamping = False, (* False by default, True to recalculate just \
damping-dependent stuff *)
\texceptdamping = True (* DON\"T CHANGE *)
];\
\>", "Input"],

Cell[CellGroupData[{

Cell["\<\
Definition of the current case - label, descriptive comment, and \
specification in terms of overrides relative to the default parameters
**** EDIT THIS SECTION TO DEFINE A NEW CASE ****\
\>", "Text"],

Cell["modelcase = \"TT\";", "Input",
  CellChangeTimes -> {{3.451735605084487*^9, 3.451735610137718*^9}}],

Cell["\<\
modelcasecomment = \"LIGO-I ETM, SOS with blades creating the \
Undulators....\";\
\>", "Input"],

Cell["\<\
overrides = {
\ttx -> 0.0127,              (* thickness of optic, 1inch *)
\ttr -> (68.2*10^-3)/2,     (* radius of optic, 3inch diameter *)
\tm0 -> 124*10^-3,          (* mass of the compound 2\" mirror and holder *)
\tl0 -> 0.140,               (* wire length *)
\tr0 -> (127*10^-6)/2,      (* radius of wire, not critical can be adjusted
\t\t\t\t\t available diameters: 101um, 113um, 127um, 143um, 160um, 
\t\t\t\t\t\t\t\t\t180um, 202um, 310um, 355um, 370um *)

\tdpitch -> 1.5*10^-3,        (* height of wire break-off above c.o.m. *)
\tdyaw1 -> 35*10^-3,        (* y-separation of wires at structure *)
\tdyaw2 -> 76.2*10^-3,  (* y-separation of wires at optic, 
\t\t\t\t\t\t\t\toptic diameter + 2*1mm standoffs *)
\tkbz -> 75,\t\t\t\t  (* per-blade elastic constant in N/m *)
\tI0y -> 48.6*10^-6,        (* moment of inertia (longitudinal, pitch) *)
\tI0z -> 50.9*10^-6,         (* moment of inertia (yaw) *)
\tI0x -> 91.5*10^-6\t\t\t(* moment of inertia (roll) *)
};\
\>", "Input",
  CellChangeTimes -> {{3.451735653241503*^9, 3.451735656671795*^9}, \
{3.451736835316125*^9, 3.451736838490003*^9}, {3.451736880785919*^9, \
3.45173688180026*^9}}],

Cell["\<\
nonoptvars = {
\t
};\
\>", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The path in which the core model definition and model-specific support files \
are installed. 
**** EDIT THE PATHS AND/OR ADD CLAUSES FOR NEW SYSTEMS AS APPROPRIATE ****\
\>", "Text"],

Cell[BoxData[
    \(\(modeldirectory\  = \ 
        Switch[\[IndentingNewLine]$System, \[IndentingNewLine]"\<Power \
Macintosh\>", \
"\<Boadicea:Users:mbarton:Work:LIGO:analysis:AdvLIGOModel:twowiresimpleblades:\
current\>", \[IndentingNewLine]"\<Mac OS X\>", \
"\</Users/slagmolen/Documents/mathematica/pendmodels/TwoWireSimpleBlades/\
current\>", \[IndentingNewLine]"\<Microsoft Windows\>", \
"\<C:\winslagmolen\mathematica\pendmodels\TwoWireSimpleBlades\current\>"\
\[IndentingNewLine]];\)\)], "Input",
  CellChangeTimes -> {{3.4517175049427156`*^9, 3.451717517645606*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
The path in which custom packages are installed (if different from above). 
**** EDIT THE PATHS AND/OR ADD CLAUSES FOR NEW SYSTEMS AS APPROPRIATE ****\
\>", "Text"],

Cell[BoxData[
    \(\(modelsupportdirectory\  = \ 
        Switch[\[IndentingNewLine]$System, \[IndentingNewLine]"\<Power \
Macintosh\>", "\<Boadicea:Users:mbarton:Work:MathLib\>", \[IndentingNewLine]"\
\<Mac OS X\>", "\</Users/slagmolen/Documents/mathematica/pendtoolkit/v60\>", \
\[IndentingNewLine]"\<Mac OS X x86 (32-bit)\>", \
"\</Users/slagmolen/Documents/mathematica/pendtoolkit/v60\>", \
\[IndentingNewLine]"\<Solaris\>", "\</home/mbarton/MathLib\>", \
\[IndentingNewLine]"\<Linux\>", "\</home/mbarton/MathLib\>", \
\[IndentingNewLine]"\<Linux x86 (64 bit)\>", "\</home/mbarton/MathLib\>", \
\[IndentingNewLine]"\<Microsoft Windows\>", \
"\<C:\winslagmolen\mathematica\pendtoolkit\v50\>"\[IndentingNewLine]];\)\)], \
"Input",
  CellChangeTimes -> {{3.4517370857194138`*^9, 3.451737105314629*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Enable the mode shape plots", "Text"],

Cell["doplots = True;", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Enable export of state space to Matlab", "Text"],

Cell["domatlabexport = False;", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["The number of interesting low frequency modes", "Text"],

Cell["noofLF = 6;", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Usage notes for switches", "Text"],

Cell["\<\
useprecomputed::usage = \"useprecomputed is a switch variable which, when set \
to True, causes results to be read in from files in the data subdirectory \
rather than being calculated afresh.\";\
\>", "Input"],

Cell["\<\
domatlabexport::usage = \"domatlabexport is a switch variable which enables \
the calculation of the state space matrices for Matlab.\";\
\>", "Input"],

Cell["\<\
doplots::usage = \"doplots is a switch variable which enables mode shape \
plots.\";\
\>", "Input"],

Cell["\<\
modelcase::usage = \"modelcase is a string that serves as a label for the \
case of the model currently being calculated, as well as as a name for the \
subdirectory where the files for that case are stored.\";\
\>", "Input"],

Cell["\<\
modelcasecomment::usage = \"modelcasecomment is a string that describes the \
case of the model currently being calculated.\";\
\>", "Input"],

Cell["\<\
modeldirectory::usage = \"modeldirectory is a string (in the format \
appropriate for the local filesystem) that specifies the directory where the \
model definition files (ASUS3ModelDefn.nb and ASUS3ModelDefn.m) is stored. \
The files for particular cases will be stored in subdirectories of this \
directory.\";\
\>", "Input"],

Cell["\<\
modelsupportdirectory::usage = \"modelsupportdirectory is a string (in the \
format appropriate for the local filesystem) that specifies the directory \
where additional support files (e.g., StatusWindow.nb/StatusWindow.m) are \
stored (if different from modeldirectory).\";\
\>", "Input"],

Cell["\<\
overrides::usage = \"overrides is a list of substitutions that modify or \
replace those in defaultvalues.\";\
\>", "Input"],

Cell["\<\
nonoptvars::usage = \"nonoptvars is a list of variables that should be held \
frozen for debugging purpose in the optimization.\";\
\>", "Input"],

Cell["\<\
noofLF::usage = \"noofLF should be set to the number of interesting low \
frequency modes.\";\
\>", "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Version history", "Subsection"],

Cell["See matching ASUS4ModelDefn.nb in directory above this.", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Instructions", "Subsection"]], "Subsection"],

Cell[CellGroupData[{

Cell["Initial installation", "Subsubsection"],

Cell[TextData[{
  "1. Check the assignment to ",
  StyleBox["modelcase",
    FontFamily->"Courier"],
  " in the Switches sextion above. It should correspond to the name of the \
directory in which this copy of ",
  StyleBox["ASUS4ModelCalcXXX.nb",
    FontFamily->"Courier"],
  " is installed.\n2. Check the assignment to ",
  StyleBox["modeldirectory",
    FontFamily->"Courier"],
  " in the Switches section above. Check that there is a case in the ",
  StyleBox["Switch[]", "Program"],
  " statement corresponding to the value of ",
  StyleBox["$System", "Program"],
  " for your version of ",
  StyleBox["Mathematica,",
    FontSlant->"Italic"],
  " and if not, create one. The value returned for that case should be a \
string giving an absolute path to the root directory for the quad pendulum \
model. The model root directory will be the parent of the one containing this \
copy of ASUS4ModelCalc.nb and contains the factory version of ",
  StyleBox["A",
    FontFamily->"Courier"],
  "SUS4",
  StyleBox["ModelDefn.nb",
    FontFamily->"Courier"],
  ", ",
  StyleBox["A",
    FontFamily->"Courier"],
  "SUS4",
  StyleBox["ModelDefn.m",
    FontFamily->"Courier"],
  ", and various other definition and support files. The path string should \
be in the particular standard syntax for your OS (e.g., slash-delimited for \
Unix, colon-delimited for Mac, etc).\n3. Check the assignment to ",
  StyleBox["modelsupportdirectory",
    FontFamily->"Courier"],
  " in the Switches section above. Check that there is a case in the Switch[] \
statement corresponding to the value of $System for your version of ",
  StyleBox["Mathematica,",
    FontSlant->"Italic"],
  " and if not, create one. The value returned for that case should be a \
string giving an absolute path to the directory where you have placed the \
custom packages  ",
  StyleBox["RotationsXYZ.nb",
    FontFamily->"Courier"],
  ", ",
  StyleBox["RotationsXYZ.m",
    FontFamily->"Courier"],
  ", ",
  StyleBox["MyShapes.nb",
    FontFamily->"Courier"],
  " and ",
  StyleBox["MyShapes.m",
    FontFamily->"Courier"],
  ".  The path string should be in the particular standard syntax for your OS \
(e.g., slash-delimited for Unix, colon-delimited for Mac, etc)."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["To do calculations with the precomputed values", "Subsubsection"],

Cell[TextData[{
  "1. Check sure that this directory contains a ",
  StyleBox["precomputed",
    FontFamily->"Courier"],
  " subdirectory with various saved results (",
  StyleBox["allparams.m",
    FontFamily->"Courier"],
  " etc). If the directory is empty, there are no precomputed results and you \
will need to do the full calculation.\n2. If there are precomputed results, \
look for an assignment statement to the variable ",
  StyleBox["precomputed",
    FontFamily->"Courier"],
  " at the very beginning of this file and make sure that it is set to ",
  StyleBox["True",
    FontFamily->"Courier"],
  ". (Otherwise set it to ",
  StyleBox["False",
    FontFamily->"Courier"],
  " to force the full calculation)\n3. Evaluate cells in this notebook in \
order from the top. If the wire bending elasticity is not of interest, you \
can stop after the sections \"Stage 0 of the computation\" and \"Listings and \
plots with Stage 0 data\". The final two sections, \"Stages 1 and 2\" and \
\"Listings and plots with Stage 2 data\" take much longer to run.\n4. View \
the output in the \"Listings and plots\" sections. Add commands for new \
listings and plots using the examples there as a guide."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["To try different values with the same basic model structure", \
"Subsubsection"],

Cell[TextData[{
  "Many interesting variations can be implemented by just defining overrides \
to some or all of the default values of constants in the substitution list ",
  StyleBox["defaultvalues",
    FontFamily->"Courier"],
  ".Use this method where possible so that differences are confined to one \
well-defined spot in the code.To do this, proceed as follows:"
}], "Text"],

Cell[TextData[{
  "1. If you want to preserve the results from the current variation, (i) \
duplicate the entire directory containing containing this file, (ii) give the \
new directory a name reflecting the variation you're going to try, e.g., ",
  StyleBox["heavieroptic",
    FontFamily->"Courier"],
  ",  (iii) rename the new copy of this file to include some or all of the \
case name (e.g., ",
  StyleBox["A",
    FontFamily->"Courier"],
  "SUS4",
  StyleBox["ModelCalcDefault.nb",
    FontFamily->"Courier"],
  " -> ",
  StyleBox["A",
    FontFamily->"Courier"],
  "SUS4",
  StyleBox["ModelCalcHeavierOptic.nb",
    FontFamily->"Courier"],
  "), (iv) close this file and continue from here new copy in the new \
directory, (iv) (you should be in the new copy now) edit the assignment to ",
  StyleBox["modelcase",
    FontFamily->"Courier"],
  " in the Switches section above to correspond to the new directory name, \
and (v) edit the assignment to ",
  StyleBox["modelcasecomment",
    FontFamily->"Courier"],
  " in the Switches section to describe the new case.\n2. Edit the assignment \
to ",
  StyleBox["overrides",
    FontFamily->"Courier"],
  " in the Switches section above, adding, removing or changing overrides to \
reflect whatever new configuration you want. For example, ",
  StyleBox["m3->80",
    FontFamily->"Courier"],
  " will set the optic mass to 80 kg, ",
  StyleBox["m3->scale[2",
    FontFamily->"Courier"],
  "] will double it from what ever it was, and ",
  StyleBox["m3->increment[5",
    FontFamily->"Courier"],
  "] will add 5 kg.\n3. Edit the assignment to ",
  StyleBox["useprecomputed",
    FontFamily->"Courier"],
  " in the Switches section above to make it set ",
  StyleBox["useprecomputed",
    FontFamily->"Courier"],
  " to ",
  StyleBox["False",
    FontFamily->"Courier"],
  ".\n4. Delete all the saved result files in the ",
  StyleBox["precomputed",
    FontFamily->"Courier"],
  " subdirectory (of the new copy!).\n5. Select all the cells in this \
notebook and evaluate them.WARNING: recomputing the whole notebook takes \
several hours. Stage 0 is about 3 minutes, Stage 1 is about an hour, Stage 2 \
is about two hours, and the full collection of listings and plots at the end \
are a few minutes. Depending on what precision you want, you might be able to \
get away with evaluating only Stages 0 and 1, or only Stage 0.\n6. Edit the \
assignment to ",
  StyleBox["useprecomputed",
    FontFamily->"Courier"],
  " in the Switches section above to make it set ",
  StyleBox["useprecomputed",
    FontFamily->"Courier"],
  " to ",
  StyleBox["True", "Program"],
  ". Evaluate it. Save the file."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["To hack the model structure", "Subsubsection"],

Cell["\<\
Some changes, such as adding asymmetries, are too radical to be implemented \
by overriding values. And sometimes, as in starting a design for a new optic, \
you want to make a new set of default values to avoid having to override \
ridiculous numbers of them. In such cases the model definition needs to be \
hacked.\
\>", "Text"],

Cell[TextData[{
  "1. Duplicate the entire directory containing this file and edit the \
assignments to ",
  StyleBox["modelcase",
    FontFamily->"Courier"],
  " and ",
  StyleBox["modelcasecomment", "Program"],
  " in the new copy of this file as explained in \"To try different values \
with the same basic model structure\", step 1, above.\n2. Make a local copy \
of ",
  StyleBox["A",
    FontFamily->"Courier"],
  "SUS4",
  StyleBox["ModelDefn.nb",
    FontFamily->"Courier"],
  " in the new directory (e.g., by copying it from the factory version in the \
model root directory one level above).\n3. Hack the local copy to change the \
structure of the model as desired (this is left as an exercise for the \
reader).\n4. PUT CONSPICUOUS COMMENTS AT THE TOP OF THE NEW MODEL SAYING HOW \
IT DIFFERS FROM THE FACTORY VERSION!\n5. Continue from Step 2 of \"To try \
different values with the same basic model structure\" above. ",
  StyleBox["ASUS4ModelCalc.nb",
    FontFamily->"Courier"],
  " will find the customized version of ",
  StyleBox["ASUS4ModelDefn.m",
    FontFamily->"Courier"],
  " because it looks in its own directory (specified by ",
  StyleBox["modelcase",
    FontFamily->"Courier"],
  ") before checking the root directory."
}], "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Preliminaries", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
The directory in which this copy of ASUSModelCalc.nb and the other files \
associated with this case are stored.\
\>", "Text"],

Cell[BoxData[
    \(\(SetDirectory[ToFileName[{modeldirectory, modelcase}]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The path in which the model definition and model-specific support files are \
installed.\
\>", "Text"],

Cell[BoxData[
    \( (*Clear[$Path]\[IndentingNewLine]$Path = \
{"\</Applications/Mathematica.app/SystemFiles/Links\>", \
"\</Users/slagmolen/Library/Mathematica/Kernel\>", \
"\</Users/slagmolen/Library/Mathematica/Autoload\>", \
"\</Users/slagmolen/Library/Mathematica/Applications\>", \
"\</Library/Mathematica/Kernel\>", "\</Library/Mathematica/Autoload\>", \
"\</Library/Mathematica/Applications\>", "\<.\>", "\</Users/slagmolen\>", \
"\</Applications/Mathematica.app/AddOns/Packages\>", \
"\</Applications/Mathematica.app/AddOns/LegacyPackages\>", \
"\</Applications/Mathematica.app/SystemFiles/Autoload\>", \
"\</Applications/Mathematica.app/AddOns/Autoload\>", \
"\</Applications/Mathematica.app/AddOns/Applications\>", \
"\</Applications/Mathematica.app/AddOns/ExtraPackages\>", \
"\</Applications/Mathematica.app/SystemFiles/Kernel/Packages\>", \
"\</Applications/Mathematica.app/Documentation/English/System\>"}*) \)], \
"Input"],

Cell[BoxData[
    \(\($Path\  = \ Append[$Path, modeldirectory];\)\)], "Input",
  CellChangeTimes -> {3.451736698892377*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
The path in which custom packages are installed (if different from above).\
\>", "Text"],

Cell[BoxData[
    \(\($Path\  = \ Append[$Path, modelsupportdirectory];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Read in the model definition. First look for a customized model in the \
current directory, then look for the factory model in the directory above.\
\>", "Text"],

Cell["\<\
Get[\"TwoWireSimpleBladesDefn.m\",Path->{Directory[],ParentDirectory[\
Directory[]]}];\
\>", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Check that core model is loaded and correct", "Text"],

Cell["\<\
If[
\tmodelcomment!=\"Two-wire simple pendulum with blades\"
\t||modelversion<3.0,
\tAbort[]
];\
\>", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Archive some stuff that doesn't get recomputed here, just in case it's useful \
to look at\
\>", "Text"],

Cell["saveprecomputed[\"allvars.m\",allvars];", "Input"],

Cell["saveprecomputed[\"startpos.m\",startpos];", "Input"],

Cell["saveprecomputed[\"gravlist.m\",gravlist];", "Input"],

Cell["saveprecomputed[\"wirelist.m\",wirelist];", "Input"],

Cell["saveprecomputed[\"springlist.m\",springlist];", "Input"],

Cell["saveprecomputed[\"kinetic.m\",kinetic];", "Input"],

Cell["saveprecomputed[\"defaultvalues.m\",defaultvalues];", "Input"],

Cell["saveprecomputed[\"overrides.m\",overrides];", "Input"],

Cell["saveprecomputed[\"nonoptvars.m\",nonoptvars];", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Open the status window", "Text"],

Cell["OpenStatusWindow[WindowSize->{500,300}];", "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell["Reset[All]", "Input"],

Cell[CellGroupData[{

Cell["Listings and plots with Stage 0A Data", "Subsection"],

Cell["Calculate[Stage0A]", "Input"],

Cell[CellGroupData[{

Cell["View the eigenfrequencies", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
Table[{Length[allvars]-index+1, Hz0A[[index]]}, {index, 1, \
Length[allvars]}]\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \({{6, 7.74666376915459`}, {5, 5.521318429551293`}, {4, 
        1.7072638005392924`}, {3, 1.3476233573742042`}, {2, 
        1.3320127099692072`}, {1, 0.9693745454743624`}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["View the important low-frequency modes", "Text"],

Cell[CellGroupData[{

Cell["\<\
Join[\t
\t{{\"N\",\"f\",\"type\"}},
\tTable[
\t\tJoin[
\t\t\t{i},
\t\t\t{Hz0A[[-i]]},
\t\t\timportant[e2ni.eigenvectors0A[[-i]],0.7]
\t\t],
\t\t{i,noofLF}
\t]
]//TableForm\
\>", "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"N\"\>", "\<\"f\"\>", "\<\"type\"\>"},
          {"1", "0.9693745454743624`", "pitch0"},
          {"2", "1.3320127099692072`", "roll0"},
          {"3", "1.3476233573742042`", "pitch0"},
          {"4", "1.7072638005392924`", "yaw0"},
          {"5", "5.521318429551293`", "z0"},
          {"6", "7.74666376915459`", "roll0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["View the higher frequency modes", "Text"],

Cell[CellGroupData[{

Cell["\<\
Join[\t
\t{{\"N\",\"f\",\"type\"}},
\tTable[
\t\tJoin[
\t\t\t{i},
\t\t\t{Hz0A[[-i]]},
\t\t\timportant[e2ni.eigenvectors0A[[-i]],0.7]
\t\t],
\t\t{i,noofLF+1,Length[allvars]}
\t]
]//TableForm\
\>", "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"N\"\>", "\<\"f\"\>", "\<\"type\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Classify the modes", "Text"],

Cell[CellGroupData[{

Cell["\<\
longpitchmodes0 = \
Select[Range[-noofLF,-1],longpitchQ[e2ni.eigenvectors0A[[#]]]&]\
\>", "Input"],

Cell[BoxData[
    \({\(-3\), \(-1\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
transrollmodes0 = \
Select[Range[-noofLF,-1],transrollQ[e2ni.eigenvectors0A[[#]]]&]\
\>", "Input"],

Cell[BoxData[
    \({\(-6\), \(-2\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
yawmodes0 = Select[Range[-noofLF,-1],yawQ[e2ni.eigenvectors0A[[#]]]&]\
\>", "Input"],

Cell[BoxData[
    \({\(-4\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
vertmodes0 = Select[Range[-noofLF,-1],vertQ[e2ni.eigenvectors0A[[#]]]&]\
\>", "Input"],

Cell[BoxData[
    \({\(-5\)}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["View the mode frequencies by groups", "Text"],

Cell[CellGroupData[{

Cell["longpitchfreqs0 = Hz0A[[longpitchmodes0]]", "Input"],

Cell[BoxData[
    \({1.3476233573742042`, 0.9693745454743624`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["transrollfreqs0 = Hz0A[[transrollmodes0]]", "Input"],

Cell[BoxData[
    \({7.74666376915459`, 1.3320127099692072`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["yawfreqs0 = Hz0A[[yawmodes0]]", "Input"],

Cell[BoxData[
    \({1.7072638005392924`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["vertfreqs0 = Hz0A[[vertmodes0]]", "Input"],

Cell[BoxData[
    \({5.521318429551293`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Export stuff for Matlab comparison", "Text"],

Cell["\<\
longpitchfreqs00 = longpitchfreqs0;
transrollfreqs00 = transrollfreqs0;
yawfreqs00 = yawfreqs0;
vertfreqs00 = vertfreqs0;
constval0 = constval;\
\>", "Input"],

Cell["\<\
saveprecomputed[\"matlabcomp0.m\",longpitchfreqs00,transrollfreqs00,\
yawfreqs00,vertfreqs00,constval0];\
\>", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Mode shape listings/plots", "Text"],

Cell[CellGroupData[{

Cell["#1", "Text"],

Cell[CellGroupData[{

Cell["Hz0A[[-1]]", "Input"],

Cell[BoxData[
    \(0.9693745454743624`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pretty[Chop[e2ni . eigenvectors0A[\([\(-1\)]\)], 10^\(-4\)]]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
          {"\<\"optic\"\>", "0.003148991491153312`", "0", "0", 
            "0", \(-0.9999950419140031`\), "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DoWithStatus["\<Plotting stage 0A mode 1\>", \ 
      eigenplot[eigenvectors0A[\([\(-1\)]\)],  .1, {0, \(-1\), 0}, \ 
        floatmatrix0A]]\)], "Input",
  CellChangeTimes -> {{3.4517357002801437`*^9, 3.451735738493672*^9}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 7.1936 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-3.0968 7.1936 1.33227e-15 7.1936 [
[ 0 0 0 0 ]
[ 1 7.1936 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 7.1936 L
s
0 7.1936 m
.17254 5.95241 L
s
.17254 5.95241 m
.17254 1.24119 L
s
.17254 1.24119 m
0 0 L
s
1 0 m
.82746 1.24119 L
s
.82746 1.24119 m
.82746 5.95241 L
s
.82746 5.95241 m
1 7.1936 L
s
1 7.1936 m
1 0 L
s
0 0 m
0 7.1936 L
s
0 7.1936 m
1 7.1936 L
s
1 7.1936 m
1 0 L
s
1 0 m
0 0 L
s
.17254 1.24119 m
.82746 1.24119 L
s
.82746 1.24119 m
.82746 5.95241 L
s
.82746 5.95241 m
.17254 5.95241 L
s
.17254 5.95241 m
.17254 1.24119 L
s
0 0 m
1 0 L
1 7.1936 L
0 7.1936 L
closepath
clip
newpath
.5 Mabswid
.71 .499 .602 r
.36894 3.72521 m .60367 3.74876 L .62255 3.55423 L p F P
0 g
s
.50294 3.63487 m
.50301 3.57043 L
s
.71 .499 .602 r
.62255 3.55423 m .38909 3.53081 L .36894 3.72521 L p F P
0 g
s
.69 .644 .798 r
.38909 3.53081 m .62255 3.55423 L .64276 3.35924 L p F P
0 g
s
.69 .644 .798 r
.64276 3.35924 m .40802 3.33568 L .38909 3.53081 L p F P
0 g
s
.707 .577 .707 r
.5 6.14181 m .77857 6.14181 L p .22143 5.86324 L F P
0 g
s
.707 .577 .707 r
.77857 6.14181 m .77857 5.86324 L .22143 5.86324 L p F P
0 g
s
.707 .577 .707 r
.22143 5.86324 m .22143 6.14181 L .5 6.14181 L p F P
0 g
s
.745 .608 .039 r
.22143 6.14181 m .22143 5.86324 L .19121 6.10908 L p F P
0 g
s
0 0 .039 r
.77857 5.86324 m .77857 6.14181 L .7929 6.27274 L p F P
0 g
s
0 0 .039 r
.80879 6.10908 m .77857 5.86324 L p .7929 6.27274 L F P
0 g
s
.288 0 0 r
.77857 5.86324 m .80879 6.10908 L .19121 6.10908 L p F P
0 g
s
.50223 4.2691 m
.50282 3.73864 L
s
.288 0 0 r
.19121 6.10908 m .22143 5.86324 L .77857 5.86324 L p F P
0 g
s
.5 6.27274 m
.50018 6.10908 L
s
.50035 5.96174 m
.50223 4.2691 L
s
.745 .608 .039 r
.2071 6.27274 m .22143 6.14181 L p .19121 6.10908 L F P
0 g
s
.674 .314 .356 r
.34893 3.90579 m .58743 3.92972 L .60367 3.74876 L p F P
0 g
s
.674 .314 .356 r
.60367 3.74876 m .36894 3.72521 L .34893 3.90579 L p F P
0 g
s
.617 .738 .932 r
.40802 3.33568 m .64276 3.35924 L .66296 3.1769 L p F P
0 g
s
.617 .738 .932 r
.66296 3.1769 m .42446 3.15297 L .40802 3.33568 L p F P
0 g
s
.582 .101 .077 r
.33047 4.05903 m .57509 4.08357 L .58743 3.92972 L p F P
0 g
s
.582 .101 .077 r
.58743 3.92972 m .34893 3.90579 L .33047 4.05903 L p F P
0 g
s
.495 .775 .994 r
.42446 3.15297 m .66296 3.1769 L .68172 3.02082 L p F P
0 g
s
.495 .775 .994 r
.68172 3.02082 m .4371 2.99628 L .42446 3.15297 L p F P
0 g
s
.439 0 0 r
.31514 4.17087 m .56793 4.19624 L .57509 4.08357 L p F P
0 g
s
.439 0 0 r
.57509 4.08357 m .33047 4.05903 L .31514 4.17087 L p F P
0 g
s
.33 .749 .976 r
.4371 2.99628 m .68172 3.02082 L .69746 2.90518 L p F P
0 g
s
.33 .749 .976 r
.69746 2.90518 m .44467 2.87981 L .4371 2.99628 L p F P
0 g
s
.01 w
.37666 2.87738 Mdot
.5 Mabswid
.745 .608 .039 r
.19121 6.10908 m .19121 6.41787 L .2071 6.27274 L p F P
0 g
s
0 0 .039 r
.7929 6.27274 m .80879 6.41787 L .80879 6.10908 L p F P
0 g
s
.131 .659 .874 r
.44467 2.87981 m .69746 2.90518 L .70852 2.84409 L p F P
0 g
s
.131 .659 .874 r
.70852 2.84409 m .44601 2.81775 L .44467 2.87981 L p F P
0 g
s
.254 0 0 r
.30457 4.22744 m .56708 4.25378 L .56793 4.19624 L p F P
0 g
s
.254 0 0 r
.56793 4.19624 m .31514 4.17087 L .30457 4.22744 L p F P
0 g
s
.707 .577 .707 r
.5 6.41787 m .19121 6.41787 L .19121 6.10908 L p F P
0 g
s
.707 .577 .707 r
.80879 6.10908 m .80879 6.41787 L .5 6.41787 L p F P
0 g
s
.707 .577 .707 r
.19121 6.10908 m .80879 6.10908 L p .5 6.41787 L F P
0 g
s
.087 0 0 r
.44601 2.81775 m .70852 2.84409 L .71325 2.84987 L p F P
0 g
s
.087 0 0 r
.71325 2.84987 m .44025 2.82248 L .44601 2.81775 L p F P
0 g
s
0 .542 .734 r
.30035 4.21678 m .57336 4.24417 L .56708 4.25378 L p F P
0 g
s
0 .542 .734 r
.56708 4.25378 m .30457 4.22744 L .30035 4.21678 L p F P
0 g
s
.707 .577 .707 r
.5 6.46981 m .81448 6.46981 L p .18552 6.15533 L F P
0 g
s
.707 .577 .707 r
.81448 6.46981 m .81448 6.15533 L .18552 6.15533 L p F P
0 g
s
.707 .577 .707 r
.18552 6.15533 m .18552 6.46981 L .5 6.46981 L p F P
0 g
s
.745 .608 .039 r
.16714 6.63777 m .18552 6.46981 L p .14647 6.47306 L F P
0 g
s
.745 .608 .039 r
.18552 6.46981 m .18552 6.15533 L .14647 6.47306 L p F P
0 g
s
0 0 .039 r
.81448 6.15533 m .81448 6.46981 L .83286 6.63777 L p F P
0 g
s
0 0 .039 r
.85353 6.47306 m .81448 6.15533 L p .83286 6.63777 L F P
0 g
s
.288 0 0 r
.81448 6.15533 m .85353 6.47306 L .14647 6.47306 L p F P
0 g
s
.288 0 0 r
.14647 6.47306 m .18552 6.15533 L .81448 6.15533 L p F P
0 g
s
.306 0 0 r
.44025 2.82248 m .71325 2.84987 L .7104 2.92993 L p F P
0 g
s
.306 0 0 r
.7104 2.92993 m .42718 2.90152 L .44025 2.82248 L p F P
0 g
s
.187 .689 .91 r
.30372 4.13197 m .58694 4.16038 L .57336 4.24417 L p F P
0 g
s
.187 .689 .91 r
.57336 4.24417 m .30035 4.21678 L .30372 4.13197 L p F P
0 g
s
.745 .608 .039 r
.14647 6.47306 m .14647 6.82659 L .16714 6.63777 L p F P
0 g
s
0 0 .039 r
.83286 6.63777 m .85353 6.82659 L .85353 6.47306 L p F P
0 g
s
.5 6.63777 m
.50021 6.47306 L
s
.01 w
.35823 2.7699 Mdot
.64177 2.7699 Mdot
.5 Mabswid
.502 0 0 r
.42718 2.90152 m .7104 2.92993 L .69944 3.08291 L p F P
0 g
s
.502 0 0 r
.69944 3.08291 m .40755 3.05362 L .42718 2.90152 L p F P
0 g
s
.4 .767 .993 r
.31511 3.97496 m .607 4.00424 L .58694 4.16038 L p F P
0 g
s
.4 .767 .993 r
.58694 4.16038 m .30372 4.13197 L .31511 3.97496 L p F P
0 g
s
.644 .232 .248 r
.40755 3.05362 m .69944 3.08291 L .68108 3.29547 L p F P
0 g
s
.644 .232 .248 r
.68108 3.29547 m .38334 3.26559 L .40755 3.05362 L p F P
0 g
s
.574 .76 .966 r
.33376 3.75968 m .6315 3.78955 L .607 4.00424 L p F P
0 g
s
.574 .76 .966 r
.607 4.00424 m .31511 3.97496 L .33376 3.75968 L p F P
0 g
s
.5004 6.32867 m
.50342 4.00045 L
s
.50342 4.00045 m
.50369 3.78971 L
s
.708 .476 .57 r
.38334 3.26559 m .68108 3.29547 L .65738 3.54213 L p F P
0 g
s
.708 .476 .57 r
.65738 3.54213 m .35757 3.51205 L .38334 3.26559 L p F P
0 g
s
.683 .66 .821 r
.35757 3.51205 m .65738 3.54213 L .6315 3.78955 L p F P
0 g
s
.683 .66 .821 r
.6315 3.78955 m .33376 3.75968 L .35757 3.51205 L p F P
0 g
s
.50369 3.78971 m
.50398 3.56192 L
s
.707 .577 .707 r
.5 6.82659 m .14647 6.82659 L .14647 6.47306 L p F P
0 g
s
.707 .577 .707 r
.85353 6.47306 m .85353 6.82659 L .5 6.82659 L p F P
0 g
s
.707 .577 .707 r
.14647 6.47306 m .85353 6.47306 L p .5 6.82659 L F P
0 g
s
.25 Mabswid
0 0 m
0 7.1936 L
s
0 7.1936 m
1 7.1936 L
s
1 7.1936 m
1 0 L
s
1 0 m
0 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{37.4375, 269.25},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40000U00013B000`400?l00000o`00003o9Oooool0
02Gooooo000Uooooo`009Ol000000003o`000?oooooooooo027ooooo0Ol000000003o`000?oooooo
oooo027ooooo0Ol000000003o`000?oooooooooo027ooooo0Ol000000003o`000?oooooooooo027o
oooo0Ol0000000;o00008Oooool2o`0000000_l0000Qooooo`;o00000002o`00027ooooo0_l00000
00;o00008Oooool2o`0000000_l0000Qooooo`;o00000002o`00027ooooo0_l0000000;o00008Ooo
ool2o`00000000?o0000ooooool000007oooool1o`00007ooooo0Ol000000003o`000?oooooo0000
01oooooo0Ol00001ooooo`7o000000000ol0003oooooo`00000Oooooo`7o00000Oooool1o`000000
00?o0000ooooool000007oooool1o`00007ooooo0Ol000000003o`000?oooooo000001oooooo0Ol0
0001ooooo`7o000000000ol0003oooooo`00000Oooooo`7o00000Oooool1o`00000000?o0000oooo
ool000007oooool1o`00007ooooo0Ol000000003o`000?oooooo000001oooooo0Ol00001ooooo`7o
000000001?l0003oooooooooool0000Mooooo`03o`000?oooooooooo007o000000001?l0003ooooo
ooooool0000Mooooo`03o`000?oooooooooo007o000000001?l0003oooooooooool0000Mooooo`03
o`000?oooooooooo007o000000001?l0003oooooooooool0000Mooooo`03o`000?oooooooooo007o
000000001?l0003oooooooooool0000Mooooo`03o`000?oooooooooo007o000000001?l0003ooooo
ooooool0000Mooooo`03o`000?oooooooooo007o000000001?l0003oooooooooool0000Mooooo`03
o`000?oooooooooo007o000000001?l0003oooooooooool0000Mooooo`03o`000?oooooooooo007o
000000001Ol0003ooooooooooooooooo000001_ooooo00Co0000oooooooooooooooo0Ol000000005
o`000?ooooooooooooooool000006oooool01?l0003oooooooooooooool1o`00000000Go0000oooo
ooooooooooooo`00000Kooooo`04o`000?ooooooooooooooo`7o000000001Ol0003ooooooooooooo
oooo000001_ooooo00Co0000oooooooooooooooo0Ol000000005o`000?ooooooooooooooool00000
6oooool01?l0003oooooooooooooool1o`00000000Go0000ooooooooooooooooo`00000Kooooo`04
o`000?ooooooooooooooo`7o000000001Ol0003ooooooooooooooooo000001_ooooo00Co0000oooo
oooooooooooo0Ol000000003o`000?oooooooooo00;ooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`02ooooo`7o000000000ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool00_ooool1o`00000000?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo00;ooooo0Ol000000003o`000?oooooooooo00;ooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`02ooooo`7o000000000ol0003oooooooooo`02
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00_ooool1o`00000000?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00;ooooo0Ol000000003
o`000?oooooooooo00;ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`02ooooo`7o
000000000ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
0_ooool1o`00000000?o0000ooooooooool00oooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo00?ooooo0Ol000000003o`000?oooooooooo00?ooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`03ooooo`7o000000000ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool00oooool1o`00000000?o0000ooooooooool00ooooolIo`0000Go
oooo0Ol000000003o`000?oooooooooo00?ooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`03ooooo`7o000000000ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool00oooool1o`00000000?o0000ooooooooool00oooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo00?ooooo0Ol000000003o`000?oooooooooo00?ooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`03ooooo`7o000000000ol0003oooooooooo`03ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool00oooool1o`00000000?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo0Ol000000003o`000?oo
oooooooo00?ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`03ooooo`7o00000000
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00oooool1
o`00000000?o0000ooooooooool00oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
00?ooooo0Ol000000003o`000?oooooooooo00?ooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`03ooooo`7o000000000ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool00oooool1o`00000000?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo00?ooooo0Ol000000003o`000?oooooooooo00?ooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`03ooooo`7o000000000ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00oooool1o`00000000?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo0Ol000000003o`00
0?oooooooooo00?ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`03ooooo`7o0000
00000ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00ooo
ool1o`00000000?o0000ooooooooool00oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo00?ooooo0Ol000000003o`000?oooooooooo00?ooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`03ooooo`7o000000000ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool00oooool1o`00000000?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00?ooooo0Ol000000003o`000?oooooooooo00?ooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`03ooooo`7o000000000ol0003oooooooooo`03
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00oooool1o`00000000?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo0Ol000000003
o`000?oooooooooo00?ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`03ooooo`7o
000000000ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
0oooool1o`00000000?o0000ooooooooool00oooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo00?ooooo0Ol000000003o`000?oooooooooo00?ooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`03ooooo`7o000000000ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool00oooool1o`00000000?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo0Ol000000003o`000?oooooooooo00?ooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`03ooooo`7o000000000ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00oooool1o`00000000?o0000
ooooooooool00oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo0Ol00000
0003o`000?oooooooooo00?ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`03oooo
o`7o000000000ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool00oooool1o`00000000?o0000ooooooooool00oooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo00?ooooo0Ol000000003o`000?oooooooooo00?ooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`03ooooo`7o000000000ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool00oooool1o`00000000?o0000ooooooooool00oooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo0Ol000000003o`000?oooooooooo00?o
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`03ooooo`7o000000000ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00oooool1o`00000000?o
0000ooooooooool00oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo0Ol0
00000003o`000?oooooooooo00?ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`03
ooooo`7o000000000ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool00oooool1o`00000000?o0000ooooooooool00oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo00?ooooo0Ol000000003o`000?oooooooooo00?ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`03ooooo`7o000000000ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool00oooool1o`00000000?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo0Ol000000003o`000?oooooooooo
00?ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`03ooooo`7o000000000ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00oooool1o`000000
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo
0Ol000000003o`000?oooooooooo00?ooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`03ooooo`7o000000000ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool00oooool1o`00000000?o0000ooooooooool00oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00?ooooo0Ol000000003o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00oooool1o`00000000?o0000ooooooooool00oooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo00?ooooo0Ol000000003o`000?oooooooooo00?ooooo00?o0000ooooooooool01ooo
ool6o`0000Sooooo00?o0000ooooooooool00oooool1o`00000000?o0000ooooooooool00oooool0
0ol0003oooooooooo`07ooooo`03o`000?m>003oCP0000?oCP001?l00004ooooo`03o`000?oooooo
oooo00?ooooo0Ol000000003o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool2o`00
00WoCP0000?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`7o000000000ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Kooooo1_l00004odh00003o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool1o`00000000?o0000ooooooooool00oooool00ol0003ooooo
ooooo`06ooooo`03o`000?n0003oP00000?oP0001Ol00004ooooo`03o`000?oooooooooo00?ooooo
0Ol000000003o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003oP000oh00
0007oh000003o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool1o`00000000?o0000
ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?n0003oP00000OoP00000?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`7o000000000ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Gooooo00?o0000oh000?n000002?n000000ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo0Ol000000003o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01Oooool00ol0003oP000oh000008oh000003o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool1o`00000000?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`Oo0000
1?n000000ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo0Ol000000003o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oY3/ooj@k?`04oj@k?`Go00001?oo
ool00ol0003oooooooooo`03ooooo`7o000000000ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Gooooo00?o0000oj@k?onT>cl02?nT>cl00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo0Ol000000003o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0
003oY3/ooj@k?`08oj@k?`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool1o`00
000000?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?nT>cooY3/o00Wo
Y3/o00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`7o000000000ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oj@k?onT>cl02?nT>cl00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo0Ol000000003o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oY3/ooj@k?`08oj@k?`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool1o`00000000?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`Oo00001?nT>cl00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0Ol00000
0003o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003o]GVAokEiT@04okEi
T@Go00001Oooool00ol0003oooooooooo`03ooooo`7o000000000ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Cooooo00?o0000okEiTOneNI402?neNI400ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo0Ol000000003o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003o]GVAokEiT@08okEiT@03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool1o`00000000?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?ne
NI7o]GVA00So]GVA00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`7o00000000
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000okEiTOneNI402?neNI40
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0Ol000000003o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003o]GVAokEiT@07okEiT@03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool1o`00000000?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?neNI7o]GVA00Oo]GVA00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`03ooooo`7o000000000ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000okEiTOneNI401oneNI400ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
0Ol000000003o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool6o`0000Co]GVA00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`7o000000000ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ojjXd_n^Z=800on^Z=85o`0000Kooooo00?o0000
ooooooooool00oooool1o`00000000?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?n^Z=;o[ZSB00;o[ZSB00?o0000ojjXd_n^Z=800_n^Z=800ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo0Ol000000003o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003o[ZSBojjXdP02ojjXdP03o`000?n^Z=;o[ZSB00;o[ZSB00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`7o000000000ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ojjXd_n^Z=800_n^Z=800ol0003o[ZSBojjXdP02ojjXdP03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool1o`00000000?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?n^Z=;o[ZSB00?o[ZSB00?o0000ojjXd_n^Z=800_n^
Z=800ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo0Ol000000003o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003o[ZSBojjXdP03ojjXdP03o`000?n^Z=;o
[ZSB00;o[ZSB00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`7o000000000ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ojjXd_n^Z=800on^Z=800ol0
003o[ZSBojjXdP02ojjXdP03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool1o`00
000000?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?n^Z=;o[ZSB00?o
[ZSB00?o0000ojjXd_n^Z=800_n^Z=800ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo0Ol000000003o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool7o`0000Co[ZSB
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`7o000000000ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oi;2monB`_L00onB`_L6o`0000Kooooo00?o
0000ooooooooool00oooool1o`00000000?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?nB`_OoT/;g00?oT/;g00?o0000oi;2monB`_L00_nB`_L00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo0Ol000000003o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oT/;goi;2m`03oi;2m`03o`000?nB`_OoT/;g00;oT/;g00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`7o000000000ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000oi;2monB`_L00onB`_L00ol0003oT/;goi;2m`02oi;2m`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool1o`00000000?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?nB`_OoT/;g00CoT/;g00?o0000oi;2monB`_L0
0_nB`_L00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo0Ol000000003o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oT/;goi;2m`04oi;2m`05o`000?nB
`_OoT/;goi;2mol000001oooool00ol0003oooooooooo`03ooooo`7o000000000ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oi;2monB`_L01?nB`_L01Ol0003oT/;goi;2
monB`_Oo000000Oooooo00?o0000ooooooooool00oooool1o`00000000?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`So00000onB`_L00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00?ooooo0Ol000000003o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oI/CnofK4oP04ofK4oPGo00001oooool00ol0003oooooooooo`03ooooo`7o000000000ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ofK4o_mVa?h01?mVa?h01Ol0
003oI/CnofK4o_mVa?ko000000Oooooo00?o0000ooooooooool00oooool1o`00000000?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?mVa?koI/Cn00CoI/Cn00Go0000ofK4
o_mVa?koI/Cno`000007ooooo`03o`000?oooooooooo00?ooooo0Ol000000003o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oI/CnofK4oP04ofK4oP05o`000?mVa?koI/Cn
ofK4o_l000001oooool00ol0003oooooooooo`03ooooo`7o000000000ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ofK4o_mVa?h01?mVa?h01?l0003oI/CnofK4o_l00008
ooooo`03o`000?oooooooooo00?ooooo0Ol000000003o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool6o`000005ofK4o_l0003oI/CnofK4o_l000002?ooool00ol0003oooooooooo`03
ooooo`7o000000000ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000obn`
j?l_/>P00ol_/>P5o`0000Sooooo00?o0000ooooooooool00oooool1o`00000000?o0000oooooooo
ool00oooool01Ol0003ooooooooooooooooo000000Oo;k3X00Co0000obn`j?l_/>So00002?ooool0
0ol0003oooooooooo`03ooooo`7o000000000ol0003oooooooooo`03ooooo`04o`000?oooooooooo
ooooo`Ko00000_l_/>P00ol0003o;k3Xo`000009ooooo`03o`000?oooooooooo00?ooooo0Ol00000
0003o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool5o`0000Wooooo00?o0000oooo
ooooool00oooool1o`00000000?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool1o`00000000?o0000ooooooooool0
0oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
0oooool1o`00000000?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool00oooool1o`00000000?o0000ooooooooool00oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool1
o`00000000?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool00oooool1o`00000000?o0000ooooooooool00oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool1o`000000
00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool00oooool1o`00000000?o0000ooooooooool00oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool1o`00000000?o0000
ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool00oooool1o`00000000?o0000ooooooooool00oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool1o`00000000?o0000oooooooo
ool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool00oooool1o`00000000?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool00oooool1o`00000000?o0000ooooooooool00ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00ooo
ool1o`00000000?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool00oooool1o`00000000?o0000ooooooooool00oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool1o`00
000000?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool00oooool1o`00000000?o0000ooooooooool00oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool1o`00000000?o
0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool00oooool1o`00000000?o0000ooooooooool00oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool1o`00000000?o0000oooo
ooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool00oooool1o`00000000?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool1o`00000000?o0000ooooooooool0
0oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
0oooool1o`00000000?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool00oooool1o`00000000?o0000ooooooooool00oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool1
o`00000000?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool00oooool1o`00000000?o0000ooooooooool00oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool1o`000000
00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool00oooool1o`00000000?o0000ooooooooool00oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool1o`00000000?o0000
ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool00oooool1o`00000000?o0000ooooooooool00oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool1o`00000000?o0000oooooooo
ool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool00oooool1o`00000000?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool00oooool1o`00000000?o0000ooooooooool00ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00ooo
ool1o`00000000?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool00oooool1o`00000000?o0000ooooooooool00oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool1o`00
000000?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool00oooool1o`00000000?o0000ooooooooool00oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool1o`00000000?o
0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool00oooool1o`00000000?o0000ooooooooool00oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool1o`00000000?o0000oooo
ooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool00oooool1o`00000000?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool1o`00000000?o0000ooooooooool0
0oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
0oooool1o`00000000?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool00oooool1o`00000000?o0000ooooooooool00oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool1
o`00000000?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool00oooool1o`00000000?o0000ooooooooool00oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool1o`000000
00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool00oooool1o`00000000?o0000ooooooooool00oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool1o`00000000?o0000
ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool00oooool1o`00000000?o0000ooooooooool00oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool1o`00000000?o0000oooooooo
ool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool00oooool1o`00000000?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool00oooool1o`00000000?o0000ooooooooool00ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00ooo
ool1o`00000000?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool00oooool1o`00000000?o0000ooooooooool00oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool1o`00
000000?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool00oooool1o`00000000?o0000ooooooooool00oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool1o`00000000?o
0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool00oooool1o`00000000?o0000ooooooooool00oooool00ol0003oooooo`00000D
o`000003ooooool0003ooooo00Cooooo0Ol000000003o`000?oooooooooo00?ooooo00?o0000oooo
ool000002Om900000ol0003oB@00odT00007odT00003o`000?oooooo000000Gooooo0Ol000000003
o`000?oooooooooo00?ooooo00?o0000ooooool000002Om900000ol0003oB@00odT00007odT00003
o`000?oooooo000000Gooooo0Ol000000003o`000?oooooooooo00?ooooo0_l0000:odT00003o`00
0?m9003oB@0000OoB@000ol00005ooooo`7o000000000ol0003oooooooooo`03ooooo`;o00002_m9
00000ol0003oB@00odT00007odT00003o`000?oooooo000000Gooooo0Ol000000003o`000?oooooo
oooo00?ooooo0_l0000:odT00003o`000?m9003oB@0000SoB@000_l00005ooooo`7o000000000ol0
003oooooooooo`03ooooo`;o00002_m900000ol0003oB@00odT00008odT000;o00001Oooool1o`00
000000?o0000ooooooooool00oooool2o`0000[oB@0000?o0000odT00?m900002?m90002o`0000Go
oooo0Ol000000003o`000?oooooooooo00;ooooo0_l0000;odT00003o`000?m9003oB@0000SoB@00
00?o0000ooooool000001?ooool1o`00000000?o0000ooooooooool00_oooolIo`000003ooooool0
003ooooo00?ooooo0Ol000000003o`000?oooooooooo00;ooooo0_l0000;okBC]003o`000?ndTkCo
]9>d00So]9>d00?o0000ooooool000001?ooool1o`00000000?o0000ooooooooool00_oooolIo`00
0003ooooool0003ooooo00?ooooo0Ol000000003o`000?oooooooooo00;ooooo0_l0000;odT00003
o`000?m9003oB@0000SoB@0000?o0000ooooool000001?ooool1o`00000000?o0000ooooooooool0
0_ooool2o`0000_oB@0000?o0000odT00?m900002?m900000ol0003oooooo`000004ooooo`7o0000
00000ol0003oooooooooo`02ooooo`;o00002om900000ol0003oB@00odT00008odT00003o`000?oo
oooo000000Cooooo0Ol000000007o`000?ooooooooooooooool0003oooooo`00000;odT00003o`00
0?m9003oB@0000WoB@0000?o0000ooooool000000oooool1o`00000000Oo0000oooooooooooooooo
o`000?oooooo000000_oB@0000?o0000odT00?m900002Om900000ol0003oooooo`000003ooooo`7o
000000001?l0003oooooooooooooool2o`0000coB@0000?o0000odT00?m900002Om900000ol0003o
ooooo`000003ooooo`7o000000001?l0003oooooooooooooool2o`0001SoB@0000?o0000ooooool0
00000oooool1o`00000000Co0000oooooooooooooooo0_l0000HodT00003o`000?oooooo000000?o
oooo0Ol000000004o`000?ooooooooooooooo`;o00006Om90002o`0000?ooooo0Ol000000004o`00
0?ooooooooooooooo`;o00006Om90002o`0000?ooooo0Ol000000004o`000?oooooooooooooooago
00000oooool1o`00000000Ko0000oooooooooooo0000ooooool0000IokBC]003o`000?oooooo0000
00;ooooo0Ol000000006o`000?ooooooooooo`000?oooooo00006OndTk@00ol0003oooooo`000002
ooooo`7o000000001_l0003oooooooooool0003oooooo`0001Wo]9>d00?o0000ooooool000000_oo
ool1o`00000000Ko0000oooooooooooo0000ooooool0000IokBC]003o`000?oooooo000000;ooooo
0Ol000000006o`000?ooooooooooo`000?oooooo00006OndTk@00ol0003oooooo`000002ooooo`7o
000000001_l0003oooooooooool0003oooooo`0001Wo]9>d00?o0000ooooool000000_ooool1o`00
000000Ko0000oooooooooooo0000ooooool0000IokBC]003o`000?oooooo000000;ooooo0Ol00000
0003o`000?oooooo000000;ooooo00?o0000okBC]?ndTk@05ondTk@01Ol0003oooooooooool0003o
oooo007o000000000ol0003oooooo`000002ooooo`03o`000?ndTkCo]9>d01Oo]9>d00Go0000oooo
oooooooo0000ooooo`01o`00000000?o0000ooooool000000_ooool00ol0003o]9>dokBC]00GokBC
]005o`000?ooooooooooo`000?ooool00Ol000000003o`000?oooooo000000;ooooo00?o0000okBC
]?ndTk@05ondTk@01Ol0003oooooooooool0003ooooo007o000000000ol0003oooooo`000002oooo
o`03o`000?ndTkCo]9>d01Oo]9>d00Go0000oooooooooooo0000ooooo`01o`00000000?o0000oooo
ool000000_ooool=o`000003okBC]?l0003o000000_o00000_ooool1o`00007ooooo0Ol000000003
o`000?oooooo000001oooooo0Ol00001ooooo`7o000000000ol0003oooooo`00000Oooooo`7o0000
0Oooool1o`0000000_l0000Qooooo`;o00000002o`00027ooooo0_l0000000;o00008Oooool2o`00
00000_l0000Qooooo`;o00000002o`00027ooooo0_l0000000;o00008Oooool2o`0000000_l0000Q
ooooo`;o000000000ol0003oooooooooo`0Qooooo`7o000000000ol0003oooooooooo`0Qooooo`7o
000000000ol0003oooooooooo`0Qooooo`7o0000000Uo`0000009Oooool002Gooooo000Uooooo`00
\
\>"],
  ImageRangeCache->{{{0, 36.4375}, {268.25, 0}} -> {0.430493, -0.0117045, \
0.00381513, 0.00381513}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#2", "Text"],

Cell[CellGroupData[{

Cell["Hz0A[[-2]]", "Input"],

Cell[BoxData[
    \(1.3320127099692072`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pretty[Chop[e2ni . eigenvectors0A[\([\(-2\)]\)], 10^\(-4\)]]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
          {"\<\"optic\"\>", "0", \(-0.23375090875976173`\), "0", "0", 
            "0", \(-0.9722965147803346`\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(DoWithStatus["\<Plotting stage 0A mode 2\>", \ 
      eigenplot[eigenvectors0A[\([\(-2\)]\)],  .1, {\(-1\), 0, 0}, \ 
        floatmatrix0A]]\), "\[IndentingNewLine]", 
    \( (*Status["\<Plotting stage 0A mode 2\>"]\ ; 
      eigenplot[eigenvectors0A[\([\(-2\)]\)],  .1, {\(-1\), 0, 0}, \ 
        floatmatrix0A]\ \ ; Done[]*) \)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 2.39787 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.698933 2.39787 0 2.39787 [
[ 0 0 0 0 ]
[ 1 2.39787 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
1 0 m
1 2.39787 L
s
1 2.39787 m
0 2.39787 L
s
0 2.39787 m
0 0 L
s
0 0 m
1 0 L
s
.93501 .15584 m
.06499 .15584 L
s
.06499 .15584 m
.06499 2.24203 L
s
.06499 2.24203 m
.93501 2.24203 L
s
.93501 2.24203 m
.93501 .15584 L
s
1 0 m
1 2.39787 L
s
1 2.39787 m
.93501 2.24203 L
s
.93501 2.24203 m
.93501 .15584 L
s
.93501 .15584 m
1 0 L
s
0 0 m
.06499 .15584 L
s
.06499 .15584 m
.06499 2.24203 L
s
.06499 2.24203 m
0 2.39787 L
s
0 2.39787 m
0 0 L
s
0 0 m
1 0 L
1 2.39787 L
0 2.39787 L
closepath
clip
newpath
.5 Mabswid
.707 .577 .707 r
.36301 2.25665 m .4807 2.25665 L .4807 2.13895 L p F P
0 g
s
.707 .577 .707 r
.4807 2.13895 m .24915 2.13895 L p .36301 2.25665 L F P
0 g
s
.287 0 0 r
.24915 2.13895 m .4807 2.13895 L .47847 2.2478 L p F P
0 g
s
.785 .641 .083 r
.24915 2.25665 m .24915 2.13895 L .22011 2.2478 L p F P
0 g
s
.707 .577 .707 r
.24915 2.13895 m .24915 2.25665 L .36301 2.25665 L p F P
0 g
s
.287 0 0 r
.47847 2.2478 m .22011 2.2478 L .24915 2.13895 L p F P
0 g
s
.714 .583 .006 r
.4807 2.13895 m .4807 2.25665 L .47967 2.31352 L p F P
0 g
s
.714 .583 .006 r
.47847 2.2478 m .4807 2.13895 L p .47967 2.31352 L F P
0 g
s
.785 .641 .083 r
.23566 2.31352 m .24915 2.25665 L p .22011 2.2478 L F P
0 g
s
0 0 .083 r
.75085 2.14279 m .75085 2.25665 L .76482 2.31555 L p F P
0 g
s
0 0 .083 r
.77989 2.25208 m .75085 2.14279 L p .76482 2.31555 L F P
0 g
s
.707 .577 .707 r
.63699 2.25665 m .75085 2.25665 L .75085 2.14279 L p F P
0 g
s
.707 .577 .707 r
.75085 2.14279 m .5193 2.14279 L p .63699 2.25665 L F P
0 g
s
.288 0 0 r
.5193 2.14279 m .75085 2.14279 L .77989 2.25208 L p F P
0 g
s
.707 .577 .707 r
.5193 2.14279 m .5193 2.25665 L .63699 2.25665 L p F P
0 g
s
.288 0 0 r
.77989 2.25208 m .52153 2.25208 L .5193 2.14279 L p F P
0 g
s
0 0 .006 r
.52037 2.31555 m .5193 2.25665 L p .52153 2.25208 L F P
0 g
s
0 0 .006 r
.5193 2.25665 m .5193 2.14279 L .52153 2.25208 L p F P
0 g
s
.132 .679 .79 r
.63364 .89692 m .62759 .9106 L .71232 .90552 L p F P
0 g
s
.132 .679 .79 r
.71232 .90552 m .72239 .8916 L .63364 .89692 L p F P
0 g
s
0 .497 .784 r
.72239 .8916 m .71232 .90552 L .79448 .92688 L p F P
0 g
s
0 .497 .784 r
.79448 .92688 m .80845 .91397 L .72239 .8916 L p F P
0 g
s
0 .274 .71 r
.80845 .91397 m .79448 .92688 L .86601 .97258 L p F P
0 g
s
0 .274 .71 r
.86601 .97258 m .88338 .96184 L .80845 .91397 L p F P
0 g
s
0 .033 .576 r
.88338 .96184 m .86601 .97258 L .91993 1.03814 L p F P
0 g
s
0 .033 .576 r
.91993 1.03814 m .93985 1.03052 L .88338 .96184 L p F P
0 g
s
0 0 .396 r
.93985 1.03052 m .91993 1.03814 L .95094 1.11716 L p F P
0 g
s
0 0 .396 r
.95094 1.11716 m .97233 1.11328 L .93985 1.03052 L p F P
0 g
s
0 0 .186 r
.95094 1.11716 m .95471 1.18011 L .96007 1.17989 L p F P
0 g
s
0 0 .186 r
.97233 1.11328 m .95094 1.11716 L p .96007 1.17989 L F P
0 g
s
.714 .728 .208 r
.41196 1.14686 m .41595 1.14922 L .4373 1.06706 L p F P
0 g
s
.714 .728 .208 r
.4373 1.06706 m .43433 1.06081 L .41196 1.14686 L p F P
0 g
s
.635 .829 .42 r
.43433 1.06081 m .4373 1.06706 L .483 .99553 L p F P
0 g
s
.635 .829 .42 r
.483 .99553 m .4822 .98588 L .43433 1.06081 L p F P
0 g
s
.502 .855 .599 r
.4822 .98588 m .483 .99553 L .54857 .94161 L p F P
0 g
s
.502 .855 .599 r
.54857 .94161 m .55087 .92941 L .4822 .98588 L p F P
0 g
s
.329 .803 .726 r
.55087 .92941 m .54857 .94161 L .62759 .9106 L p F P
0 g
s
.329 .803 .726 r
.62759 .9106 m .63364 .89692 L .55087 .92941 L p F P
0 g
s
0 0 0 r
.9749 1.20727 m .95471 1.20692 L .93466 1.28405 L p F P
0 g
s
.732 .563 0 r
.41728 1.23561 m .42103 1.23395 L .41595 1.14922 L p F P
0 g
s
.732 .563 0 r
.41595 1.14922 m .41196 1.14686 L .41728 1.23561 L p F P
0 g
s
.01 w
.34843 .90424 Mdot
.5 Mabswid
0 0 0 r
.93466 1.28405 m .95528 1.28809 L p .9749 1.20727 L F P
0 g
s
0 0 0 r
.95528 1.28809 m .93466 1.28405 L .88896 1.35559 L p F P
0 g
s
0 0 0 r
.88896 1.35559 m .90741 1.36302 L .95528 1.28809 L p F P
0 g
s
0 0 0 r
.90741 1.36302 m .88896 1.35559 L .8234 1.4095 L p F P
0 g
s
.581 .108 0 r
.50624 1.38706 m .50595 1.37854 L .45204 1.31297 L p F P
0 g
s
.581 .108 0 r
.45204 1.31297 m .44976 1.31838 L .50624 1.38706 L p F P
0 g
s
.686 .349 0 r
.44976 1.31838 m .45204 1.31297 L .42103 1.23395 L p F P
0 g
s
.686 .349 0 r
.42103 1.23395 m .41728 1.23561 L .44976 1.31838 L p F P
0 g
s
0 0 0 r
.8234 1.4095 m .83874 1.41949 L .90741 1.36302 L p F P
0 g
s
0 0 0 r
.83874 1.41949 m .8234 1.4095 L .74438 1.44051 L p F P
0 g
s
0 0 0 r
.74438 1.44051 m .75597 1.45197 L .83874 1.41949 L p F P
0 g
s
.04 0 0 r
.75597 1.45197 m .74438 1.44051 L .65964 1.44559 L p F P
0 g
s
.04 0 0 r
.65964 1.44559 m .66722 1.45729 L .75597 1.45197 L p F P
0 g
s
.241 0 0 r
.66722 1.45729 m .65964 1.44559 L .57749 1.42424 L p F P
0 g
s
.241 0 0 r
.57749 1.42424 m .58116 1.43492 L .66722 1.45729 L p F P
0 g
s
.428 0 0 r
.58116 1.43492 m .57749 1.42424 L .50595 1.37854 L p F P
0 g
s
.428 0 0 r
.50595 1.37854 m .50624 1.38706 L .58116 1.43492 L p F P
0 g
s
0 0 .186 r
.96007 1.17989 m .97628 1.17922 L .97233 1.11328 L p F P
0 g
s
.714 .583 .006 r
.47967 2.31352 m .47847 2.37912 L .47847 2.2478 L p F P
0 g
s
.785 .641 .083 r
.22011 2.2478 m .22011 2.37912 L .23566 2.31352 L p F P
0 g
s
.35995 2.1904 m
.38041 1.15706 L
s
.35754 2.31251 m
.35882 2.2478 L
s
.68194 2.19444 m
.76458 1.93879 L
s
.64312 2.31453 m
.66331 2.25208 L
s
.94909 1.36799 m
.96525 1.318 L
s
.76458 1.93879 m
.94909 1.36799 L
s
0 0 .083 r
.76482 2.31555 m .77989 2.37912 L .77989 2.25208 L p F P
0 g
s
0 0 .006 r
.52153 2.25208 m .52153 2.37912 L .52037 2.31555 L p F P
0 g
s
0 0 0 r
.95528 1.28809 m .97628 1.20729 L .9749 1.20727 L p F P
0 g
s
.01 w
.65876 .89026 Mdot
.34124 .89026 Mdot
.5 Mabswid
.707 .577 .707 r
.34715 2.37912 m .22011 2.37912 L p .47847 2.2478 L F P
0 g
s
.707 .577 .707 r
.22011 2.37912 m .22011 2.2478 L .47847 2.2478 L p F P
0 g
s
.707 .577 .707 r
.47847 2.2478 m .47847 2.37912 L .34715 2.37912 L p F P
0 g
s
.707 .577 .707 r
.65285 2.37912 m .52153 2.37912 L p .77989 2.25208 L F P
0 g
s
.707 .577 .707 r
.52153 2.37912 m .52153 2.25208 L .77989 2.25208 L p F P
0 g
s
.707 .577 .707 r
.77989 2.25208 m .77989 2.37912 L .65285 2.37912 L p F P
0 g
s
.25 Mabswid
1 0 m
1 2.39787 L
s
1 2.39787 m
0 2.39787 L
s
0 2.39787 m
0 0 L
s
0 0 m
1 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{119, 285.312},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#3", "Text"],

Cell[CellGroupData[{

Cell["Hz0A[[-3]]", "Input"],

Cell[BoxData[
    \(1.3476233573742042`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pretty[Chop[e2ni . eigenvectors0A[\([\(-3\)]\)], 10^\(-4\)]]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
          {"\<\"optic\"\>", "0.12351021728844276`", "0", "0", "0", 
            "0.9923433005897513`", "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Status["\<Plotting stage 0A mode 3\>"]\ ; 
    eigenplot[eigenvectors0A[\([\(-3\)]\)],  .1, {0, \(-1\), \(- .25\)}, \ 
      floatmatrix0A]\ \ ; Done[]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 5.99483 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.6256 6.25121 -4.44089e-16 6.25121 [
[ 0 0 0 0 ]
[ 1 5.99483 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
.12768 5.99483 L
s
.12768 5.99483 m
.23891 4.75775 L
s
.23891 4.75775 m
.18195 .67458 L
s
.18195 .67458 m
0 0 L
s
1 0 m
.81805 .67458 L
s
.81805 .67458 m
.76109 4.75775 L
s
.76109 4.75775 m
.87232 5.99483 L
s
.87232 5.99483 m
1 0 L
s
0 0 m
.12768 5.99483 L
s
.12768 5.99483 m
.87232 5.99483 L
s
.87232 5.99483 m
1 0 L
s
1 0 m
0 0 L
s
.18195 .67458 m
.81805 .67458 L
s
.81805 .67458 m
.76109 4.75775 L
s
.76109 4.75775 m
.23891 4.75775 L
s
.23891 4.75775 m
.18195 .67458 L
s
0 0 m
1 0 L
1 5.99483 L
0 5.99483 L
closepath
clip
newpath
.5 Mabswid
.691 .687 .841 r
.5 4.95773 m .71974 4.95773 L p .27793 4.76168 L F P
0 g
s
.691 .687 .841 r
.71974 4.95773 m .72207 4.76168 L .27793 4.76168 L p F P
0 g
s
.691 .687 .841 r
.27793 4.76168 m .28026 4.95773 L .5 4.95773 L p F P
0 g
s
.745 .608 .039 r
.27065 5.09348 m .28026 4.95773 L p .25738 5.03076 L F P
0 g
s
.745 .608 .039 r
.28026 4.95773 m .27793 4.76168 L .25738 5.03076 L p F P
0 g
s
0 0 .039 r
.72207 4.76168 m .71974 4.95773 L .72935 5.09348 L p F P
0 g
s
0 0 .039 r
.74262 5.03076 m .72207 4.76168 L p .72935 5.09348 L F P
0 g
s
.412 0 0 r
.72207 4.76168 m .74262 5.03076 L .25738 5.03076 L p F P
0 g
s
.412 0 0 r
.25738 5.03076 m .27793 4.76168 L .72207 4.76168 L p F P
0 g
s
.745 .608 .039 r
.25738 5.03076 m .26016 5.24166 L .27065 5.09348 L p F P
0 g
s
0 0 .039 r
.72935 5.09348 m .73984 5.24166 L .74262 5.03076 L p F P
0 g
s
.52079 4.87043 m
.69927 2.95594 L
s
.5 5.09348 m
.50585 5.03076 L
s
.688 .696 .853 r
.5 5.24166 m .26016 5.24166 L .25738 5.03076 L p F P
0 g
s
.688 .696 .853 r
.74262 5.03076 m .73984 5.24166 L .5 5.24166 L p F P
0 g
s
.688 .696 .853 r
.25738 5.03076 m .74262 5.03076 L p .5 5.24166 L F P
0 g
s
.665 .431 .556 r
.80702 3.10804 m .61394 3.12668 L .63009 3.29464 L p F P
0 g
s
.695 .612 .759 r
.61394 3.12668 m .80702 3.10804 L .80761 2.99838 L p F P
0 g
s
.695 .612 .759 r
.80761 2.99838 m .80179 2.93598 L p .61394 3.12668 L F P
0 g
s
.695 .612 .759 r
.80179 2.93598 m .59741 2.95587 L .61394 3.12668 L p F P
0 g
s
.665 .431 .556 r
.80715 3.11759 m .80702 3.10804 L p .63009 3.29464 L F P
0 g
s
.665 .431 .556 r
.63009 3.29464 m .80935 3.27748 L .80715 3.11759 L p F P
0 g
s
.674 .748 .906 r
.59741 2.95587 m .80179 2.93598 L .78873 2.77343 L p F P
0 g
s
.674 .748 .906 r
.78873 2.77343 m .58163 2.79375 L .59741 2.95587 L p F P
0 g
s
.585 .215 .308 r
.80935 3.27748 m .63009 3.29464 L .64476 3.44815 L p F P
0 g
s
.687 .698 .855 r
.5 5.29411 m .74356 5.29411 L p .25358 5.08052 L F P
0 g
s
.687 .698 .855 r
.74356 5.29411 m .74642 5.08052 L .25358 5.08052 L p F P
0 g
s
.687 .698 .855 r
.25358 5.08052 m .25644 5.29411 L .5 5.29411 L p F P
0 g
s
.745 .608 .039 r
.24458 5.46167 m .25644 5.29411 L p .22802 5.41523 L F P
0 g
s
.745 .608 .039 r
.25644 5.29411 m .25358 5.08052 L .22802 5.41523 L p F P
0 g
s
0 0 .039 r
.74642 5.08052 m .74356 5.29411 L .75542 5.46167 L p F P
0 g
s
.585 .215 .308 r
.81008 3.29803 m .80935 3.27748 L p .64476 3.44815 L F P
0 g
s
.585 .215 .308 r
.64476 3.44815 m .81486 3.43199 L .81008 3.29803 L p F P
0 g
s
.601 .829 .987 r
.58163 2.79375 m .78873 2.77343 L .7796 2.63121 L p F P
0 g
s
.601 .829 .987 r
.7796 2.63121 m .56775 2.65214 L .58163 2.79375 L p F P
0 g
s
0 0 .039 r
.77198 5.41523 m .74642 5.08052 L p .75542 5.46167 L F P
0 g
s
.412 0 0 r
.74642 5.08052 m .77198 5.41523 L .22802 5.41523 L p F P
0 g
s
.412 0 0 r
.22802 5.41523 m .25358 5.08052 L .74642 5.08052 L p F P
0 g
s
.455 0 .028 r
.81486 3.43199 m .64476 3.44815 L .65678 3.5752 L p F P
0 g
s
.455 0 .028 r
.81646 3.45614 m .81486 3.43199 L p .65678 3.5752 L F P
0 g
s
.455 0 .028 r
.65678 3.5752 m .82331 3.55948 L .81646 3.45614 L p F P
0 g
s
.477 .845 .99 r
.56775 2.65214 m .7796 2.63121 L .77536 2.52164 L p F P
0 g
s
.477 .845 .99 r
.77536 2.52164 m .55695 2.54334 L .56775 2.65214 L p F P
0 g
s
.282 0 0 r
.82331 3.55948 m .65678 3.5752 L .66499 3.66347 L p F P
0 g
s
.282 0 0 r
.82573 3.57898 m .82331 3.55948 L p .66499 3.66347 L F P
0 g
s
.745 .608 .039 r
.22802 5.41523 m .2315 5.6464 L .24458 5.46167 L p F P
0 g
s
0 0 .039 r
.75542 5.46167 m .7685 5.6464 L .77198 5.41523 L p F P
0 g
s
.52351 5.26464 m
.677 3.97831 L
s
.5 5.46167 m
.50554 5.41523 L
s
.282 0 0 r
.66499 3.66347 m .83425 3.64756 L .82573 3.57898 L p F P
0 g
s
.306 .789 .906 r
.55695 2.54334 m .77536 2.52164 L .77684 2.4571 L p F P
0 g
s
.306 .789 .906 r
.77684 2.4571 m .55044 2.47965 L .55695 2.54334 L p F P
0 g
s
.01 w
.38937 2.41909 Mdot
.61063 2.41909 Mdot
.5 Mabswid
.075 0 0 r
.83425 3.64756 m .66499 3.66347 L .66825 3.7011 L p F P
0 g
s
.677 3.97831 m
.699 3.79399 L
s
.075 0 0 r
.83715 3.65593 m .83425 3.64756 L p .66825 3.7011 L F P
0 g
s
.075 0 0 r
.66825 3.7011 m .84697 3.68434 L .83715 3.65593 L p F P
0 g
s
.098 .654 .731 r
.55044 2.47965 m .77684 2.4571 L .78453 2.44869 L p F P
0 g
s
.098 .654 .731 r
.78453 2.44869 m .54933 2.47213 L .55044 2.47965 L p F P
0 g
s
.682 .71 .869 r
.5 5.6464 m .2315 5.6464 L .22802 5.41523 L p F P
0 g
s
.682 .71 .869 r
.77198 5.41523 m .7685 5.6464 L .5 5.6464 L p F P
0 g
s
.682 .71 .869 r
.22802 5.41523 m .77198 5.41523 L p .5 5.6464 L F P
0 g
s
.146 .691 .782 r
.84697 3.68434 m .66825 3.7011 L .66567 3.67852 L p F P
0 g
s
.146 .691 .782 r
.84978 3.67929 m .84697 3.68434 L p .66567 3.67852 L F P
0 g
s
.146 .691 .782 r
.66567 3.67852 m .86039 3.66024 L .84978 3.67929 L p F P
0 g
s
.129 0 0 r
.54933 2.47213 m .78453 2.44869 L .79832 2.50389 L p F P
0 g
s
.129 0 0 r
.79832 2.50389 m .55435 2.52814 L .54933 2.47213 L p F P
0 g
s
.359 .811 .942 r
.86039 3.66024 m .66567 3.67852 L .65687 3.59126 L p F P
0 g
s
.359 .811 .942 r
.86256 3.64497 m .86039 3.66024 L p .65687 3.59126 L F P
0 g
s
.359 .811 .942 r
.65687 3.59126 m .8731 3.57087 L .86256 3.64497 L p F P
0 g
s
.699 3.79399 m
.71822 3.6329 L
s
.348 0 0 r
.55435 2.52814 m .79832 2.50389 L .81727 2.62329 L p F P
0 g
s
.348 0 0 r
.81727 2.62329 m .5656 2.64816 L .55435 2.52814 L p F P
0 g
s
.535 .843 .999 r
.8731 3.57087 m .65687 3.59126 L .64227 3.44324 L p F P
0 g
s
.535 .843 .999 r
.87429 3.5535 m .8731 3.57087 L p .64227 3.44324 L F P
0 g
s
.535 .843 .999 r
.64227 3.44324 m .88346 3.42033 L .87429 3.5535 L p F P
0 g
s
.71822 3.6329 m
.73779 3.46891 L
s
.53 .11 .189 r
.5656 2.64816 m .81727 2.62329 L .83945 2.79765 L p F P
0 g
s
.53 .11 .189 r
.83945 2.79765 m .58223 2.82285 L .5656 2.64816 L p F P
0 g
s
.01 w
.37334 2.50103 Mdot
.62666 2.50103 Mdot
.5 Mabswid
.651 .778 .941 r
.88346 3.42033 m .64227 3.44324 L .62331 3.24888 L p F P
0 g
s
.651 .778 .941 r
.88376 3.41092 m .88346 3.42033 L p .62331 3.24888 L F P
0 g
s
.651 .778 .941 r
.88212 3.22405 m .88754 3.29582 L .88376 3.41092 L p F P
0 g
s
.651 .778 .941 r
.62331 3.24888 m .88212 3.22405 L p .88376 3.41092 L F P
0 g
s
.73779 3.46891 m
.75935 3.28824 L
s
.65 .389 .511 r
.58223 2.82285 m .83945 2.79765 L .8621 3.00712 L p F P
0 g
s
.65 .389 .511 r
.8621 3.00712 m .60235 3.03231 L .58223 2.82285 L p F P
0 g
s
.692 .621 .773 r
.88212 3.22405 m .62331 3.24888 L .60235 3.03231 L p F P
0 g
s
.692 .621 .773 r
.60235 3.03231 m .8621 3.00712 L .88212 3.22405 L p F P
0 g
s
.25 Mabswid
0 0 m
.12768 5.99483 L
s
.12768 5.99483 m
.87232 5.99483 L
s
.87232 5.99483 m
1 0 L
s
1 0 m
0 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{48, 287.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#4", "Text"],

Cell[CellGroupData[{

Cell["Hz0A[[-4]]", "Input"],

Cell[BoxData[
    \(1.7072638005392924`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pretty[Chop[e2ni . eigenvectors0A[\([\(-4\)]\)], 10^\(-4\)]]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
          {"\<\"optic\"\>", "0", "0", "0", "1.`", "0", "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Status["\<Plotting stage 0A mode 4\>"]\ ; 
    eigenplot[eigenvectors0A[\([\(-4\)]\)],  .5, {0, \(-3\), \(- .25\)}, \ 
      floatmatrix0A]\ \ ; Done[]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 7.06045 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-3.10065 7.20129 -0.140839 7.20129 [
[ 0 0 0 0 ]
[ 1 7.06045 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
.0146 7.06045 L
s
.0146 7.06045 m
.07649 6.39036 L
s
.07649 6.39036 m
.06541 .2361 L
s
.06541 .2361 m
0 0 L
s
1 0 m
.93459 .2361 L
s
.93459 .2361 m
.92351 6.39036 L
s
.92351 6.39036 m
.9854 7.06045 L
s
.9854 7.06045 m
1 0 L
s
0 0 m
.0146 7.06045 L
s
.0146 7.06045 m
.9854 7.06045 L
s
.9854 7.06045 m
1 0 L
s
1 0 m
0 0 L
s
.06541 .2361 m
.93459 .2361 L
s
.93459 .2361 m
.92351 6.39036 L
s
.92351 6.39036 m
.07649 6.39036 L
s
.07649 6.39036 m
.06541 .2361 L
s
0 0 m
1 0 L
1 7.06045 L
0 7.06045 L
closepath
clip
newpath
.5 Mabswid
.707 .593 .726 r
.5 6.52002 m .8429 6.52002 L p .1566 6.1822 L F P
0 g
s
.707 .593 .726 r
.8429 6.52002 m .8434 6.1822 L .1566 6.1822 L p F P
0 g
s
.707 .593 .726 r
.1566 6.1822 m .1571 6.52002 L .5 6.52002 L p F P
0 g
s
.745 .608 .039 r
.15109 6.60256 m .1571 6.52002 L p .14435 6.33843 L F P
0 g
s
.745 .608 .039 r
.1571 6.52002 m .1566 6.1822 L .14435 6.33843 L p F P
0 g
s
0 0 .039 r
.8434 6.1822 m .8429 6.52002 L .84891 6.60256 L p F P
0 g
s
0 0 .039 r
.85565 6.33843 m .8434 6.1822 L p .84891 6.60256 L F P
0 g
s
.405 0 0 r
.8434 6.1822 m .85565 6.33843 L .14435 6.33843 L p F P
0 g
s
.405 0 0 r
.14435 6.33843 m .1566 6.1822 L .8434 6.1822 L p F P
0 g
s
.15256 3.93932 m
.454 6.24998 L
s
.46554 6.33843 m
.5 6.60256 L
s
.816 .649 .675 r
.05609 3.53518 m .05599 3.58493 L p .25046 3.3286 L F P
0 g
s
.07729 3.36239 m
.09451 3.49435 L
s
.816 .649 .675 r
.05599 3.58493 m .26883 3.57467 L .25046 3.3286 L p F P
0 g
s
.10601 3.58252 m
.15256 3.93932 L
s
.816 .649 .675 r
.25046 3.3286 m .05652 3.33664 L .05609 3.53518 L p F P
0 g
s
.816 .715 .753 r
.05652 3.33664 m .25046 3.3286 L .26836 3.08722 L p F P
0 g
s
.804 .572 .586 r
.05948 3.81807 m .32193 3.80376 L .26883 3.57467 L p F P
0 g
s
.804 .572 .586 r
.26883 3.57467 m .05599 3.58493 L .05379 3.79302 L p F P
0 g
s
.804 .572 .586 r
.05379 3.79302 m .05948 3.81807 L p .26883 3.57467 L F P
0 g
s
.816 .715 .753 r
.05617 3.27863 m .05652 3.33664 L p .26836 3.08722 L F P
0 g
s
.816 .715 .753 r
.26836 3.08722 m .05507 3.09467 L .05617 3.27863 L p F P
0 g
s
.803 .778 .829 r
.05507 3.09467 m .26836 3.08722 L .32123 2.87199 L p F P
0 g
s
.745 .608 .039 r
.14435 6.33843 m .14488 6.68805 L .15109 6.60256 L p F P
0 g
s
0 0 .039 r
.84891 6.60256 m .85512 6.68805 L .85565 6.33843 L p F P
0 g
s
.774 .467 .466 r
.14171 4.01101 m .40542 3.99522 L .32193 3.80376 L p F P
0 g
s
.774 .467 .466 r
.32193 3.80376 m .05948 3.81807 L .14171 4.01101 L p F P
0 g
s
.803 .778 .829 r
.05457 3.06184 m .05507 3.09467 L p .32123 2.87199 L F P
0 g
s
.803 .778 .829 r
.32123 2.87199 m .05774 2.87966 L p .05457 3.06184 L F P
0 g
s
.763 .842 .911 r
.05774 2.87966 m .32123 2.87199 L .4049 2.70279 L p F P
0 g
s
.803 .778 .829 r
.05774 2.87966 m .05212 2.90323 L .05457 3.06184 L p F P
0 g
s
.7 .292 .271 r
.24688 4.14774 m .51232 4.13081 L .40542 3.99522 L p F P
0 g
s
.7 .292 .271 r
.40542 3.99522 m .14171 4.01101 L .24688 4.14774 L p F P
0 g
s
.763 .842 .911 r
.4049 2.70279 m .13975 2.70931 L .05774 2.87966 L p F P
0 g
s
.643 .89 .985 r
.13975 2.70931 m .4049 2.70279 L .5124 2.59648 L p F P
0 g
s
.01 w
.35003 2.55072 Mdot
.64997 2.55072 Mdot
.5 Mabswid
.481 0 0 r
.36578 4.21387 m .63324 4.19627 L .51232 4.13081 L p F P
0 g
s
.481 0 0 r
.51232 4.13081 m .24688 4.14774 L .36578 4.21387 L p F P
0 g
s
.707 .593 .726 r
.5 6.68805 m .14488 6.68805 L .14435 6.33843 L p F P
0 g
s
.707 .593 .726 r
.85565 6.33843 m .85512 6.68805 L .5 6.68805 L p F P
0 g
s
.707 .593 .726 r
.14435 6.33843 m .85565 6.33843 L p .5 6.68805 L F P
0 g
s
.643 .89 .985 r
.5124 2.59648 m .24524 2.60228 L .13975 2.70931 L p F P
0 g
s
.253 .758 .878 r
.24524 2.60228 m .5124 2.59648 L .63416 2.56514 L p F P
0 g
s
.707 .593 .726 r
.5 6.71723 m .85725 6.71723 L p .14222 6.36556 L F P
0 g
s
.707 .593 .726 r
.85725 6.71723 m .85778 6.36556 L .14222 6.36556 L p F P
0 g
s
.707 .593 .726 r
.14222 6.36556 m .14275 6.71723 L .5 6.71723 L p F P
0 g
s
.745 .608 .039 r
.13623 6.80689 m .14275 6.71723 L p .1289 6.5354 L F P
0 g
s
.745 .608 .039 r
.14275 6.71723 m .14222 6.36556 L .1289 6.5354 L p F P
0 g
s
0 0 .039 r
.85778 6.36556 m .85725 6.71723 L .86377 6.80689 L p F P
0 g
s
0 0 .039 r
.8711 6.5354 m .85778 6.36556 L p .86377 6.80689 L F P
0 g
s
.405 0 0 r
.85778 6.36556 m .8711 6.5354 L .1289 6.5354 L p F P
0 g
s
.405 0 0 r
.1289 6.5354 m .14222 6.36556 L .85778 6.36556 L p F P
0 g
s
.09 .649 .741 r
.48731 4.20071 m .75693 4.18301 L .63324 4.19627 L p F P
0 g
s
.09 .649 .741 r
.63324 4.19627 m .36578 4.21387 L .48731 4.20071 L p F P
0 g
s
.253 .758 .878 r
.63416 2.56514 m .36485 2.57077 L .24524 2.60228 L p F P
0 g
s
.383 0 0 r
.36485 2.57077 m .63416 2.56514 L .75862 2.61437 L p F P
0 g
s
.596 .902 .985 r
.59941 4.10691 m .87107 4.08972 L .75693 4.18301 L p F P
0 g
s
.596 .902 .985 r
.75693 4.18301 m .48731 4.20071 L .59941 4.10691 L p F P
0 g
s
.745 .608 .039 r
.1289 6.5354 m .12947 6.89989 L .13623 6.80689 L p F P
0 g
s
0 0 .039 r
.86377 6.80689 m .87053 6.89989 L .8711 6.5354 L p F P
0 g
s
.54816 6.45872 m
.86554 4.16414 L
s
.5 6.80689 m
.53755 6.5354 L
s
.383 0 0 r
.75862 2.61437 m .48723 2.62043 L .36485 2.57077 L p F P
0 g
s
.682 .24 .195 r
.48723 2.62043 m .75862 2.61437 L .87318 2.74176 L p F P
0 g
s
.76 .867 .927 r
.69018 3.93962 m .9636 3.92353 L .87107 4.08972 L p F P
0 g
s
.76 .867 .927 r
.87107 4.08972 m .59941 4.10691 L .69018 3.93962 L p F P
0 g
s
.86554 4.16414 m
.87403 4.1027 L
s
.682 .24 .195 r
.87318 2.74176 m .59997 2.74885 L .48723 2.62043 L p F P
0 g
s
.777 .45 .434 r
.59997 2.74885 m .87318 2.74176 L .96552 2.9362 L p F P
0 g
s
.81 .796 .839 r
.97011 3.8995 m .9636 3.92353 L p .74944 3.7146 L F P
0 g
s
.81 .796 .839 r
.9636 3.92353 m .69018 3.93962 L .74944 3.7146 L p F P
0 g
s
.81 .796 .839 r
.74944 3.7146 m .97341 3.70279 L .97011 3.8995 L p F P
0 g
s
.87403 4.1027 m
.92547 3.73082 L
s
.707 .594 .727 r
.5 6.89989 m .12947 6.89989 L .1289 6.5354 L p F P
0 g
s
.707 .594 .727 r
.8711 6.5354 m .87053 6.89989 L .5 6.89989 L p F P
0 g
s
.707 .594 .727 r
.1289 6.5354 m .8711 6.5354 L p .5 6.89989 L F P
0 g
s
.01 w
.34294 2.58599 Mdot
.65706 2.58599 Mdot
.5 Mabswid
.777 .45 .434 r
.96552 2.9362 m .69097 2.94483 L .59997 2.74885 L p F P
0 g
s
.812 .57 .572 r
.96552 2.9362 m .97196 2.96229 L .97402 3.14251 L p F P
0 g
s
.812 .57 .572 r
.69097 2.94483 m .96552 2.9362 L p .97402 3.14251 L F P
0 g
s
.825 .727 .756 r
.97374 3.65147 m .97341 3.70279 L p .77025 3.45504 L F P
0 g
s
.825 .727 .756 r
.97341 3.70279 m .74944 3.7146 L .77025 3.45504 L p F P
0 g
s
.825 .727 .756 r
.77025 3.45504 m .97505 3.44571 L .97374 3.65147 L p F P
0 g
s
.92547 3.73082 m
.95829 3.49352 L
s
.812 .57 .572 r
.97402 3.14251 m .97445 3.18026 L p .69097 2.94483 L F P
0 g
s
.812 .57 .572 r
.97445 3.18026 m .74999 3.18884 L .69097 2.94483 L p F P
0 g
s
.825 .655 .671 r
.74999 3.18884 m .97445 3.18026 L .97491 3.38185 L p F P
0 g
s
.825 .655 .671 r
.97491 3.38185 m .97505 3.44571 L p .74999 3.18884 L F P
0 g
s
.825 .655 .671 r
.97505 3.44571 m .77025 3.45504 L .74999 3.18884 L p F P
0 g
s
.25 Mabswid
0 0 m
.0146 7.06045 L
s
.0146 7.06045 m
.9854 7.06045 L
s
.9854 7.06045 m
1 0 L
s
1 0 m
0 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{40.75, 287.688},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#5", "Text"],

Cell[CellGroupData[{

Cell["Hz0A[[-5]]", "Input"],

Cell[BoxData[
    \(5.521318429551293`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pretty[Chop[e2ni . eigenvectors0A[\([\(-5\)]\)], 10^\(-4\)]]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
          {"\<\"optic\"\>", "0", "0", \(-1.`\), "0", "0", "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Status["\<Plotting stage 0A mode 5\>"]\ ; 
    eigenplot[
      eigenvectors0A[\([\(-5\)]\)], \(- .2\), {0, \(-1\), \(- .25\)}, \ 
      floatmatrix0A]\ \ ; Done[]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 5.99483 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.6256 6.25121 -4.44089e-16 6.25121 [
[ 0 0 0 0 ]
[ 1 5.99483 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
.12768 5.99483 L
s
.12768 5.99483 m
.23891 4.75775 L
s
.23891 4.75775 m
.18195 .67458 L
s
.18195 .67458 m
0 0 L
s
1 0 m
.81805 .67458 L
s
.81805 .67458 m
.76109 4.75775 L
s
.76109 4.75775 m
.87232 5.99483 L
s
.87232 5.99483 m
1 0 L
s
0 0 m
.12768 5.99483 L
s
.12768 5.99483 m
.87232 5.99483 L
s
.87232 5.99483 m
1 0 L
s
1 0 m
0 0 L
s
.18195 .67458 m
.81805 .67458 L
s
.81805 .67458 m
.76109 4.75775 L
s
.76109 4.75775 m
.23891 4.75775 L
s
.23891 4.75775 m
.18195 .67458 L
s
0 0 m
1 0 L
1 5.99483 L
0 5.99483 L
closepath
clip
newpath
.01 w
.40334 5.07891 Mdot
.59666 5.07891 Mdot
.39133 5.47992 Mdot
.60867 5.47992 Mdot
.38937 2.41909 Mdot
.61063 2.41909 Mdot
.37334 2.50103 Mdot
.62666 2.50103 Mdot
.25 Mabswid
0 0 m
.12768 5.99483 L
s
.12768 5.99483 m
.87232 5.99483 L
s
.87232 5.99483 m
1 0 L
s
1 0 m
0 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{48, 287.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#6", "Text"],

Cell[CellGroupData[{

Cell["Hz0A[[-6]]", "Input"],

Cell[BoxData[
    \(7.74666376915459`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pretty[Chop[e2ni . eigenvectors0A[\([\(-6\)]\)], 10^\(-4\)]]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
          {"\<\"optic\"\>", "0", "0.0030693243460986263`", "0", "0", 
            "0", \(-0.9999952896129354`\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Status["\<Plotting stage 0A mode 6\>"]\ ; 
    eigenplot[
      eigenvectors0A[\([\(-6\)]\)], \(- .2\), {\(-1\), 0, \(- .25\)}, \ 
      floatmatrix0A]\ \ ; Done[]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 2.05714 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.622713 2.24543 0 2.24543 [
[ 0 0 0 0 ]
[ 1 2.05714 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
1 0 m
.88819 2.05714 L
s
.88819 2.05714 m
.11181 2.05714 L
s
.11181 2.05714 m
0 0 L
s
0 0 m
1 0 L
s
.93098 .0853 m
.06902 .0853 L
s
.06902 .0853 m
.15474 1.89797 L
s
.15474 1.89797 m
.84526 1.89797 L
s
.84526 1.89797 m
.93098 .0853 L
s
1 0 m
.88819 2.05714 L
s
.88819 2.05714 m
.84526 1.89797 L
s
.84526 1.89797 m
.93098 .0853 L
s
.93098 .0853 m
1 0 L
s
0 0 m
.06902 .0853 L
s
.06902 .0853 m
.15474 1.89797 L
s
.15474 1.89797 m
.11181 2.05714 L
s
.11181 2.05714 m
0 0 L
s
0 0 m
1 0 L
1 2.05714 L
0 2.05714 L
closepath
clip
newpath
.5 Mabswid
.689 .692 .848 r
.44019 1.9132 m .48472 1.9132 L .48463 1.87402 L p F P
0 g
s
.714 .583 .006 r
.48463 1.87402 m .48472 1.9132 L .48362 2.0058 L p F P
0 g
s
.785 .641 .083 r
.28712 2.0058 m .30132 1.9132 L p .28084 1.99611 L F P
0 g
s
.785 .641 .083 r
.30132 1.9132 m .30025 1.87402 L .28084 1.99611 L p F P
0 g
s
.689 .692 .848 r
.30025 1.87402 m .30132 1.9132 L .44019 1.9132 L p F P
0 g
s
.689 .692 .848 r
.48463 1.87402 m .30025 1.87402 L p .44019 1.9132 L F P
0 g
s
0 0 .083 r
.70205 1.7896 m .69868 1.9132 L .70302 1.94152 L p F P
0 g
s
.689 .692 .848 r
.51554 1.7896 m .51528 1.9132 L .55981 1.9132 L p F P
0 g
s
0 0 .006 r
.51562 1.94152 m .51528 1.9132 L p .51707 1.90493 L F P
0 g
s
0 0 .006 r
.51528 1.9132 m .51554 1.7896 L .51707 1.90493 L p F P
0 g
s
.689 .692 .848 r
.55981 1.9132 m .69868 1.9132 L .70205 1.7896 L p F P
0 g
s
.689 .692 .848 r
.70205 1.7896 m .51554 1.7896 L p .55981 1.9132 L F P
0 g
s
.423 0 0 r
.30025 1.87402 m .48463 1.87402 L .48314 1.99611 L p F P
0 g
s
.423 0 0 r
.48314 1.99611 m .28084 1.99611 L .30025 1.87402 L p F P
0 g
s
.714 .583 .006 r
.48314 1.99611 m .48463 1.87402 L p .48362 2.0058 L F P
0 g
s
0 0 .083 r
.72194 1.90493 m .70205 1.7896 L p .70302 1.94152 L F P
0 g
s
.401 0 0 r
.51554 1.7896 m .70205 1.7896 L .72194 1.90493 L p F P
0 g
s
.401 0 0 r
.72194 1.90493 m .51707 1.90493 L .51554 1.7896 L p F P
0 g
s
0 0 .083 r
.70302 1.94152 m .71788 2.03836 L .72194 1.90493 L p F P
0 g
s
0 0 .006 r
.51707 1.90493 m .51676 2.03836 L .51562 1.94152 L p F P
0 g
s
.27447 1.35753 m
.37429 1.93224 L
s
.62854 1.84456 m
.72658 1.32099 L
s
.61258 1.92981 m
.61724 1.90493 L
s
.714 .583 .006 r
.48362 2.0058 m .48324 2.03836 L .48314 1.99611 L p F P
0 g
s
.785 .641 .083 r
.28084 1.99611 m .28212 2.03836 L .28712 2.0058 L p F P
0 g
s
.685 .703 .861 r
.43441 2.03836 m .28212 2.03836 L p .48314 1.99611 L F P
0 g
s
.685 .703 .861 r
.28212 2.03836 m .28084 1.99611 L .48314 1.99611 L p F P
0 g
s
.685 .703 .861 r
.48314 1.99611 m .48324 2.03836 L .43441 2.03836 L p F P
0 g
s
.685 .703 .861 r
.56559 2.03836 m .51676 2.03836 L p .72194 1.90493 L F P
0 g
s
.685 .703 .861 r
.51676 2.03836 m .51707 1.90493 L .72194 1.90493 L p F P
0 g
s
.685 .703 .861 r
.72194 1.90493 m .71788 2.03836 L .56559 2.03836 L p F P
0 g
s
.218 0 0 r
.55258 1.34412 m .55039 1.31389 L .4777 1.31685 L p F P
0 g
s
.218 0 0 r
.4777 1.31685 m .47674 1.34719 L .55258 1.34412 L p F P
0 g
s
.424 0 0 r
.47674 1.34719 m .4777 1.31685 L .40741 1.29836 L p F P
0 g
s
0 0 0 r
.62411 1.319 m .61893 1.28973 L .55039 1.31389 L p F P
0 g
s
0 0 0 r
.55039 1.31389 m .55258 1.34412 L .62411 1.319 L p F P
0 g
s
.424 0 0 r
.40741 1.29836 m .40338 1.32796 L .47674 1.34719 L p F P
0 g
s
.599 .036 0 r
.40338 1.32796 m .40741 1.29836 L .3459 1.25994 L p F P
0 g
s
0 0 0 r
.6848 1.2739 m .67704 1.24637 L .61893 1.28973 L p F P
0 g
s
0 0 0 r
.61893 1.28973 m .62411 1.319 L .6848 1.2739 L p F P
0 g
s
.599 .036 0 r
.3459 1.25994 m .33916 1.28802 L .40338 1.32796 L p F P
0 g
s
.727 .253 0 r
.33916 1.28802 m .3459 1.25994 L .29895 1.20485 L p F P
0 g
s
0 0 0 r
.72888 1.21265 m .7192 1.1875 L .67704 1.24637 L p F P
0 g
s
.75822 1.15205 m
.77554 1.05956 L
s
0 0 0 r
.67704 1.24637 m .6848 1.2739 L .72888 1.21265 L p F P
0 g
s
.727 .253 0 r
.29895 1.20485 m .29009 1.23071 L .33916 1.28802 L p F P
0 g
s
.793 .455 0 r
.29009 1.23071 m .29895 1.20485 L .27126 1.13793 L p F P
0 g
s
0 0 0 r
.75181 1.14066 m .74107 1.11837 L .7192 1.1875 L p F P
0 g
s
0 0 0 r
.7192 1.1875 m .72888 1.21265 L .75181 1.14066 L p F P
0 g
s
.72658 1.32099 m
.75822 1.15205 L
s
.793 .455 0 r
.27126 1.13793 m .2611 1.16103 L .29009 1.23071 L p F P
0 g
s
.24099 1.1648 m
.27447 1.35753 L
s
.792 .623 .063 r
.2611 1.16103 m .27126 1.13793 L .26598 1.06532 L p F P
0 g
s
0 0 .11 r
.75081 1.06462 m .74002 1.0454 L .74107 1.11837 L p F P
0 g
s
0 0 .11 r
.74107 1.11837 m .75181 1.14066 L .75081 1.06462 L p F P
0 g
s
.792 .623 .063 r
.26598 1.06532 m .25549 1.08538 L .2611 1.16103 L p F P
0 g
s
.722 .739 .224 r
.25549 1.08538 m .26598 1.06532 L .28422 .99404 L p F P
0 g
s
0 0 .27 r
.72532 .992 m .71555 .97577 L .74002 1.0454 L p F P
0 g
s
0 0 .27 r
.74002 1.0454 m .75081 1.06462 L .72532 .992 L p F P
0 g
s
.722 .739 .224 r
.28422 .99404 m .27445 1.01107 L .25549 1.08538 L p F P
0 g
s
0 0 0 r
.27445 1.01107 m .28422 .99404 L .32472 .93137 L p F P
0 g
s
.577 .119 0 r
.67731 .93031 m .66956 .91665 L .71555 .97577 L p F P
0 g
s
.577 .119 0 r
.71555 .97577 m .72532 .992 L .67731 .93031 L p F P
0 g
s
0 0 0 r
.32472 .93137 m .31673 .94567 L .27445 1.01107 L p F P
0 g
s
0 0 0 r
.31673 .94567 m .32472 .93137 L .3838 .88398 L p F P
0 g
s
.452 0 0 r
.61129 .88621 m .6064 .87442 L .66956 .91665 L p F P
0 g
s
.452 0 0 r
.66956 .91665 m .67731 .93031 L .61129 .88621 L p F P
0 g
s
0 0 0 r
.37847 .89619 m .3838 .88398 L .45555 .8571 L p F P
0 g
s
0 0 0 r
.3838 .88398 m .37847 .89619 L .31673 .94567 L p F P
0 g
s
.271 0 0 r
.53396 .86466 m .53247 .85379 L .6064 .87442 L p F P
0 g
s
.271 0 0 r
.6064 .87442 m .61129 .88621 L .53396 .86466 L p F P
0 g
s
0 0 0 r
.45555 .8571 m .4535 .86812 L .37847 .89619 L p F P
0 g
s
.053 0 0 r
.4535 .86812 m .45555 .8571 L .53247 .85379 L p F P
0 g
s
.053 0 0 r
.53247 .85379 m .53396 .86466 L .4535 .86812 L p F P
0 g
s
.01 w
.63753 .85219 Mdot
.36247 .85219 Mdot
.64387 .86298 Mdot
.35613 .86298 Mdot
.25 Mabswid
1 0 m
.88819 2.05714 L
s
.88819 2.05714 m
.11181 2.05714 L
s
.11181 2.05714 m
0 0 L
s
0 0 m
1 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{140, 287.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002<00017b000`400?l00000o`00003oS?l00000
0003o`000?oooooooooo08Sooooo0Ol0000000;o0000R?ooool2o`00000000?o0000ooooool00000
Q_ooool1o`00007ooooo0Ol000000004o`000?ooooooooooo`0008Cooooo00?o0000ooooooooool0
0Ol000000004o`000?ooooooooooo`0008?ooooo00Co0000oooooooooooooooo0Ol000000005o`00
0?ooooooooooooooool00000POooool00ol0003oooooooooo`02ooooo`7o000000000ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool00_ooool1o`00000000?o
0000ooooooooool00oooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo00?ooooo0Ol0
00000003o`000?oooooooooo00?ooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`04
ooooo`7o000000000ol0003oooooooooo`04ooooo`03o`000?oooooooooo07Wooooo00?o0000oooo
ooooool01?ooool1o`00007ooooo00000ooooooo0000ooooo`05ooooo`03o`000?oooooooooo07Oo
oooo00?o0000ooooooooool01Oooool1o`00007ooooo00000ooooooo0000ooooo`06ooooogWo0000
2?ooool1o`00007ooooo00000ooooooo0000ooooo`06ooooo`03o`000?oooooooooo07Gooooo00?o
0000ooooooooool01_ooool1o`00007ooooo00000ooooooo0000ooooo`06ooooo`03o`000?oooooo
oooo07Gooooo00?o0000ooooooooool01_ooool1o`00007ooooo00000ooooooo0000ooooo`06oooo
o`03o`000?oooooooooo07Gooooo00?o0000ooooooooool01_ooool1o`00007ooooo00000ooooooo
0000ooooo`06ooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool01_ooool1o`00007o
oooo00000ooooooo0000ooooo`06ooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool0
1_ooool1o`00007ooooo00000ooooooo0000ooooo`06ooooo`03o`000?oooooooooo07Gooooo00?o
0000ooooooooool01_ooool1o`00007ooooo00000ooooooo0000ooooo`06ooooo`03o`000?oooooo
oooo07Gooooo00?o0000ooooooooool01_ooool1o`00007ooooo00000ooooooo0000ooooo`06oooo
o`03o`000?oooooooooo07Gooooo00?o0000ooooooooool01_ooool1o`00007ooooo00000ooooooo
0000ooooo`06ooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool01_ooool1o`00007o
oooo00000ooooooo0000ooooo`06ooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool0
1_ooool1o`00007ooooo00000ooooooo0000ooooo`07ooooo`03o`000?oooooooooo07?ooooo00?o
0000ooooooooool01oooool1o`00007ooooo00000ooooooo0000ooooo`07ooooo`03o`000?oooooo
oooo07?ooooo00?o0000ooooooooool01oooool1o`00007ooooo00000ooooooo0000ooooo`07oooo
o`03o`000?oooooooooo07?ooooo00?o0000ooooooooool01oooool1o`00007ooooo00000ooooooo
0000ooooo`07ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool01oooool1o`00007o
oooo00000ooooooo0000ooooo`07ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool0
1oooool1o`00007ooooo00000ooooooo0000ooooo`07ooooo`03o`000?oooooooooo07?ooooo00?o
0000ooooooooool01_ooool1o`00007ooooo0Oooool00003ooooool0003ooooo00Oooooo00?o0000
ooooooooool0Loooool00ol0003oooooooooo`06ooooo`7o00000Oooool1ooooo`000_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool01_ooool1o`00
007ooooo0Oooool000;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1cooooo`03
o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo0002ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0Loooool00ol0003oooooooooo`06ooooo`7o00000Oooool1ooooo`000_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool01_oo
ool1o`00007ooooo0Oooool000;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1c
ooooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo0002ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`06ooooo`7o00000Oooool1oooo
o`000_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07?ooooo00?o0000oooooooo
ool01_ooool1o`00007ooooo0Oooool000;ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`1cooooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo0002ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`06ooooo`7o00000Ooo
ool1ooooo`000_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07?ooooo00?o0000
ooooooooool01_ooool1o`00007ooooo0Oooool000;ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1cooooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo0002ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`06ooooo`7o
00000Oooool1ooooo`000_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07?ooooo
00?o0000ooooooooool01_ooool1o`00007ooooo0Oooool000;ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo0002
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`07
ooooo`7o00000Oooool1ooooo`000_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
077ooooo00?o0000ooooooooool01oooool1o`00007ooooo0Oooool000;ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool00Oooool000;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1aooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool00Oooool000;ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00Ooo
ool000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1aooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool00Oooool000?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00Oooool000?o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool00Oooool000?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`1aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00Oooool000?ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool00Oooool000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1a
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00Oooool000?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool00Oooool000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1aooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool00Oooool000?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
0Oooool000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1aooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool00Oooool000?ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00Oooool0
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool00Oooool000?ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`1aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00Oooool000?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool00Oooool000?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00Oooool000?ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1_oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool000?ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool00_ooool000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1_ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool00_ooool000Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_oo
ool000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1_ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool00_ooool000Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1_ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool000Co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool00_ooool000Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`1_ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool000Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool00_ooool000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1_
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool000Cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool00_ooool000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1_ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool000Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
0_ooool000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1_ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool00_ooool000Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool0
00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool00_ooool000Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`1_ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool000Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00oooool000Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1_ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool000Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1_oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool000Cooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool00oooool000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1]ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool00oooool000Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00ooo
ool000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool00oooool000Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool000Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool00oooool000Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`1]ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool000Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool00oooool000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool000Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool00oooool000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1]ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool000Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
0oooool000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1]ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool00oooool000Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool0
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01?ooool000Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool000Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool000Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool000Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01?ooool000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool000Kooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01?ooool000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1[ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01?ooool000Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?oo
ool000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01?ooool000Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1[ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool000Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01?ooool000Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`1[ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool000Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01?ooool000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1[
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool000Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01?ooool000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1[ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool000Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1[ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool000Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Wooooo3ol0000;ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`001_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01oooool5o`00
00Go3@002ol00009ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02So
oooo3?l00008ooooo`Ko0000:Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo0006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09Oooool8o`0001;ooooo
1_l0000Vooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool000Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Sooooo`Oo00006?ooool5o`0002Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`001_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo02;ooooo1Ol0000Nooooo`Co00008_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo0007ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool08Oooool3o`0002?ooooo00?o0000og<00?l000008Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo0007ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool08?ooool2o`0002Kooooo1?l0000Oooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool000Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Oooooo`;o0000
:Oooool3o`0001kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`001ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01gooooo0_l0000/ooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`001oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01cooooo0_l0000^ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`001oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo01_ooooo0_l0000_ooooo`;o00006oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo0007ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`001oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool000Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Iooooo`;o0000<oooool2o`0001Wooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`001oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01Sooooo0_l0000eooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`001oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool000Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Gooooo`;o0000=oooool2o`0001Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`001oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01Kooooo0_l0000iooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`06ooooo`001oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01Gooooo0_l0000kooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo01Gooooo0_l0000kooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
01Cooooo0_l0000looooo`03o`00AOl0003ooooo01Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01_ooool000Oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo0007ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0looooo`03o`00AOl0003ooooo01?ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`002?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool000Sooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03kooooo0_l0000Coooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool000Sooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03kooooo0_l0000Cooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool000Sooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo03oooooo0_l00003ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`002?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0?ooo
ool00ol0003o000Lo`000002ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`002?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool0?oooool00ol0003o000Lo`000002ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`002?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo013ooooo0_l00011ooooo`03o`000?l001co0000
00;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Kooooo0008ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04?ooool2o`0004;o
oooo0_l000000ooooooo0000ooooo`0>ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01_ooool000Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0@ooooo`;o0000
@_ooool2o`000003ooooool0003ooooo00kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`06ooooo`002?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo013ooooo0_l0
0012ooooo`;o000000?oooooo`000?ooool03_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Oooooo0008ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04?ooool0
0ol0003obYl@o`000011ooooo`04o`007?l0003oooooo`0000oooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo013ooooo00?o0000olZO4?l00000@Oooool01?l001co0000ooooool0000?ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0@ooooo`03o`000?o:Wa3o0000047ooooo0_l000000ooooooo0000ooooo`0>
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool000Sooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Aooooo`;o0000@Oooool2o`000003ooooool0003ooooo
00kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`002?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo017ooooo0_l00010ooooo`Co00004?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool04Oooool2o`00043ooooo1?l0000@ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Aooooo`03o`000?o;M03o000003kooooo1Ol0000@ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01oooool000Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0A
ooooo`03o`000?o;M03o000003kooooo1Ol0000@ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01oooool000Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0>oooo
o`06o`000?ooooooooooo`000?o;M03o0000?_ooool3o`000003ooooool0003ooooo00oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`002Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00kooooo00Oo0000ooooooooooooooooo`000?o;M03o000003cooooo
1Ol0000Aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool000Wooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0>ooooo`07o`000?ooooooooooooooool0003o
bg@0o`00000looooo`Go00004Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oo
oooo0009ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03_ooool01Ol0003ooooo
oooooooooooo000000;obg@000?o0000ooooooooool0>?ooool4o`000003ooooool0003ooooo013o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`002Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00oooooo00Oo0000ooooooooooooooooo`000?o;M03o0000
03[ooooo1?l000000ooooooo0000ooooo`0@ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01oooool000Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0?ooooo`07
o`000?ooooooooooooooool0003obg@0o`00000iooooo`Go000000?oooooo`000?ooool04?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo0009ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`03o`000?o;M03o0000
03Oooooo1Ol000000ooooooo0000ooooo`0Aooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01oooool000Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00;ooooo00Co0000ol]d0?l0003o0000=_ooool5o`000003ooooool0003ooooo
017ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`002Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool2o`0000;o
^T0000?o0000ooooooooool0<_ooool6o`000003ooooool0003ooooo013ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`07ooooo`002Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool00_ooool01Ol0003o^T00okY00?nj@03o000003?o
oooo1Ol00002ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool00_ooool00ol0003o^T00okY00002okY00003o`000?oooooooooo02oooooo
1Ol00003ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool00oooool00ol0003o^T00okY00002okY00003o`000?oooooooooo02cooooo1_l0
0003ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01?ooool00ol0003o^T00okY00002okY00003o`000?oooooooooo02[ooooo1ol00003
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool01Oooool00ol0003o^T00okY00002okY000;o0000:Oooool7o`0000Cooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`05ooooo`07
o`000?nj@03o^T00okY00?l0003oV@T0o`00000Vooooo`So00001Oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Kooooo00Co0000okY0
0?nj@03o00000_nI2@000ol0003oooooooooo`0Rooooo`So00001_ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo0_l00004oiT9
00;o00008Oooool7o`0000Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`08ooooo`;o00001OnI2@000ol0003oooooooooo`0Looooo`So
00002?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo00[ooooo00?o0000oiT90?nI2@000onI2@000ol0003oooooooooo`0Hooooo`Wo0000
2_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00_ooooo0_l00004oiT900Co00005?ooool:o`0000_ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo000:ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0<ooooo`05o`000?nI2@3o
V@T0oiT90?l000000om/0005o`0000cooooo2ol0000=ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`002_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03Oooool2o`000003oiT90?l0003o
K00000OoK0005_l0000=ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`08ooooo`002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool03oooool2o`0000WoK00000?o0000ocL00?lg00001olg0009o`00
00oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Sooooo000:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0@ooooo`Co00001_m/00000ol0003o=`00ocL00007ocL000Ko00004_ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool000[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Cooooo
1Ol000000om/003o0000ocL00008ocL000Co00005?ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool02?ooool000[ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Sooooo3?l0000Gooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`002_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool0
00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
03[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Wooooo000:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`09ooooo`002_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`002_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0>?oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Ooo
ool000[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo03Sooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02Oooool000_ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Wooooo000;ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`002oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool000_ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo000;ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`00
2oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
2Oooool000_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00[ooooo000;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0dooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0:ooooo`002oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool02_ooool000_ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00[ooooo000;ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`002oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0<_ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool000_ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo000;oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0boooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:oooo
o`002oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool02_ooool000_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00[ooooo000;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0:ooooo`002oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02_ooool000_ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo000<ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`003?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool000cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo000<
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:
ooooo`003?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool02oooool000cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00_ooooo000<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0;ooooo`003?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02oooool000cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo000<ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`003?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0;?ooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool000cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02cooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo
000<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0[ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0;ooooo`003?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool0:_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02oooool000cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00_ooooo000<ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0;ooooo`003?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool02oooool000cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo000<ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`003Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool000go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_o
oooo000=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0;ooooo`003Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool03?ooool000gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`003Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool0
00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
01Cooooo6ol0000Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool000go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01?o
oooo00?o0000ofH00?mV00003_mV00000ol0003oIP00ofH00006ofH00003o`000?oooooooooo01;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool04oooool00ol0003oIP00
ofH0000>ofH00003o`000?mV003oIP0000KoIP0000?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Cooooo`03o`000?mV003oIP0000koIP0000?o
0000ofH00?mV00001_mV00000ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool03?ooool000gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo01?ooooo00?o0000ofH00?mV00003_mV00000ol0003oIP00ofH00007
ofH00003o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<
ooooo`003Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool04oooool00ol0003oIP00ofH0000=ofH00003o`000?mV003oIP0000SoIP0000?o0000oooo
ooooool04?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo000=ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Cooooo`03
o`000?mV003oIP0000goIP0000?o0000ofH00?mV00002?mV00000ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01;ooooo00?o0000ofH00?mV0000
3OmV00000ol0003oIP00ofH00008ofH00003o`000?oooooooooo013ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool04_ooool00ol0003oIP00ofH0000HofH00003o`000?oo
oooooooo013ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`003_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool04_ooool0
0ol0003oIP00ofH0000IofH00003o`000?oooooooooo00oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool04_ooool00ol0003oIP00ofH0000IofH00003o`000?oooooooooo
00oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool04_ooool00ol0003o
IP00ofH0000IofH00003o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0=ooooo`003_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo017ooooo
6ol00003ooooo`03o`000?mV003oIP0001WoIP0000?o0000ooooooooool03oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00gooooo000>ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool04Oooool00ol0003oK000of`00007of`00003o`000?m/003oK00000goK00000Go
0000ooooooooooooooooo`00000KofH00003o`000?oooooooooo00oooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0=ooooo`003_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo017ooooo00?o0000of`00?m/00001om/00000ol0003oK000of`0000=of`00005o`000?oo
ooooooooooooool000007?mV00000ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool03Oooool000kooooo00?o0000ooooooooool01?oooolEo`0000WoK00000?o
0000of`00?m/00003Om/0005o`0001coIP004_l00006ooooo`03o`000?oooooooooo00gooooo000>
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04Oooool00ol0003oK000of`00007
of`00003o`000?m/003oK00000goK00000Co0000oooooooooooooooo7_l0000@ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool03Oooool000kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0@ooooo`03o`000?m/003oK00000SoK00000?o0000of`00?m/00003Om/0000
1Ol0003ooooooooooooooooo000001co[k?L00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00gooooo000>ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool04Oooool00ol0003oK000of`00009of`00003o`000?m/003oK00000coK00000Go0000
ooooooooooooooooo`00000Lojncg003o`000?oooooooooo00oooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0=ooooo`003_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo017ooooo00?o0000of`00?m/00002Om/00000ol0003oK000of`0000<of`00005o`000?oooooo
ooooooooool000007?n_/m`00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool03Oooool000kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0A
ooooo`03o`000?m/003oK00000WoK00000?o0000of`00?m/00003?m/00001Ol0003ooooooooooooo
oooo000001co[k?L00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00gooooo000>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04_ooool0
0ol0003oK000of`0000Hof`00005o`000?ooooooooooooooool000007?n_/m`00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool000kooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Booooo`03o`000?m/003oK00001SoK00000Go0000
ooooooooooooooooo`00000Lojncg003o`000?oooooooooo013ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0=ooooo`003_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo01;ooooo00?o0000of`00?m/00006?m/00001Ol0003ooooooooooooooooo000001co[k?L00?o
0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo000>
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04_ooool00ol0003oK000of`0000H
of`00005o`000?ooooooooooooooool000007?n_/m`00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool03Oooool000kooooo00Go0000ooooooooooooooooo`00
000Eooooo`03o`000?m/003oK00001SoK00000Go0000ooooooooooooooooo`00000Lojncg003o`00
0?oooooooooo017ooooo00Go0000ooooooooooooooooo`00000?ooooo`003_ooool01Ol0003ooooo
oooooooooooo000001Cooooo00?o0000of`00?m/00006Om/00001Ol0003ooooooooooooooooo0000
01_o[k?L00?o0000ooooooooool04_ooool01Ol0003ooooooooooooooooo000000oooooo000>oooo
o`05o`000?ooooooooooooooool000005?ooool00ol0003oK000of`0000Iof`00005o`000?oooooo
ooooooooool000006on_/m`00ol0003oooooooooo`0Booooo`05o`000?ooooooooooooooool00000
3oooool000oooooo00Co0000oooooooooooo00005?ooool00ol0003oK000of`0000Iof`00005o`00
0?ooooooooooooooool000006on_/m`00ol0003oooooooooo`0Booooo`05o`000?oooooooooooooo
ool000003oooool000oooooo00?o0000ooooool000005OoooolMo`0000?ooooo00?o0000ojncg?n_
/m`06On_/m`00ol0003oooooooooo`0Cooooo`03o`000?oooooo0000013ooooo000?ooooo`03o`00
0?oooooo000001Gooooo00?o0000ojncg?n_/m`06On_/m`01Ol0003ooooooooooooooooo000001_o
[k?L00?o0000ooooooooool04oooool00ol0003oooooo`00000@ooooo`003oooool00ol0003ooooo
o`00000Eooooo`03o`000?n_/mco[k?L01Wo[k?L00Go0000ooooooooooooooooo`00000Kojncg003
o`000?oooooooooo01?ooooo00?o0000ooooool000004?ooool000oooooo0_l0000Fooooo`03o`00
0?n_/mco[k?L01Wo[k?L00Go0000ooooooooooooooooo`00000Kojncg003o`000?oooooooooo01Co
oooo0_l0000@ooooo`003oooool2o`0001Kooooo00?o0000ojncg?n_/m`06On_/m`01Ol0003ooooo
oooooooooooo000001_o[k?L00?o0000ooooooooool05?ooool2o`00013ooooo000?ooooo`;o0000
5_ooool00ol0003o[k?Lojncg00Jo`0000?ooooo7Ol0000Fooooo`;o00004?ooool000oooooo0_l0
001Yooooo`;o00004?ooool000oooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0>
ooooo`003ooooom]o`00013ooooo0000\
\>"],
  ImageRangeCache->{{{0, 139}, {286.938, 0}} -> {0.277322, -0.00159863, \
0.00320398, 0.00320398}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Listings and plots with Stage 2 Data", "Subsection"],

Cell["Calculate[Stage2]", "Input"],

Cell[CellGroupData[{

Cell["View the eigenfrequencies", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
Table[{Length[allvars]-index+1, Hz2[[index]]}, {index, 1, Length[allvars]}]\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \({{6, 7.790049616529068`}, {5, 5.521318432045177`}, {4, 
        1.7374645454176607`}, {3, 1.533872409023967`}, {2, 
        1.3426368379847025`}, {1, 1.286258659943255`}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["View the important low-frequency modes", "Text"],

Cell[CellGroupData[{

Cell["\<\
Join[\t
\t{{\"N\",\"f\",\"type\"}},
\tTable[
\t\tJoin[
\t\t\t{i},
\t\t\t{Hz2[[-i]]},
\t\t\timportant[e2ni.eigenvectors2[[-i]],0.7]
\t\t],
\t\t{i,noofLF}
\t]
]//TableForm\
\>", "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"N\"\>", "\<\"f\"\>", "\<\"type\"\>"},
          {"1", "1.286258659943255`", "pitch0"},
          {"2", "1.3426368379847025`", "roll0"},
          {"3", "1.533872409023967`", "pitch0"},
          {"4", "1.7374645454176607`", "yaw0"},
          {"5", "5.521318432045177`", "z0"},
          {"6", "7.790049616529068`", "roll0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["View the higher frequency modes", "Text"],

Cell[CellGroupData[{

Cell["\<\
Join[\t
\t{{\"N\",\"f\",\"type\"}},
\tTable[
\t\tJoin[
\t\t\t{i},
\t\t\t{Hz2[[-i]]},
\t\t\timportant[e2ni.eigenvectors2[[-i]],0.7]
\t\t],
\t\t{i,noofLF+1,Length[allvars]}
\t]
]//TableForm\
\>", "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"N\"\>", "\<\"f\"\>", "\<\"type\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Classify the modes", "Text"],

Cell[CellGroupData[{

Cell["\<\
longpitchmodes2 = \
Select[Range[-noofLF,-1],longpitchQ[e2ni.eigenvectors2[[#]]]&]\
\>", "Input"],

Cell[BoxData[
    \({\(-3\), \(-1\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
transrollmodes2 = \
Select[Range[-noofLF,-1],transrollQ[e2ni.eigenvectors2[[#]]]&]\
\>", "Input"],

Cell[BoxData[
    \({\(-6\), \(-2\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
yawmodes2 = Select[Range[-noofLF,-1],yawQ[e2ni.eigenvectors2[[#]]]&]\
\>", "Input"],

Cell[BoxData[
    \({\(-4\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
vertmodes2 = Select[Range[-noofLF,-1],vertQ[e2ni.eigenvectors2[[#]]]&]\
\>", "Input"],

Cell[BoxData[
    \({\(-5\)}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["View the mode frequencies by groups", "Text"],

Cell[CellGroupData[{

Cell["longpitchfreqs2 = Hz2[[longpitchmodes2]]", "Input"],

Cell[BoxData[
    \({1.533872409023967`, 1.286258659943255`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["transrollfreqs2 = Hz2[[transrollmodes2]]", "Input"],

Cell[BoxData[
    \({7.790049616529068`, 1.3426368379847025`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["yawfreqs2 = Hz2[[yawmodes2]]", "Input"],

Cell[BoxData[
    \({1.7374645454176607`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["vertfreqs2 = Hz2[[vertmodes2]]", "Input"],

Cell[BoxData[
    \({5.521318432045177`}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Mode shape listings/plots", "Text"],

Cell[CellGroupData[{

Cell["#1", "Text"],

Cell[CellGroupData[{

Cell["Hz2[[-1]]", "Input"],

Cell[BoxData[
    \(1.286258659943255`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pretty[Chop[e2ni . eigenvectors2[\([\(-1\)]\)], 10^\(-4\)]]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
          {"\<\"optic\"\>", \(-0.03251173411024383`\), "0", "0", "0", 
            "0.9994713538391908`", "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Status["\<Plotting stage 2 mode 1\>"]\ ; 
    eigenplot[eigenvectors2[\([\(-1\)]\)],  .5, {0, \(-1\), 0}, \ 
      floatmatrix2]\ ; Done[]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 7.1936 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-3.0968 7.1936 1.33227e-15 7.1936 [
[ 0 0 0 0 ]
[ 1 7.1936 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 7.1936 L
s
0 7.1936 m
.17254 5.95241 L
s
.17254 5.95241 m
.17254 1.24119 L
s
.17254 1.24119 m
0 0 L
s
1 0 m
.82746 1.24119 L
s
.82746 1.24119 m
.82746 5.95241 L
s
.82746 5.95241 m
1 7.1936 L
s
1 7.1936 m
1 0 L
s
0 0 m
0 7.1936 L
s
0 7.1936 m
1 7.1936 L
s
1 7.1936 m
1 0 L
s
1 0 m
0 0 L
s
.17254 1.24119 m
.82746 1.24119 L
s
.82746 1.24119 m
.82746 5.95241 L
s
.82746 5.95241 m
.17254 5.95241 L
s
.17254 5.95241 m
.17254 1.24119 L
s
0 0 m
1 0 L
1 7.1936 L
0 7.1936 L
closepath
clip
newpath
.5 Mabswid
.653 .462 .613 r
.1883 3.77055 m .39536 3.6575 L .30264 3.4863 L p F P
0 g
s
.21663 3.56723 m
.22767 3.67267 L
s
.653 .462 .613 r
.30264 3.4863 m .14805 3.5707 L .147 3.69307 L p F P
0 g
s
.653 .462 .613 r
.147 3.69307 m .1883 3.77055 L p .30264 3.4863 L F P
0 g
s
.747 .68 .786 r
.14718 3.46928 m .14805 3.5707 L p .20777 3.31389 L F P
0 g
s
.747 .68 .786 r
.14805 3.5707 m .30264 3.4863 L .20777 3.31389 L p F P
0 g
s
.747 .68 .786 r
.20777 3.31389 m .14613 3.34755 L .14718 3.46928 L p F P
0 g
s
.707 .577 .707 r
.5 6.14181 m .77857 6.14181 L p .22143 5.86324 L F P
0 g
s
.707 .577 .707 r
.77857 6.14181 m .77857 5.86324 L .22143 5.86324 L p F P
0 g
s
.707 .577 .707 r
.22143 5.86324 m .22143 6.14181 L .5 6.14181 L p F P
0 g
s
.745 .608 .039 r
.22143 6.14181 m .22143 5.86324 L .19121 6.10908 L p F P
0 g
s
0 0 .039 r
.77857 5.86324 m .77857 6.14181 L .7929 6.27274 L p F P
0 g
s
0 0 .039 r
.80879 6.10908 m .77857 5.86324 L p .7929 6.27274 L F P
0 g
s
.288 0 0 r
.77857 5.86324 m .80879 6.10908 L .19121 6.10908 L p F P
0 g
s
.23524 3.74492 m
.28989 4.26672 L
s
.288 0 0 r
.19121 6.10908 m .22143 5.86324 L .77857 5.86324 L p F P
0 g
s
.48286 6.10908 m
.5 6.27274 L
s
.28989 4.26672 m
.46743 5.96176 L
s
.745 .608 .039 r
.2071 6.27274 m .22143 6.14181 L p .19121 6.10908 L F P
0 g
s
.503 .201 .386 r
.26927 3.93082 m .47966 3.81595 L .39536 3.6575 L p F P
0 g
s
.503 .201 .386 r
.39536 3.6575 m .1883 3.77055 L .26927 3.93082 L p F P
0 g
s
.784 .844 .897 r
.14613 3.34755 m .20777 3.31389 L .14201 3.19639 L closepath p F P
0 g
s
.307 0 .121 r
.33333 4.06756 m .54912 3.94975 L .47966 3.81595 L p F P
0 g
s
.307 0 .121 r
.47966 3.81595 m .26927 3.93082 L .33333 4.06756 L p F P
0 g
s
.079 0 0 r
.3742 4.16833 m .59719 4.04659 L .54912 3.94975 L p F P
0 g
s
.079 0 0 r
.54912 3.94975 m .33333 4.06756 L .3742 4.16833 L p F P
0 g
s
.01 w
.37666 2.87738 Mdot
.62334 2.87738 Mdot
.5 Mabswid
.745 .608 .039 r
.19121 6.10908 m .19121 6.41787 L .2071 6.27274 L p F P
0 g
s
0 0 .039 r
.7929 6.27274 m .80879 6.41787 L .80879 6.10908 L p F P
0 g
s
0 0 0 r
.38598 4.22073 m .61754 4.09431 L .59719 4.04659 L p F P
0 g
s
0 0 0 r
.59719 4.04659 m .3742 4.16833 L .38598 4.22073 L p F P
0 g
s
.707 .577 .707 r
.5 6.41787 m .19121 6.41787 L .19121 6.10908 L p F P
0 g
s
.707 .577 .707 r
.80879 6.10908 m .80879 6.41787 L .5 6.41787 L p F P
0 g
s
.707 .577 .707 r
.19121 6.10908 m .80879 6.10908 L p .5 6.41787 L F P
0 g
s
.389 .823 .67 r
.36414 4.21403 m .60496 4.08255 L .61754 4.09431 L p F P
0 g
s
.389 .823 .67 r
.61754 4.09431 m .38598 4.22073 L .36414 4.21403 L p F P
0 g
s
.707 .577 .707 r
.5 6.46981 m .81448 6.46981 L p .18552 6.15533 L F P
0 g
s
.707 .577 .707 r
.81448 6.46981 m .81448 6.15533 L .18552 6.15533 L p F P
0 g
s
.707 .577 .707 r
.18552 6.15533 m .18552 6.46981 L .5 6.46981 L p F P
0 g
s
.745 .608 .039 r
.16714 6.63777 m .18552 6.46981 L p .14647 6.47306 L F P
0 g
s
.745 .608 .039 r
.18552 6.46981 m .18552 6.15533 L .14647 6.47306 L p F P
0 g
s
0 0 .039 r
.81448 6.15533 m .81448 6.46981 L .83286 6.63777 L p F P
0 g
s
0 0 .039 r
.85353 6.47306 m .81448 6.15533 L p .83286 6.63777 L F P
0 g
s
.288 0 0 r
.81448 6.15533 m .85353 6.47306 L .14647 6.47306 L p F P
0 g
s
.288 0 0 r
.14647 6.47306 m .18552 6.15533 L .81448 6.15533 L p F P
0 g
s
.582 .944 .842 r
.30703 4.14185 m .55687 4.00545 L .60496 4.08255 L p F P
0 g
s
.582 .944 .842 r
.60496 4.08255 m .36414 4.21403 L .30703 4.14185 L p F P
0 g
s
.745 .608 .039 r
.14647 6.47306 m .14647 6.82659 L .16714 6.63777 L p F P
0 g
s
0 0 .039 r
.83286 6.63777 m .85353 6.82659 L .85353 6.47306 L p F P
0 g
s
.47995 6.47306 m
.5 6.63777 L
s
.01 w
.35823 2.7699 Mdot
.64177 2.7699 Mdot
.5 Mabswid
.719 .97 .932 r
.21763 4.00558 m .47511 3.86501 L .55687 4.00545 L p F P
0 g
s
.719 .97 .932 r
.55687 4.00545 m .30703 4.14185 L .21763 4.00558 L p F P
0 g
s
.18242 4.02847 m
.46238 6.32863 L
s
.782 .892 .923 r
.10464 3.81719 m .36728 3.6738 L .47511 3.86501 L p F P
0 g
s
.782 .892 .923 r
.47511 3.86501 m .21763 4.00558 L .10464 3.81719 L p F P
0 g
s
.43 .089 .284 r
.05304 3.22828 m .05761 3.10198 L .12933 3.23796 L p F P
0 g
s
.43 .089 .284 r
.12933 3.23796 m .05115 3.28064 L .05304 3.22828 L p F P
0 g
s
.635 .428 .584 r
.04964 3.41677 m .05115 3.28064 L p .24655 3.4549 L F P
0 g
s
.635 .428 .584 r
.05115 3.28064 m .12933 3.23796 L .24655 3.4549 L p F P
0 g
s
.756 .707 .806 r
.04856 3.61215 m .04803 3.56329 L p .36728 3.6738 L F P
0 g
s
.756 .707 .806 r
.04803 3.56329 m .24655 3.4549 L .36728 3.6738 L p F P
0 g
s
.756 .707 .806 r
.10464 3.81719 m .04975 3.7196 L .04856 3.61215 L p F P
0 g
s
.756 .707 .806 r
.36728 3.6738 m .10464 3.81719 L p .04856 3.61215 L F P
0 g
s
.13917 3.67309 m
.18242 4.02847 L
s
.707 .577 .707 r
.5 6.82659 m .14647 6.82659 L .14647 6.47306 L p F P
0 g
s
.707 .577 .707 r
.85353 6.47306 m .85353 6.82659 L .5 6.82659 L p F P
0 g
s
.707 .577 .707 r
.14647 6.47306 m .85353 6.47306 L p .5 6.82659 L F P
0 g
s
.635 .428 .584 r
.24655 3.4549 m .04803 3.56329 L .04964 3.41677 L p F P
0 g
s
.12512 3.55768 m
.13917 3.67309 L
s
.25 Mabswid
0 0 m
0 7.1936 L
s
0 7.1936 m
1 7.1936 L
s
1 7.1936 m
1 0 L
s
1 0 m
0 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{108.812, 782.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#2", "Text"],

Cell[CellGroupData[{

Cell["Hz2[[-2]]", "Input"],

Cell[BoxData[
    \(1.3426368379847025`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pretty[Chop[e2ni . eigenvectors2[\([\(-2\)]\)], 10^\(-4\)]]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
          {"\<\"optic\"\>", "0", \(-0.2317776603438512`\), "0", "0", 
            "0", \(-0.9727687886468863`\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Status["\<Plotting stage 2 mode 2\>"]\ ; 
    eigenplot[eigenvectors2[\([\(-2\)]\)],  .1, {\(-1\), 0, 0}, \ 
      floatmatrix2]\ ; Done[]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 2.39787 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.698933 2.39787 0 2.39787 [
[ 0 0 0 0 ]
[ 1 2.39787 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
1 0 m
1 2.39787 L
s
1 2.39787 m
0 2.39787 L
s
0 2.39787 m
0 0 L
s
0 0 m
1 0 L
s
.93501 .15584 m
.06499 .15584 L
s
.06499 .15584 m
.06499 2.24203 L
s
.06499 2.24203 m
.93501 2.24203 L
s
.93501 2.24203 m
.93501 .15584 L
s
1 0 m
1 2.39787 L
s
1 2.39787 m
.93501 2.24203 L
s
.93501 2.24203 m
.93501 .15584 L
s
.93501 .15584 m
1 0 L
s
0 0 m
.06499 .15584 L
s
.06499 .15584 m
.06499 2.24203 L
s
.06499 2.24203 m
0 2.39787 L
s
0 2.39787 m
0 0 L
s
0 0 m
1 0 L
1 2.39787 L
0 2.39787 L
closepath
clip
newpath
.5 Mabswid
.707 .577 .707 r
.36277 2.25665 m .4807 2.25665 L .4807 2.13871 L p F P
0 g
s
.707 .577 .707 r
.4807 2.13871 m .24915 2.13871 L p .36277 2.25665 L F P
0 g
s
.287 0 0 r
.24915 2.13871 m .4807 2.13871 L .47847 2.24753 L p F P
0 g
s
.785 .641 .083 r
.24915 2.25665 m .24915 2.13871 L .22011 2.24753 L p F P
0 g
s
.707 .577 .707 r
.24915 2.13871 m .24915 2.25665 L .36277 2.25665 L p F P
0 g
s
.287 0 0 r
.47847 2.24753 m .22011 2.24753 L .24915 2.13871 L p F P
0 g
s
.714 .583 .006 r
.4807 2.13871 m .4807 2.25665 L .47967 2.3134 L p F P
0 g
s
.714 .583 .006 r
.47847 2.24753 m .4807 2.13871 L p .47967 2.3134 L F P
0 g
s
.785 .641 .083 r
.23569 2.3134 m .24915 2.25665 L p .22011 2.24753 L F P
0 g
s
0 0 .083 r
.75085 2.14303 m .75085 2.25665 L .76485 2.31567 L p F P
0 g
s
0 0 .083 r
.77989 2.25235 m .75085 2.14303 L p .76485 2.31567 L F P
0 g
s
.707 .577 .707 r
.63723 2.25665 m .75085 2.25665 L .75085 2.14303 L p F P
0 g
s
.707 .577 .707 r
.75085 2.14303 m .5193 2.14303 L p .63723 2.25665 L F P
0 g
s
.288 0 0 r
.5193 2.14303 m .75085 2.14303 L .77989 2.25235 L p F P
0 g
s
.707 .577 .707 r
.5193 2.14303 m .5193 2.25665 L .63723 2.25665 L p F P
0 g
s
.288 0 0 r
.77989 2.25235 m .52153 2.25235 L .5193 2.14303 L p F P
0 g
s
0 0 .006 r
.52037 2.31567 m .5193 2.25665 L p .52153 2.25235 L F P
0 g
s
0 0 .006 r
.5193 2.25665 m .5193 2.14303 L .52153 2.25235 L p F P
0 g
s
.132 .679 .79 r
.63201 .89692 m .62603 .9106 L .71076 .90552 L p F P
0 g
s
.132 .679 .79 r
.71076 .90552 m .72076 .89161 L .63201 .89692 L p F P
0 g
s
0 .497 .784 r
.72076 .89161 m .71076 .90552 L .79292 .92688 L p F P
0 g
s
0 .497 .784 r
.79292 .92688 m .80681 .91398 L .72076 .89161 L p F P
0 g
s
0 .274 .71 r
.80681 .91398 m .79292 .92688 L .86445 .97258 L p F P
0 g
s
0 .274 .71 r
.86445 .97258 m .88174 .96185 L .80681 .91398 L p F P
0 g
s
0 .033 .576 r
.88174 .96185 m .86445 .97258 L .91836 1.03815 L p F P
0 g
s
0 .033 .576 r
.91836 1.03815 m .93821 1.03053 L .88174 .96185 L p F P
0 g
s
0 0 .395 r
.93821 1.03053 m .91836 1.03815 L .94937 1.11717 L p F P
0 g
s
0 0 .395 r
.94937 1.11717 m .97069 1.11329 L .93821 1.03053 L p F P
0 g
s
0 0 .185 r
.97069 1.11329 m .94937 1.11717 L .95445 1.20191 L p F P
0 g
s
.715 .729 .209 r
.41032 1.14685 m .41438 1.14921 L .43574 1.06705 L p F P
0 g
s
.715 .729 .209 r
.43574 1.06705 m .43269 1.06079 L .41032 1.14685 L p F P
0 g
s
.635 .829 .421 r
.43269 1.06079 m .43574 1.06705 L .48144 .99552 L p F P
0 g
s
.635 .829 .421 r
.48144 .99552 m .48056 .98587 L .43269 1.06079 L p F P
0 g
s
.502 .855 .599 r
.48056 .98587 m .48144 .99552 L .54701 .94161 L p F P
0 g
s
.502 .855 .599 r
.54701 .94161 m .54924 .9294 L .48056 .98587 L p F P
0 g
s
.329 .803 .727 r
.54924 .9294 m .54701 .94161 L .62603 .9106 L p F P
0 g
s
.329 .803 .727 r
.62603 .9106 m .63201 .89692 L .54924 .9294 L p F P
0 g
s
0 0 .185 r
.95445 1.20191 m .976 1.20205 L .97069 1.11329 L p F P
0 g
s
0 0 0 r
.976 1.20205 m .95445 1.20191 L .93309 1.28406 L p F P
0 g
s
.732 .563 0 r
.41563 1.2356 m .41945 1.23394 L .41438 1.14921 L p F P
0 g
s
.732 .563 0 r
.41438 1.14921 m .41032 1.14685 L .41563 1.2356 L p F P
0 g
s
.01 w
.34843 .90424 Mdot
.5 Mabswid
0 0 0 r
.93309 1.28406 m .95363 1.2881 L .976 1.20205 L p F P
0 g
s
0 0 0 r
.95363 1.2881 m .93309 1.28406 L .88739 1.3556 L p F P
0 g
s
0 0 0 r
.88739 1.3556 m .90576 1.36303 L .95363 1.2881 L p F P
0 g
s
0 0 0 r
.90576 1.36303 m .88739 1.3556 L .82182 1.40951 L p F P
0 g
s
.581 .108 0 r
.50458 1.38705 m .50437 1.37853 L .45046 1.31296 L p F P
0 g
s
.581 .108 0 r
.45046 1.31296 m .44811 1.31837 L .50458 1.38705 L p F P
0 g
s
.686 .349 0 r
.44811 1.31837 m .45046 1.31296 L .41945 1.23394 L p F P
0 g
s
.686 .349 0 r
.41945 1.23394 m .41563 1.2356 L .44811 1.31837 L p F P
0 g
s
0 0 0 r
.82182 1.40951 m .83708 1.4195 L .90576 1.36303 L p F P
0 g
s
0 0 0 r
.83708 1.4195 m .82182 1.40951 L .7428 1.44052 L p F P
0 g
s
0 0 0 r
.7428 1.44052 m .75431 1.45198 L .83708 1.4195 L p F P
0 g
s
.04 0 0 r
.75431 1.45198 m .7428 1.44052 L .65806 1.44559 L p F P
0 g
s
.04 0 0 r
.65806 1.44559 m .66556 1.45729 L .75431 1.45198 L p F P
0 g
s
.241 0 0 r
.66556 1.45729 m .65806 1.44559 L .57591 1.42423 L p F P
0 g
s
.241 0 0 r
.57591 1.42423 m .57951 1.43492 L .66556 1.45729 L p F P
0 g
s
.428 0 0 r
.57951 1.43492 m .57591 1.42423 L .50437 1.37853 L p F P
0 g
s
.428 0 0 r
.50437 1.37853 m .50458 1.38705 L .57951 1.43492 L p F P
0 g
s
.714 .583 .006 r
.47967 2.3134 m .47847 2.37912 L .47847 2.24753 L p F P
0 g
s
.785 .641 .083 r
.22011 2.24753 m .22011 2.37912 L .23569 2.3134 L p F P
0 g
s
.35978 2.19014 m
.3788 1.15704 L
s
.35754 2.31226 m
.35873 2.24753 L
s
.68175 2.1947 m
.76458 1.93725 L
s
.6432 2.31453 m
.6632 2.25235 L
s
.94775 1.36789 m
.96525 1.3135 L
s
.76458 1.93725 m
.94775 1.36789 L
s
0 0 .083 r
.76485 2.31567 m .77989 2.37912 L .77989 2.25235 L p F P
0 g
s
0 0 .006 r
.52153 2.25235 m .52153 2.37912 L .52037 2.31567 L p F P
0 g
s
.01 w
.65876 .89026 Mdot
.34124 .89026 Mdot
.5 Mabswid
.707 .577 .707 r
.34688 2.37912 m .22011 2.37912 L p .47847 2.24753 L F P
0 g
s
.707 .577 .707 r
.22011 2.37912 m .22011 2.24753 L .47847 2.24753 L p F P
0 g
s
.707 .577 .707 r
.47847 2.24753 m .47847 2.37912 L .34688 2.37912 L p F P
0 g
s
.707 .577 .707 r
.65312 2.37912 m .52153 2.37912 L p .77989 2.25235 L F P
0 g
s
.707 .577 .707 r
.52153 2.37912 m .52153 2.25235 L .77989 2.25235 L p F P
0 g
s
.707 .577 .707 r
.77989 2.25235 m .77989 2.37912 L .65312 2.37912 L p F P
0 g
s
.25 Mabswid
1 0 m
1 2.39787 L
s
1 2.39787 m
0 2.39787 L
s
0 2.39787 m
0 0 L
s
0 0 m
1 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{170.25, 408.188},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#3", "Text"],

Cell[CellGroupData[{

Cell["Hz2[[-3]]", "Input"],

Cell[BoxData[
    \(1.533872409023967`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pretty[Chop[e2ni . eigenvectors2[\([\(-3\)]\)], 10^\(-4\)]]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
          {"\<\"optic\"\>", "0.012047953394874723`", "0", "0", "0", 
            "0.9999274207756257`", "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Status["\<Plotting stage 2 mode 2\>"]\ ; 
    eigenplot[eigenvectors2[\([\(-3\)]\)],  .5, {0, \(-1\), \(- .25\)}, \ 
      floatmatrix2]\ ; Done[]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 5.99483 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.6256 6.25121 -4.44089e-16 6.25121 [
[ 0 0 0 0 ]
[ 1 5.99483 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
.12768 5.99483 L
s
.12768 5.99483 m
.23891 4.75775 L
s
.23891 4.75775 m
.18195 .67458 L
s
.18195 .67458 m
0 0 L
s
1 0 m
.81805 .67458 L
s
.81805 .67458 m
.76109 4.75775 L
s
.76109 4.75775 m
.87232 5.99483 L
s
.87232 5.99483 m
1 0 L
s
0 0 m
.12768 5.99483 L
s
.12768 5.99483 m
.87232 5.99483 L
s
.87232 5.99483 m
1 0 L
s
1 0 m
0 0 L
s
.18195 .67458 m
.81805 .67458 L
s
.81805 .67458 m
.76109 4.75775 L
s
.76109 4.75775 m
.23891 4.75775 L
s
.23891 4.75775 m
.18195 .67458 L
s
0 0 m
1 0 L
1 5.99483 L
0 5.99483 L
closepath
clip
newpath
.5 Mabswid
.691 .687 .841 r
.5 4.95773 m .71974 4.95773 L p .27793 4.76168 L F P
0 g
s
.691 .687 .841 r
.71974 4.95773 m .72207 4.76168 L .27793 4.76168 L p F P
0 g
s
.691 .687 .841 r
.27793 4.76168 m .28026 4.95773 L .5 4.95773 L p F P
0 g
s
.745 .608 .039 r
.27065 5.09348 m .28026 4.95773 L p .25738 5.03076 L F P
0 g
s
.745 .608 .039 r
.28026 4.95773 m .27793 4.76168 L .25738 5.03076 L p F P
0 g
s
0 0 .039 r
.72207 4.76168 m .71974 4.95773 L .72935 5.09348 L p F P
0 g
s
0 0 .039 r
.74262 5.03076 m .72207 4.76168 L p .72935 5.09348 L F P
0 g
s
.412 0 0 r
.72207 4.76168 m .74262 5.03076 L .25738 5.03076 L p F P
0 g
s
.412 0 0 r
.25738 5.03076 m .27793 4.76168 L .72207 4.76168 L p F P
0 g
s
.745 .608 .039 r
.25738 5.03076 m .26016 5.24166 L .27065 5.09348 L p F P
0 g
s
0 0 .039 r
.72935 5.09348 m .73984 5.24166 L .74262 5.03076 L p F P
0 g
s
.5112 4.87045 m
.60751 2.95319 L
s
.5 5.09348 m
.50315 5.03076 L
s
.688 .696 .853 r
.5 5.24166 m .26016 5.24166 L .25738 5.03076 L p F P
0 g
s
.688 .696 .853 r
.74262 5.03076 m .73984 5.24166 L .5 5.24166 L p F P
0 g
s
.688 .696 .853 r
.25738 5.03076 m .74262 5.03076 L p .5 5.24166 L F P
0 g
s
.552 .365 .581 r
.76908 3.04968 m .58852 3.14505 L .66322 3.29559 L p F P
0 g
s
.657 .589 .768 r
.58852 3.14505 m .76908 3.04968 L .68781 2.89768 L p F P
0 g
s
.657 .589 .768 r
.68781 2.89768 m .50727 2.99395 L .58852 3.14505 L p F P
0 g
s
.713 .771 .898 r
.50727 2.99395 m .68781 2.89768 L .60732 2.75438 L p F P
0 g
s
.713 .771 .898 r
.60732 2.75438 m .42493 2.85252 L .50727 2.99395 L p F P
0 g
s
.552 .365 .581 r
.80928 3.12864 m .76908 3.04968 L p .66322 3.29559 L F P
0 g
s
.406 .111 .348 r
.81025 3.21864 m .66322 3.29559 L .72601 3.43512 L p F P
0 g
s
.552 .365 .581 r
.66322 3.29559 m .81025 3.21864 L .80928 3.12864 L p F P
0 g
s
.687 .698 .855 r
.5 5.29411 m .74356 5.29411 L p .25358 5.08052 L F P
0 g
s
.687 .698 .855 r
.74356 5.29411 m .74642 5.08052 L .25358 5.08052 L p F P
0 g
s
.687 .698 .855 r
.25358 5.08052 m .25644 5.29411 L .5 5.29411 L p F P
0 g
s
.745 .608 .039 r
.24458 5.46167 m .25644 5.29411 L p .22802 5.41523 L F P
0 g
s
.745 .608 .039 r
.25644 5.29411 m .25358 5.08052 L .22802 5.41523 L p F P
0 g
s
0 0 .039 r
.74642 5.08052 m .74356 5.29411 L .75542 5.46167 L p F P
0 g
s
.406 .111 .348 r
.81175 3.26673 m .81025 3.21864 L p .72601 3.43512 L F P
0 g
s
.717 .897 .961 r
.42493 2.85252 m .60732 2.75438 L .53332 2.63021 L p F P
0 g
s
.717 .897 .961 r
.53332 2.63021 m .34727 2.73112 L .42493 2.85252 L p F P
0 g
s
.406 .111 .348 r
.72601 3.43512 m .81554 3.38867 L .81175 3.26673 L p F P
0 g
s
0 0 .039 r
.77198 5.41523 m .74642 5.08052 L p .75542 5.46167 L F P
0 g
s
.412 0 0 r
.74642 5.08052 m .77198 5.41523 L .22802 5.41523 L p F P
0 g
s
.412 0 0 r
.22802 5.41523 m .25358 5.08052 L .74642 5.08052 L p F P
0 g
s
.223 0 .081 r
.81554 3.38867 m .72601 3.43512 L .77161 3.55273 L p F P
0 g
s
.223 0 .081 r
.82093 3.47758 m .81554 3.38867 L p .77161 3.55273 L F P
0 g
s
.663 .955 .947 r
.34727 2.73112 m .53332 2.63021 L .47188 2.53589 L p F P
0 g
s
.663 .955 .947 r
.47188 2.53589 m .28053 2.64031 L .34727 2.73112 L p F P
0 g
s
.223 0 .081 r
.77161 3.55273 m .82385 3.52582 L .82093 3.47758 L p F P
0 g
s
.016 0 0 r
.82385 3.52582 m .77161 3.55273 L .7949 3.63709 L p F P
0 g
s
.016 0 0 r
.83233 3.59636 m .82385 3.52582 L p .7949 3.63709 L F P
0 g
s
.745 .608 .039 r
.22802 5.41523 m .2315 5.6464 L .24458 5.46167 L p F P
0 g
s
0 0 .039 r
.75542 5.46167 m .7685 5.6464 L .77198 5.41523 L p F P
0 g
s
.5 5.46167 m
.50299 5.41523 L
s
.549 .93 .849 r
.28053 2.64031 m .47188 2.53589 L .42933 2.4821 L p F P
0 g
s
.549 .93 .849 r
.42933 2.4821 m .23133 2.59054 L .28053 2.64031 L p F P
0 g
s
.01 w
.38937 2.41909 Mdot
.61063 2.41909 Mdot
.5 Mabswid
.016 0 0 r
.7949 3.63709 m .83477 3.61665 L .83233 3.59636 L p F P
0 g
s
0 0 0 r
.83477 3.61665 m .7949 3.63709 L .7915 3.67714 L p F P
0 g
s
0 0 0 r
.84423 3.64008 m .83477 3.61665 L p .7915 3.67714 L F P
0 g
s
.378 .816 .665 r
.23133 2.59054 m .42933 2.4821 L .41173 2.47832 L p F P
0 g
s
.378 .816 .665 r
.41173 2.47832 m .20622 2.59095 L .23133 2.59054 L p F P
0 g
s
.682 .71 .869 r
.5 5.6464 m .2315 5.6464 L .22802 5.41523 L p F P
0 g
s
.682 .71 .869 r
.77198 5.41523 m .7685 5.6464 L .5 5.6464 L p F P
0 g
s
.682 .71 .869 r
.22802 5.41523 m .77198 5.41523 L p .5 5.6464 L F P
0 g
s
0 0 0 r
.7915 3.67714 m .8476 3.64843 L .84423 3.64008 L p F P
0 g
s
.406 .845 .726 r
.8476 3.64843 m .7915 3.67714 L .75869 3.66377 L p F P
0 g
s
.406 .845 .726 r
.8557 3.6264 m .8476 3.64843 L p .75869 3.66377 L F P
0 g
s
0 0 0 r
.20622 2.59095 m .41173 2.47832 L .42385 2.53078 L p F P
0 g
s
0 0 0 r
.42385 2.53078 m .21064 2.6473 L .20622 2.59095 L p F P
0 g
s
.406 .845 .726 r
.75869 3.66377 m .86129 3.61119 L .8557 3.6264 L p F P
0 g
s
.573 .939 .897 r
.86129 3.61119 m .75869 3.66377 L .69681 3.59238 L p F P
0 g
s
.573 .939 .897 r
.86631 3.569 m .86129 3.61119 L p .69681 3.59238 L F P
0 g
s
.076 0 0 r
.21064 2.6473 m .42385 2.53078 L .4676 2.63962 L p F P
0 g
s
.076 0 0 r
.4676 2.63962 m .24735 2.75923 L .21064 2.6473 L p F P
0 g
s
.573 .939 .897 r
.69681 3.59238 m .87441 3.50089 L .86631 3.569 L p F P
0 g
s
.677 .928 .971 r
.87441 3.50089 m .69681 3.59238 L .61051 3.46582 L p F P
0 g
s
.677 .928 .971 r
.87587 3.47708 m .87441 3.50089 L p .61051 3.46582 L F P
0 g
s
.677 .928 .971 r
.83631 3.3485 m .87949 3.41804 L .87587 3.47708 L p F P
0 g
s
.677 .928 .971 r
.61051 3.46582 m .83631 3.3485 L p .87587 3.47708 L F P
0 g
s
.308 0 .238 r
.24735 2.75923 m .4676 2.63962 L .54045 2.79643 L p F P
0 g
s
.308 0 .238 r
.54045 2.79643 m .31476 2.91784 L .24735 2.75923 L p F P
0 g
s
.01 w
.37334 2.50103 Mdot
.62666 2.50103 Mdot
.5 Mabswid
.701 .808 .932 r
.83631 3.3485 m .61051 3.46582 L .5092 3.29637 L p F P
0 g
s
.701 .808 .932 r
.5092 3.29637 m .73791 3.17621 L .83631 3.3485 L p F P
0 g
s
.505 .304 .542 r
.31476 2.91784 m .54045 2.79643 L .63462 2.98349 L p F P
0 g
s
.505 .304 .542 r
.63462 2.98349 m .40594 3.1051 L .31476 2.91784 L p F P
0 g
s
.641 .591 .783 r
.73791 3.17621 m .5092 3.29637 L .40594 3.1051 L p F P
0 g
s
.62396 3.53312 m
.63993 3.28472 L
s
.51267 5.26461 m
.62396 3.53312 L
s
.641 .591 .783 r
.40594 3.1051 m .63462 2.98349 L .73791 3.17621 L p F P
0 g
s
.25 Mabswid
0 0 m
.12768 5.99483 L
s
.12768 5.99483 m
.87232 5.99483 L
s
.87232 5.99483 m
1 0 L
s
1 0 m
0 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{133.688, 801.375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#4", "Text"],

Cell[CellGroupData[{

Cell["Hz2[[-4]]", "Input"],

Cell[BoxData[
    \(1.7374645454176607`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pretty[Chop[e2ni . eigenvectors2[\([\(-4\)]\)], 10^\(-4\)]]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
          {"\<\"optic\"\>", "0", "0", "0", "1.`", "0", "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Status["\<Plotting stage 2 mode 4\>"]\ ; 
    eigenplot[eigenvectors2[\([\(-4\)]\)],  .5, {0, \(-3\), \(- .25\)}, \ 
      floatmatrix2]\ ; Done[]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 7.06045 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-3.10065 7.20129 -0.140839 7.20129 [
[ 0 0 0 0 ]
[ 1 7.06045 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
.0146 7.06045 L
s
.0146 7.06045 m
.07649 6.39036 L
s
.07649 6.39036 m
.06541 .2361 L
s
.06541 .2361 m
0 0 L
s
1 0 m
.93459 .2361 L
s
.93459 .2361 m
.92351 6.39036 L
s
.92351 6.39036 m
.9854 7.06045 L
s
.9854 7.06045 m
1 0 L
s
0 0 m
.0146 7.06045 L
s
.0146 7.06045 m
.9854 7.06045 L
s
.9854 7.06045 m
1 0 L
s
1 0 m
0 0 L
s
.06541 .2361 m
.93459 .2361 L
s
.93459 .2361 m
.92351 6.39036 L
s
.92351 6.39036 m
.07649 6.39036 L
s
.07649 6.39036 m
.06541 .2361 L
s
0 0 m
1 0 L
1 7.06045 L
0 7.06045 L
closepath
clip
newpath
.5 Mabswid
.707 .593 .726 r
.5 6.52002 m .8429 6.52002 L p .1566 6.1822 L F P
0 g
s
.707 .593 .726 r
.8429 6.52002 m .8434 6.1822 L .1566 6.1822 L p F P
0 g
s
.707 .593 .726 r
.1566 6.1822 m .1571 6.52002 L .5 6.52002 L p F P
0 g
s
.745 .608 .039 r
.15109 6.60256 m .1571 6.52002 L p .14435 6.33843 L F P
0 g
s
.745 .608 .039 r
.1571 6.52002 m .1566 6.1822 L .14435 6.33843 L p F P
0 g
s
0 0 .039 r
.8434 6.1822 m .8429 6.52002 L .84891 6.60256 L p F P
0 g
s
0 0 .039 r
.85565 6.33843 m .8434 6.1822 L p .84891 6.60256 L F P
0 g
s
.405 0 0 r
.8434 6.1822 m .85565 6.33843 L .14435 6.33843 L p F P
0 g
s
.405 0 0 r
.14435 6.33843 m .1566 6.1822 L .8434 6.1822 L p F P
0 g
s
.15256 3.93932 m
.454 6.24998 L
s
.46554 6.33843 m
.5 6.60256 L
s
.816 .649 .675 r
.05609 3.53518 m .05599 3.58493 L p .25046 3.3286 L F P
0 g
s
.07729 3.36239 m
.09451 3.49435 L
s
.816 .649 .675 r
.05599 3.58493 m .26883 3.57467 L .25046 3.3286 L p F P
0 g
s
.10601 3.58252 m
.15256 3.93932 L
s
.816 .649 .675 r
.25046 3.3286 m .05652 3.33664 L .05609 3.53518 L p F P
0 g
s
.816 .715 .753 r
.05652 3.33664 m .25046 3.3286 L .26836 3.08722 L p F P
0 g
s
.804 .572 .586 r
.05948 3.81807 m .32193 3.80376 L .26883 3.57467 L p F P
0 g
s
.804 .572 .586 r
.26883 3.57467 m .05599 3.58493 L .05379 3.79302 L p F P
0 g
s
.804 .572 .586 r
.05379 3.79302 m .05948 3.81807 L p .26883 3.57467 L F P
0 g
s
.816 .715 .753 r
.05617 3.27863 m .05652 3.33664 L p .26836 3.08722 L F P
0 g
s
.816 .715 .753 r
.26836 3.08722 m .05507 3.09467 L .05617 3.27863 L p F P
0 g
s
.803 .778 .829 r
.05507 3.09467 m .26836 3.08722 L .32123 2.87199 L p F P
0 g
s
.745 .608 .039 r
.14435 6.33843 m .14488 6.68805 L .15109 6.60256 L p F P
0 g
s
0 0 .039 r
.84891 6.60256 m .85512 6.68805 L .85565 6.33843 L p F P
0 g
s
.774 .467 .466 r
.14171 4.01101 m .40542 3.99522 L .32193 3.80376 L p F P
0 g
s
.774 .467 .466 r
.32193 3.80376 m .05948 3.81807 L .14171 4.01101 L p F P
0 g
s
.803 .778 .829 r
.05457 3.06184 m .05507 3.09467 L p .32123 2.87199 L F P
0 g
s
.803 .778 .829 r
.32123 2.87199 m .05774 2.87966 L p .05457 3.06184 L F P
0 g
s
.763 .842 .911 r
.05774 2.87966 m .32123 2.87199 L .4049 2.70279 L p F P
0 g
s
.803 .778 .829 r
.05774 2.87966 m .05212 2.90323 L .05457 3.06184 L p F P
0 g
s
.7 .292 .271 r
.24688 4.14774 m .51232 4.13081 L .40542 3.99522 L p F P
0 g
s
.7 .292 .271 r
.40542 3.99522 m .14171 4.01101 L .24688 4.14774 L p F P
0 g
s
.763 .842 .911 r
.4049 2.70279 m .13975 2.70931 L .05774 2.87966 L p F P
0 g
s
.643 .89 .985 r
.13975 2.70931 m .4049 2.70279 L .5124 2.59648 L p F P
0 g
s
.01 w
.35003 2.55072 Mdot
.64997 2.55072 Mdot
.5 Mabswid
.481 0 0 r
.36578 4.21387 m .63324 4.19627 L .51232 4.13081 L p F P
0 g
s
.481 0 0 r
.51232 4.13081 m .24688 4.14774 L .36578 4.21387 L p F P
0 g
s
.707 .593 .726 r
.5 6.68805 m .14488 6.68805 L .14435 6.33843 L p F P
0 g
s
.707 .593 .726 r
.85565 6.33843 m .85512 6.68805 L .5 6.68805 L p F P
0 g
s
.707 .593 .726 r
.14435 6.33843 m .85565 6.33843 L p .5 6.68805 L F P
0 g
s
.643 .89 .985 r
.5124 2.59648 m .24524 2.60228 L .13975 2.70931 L p F P
0 g
s
.253 .758 .878 r
.24524 2.60228 m .5124 2.59648 L .63416 2.56514 L p F P
0 g
s
.707 .593 .726 r
.5 6.71723 m .85725 6.71723 L p .14222 6.36556 L F P
0 g
s
.707 .593 .726 r
.85725 6.71723 m .85778 6.36556 L .14222 6.36556 L p F P
0 g
s
.707 .593 .726 r
.14222 6.36556 m .14275 6.71723 L .5 6.71723 L p F P
0 g
s
.745 .608 .039 r
.13623 6.80689 m .14275 6.71723 L p .1289 6.5354 L F P
0 g
s
.745 .608 .039 r
.14275 6.71723 m .14222 6.36556 L .1289 6.5354 L p F P
0 g
s
0 0 .039 r
.85778 6.36556 m .85725 6.71723 L .86377 6.80689 L p F P
0 g
s
0 0 .039 r
.8711 6.5354 m .85778 6.36556 L p .86377 6.80689 L F P
0 g
s
.405 0 0 r
.85778 6.36556 m .8711 6.5354 L .1289 6.5354 L p F P
0 g
s
.405 0 0 r
.1289 6.5354 m .14222 6.36556 L .85778 6.36556 L p F P
0 g
s
.09 .649 .741 r
.48731 4.20071 m .75693 4.18301 L .63324 4.19627 L p F P
0 g
s
.09 .649 .741 r
.63324 4.19627 m .36578 4.21387 L .48731 4.20071 L p F P
0 g
s
.253 .758 .878 r
.63416 2.56514 m .36485 2.57077 L .24524 2.60228 L p F P
0 g
s
.383 0 0 r
.36485 2.57077 m .63416 2.56514 L .75862 2.61437 L p F P
0 g
s
.596 .902 .985 r
.59941 4.10691 m .87107 4.08972 L .75693 4.18301 L p F P
0 g
s
.596 .902 .985 r
.75693 4.18301 m .48731 4.20071 L .59941 4.10691 L p F P
0 g
s
.745 .608 .039 r
.1289 6.5354 m .12947 6.89989 L .13623 6.80689 L p F P
0 g
s
0 0 .039 r
.86377 6.80689 m .87053 6.89989 L .8711 6.5354 L p F P
0 g
s
.54816 6.45872 m
.86554 4.16414 L
s
.5 6.80689 m
.53755 6.5354 L
s
.383 0 0 r
.75862 2.61437 m .48723 2.62043 L .36485 2.57077 L p F P
0 g
s
.682 .24 .195 r
.48723 2.62043 m .75862 2.61437 L .87318 2.74176 L p F P
0 g
s
.76 .867 .927 r
.69018 3.93962 m .9636 3.92353 L .87107 4.08972 L p F P
0 g
s
.76 .867 .927 r
.87107 4.08972 m .59941 4.10691 L .69018 3.93962 L p F P
0 g
s
.86554 4.16414 m
.87403 4.1027 L
s
.682 .24 .195 r
.87318 2.74176 m .59997 2.74885 L .48723 2.62043 L p F P
0 g
s
.777 .45 .434 r
.59997 2.74885 m .87318 2.74176 L .96552 2.9362 L p F P
0 g
s
.81 .796 .839 r
.97011 3.8995 m .9636 3.92353 L p .74944 3.7146 L F P
0 g
s
.81 .796 .839 r
.9636 3.92353 m .69018 3.93962 L .74944 3.7146 L p F P
0 g
s
.81 .796 .839 r
.74944 3.7146 m .97341 3.70279 L .97011 3.8995 L p F P
0 g
s
.87403 4.1027 m
.92547 3.73082 L
s
.707 .594 .727 r
.5 6.89989 m .12947 6.89989 L .1289 6.5354 L p F P
0 g
s
.707 .594 .727 r
.8711 6.5354 m .87053 6.89989 L .5 6.89989 L p F P
0 g
s
.707 .594 .727 r
.1289 6.5354 m .8711 6.5354 L p .5 6.89989 L F P
0 g
s
.01 w
.34294 2.58599 Mdot
.65706 2.58599 Mdot
.5 Mabswid
.777 .45 .434 r
.96552 2.9362 m .69097 2.94483 L .59997 2.74885 L p F P
0 g
s
.812 .57 .572 r
.96552 2.9362 m .97196 2.96229 L .97402 3.14251 L p F P
0 g
s
.812 .57 .572 r
.69097 2.94483 m .96552 2.9362 L p .97402 3.14251 L F P
0 g
s
.825 .727 .756 r
.97374 3.65147 m .97341 3.70279 L p .77025 3.45504 L F P
0 g
s
.825 .727 .756 r
.97341 3.70279 m .74944 3.7146 L .77025 3.45504 L p F P
0 g
s
.825 .727 .756 r
.77025 3.45504 m .97505 3.44571 L .97374 3.65147 L p F P
0 g
s
.92547 3.73082 m
.95829 3.49352 L
s
.812 .57 .572 r
.97402 3.14251 m .97445 3.18026 L p .69097 2.94483 L F P
0 g
s
.812 .57 .572 r
.97445 3.18026 m .74999 3.18884 L .69097 2.94483 L p F P
0 g
s
.825 .655 .671 r
.74999 3.18884 m .97445 3.18026 L .97491 3.38185 L p F P
0 g
s
.825 .655 .671 r
.97491 3.38185 m .97505 3.44571 L p .74999 3.18884 L F P
0 g
s
.825 .655 .671 r
.97505 3.44571 m .77025 3.45504 L .74999 3.18884 L p F P
0 g
s
.25 Mabswid
0 0 m
.0146 7.06045 L
s
.0146 7.06045 m
.9854 7.06045 L
s
.9854 7.06045 m
1 0 L
s
1 0 m
0 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{110.938, 783.25},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#5", "Text"],

Cell[CellGroupData[{

Cell["Hz2[[-5]]", "Input"],

Cell[BoxData[
    \(5.521318432045177`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pretty[Chop[e2ni . eigenvectors2[\([\(-5\)]\)], 10^\(-4\)]]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
          {"\<\"optic\"\>", "0", "0", \(-1.`\), "0", "0", "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Status["\<Plotting stage 2 mode 5\>"]\ ; 
    eigenplot[
      eigenvectors2[\([\(-5\)]\)], \(- .2\), {0, \(-1\), \(- .25\)}, \ 
      floatmatrix2]\ ; Done[]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 5.99483 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.6256 6.25121 -4.44089e-16 6.25121 [
[ 0 0 0 0 ]
[ 1 5.99483 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
.12768 5.99483 L
s
.12768 5.99483 m
.23891 4.75775 L
s
.23891 4.75775 m
.18195 .67458 L
s
.18195 .67458 m
0 0 L
s
1 0 m
.81805 .67458 L
s
.81805 .67458 m
.76109 4.75775 L
s
.76109 4.75775 m
.87232 5.99483 L
s
.87232 5.99483 m
1 0 L
s
0 0 m
.12768 5.99483 L
s
.12768 5.99483 m
.87232 5.99483 L
s
.87232 5.99483 m
1 0 L
s
1 0 m
0 0 L
s
.18195 .67458 m
.81805 .67458 L
s
.81805 .67458 m
.76109 4.75775 L
s
.76109 4.75775 m
.23891 4.75775 L
s
.23891 4.75775 m
.18195 .67458 L
s
0 0 m
1 0 L
1 5.99483 L
0 5.99483 L
closepath
clip
newpath
.01 w
.40334 5.07891 Mdot
.59666 5.07891 Mdot
.39133 5.47992 Mdot
.60867 5.47992 Mdot
.38937 2.41909 Mdot
.61063 2.41909 Mdot
.37334 2.50103 Mdot
.62666 2.50103 Mdot
.25 Mabswid
0 0 m
.12768 5.99483 L
s
.12768 5.99483 m
.87232 5.99483 L
s
.87232 5.99483 m
1 0 L
s
1 0 m
0 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{133.688, 801.375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#6", "Text"],

Cell[CellGroupData[{

Cell["Hz2[[-6]]", "Input"],

Cell[BoxData[
    \(7.790049616529068`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pretty[Chop[e2ni . eigenvectors2[\([\(-6\)]\)], 10^\(-4\)]]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
          {"\<\"optic\"\>", "0", "0.0030969584546009245`", "0", "0", 
            "0", \(-0.9999952044126665`\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Status["\<Plotting stage 2 mode 6\>"]\ ; 
    eigenplot[
      eigenvectors2[\([\(-6\)]\)], \(- .2\), {\(-1\), 0, \(- .25\)}, \ 
      floatmatrix2]\ ; Done[]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 2.05714 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.622713 2.24543 0 2.24543 [
[ 0 0 0 0 ]
[ 1 2.05714 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
1 0 m
.88819 2.05714 L
s
.88819 2.05714 m
.11181 2.05714 L
s
.11181 2.05714 m
0 0 L
s
0 0 m
1 0 L
s
.93098 .0853 m
.06902 .0853 L
s
.06902 .0853 m
.15474 1.89797 L
s
.15474 1.89797 m
.84526 1.89797 L
s
.84526 1.89797 m
.93098 .0853 L
s
1 0 m
.88819 2.05714 L
s
.88819 2.05714 m
.84526 1.89797 L
s
.84526 1.89797 m
.93098 .0853 L
s
.93098 .0853 m
1 0 L
s
0 0 m
.06902 .0853 L
s
.06902 .0853 m
.15474 1.89797 L
s
.15474 1.89797 m
.11181 2.05714 L
s
.11181 2.05714 m
0 0 L
s
0 0 m
1 0 L
1 2.05714 L
0 2.05714 L
closepath
clip
newpath
.5 Mabswid
.785 .641 .083 r
.28712 2.00581 m .30132 1.9132 L p .28084 1.99612 L F P
0 g
s
.785 .641 .083 r
.30132 1.9132 m .30025 1.87403 L .28084 1.99612 L p F P
0 g
s
.689 .692 .848 r
.44019 1.9132 m .48472 1.9132 L .48463 1.87403 L p F P
0 g
s
.689 .692 .848 r
.30025 1.87403 m .30132 1.9132 L .44019 1.9132 L p F P
0 g
s
.689 .692 .848 r
.48463 1.87403 m .30025 1.87403 L p .44019 1.9132 L F P
0 g
s
0 0 .083 r
.70205 1.7896 m .69868 1.9132 L .70302 1.94152 L p F P
0 g
s
.689 .692 .848 r
.55981 1.9132 m .69868 1.9132 L .70205 1.7896 L p F P
0 g
s
.689 .692 .848 r
.51554 1.7896 m .51528 1.9132 L .55981 1.9132 L p F P
0 g
s
.714 .583 .006 r
.48463 1.87403 m .48472 1.9132 L .48362 2.00581 L p F P
0 g
s
0 0 .006 r
.51562 1.94152 m .51528 1.9132 L p .51707 1.90493 L F P
0 g
s
0 0 .006 r
.51528 1.9132 m .51554 1.7896 L .51707 1.90493 L p F P
0 g
s
.689 .692 .848 r
.70205 1.7896 m .51554 1.7896 L p .55981 1.9132 L F P
0 g
s
.423 0 0 r
.30025 1.87403 m .48463 1.87403 L .48314 1.99612 L p F P
0 g
s
.423 0 0 r
.48314 1.99612 m .28084 1.99612 L .30025 1.87403 L p F P
0 g
s
.714 .583 .006 r
.48314 1.99612 m .48463 1.87403 L p .48362 2.00581 L F P
0 g
s
0 0 .083 r
.72194 1.90493 m .70205 1.7896 L p .70302 1.94152 L F P
0 g
s
.401 0 0 r
.51554 1.7896 m .70205 1.7896 L .72194 1.90493 L p F P
0 g
s
.401 0 0 r
.72194 1.90493 m .51707 1.90493 L .51554 1.7896 L p F P
0 g
s
0 0 .083 r
.70302 1.94152 m .71788 2.03836 L .72194 1.90493 L p F P
0 g
s
0 0 .006 r
.51707 1.90493 m .51676 2.03836 L .51562 1.94152 L p F P
0 g
s
.27446 1.35732 m
.37429 1.93224 L
s
.62855 1.84456 m
.72658 1.32116 L
s
.61258 1.92981 m
.61724 1.90493 L
s
.714 .583 .006 r
.48362 2.00581 m .48324 2.03836 L .48314 1.99612 L p F P
0 g
s
.785 .641 .083 r
.28084 1.99612 m .28212 2.03836 L .28712 2.00581 L p F P
0 g
s
.685 .703 .861 r
.43442 2.03836 m .28212 2.03836 L p .48314 1.99612 L F P
0 g
s
.685 .703 .861 r
.28212 2.03836 m .28084 1.99612 L .48314 1.99612 L p F P
0 g
s
.685 .703 .861 r
.48314 1.99612 m .48324 2.03836 L .43442 2.03836 L p F P
0 g
s
.685 .703 .861 r
.56558 2.03836 m .51676 2.03836 L p .72194 1.90493 L F P
0 g
s
.685 .703 .861 r
.51676 2.03836 m .51707 1.90493 L .72194 1.90493 L p F P
0 g
s
.685 .703 .861 r
.72194 1.90493 m .71788 2.03836 L .56558 2.03836 L p F P
0 g
s
.218 0 0 r
.55262 1.34412 m .55043 1.31389 L .47774 1.31685 L p F P
0 g
s
.218 0 0 r
.47774 1.31685 m .47677 1.34719 L .55262 1.34412 L p F P
0 g
s
.424 0 0 r
.47677 1.34719 m .47774 1.31685 L .40745 1.29836 L p F P
0 g
s
0 0 0 r
.62415 1.319 m .61896 1.28973 L .55043 1.31389 L p F P
0 g
s
0 0 0 r
.55043 1.31389 m .55262 1.34412 L .62415 1.319 L p F P
0 g
s
.424 0 0 r
.40745 1.29836 m .40342 1.32796 L .47677 1.34719 L p F P
0 g
s
.599 .036 0 r
.40342 1.32796 m .40745 1.29836 L .34594 1.25994 L p F P
0 g
s
0 0 0 r
.68484 1.2739 m .67708 1.24637 L .61896 1.28973 L p F P
0 g
s
0 0 0 r
.61896 1.28973 m .62415 1.319 L .68484 1.2739 L p F P
0 g
s
.599 .036 0 r
.34594 1.25994 m .3392 1.28802 L .40342 1.32796 L p F P
0 g
s
.727 .253 0 r
.3392 1.28802 m .34594 1.25994 L .29899 1.20485 L p F P
0 g
s
0 0 0 r
.72892 1.21265 m .71924 1.1875 L .67708 1.24637 L p F P
0 g
s
.75825 1.15205 m
.77558 1.05956 L
s
0 0 0 r
.67708 1.24637 m .68484 1.2739 L .72892 1.21265 L p F P
0 g
s
.727 .253 0 r
.29899 1.20485 m .29013 1.23071 L .3392 1.28802 L p F P
0 g
s
.793 .455 0 r
.29013 1.23071 m .29899 1.20485 L .2713 1.13793 L p F P
0 g
s
0 0 0 r
.75185 1.14066 m .74111 1.11837 L .71924 1.1875 L p F P
0 g
s
0 0 0 r
.71924 1.1875 m .72892 1.21265 L .75185 1.14066 L p F P
0 g
s
.72658 1.32116 m
.75825 1.15205 L
s
.793 .455 0 r
.2713 1.13793 m .26114 1.16103 L .29013 1.23071 L p F P
0 g
s
.24103 1.1648 m
.27446 1.35732 L
s
.792 .623 .063 r
.26114 1.16103 m .2713 1.13793 L .26602 1.06532 L p F P
0 g
s
0 0 .11 r
.75085 1.06462 m .74006 1.0454 L .74111 1.11837 L p F P
0 g
s
0 0 .11 r
.74111 1.11837 m .75185 1.14066 L .75085 1.06462 L p F P
0 g
s
.792 .623 .063 r
.26602 1.06532 m .25553 1.08538 L .26114 1.16103 L p F P
0 g
s
.722 .739 .224 r
.25553 1.08538 m .26602 1.06532 L .28426 .99404 L p F P
0 g
s
0 0 .27 r
.72537 .992 m .71558 .97577 L .74006 1.0454 L p F P
0 g
s
0 0 .27 r
.74006 1.0454 m .75085 1.06462 L .72537 .992 L p F P
0 g
s
.722 .739 .224 r
.28426 .99404 m .27449 1.01107 L .25553 1.08538 L p F P
0 g
s
0 0 0 r
.27449 1.01107 m .28426 .99404 L .32476 .93137 L p F P
0 g
s
.577 .119 0 r
.67735 .93031 m .6696 .91665 L .71558 .97577 L p F P
0 g
s
.577 .119 0 r
.71558 .97577 m .72537 .992 L .67735 .93031 L p F P
0 g
s
0 0 0 r
.32476 .93137 m .31677 .94567 L .27449 1.01107 L p F P
0 g
s
0 0 0 r
.31677 .94567 m .32476 .93137 L .38384 .88398 L p F P
0 g
s
.452 0 0 r
.61133 .88621 m .60644 .87442 L .6696 .91665 L p F P
0 g
s
.452 0 0 r
.6696 .91665 m .67735 .93031 L .61133 .88621 L p F P
0 g
s
0 0 0 r
.37851 .89619 m .38384 .88398 L .45559 .8571 L p F P
0 g
s
0 0 0 r
.38384 .88398 m .37851 .89619 L .31677 .94567 L p F P
0 g
s
.271 0 0 r
.53401 .86466 m .53251 .85379 L .60644 .87442 L p F P
0 g
s
.271 0 0 r
.60644 .87442 m .61133 .88621 L .53401 .86466 L p F P
0 g
s
0 0 0 r
.45559 .8571 m .45354 .86812 L .37851 .89619 L p F P
0 g
s
.053 0 0 r
.45354 .86812 m .45559 .8571 L .53251 .85379 L p F P
0 g
s
.053 0 0 r
.53251 .85379 m .53401 .86466 L .45354 .86812 L p F P
0 g
s
.01 w
.63753 .85219 Mdot
.36247 .85219 Mdot
.64387 .86298 Mdot
.35613 .86298 Mdot
.25 Mabswid
1 0 m
.88819 2.05714 L
s
.88819 2.05714 m
.11181 2.05714 L
s
.11181 2.05714 m
0 0 L
s
0 0 m
1 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{203.375, 418.312},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003;0001XR000`400?l00000o`00003oboooool0
0<_o000000000ol0003oooooooooo`37ooooo`7o00000002o`000<Oooooo0_l000000003o`000?oo
oooo00000<Gooooo0Ol00001ooooo`7o000000001?l0003oooooooooool00033ooooo`03o`000?oo
oooooooo007o000000001?l0003oooooooooool00032ooooo`04o`000?ooooooooooooooo`7o0000
00001Ol0003ooooooooooooooooo00000<3ooooo00?o0000ooooooooool00_ooool1o`00000000?o
0000ooooooooool00_ooool00ol0003oooooooooo`2mooooo`03o`000?oooooooooo00;ooooo0Ol0
00000003o`000?oooooooooo00?ooooo00?o0000ooooooooool0^oooool00ol0003oooooooooo`03
ooooo`7o000000000ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;Wooooo00?o0000oooo
ooooool01?ooool1o`00000000?oooooo`000?ooool01?ooool00ol0003oooooooooo`2hooooo`03
o`000?oooooooooo00Cooooo0Ol00001ooooo`0000?oooooo`000?ooool01Oooool00ol0003ooooo
ooooo`2fooooo`03o`000?oooooooooo00Gooooo0Ol00001ooooo`0000?oooooo`000?ooool01_oo
ool00ol0003oooooooooo`2eooooo`03o`000?oooooooooo00Gooooo0Ol00001ooooo`0000?ooooo
o`000?ooool01oooool00ol0003oooooooooo`2cooooo`03o`000?oooooooooo00Kooooo0Ol00001
ooooo`0000?oooooo`000?ooool01oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo
00Oooooo0Ol00001ooooo`0000?oooooo`000?ooool02?ooool00ol0003oooooooooo`2`ooooo`03
o`000?oooooooooo00Sooooo0Ol00001ooooo`0000?oooooo`000?ooool02Oooool00ol0003ooooo
ooooo`2^ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`0000?oooooo`000?ooool02_oo
oon`o`0000cooooo0Ol00001ooooo`0000?oooooo`000?ooool02_ooool00ol0003oooooooooo`2/
ooooo`03o`000?oooooooooo00[ooooo0Ol00001ooooo`0000?oooooo`000?ooool02_ooool00ol0
003oooooooooo`2/ooooo`03o`000?oooooooooo00[ooooo0Ol00001ooooo`0000?oooooo`000?oo
ool02_ooool00ol0003oooooooooo`2/ooooo`03o`000?oooooooooo00[ooooo0Ol00001ooooo`00
00?oooooo`000?ooool02_ooool00ol0003oooooooooo`2/ooooo`03o`000?oooooooooo00[ooooo
0Ol00001ooooo`0000?oooooo`000?ooool02_ooool00ol0003oooooooooo`2/ooooo`03o`000?oo
oooooooo00[ooooo0Ol00001ooooo`0000?oooooo`000?ooool02_ooool00ol0003oooooooooo`2/
ooooo`03o`000?oooooooooo00[ooooo0Ol00001ooooo`0000?oooooo`000?ooool02_ooool00ol0
003oooooooooo`2/ooooo`03o`000?oooooooooo00[ooooo0Ol00001ooooo`0000?oooooo`000?oo
ool02_ooool00ol0003oooooooooo`2/ooooo`03o`000?oooooooooo00[ooooo0Ol00001ooooo`00
00?oooooo`000?ooool02_ooool00ol0003oooooooooo`2/ooooo`03o`000?oooooooooo00[ooooo
0Ol00001ooooo`0000?oooooo`000?ooool02_ooool00ol0003oooooooooo`2/ooooo`03o`000?oo
oooooooo00[ooooo0Ol00001ooooo`0000?oooooo`000?ooool02oooool00ol0003oooooooooo`2[
ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`7ooooo0002ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0Z_ooool00ol0003oooooooooo`0:ooooo`7o00000Oooool1oooo
o`000_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0:[ooooo00?o0000oooooooo
ool02_ooool1o`00007ooooo0Oooool000;ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`2Zooooo`03o`000?oooooooooo00[ooooo0Ol00001ooooo`7ooooo0002ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0Z_ooool00ol0003oooooooooo`0:ooooo`7o00000Ooo
ool1ooooo`000_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0:[ooooo00?o0000
ooooooooool02_ooool1o`00007ooooo0Oooool000;ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`2Zooooo`03o`000?oooooooooo00[ooooo0Ol00001ooooo`7ooooo0002ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0Z_ooool00ol0003oooooooooo`0:ooooo`7o
00000Oooool1ooooo`000_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0:[ooooo
00?o0000ooooooooool02_ooool1o`00007ooooo0Oooool000;ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo00[ooooo0Ol00001ooooo`7ooooo0002
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Z_ooool00ol0003oooooooooo`0:
ooooo`7o00000Oooool1ooooo`000_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
0:[ooooo00?o0000ooooooooool02_ooool1o`00007ooooo0Oooool000;ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo00[ooooo0Ol00001ooooo`7o
oooo0002ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Z_ooool00ol0003ooooo
ooooo`0:ooooo`7o00000Oooool1ooooo`000_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo0:[ooooo00?o0000ooooooooool02_ooool1o`00007ooooo0Oooool000;ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo00[ooooo0Ol00001
ooooo`7ooooo0002ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Z_ooool00ol0
003oooooooooo`0:ooooo`7o00000Oooool1ooooo`000_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo0:[ooooo00?o0000ooooooooool02_ooool1o`00007ooooo0Oooool000;ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool00Oooool000;ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`2Zooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00Oooool000?ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool00Oooool000?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Yoooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00Oooool000?ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`2Xooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool00Oooool000?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Xooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool00Oooool000?ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`2Xooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00Ooo
ool000?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Xooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool00Oooool000?ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`2Xooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00Oooool000?o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Xooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool00Oooool000?ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`2Xooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00Oooool000?ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`2Xooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool00Oooool000?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2X
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00Oooool000?ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`2Xooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool00Oooool000?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Xooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool00Oooool000?ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`2Xooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
0Oooool000?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Xooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool00Oooool000?ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`2Xooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00Oooool0
00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Xooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool00_ooool000?ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`2Xooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool000?ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Xooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool00_ooool000Cooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`2Xooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool000Cooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`2Xooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool00_ooool000Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Woooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool000Cooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`2Wooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool00_ooool000Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Wooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool00_ooool000Cooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`2Vooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_oo
ool000Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Vooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool00_ooool000Cooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`2Vooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool000Co
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Vooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool00_ooool000Cooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`2Vooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool000Cooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`2Vooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool00_ooool000Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2V
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool000Cooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`2Vooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool00_ooool000Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Vooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool000Cooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`2Vooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
0_ooool000Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Vooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool00oooool000Cooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`2Vooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool0
00Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Vooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool00oooool000Cooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`2Vooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool000Gooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Vooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool00oooool000Gooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`2Vooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool000Gooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`2Vooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool00oooool000Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Uoooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool000Gooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool00oooool000Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Uooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool00oooool000Gooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00ooo
ool000Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Tooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool00oooool000Gooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`2Tooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool000Go
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Tooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool00oooool000Gooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`2Tooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool000Gooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`2Tooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool00oooool000Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2T
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool000Gooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`2Tooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool00oooool000Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Tooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool000Gooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`2Tooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
1?ooool000Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Tooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool01?ooool000Gooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`2Tooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool0
00Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Tooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01?ooool000Kooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`2Tooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool000Kooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Tooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool01?ooool000Kooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`2Tooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool000Kooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`2Tooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool01?ooool000Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Toooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool000Kooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`2Sooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool01?ooool000Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Sooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool01?ooool000Kooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`2Sooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?oo
ool000Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Sooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool01?ooool000Kooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`2Sooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool000Ko
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Rooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool01?ooool000Kooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`2Rooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool000Kooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`2Rooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool01?ooool000Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2R
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool000Kooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`2Rooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool01Oooool000Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Rooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool000Kooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`2Rooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
1Oooool000Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Rooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool01Oooool000Kooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`2Rooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool0
00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Rooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01Oooool000Oooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`2Rooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool000Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Rooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool01Oooool000Oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`2Rooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool000Oooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`2Rooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool01Oooool000Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Roooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool000Oooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`2Qooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool01Oooool000Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Qooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool01Oooool000Oooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`2Qooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Ooo
ool000Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Qooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool01Oooool000Oooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`2Qooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool000Oo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Qooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01Oooool000Oooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`2Qooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool000Oooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`2Pooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool01_ooool000Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2P
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool000Oooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`2Pooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool01_ooool000Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Pooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool000Oooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`2Pooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
1_ooool000Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Pooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool01_ooool000Sooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`2Pooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool0
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Pooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01_ooool000Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`2Pooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool000Sooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Pooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool01_ooool000Sooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`2Pooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool000Sooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`2Pooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool01_ooool000Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Poooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool000Sooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`2Pooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool01_ooool000Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Oooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool01_ooool000Sooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`2Oooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_oo
ool000Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Oooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool01_ooool000Sooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`2Oooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool000So
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Oooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`2Oooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool000Sooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`2Oooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01oooool000Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2N
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool000Sooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool01oooool000Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Nooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
1oooool000Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Nooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool01oooool000Wooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`2Nooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool0
00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01oooool000Wooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`2Nooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool000Wooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool01oooool000Wooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`2Nooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool000Wooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool01oooool000Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Noooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool000Wooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool01oooool000Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Mooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool01oooool000Wooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0`ooooo`;o00006_ooool:o`0001;ooooo0_l0000cooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool01oooool000Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0`ooooo`;o00004Oooool9o`0000Oo3@0000?o0000odD00?m500000ol0000?
ooooo`;o0000<oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0;oooool2o`0000oooooo1Ol0000?o`d0
0003o`000?m5003oA@0000;oA@000ol0000=ooooo`;o0000<_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0;oooool2o`0000gooooo6Ol00005odD000?o00002_ooool2o`0003;ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo03_ooooo1ol0000Eooooo`Co00001?m50003o`0003_ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo03Wooooo1_l0000Looooo`?o00001?m50002o`0003Wooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo03Kooooo1ol0000Qooooo`Go000000?oL`00o`000?ooool0=oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0=?ooool6o`0002Sooooo1Ol0000fooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0cooooo`Go
0000;Oooool01?l0003oL`00o`000?l0000cooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02?ooool000[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0booooo`?o
0000<Oooool2o`000003og<00?l0003ooooo037ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`08ooooo`002_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo033ooooo
0ol0000eooooo`04o`000?mc003o0000o`00033ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`08ooooo`002_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02oooooo
0ol0000gooooo`;o000000?oL`00o`000?l00000;_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Sooooo000:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0;_oo
ool3o`0003[ooooo0_l000000omc003o0000ooooo`0/ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02?ooool000[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0/
ooooo`Co0000?Oooool00ol0003oL`00o`00000/ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02?ooool000[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0[oooo
o`Co0000?oooool2o`0002cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08oooo
o`002_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02[ooooo0ol00013ooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`00
2_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02Wooooo0ol00015ooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`002_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02Wooooo0_l00016ooooo`;o0000:Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo000:ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0:?ooool2o`0004Sooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo000:ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool09_ooool2o`0004[ooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool09_ooool2o`0004_ooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool09Oooool2o`0004cooooo0_l0000Vooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool09?ooool2o`0004oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool08oooool2o`00057ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`1@ooooo`;o00008oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`09ooooo`002oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02Oooool000_ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo05Cooooo0_l0000Qooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02Oooool000_ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo05Gooooo0_l0000Pooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02Oooool000_ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo05Kooooo00?o0015o`000?ooool07_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo000;ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool07oooool2o`0005Sooooo0_l0000Oooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02Oooool000_ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Nooooo`;o0000FOooool2o`0001oooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`002oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01kooooo0_l0001J
ooooo`03o`00AOl0003ooooo01gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09
ooooo`002oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01kooooo0_l0001Joooo
o`;o00007_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo000;ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool07Oooool2o`0005_ooooo0_l0000Nooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool000_ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Mooooo`;o0000G?ooool00ol004Go0000ooooo`0Looooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool000_ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Mooooo`;o0000G?ooool00ol004Go0000ooooo`0Looooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02_ooool000_ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Mooooo`;o0000G?ooool2o`0001gooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0:ooooo`002oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
01cooooo0_l0001Nooooo`;o00007?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00[ooooo000;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06oooool2o`0005ko
oooo0_l0000Looooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool000_ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Kooooo`;o0000G_ooool2o`0001cooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`002oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo01[ooooo0_l0001Oooooo`?o00001?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool000_ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Jooooo`;o0000Goooool00ol0003o000Lo`000004
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:
ooooo`002oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01[ooooo0_l0001Ooooo
o`03o`000?l001co000000Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00[ooooo000;ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool06_ooool2o`0005oooooo00?o0000o`007?l000001?ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool000cooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Iooooo`?o0000Goooool00ol0003o000Lo`000003ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`003?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Wooooo00?o0000olZO4?l00000Gooo
ool00ol0003o000Lo`000003ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0:ooooo`003?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo01Wooooo00?o0000olZO4?l00000Goooool00ol0003o000Lo`000003ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`003?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo01Wooooo00?o0000olZO4?l00000Goooool00ol0
003o000Lo`000003ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0:ooooo`003?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Wo
oooo00?o0000olZO4?l00000Goooool00ol0003o000Lo`000003ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`003?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo01Wooooo00Co0000olZO4?o:Wa3o0000G_ooool00ol0003o
000Lo`000003ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0:ooooo`003?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Wooooo
00Co0000olZO4?o:Wa3o0000G_ooool01_l0003o000Lo`007?l0003oooooo`0001Oooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`003?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo01Wooooo00Co0000olZO4?o:Wa3o0000G_ooool3o`007003o`000?oooooo
000001Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`003?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo01Wooooo00Co0000olZO4?o:Wa3o0000G_ooool0
1_l0003o000Lo`007?l0003oooooo`0001Oooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0:ooooo`003?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Wooooo00Co
0000olZO4?o:Wa3o0000G_ooool01_l0003o000Lo`007?l0003oooooo`0001Oooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0;ooooo`003?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo01[ooooo00?o0000olZO4?l00000G_ooool2o`000004o`007?l0003oooooo`00
01Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`003?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo01[ooooo00?o0000olZO4?l00000GOooool5o`000003
ooooool0003ooooo01Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`00
3?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01[ooooo00?o0000olZO4?l00000
GOooool5o`000003ooooool0003ooooo01Kooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0;ooooo`003?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01[ooooo00?o
0000olZO4?l00000GOooool6o`0001Sooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0;ooooo`003?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Wooooo0_l00000
0oo;M03o0000ooooo`1Jooooo`Oo00006?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00_ooooo000<ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06Oooool2o`00
0003ol]d0?l0003ooooo05[ooooo1Ol000000ooooooo0000ooooo`0Gooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02oooool000cooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Iooooo`;o00000_o;M0000ol0003oooooooooo`1Hooooo`Go000000?oooooo`000?oo
ool05oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo000<ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool05Oooool01Ol0003ooooooooooooooooo000000?o
bg@000?o0000ooooooooool0F?ooool5o`000003ooooool0003ooooo01Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0;ooooo`003?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo01Gooooo00Go0000ooooooooooooooooo`000003ol]d0003o`000?oooooooooo05Oo
oooo1Ol00002ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0;ooooo`003Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool00_ooool01Ol0003obg@0ol]d0?o;M03o000005Sooooo1Ol000000ooooooo
0000ooooo`0Hooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02oooool000gooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00;ooooo
00Go0000ol]d0?o;M03obg@0o`00001Hooooo`Go000000?oooooo`000?ooool06?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00_ooooo000=ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`02ooooo`05o`000?o;M03obg@0ol]d0?l0
0000E_ooool5o`0000;ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00_ooooo000=ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`02ooooo`05o`000?o;M03obg@0ol]d0?l00000E_ooool5o`0000;o
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_o
oooo000=ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?o;M03obg@000;obg@000?o0000ooooooooool0Doooool5o`0000;ooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo
000=ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`03ooooo`05o`000?o;M03obg@0ol]d0?l00000E?ooool5o`0000;ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo000=ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`03ooooo`05o`000?o;
M03obg@0ol]d0?l00000Doooool6o`0000;ooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00_ooooo000=ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`03ooooo`05o`000?o;M03obg@0ol]d0?l00000
D_ooool6o`0000;ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00_ooooo000=ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`03ooooo`05o`000?o;M03obg@0ol]d0?l00000DOooool6o`0000?ooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00cooooo
000=ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`04ooooo`05o`000?o;M03o0000okY00?l00000Coooool7o`0000?ooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`04ooooo`03o`000?o;
M03o000000;o^T0000?o0000ooooooooool0C?ooool6o`0000Cooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`04ooooo`03o`000?o;M03o
000000?o^T0000?o0000ooooooooool0B_ooool6o`0000Cooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`05ooooo`03o`000?nj@03o^T00
00?o^T0000?o0000ooooooooool0B?ooool6o`0000Gooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`04ooooo`03o`000?nj@03o^T0000Co
^T0000?o0000ooooooooool0Aoooool6o`0000Gooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`05ooooo`03o`000?nj@03o^T0000Co^T00
00?o0000ooooooooool0AOooool6o`0000Kooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`06ooooo`03o`000?nj@03o^T0000Co^T0000?o
0000ooooooooool0@_ooool7o`0000Oooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`07ooooo`03o`000?nj@03o^T0000Co^T0000?o0000
ooooooooool0@?ooool7o`0000Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`08ooooo`03o`000?nj@03o^T0000Co^T0000?o0000oooo
ooooool0?_ooool8o`0000Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`08ooooo`03o`000?nj@03o^T0000Co^T000_l0000looooo`Wo
00002?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool03?ooool000kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo00Wooooo00?o0000okY00?nj@0000onj@0001?l0003oV@T0o`000?l0000iooooo`Wo
00002Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool03?ooool000kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo00[ooooo00Go0000okY00?nj@03o^T00o`000004oiT90003o`000?oooooooooo03Go
oooo2Ol0000:ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool02oooool01?l0003o^T00okY00?l00005oiT900;o0000<oooool9o`0000co
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00co
oooo000>ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?nj@03o000000OoV@T00_l0000`ooooo`Wo00003?ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03?ooool000kooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00gooooo0_l0
0009oiT90003o`000?oooooooooo02cooooo2Ol0000=ooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool03_ooool00ol0003oV@T0oiT90007
oiT900;o0000:_ooool:o`0000kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0?ooooo`;o00002OnI2@03o`0002Cooooo3?l0000?oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0<oooo
o`003_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool04Oooool2o`0000OoV@T000?o0000of`00?m/00000ol0000Nooooo`go00004Oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03Oooool000kooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01?ooooo
00?o0000oiT90?nI2@001?nI2@000ol0003oK000of`00003of`000Co00005oooool?o`0001;ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo
000>ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Dooooo`;o00001?nI2@000ol0003oK000of`00007of`000?o00004OoooolAo`0001;ooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo000>
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0F
ooooo`;o000000?oV@T0o`000?m/00003?m/000Qo`0001?ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00gooooo000>ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Gooooo`;o00003_m/00000ol0
003o=`00ocL0000<ocL0013o00005?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool03Oooool000kooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo01Sooooo0ol0000<of`00003o`000?lg003o=`0000co
=`003_l0000Fooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0=ooooo`003_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool06oooool4o`0000SoK00000?o0000ocL00?lg00003?lg000;o`0001Wooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00gooooo
000>ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Oooooo`?o00001Om/00000ol0003o=`00ocL0000<ocL000So00007?ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03Oooool000kooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02;ooooo1?l00000
0om/003o0000ocL0000=ocL000Go00007_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool03Oooool000kooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo02Gooooo4_l0000Qooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0=ooooo`003_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0F?ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03Oooool000kooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05Sooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00gooooo
000?ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`1Hooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0=ooooo`003oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool0Eoooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool03Oooool000oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo05Oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00gooooo000?ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0=ooooo`003oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool03Oooool000oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00gooooo000?ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0>ooooo`003oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0EOooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool000oo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05Go
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00ko
oooo000?ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`1Dooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0>ooooo`003oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool0E?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool03_ooool000oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00kooooo000?ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0>ooooo`003oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool03_ooool000oooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00kooooo000?ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Booooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0>ooooo`003oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0D_ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03_ooool0
00oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
057ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00kooooo000?ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`1Aooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0>ooooo`004?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool0DOooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool03_ooool0013ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00kooooo000@ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0>ooooo`004?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03_ooool0013ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04oooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00kooooo000@ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1?ooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`004?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0Cooo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03ooo
ool0013ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo04kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00oooooo000@ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`1=ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0?ooooo`004?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool03oooool0013ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00oooooo000@ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`004?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03oooool0013ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo04cooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo000@ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1;ooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`00
4?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
Boooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
3oooool0013ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo04_ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00oooooo000@ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`1;ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0?ooooo`004?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool03oooool0017ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00oooooo000Aooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0?ooooo`004Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0BOooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03oooool0017ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo04Wooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00oooooo000Aoooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`19oooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0?oooo
o`004Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool0B?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool04?ooool0017ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo04Oooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo013ooooo000Aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0@ooooo`004Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool04?ooool0017ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo013ooooo000Aooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0@ooooo`004Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0A_ooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04?ooool0017ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo04Gooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo013ooooo000A
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`15
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0@
ooooo`004Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool0AOooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool04?ooool0017ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo04Gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo013ooooo000Aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0@ooooo`004Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool04?ooool0017ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo013ooooo000Booooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0@ooooo`004_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0@oooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04?ooool001;ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo04;ooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo013ooooo
000Booooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`12ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0@ooooo`004_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool0@Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool04Oooool001;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo047ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo017ooooo000Booooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Aooooo`004_ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool04Oooool001;ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo017ooooo000Booooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Aooooo`004_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0?oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04Oooool001;o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03oo
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo017o
oooo000Booooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`0oooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Aooooo`004_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool04Oooool001;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo017ooooo000Booooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Aooooo`004_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool04Oooool001;ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo017ooooo000Booooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0looooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Aooooo`004oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0??ooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04Oooool0
01?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
03cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
017ooooo000Cooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`0looooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Aooooo`004oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool04_ooool001?ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo01;ooooo000Cooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Booooo`004oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool001?ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03[ooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo000Cooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0jooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`004ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>Ooo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_oo
ool001?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo03Sooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01;ooooo000Cooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0OooooobOo00007Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
01;ooooo000Cooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0Oooooo`03o`000?mV003oIP0001KoIP0000?o0000ofH00?mV00002_mV00000ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool001?ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01oooooo
00?o0000ofH00?mV00005_mV00000ol0003oIP00ofH0000:ofH00003o`000?oooooooooo01_ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`004oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07oooool00ol0003oIP00ofH0
000FofH00003o`000?mV003oIP0000[oIP0000?o0000ooooooooool06oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo01;ooooo000Cooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`03o`000?mV003oIP0001GoIP0000?o0000
ofH00?mV00003?mV00000ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool04_ooool001?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo01kooooo00?o0000ofH00?mV00005OmV00000ol0003oIP00ofH0000<ofH0
0003o`000?oooooooooo01[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Boooo
o`004oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool07_ooool00ol0003oIP00ofH0000EofH00003o`000?mV003oIP0000coIP0000?o0000oooooooo
ool06_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo000Cooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Nooooo`03o`00
0?mV003oIP0001GoIP0000?o0000ofH00?mV00003?mV00000ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool04_ooool001Cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo00?o0000ofH00?mV00005OmV
00000ol0003oIP00ofH0000<ofH00003o`000?oooooooooo01[ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Booooo`005?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool07_ooool00ol0003oIP00ofH0000DofH00003o`000?mV003o
IP0000goIP0000?o0000ooooooooool06_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01;ooooo000Dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0Mooooo`03o`000?mV003oIP0001CoIP0000?o0000ofH00?mV00003_mV00000ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04oooool001Co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01go
oooo00?o0000ofH00?mV00005?mV00000ol0003oIP00ofH0000>ofH00003o`000?oooooooooo01Wo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Cooooo`005?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07Oooool00ol0003oIP00
ofH0000UofH00003o`000?oooooooooo01Sooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Cooooo`005?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool07Oooool00ol0003oIP00ofH0000UofH00003o`000?oooooooooo01Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Cooooo`005?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07Oooool00ol0003oIP00ofH0000U
ofH00003o`000?oooooooooo01Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0C
ooooo`005?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool07?ooool00ol0003oIP00ofH0000VofH00003o`000?oooooooooo01Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Cooooo`005?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool07?ooool00ol0003oIP00ofH0000VofH00003
o`000?oooooooooo01Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Cooooo`00
5?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01[ooooo9ol00005ooooo`03o`00
0?mV003oIP0002KoIP0000?o0000ooooooooool05oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01?ooooo000Dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06_oo
ool00ol0003oK000of`0000:of`00003o`000?m/003oK00001KoK00000?o0000ooooooooool00ooo
ool00ol0003oIP00ofH0000VofH00003o`000?oooooooooo01Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Cooooo`005?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo01[ooooo00?o0000of`00?m/00002_m/00000ol0003oK000of`0000Fof`00003o`000?oooooo
oooo00?ooooo00?o0000ofH00?mV00009_mV00000ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool04oooool001Cooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Jooooo`03o`000?m/003oK00000[oK00000?o0000of`00?m/00005_m/00000ol0
003oooooooooo`03ooooo`03o`000?mV003oIP0002KoIP0000?o0000ooooooooool05oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo01?ooooo000Dooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool06Oooool00ol0003oK000of`0000<of`00003o`000?m/003oK00001Go
K00000?o0000ooooooooool00oooool00ol0003oIP00ofH0000WofH00003o`000?oooooooooo01Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Cooooo`005?ooool00ol0003ooooo
ooooo`08oooooago00003_m/00000ol0003oK000of`0000Eof`000Oo0000:OmV000Jo`0000Wooooo
00?o0000ooooooooool04oooool001Cooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Iooooo`03o`000?m/003oK00000coK00000?o0000of`00?m/00005Om/00000ol0003ooooooooo
o`03ooooob_o00006?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01?ooooo000D
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06Oooool00ol0003oK000of`0000<
of`00003o`000?m/003oK00001GoK00000?o0000ooooooooool00oooool00ol0003o[k?Lojncg00W
ojncg003o`000?oooooooooo01Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0C
ooooo`005?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01[ooooo00?o0000of`0
0?m/00003?m/00000ol0003oK000of`0000Eof`00003o`000?oooooooooo00?ooooo00?o0000ojnc
g?n_/m`09on_/m`00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool04oooool001Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Jooooo`03
o`000?m/003oK00000coK00000?o0000of`00?m/00005Om/00000ol0003oooooooooo`03ooooo`03
o`000?n_/mco[k?L02Oo[k?L00?o0000ooooooooool05oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo01?ooooo000Eooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
6Oooool00ol0003oK000of`0000>of`00003o`000?m/003oK00001CoK00000?o0000ooooooooool0
0oooool00ol0003o[k?Lojncg00Wojncg003o`000?oooooooooo01Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Cooooo`005Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01[ooooo00?o0000of`00?m/00003_m/00000ol0003oK000of`0000Dof`00003o`000?oo
oooooooo00?ooooo00?o0000ojncg?n_/m`09on_/m`00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool05?ooool001Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Jooooo`03o`000?m/003oK00000koK00000?o0000of`00?m/00005?m/0000
0ol0003oooooooooo`03ooooo`03o`000?n_/mco[k?L02Oo[k?L00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Cooooo000Eooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool06_ooool00ol0003oK000of`0000Tof`000;o00001Oooool00ol0
003o[k?Lojncg00Wojncg003o`000?oooooooooo01Sooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Dooooo`005Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01[o
oooo00?o0000of`00?m/00009?m/0002o`0000Gooooo00?o0000ojncg?n_/m`09on_/m`00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05?ooool001Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Kooooo`03o`000?m/003oK00002CoK000
0_l00005ooooo`03o`000?n_/mco[k?L02Oo[k?L00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo01Cooooo000Eooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool06oooool00ol0003oK000of`0000Tof`000;o00001Oooool00ol0003o[k?Lojnc
g00Wojncg003o`000?oooooooooo01Wooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Dooooo`005Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01[ooooo00?o0000
of`00?m/00009Om/0002o`0000Gooooo00?o0000ojncg?n_/m`09on_/m`00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05?ooool001Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Kooooo`03o`000?m/003oK00002GoK00000?o0000oooo
ooooool01?ooool00ol0003o[k?Lojncg00Wojncg003o`000?oooooooooo01Wooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Dooooo`005Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo01_ooooo00?o0000of`00?m/00009Om/00000ol0003oooooooooo`04ooooo`03
o`000?n_/mco[k?L02Oo[k?L00?o0000ooooooooool06Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo01Cooooo000Eooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
6oooool00ol0003oK000of`0000Uof`00003o`000?oooooooooo00Cooooo00?o0000ojncg?n_/m`0
9_n_/m`00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
5?ooool001Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Kooooo`03o`000?m/
003oK00002GoK00000?o0000ooooooooool01?ooool00ol0003o[k?Lojncg00Vojncg003o`000?oo
oooooooo01_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Dooooo`005Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01cooooo00?o0000of`00?m/00009Om/0000
0ol0003oooooooooo`04ooooo`03o`000?n_/mco[k?L02Ko[k?L00?o0000ooooooooool06oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Cooooo000Eooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool06oooool00ol0003oK000of`0000Vof`00003o`000?oooooooooo
00Cooooo00?o0000ojncg?n_/m`09_n_/m`00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool05?ooool001Gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Kooooo`03o`000?m/003oK00002KoK00000?o0000ooooooooool01?ooool00ol0003o
[k?Lojncg00Vojncg003o`000?oooooooooo01cooooo00Go0000ooooooooooooooooo`00000Foooo
o`005Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01_ooooo:_l00006ooooo`03
o`000?n_/mco[k?L02Ko[k?L00?o0000ooooooooool07?ooool01Ol0003ooooooooooooooooo0000
01Kooooo000Eooooo`05o`000?ooooooooooooooool000007_ooool00ol0003o[k?Lojncg00Vojnc
g003o`000?oooooooooo00Cooooo00?o0000ojncg?n_/m`09_n_/m`00ol0003oooooooooo`0Loooo
o`05o`000?ooooooooooooooool000005_ooool001Gooooo00Go0000ooooooooooooooooo`00000N
ooooo`03o`000?n_/mco[k?L02Ko[k?L00?o0000ooooooooool01?ooool00ol0003o[k?Lojncg00V
ojncg003o`000?oooooooooo01cooooo00Go0000ooooooooooooooooo`00000Fooooo`005Oooool0
1Ol0003ooooooooooooooooo000001kooooo00?o0000ojncg?n_/m`09_n_/m`00ol0003ooooooooo
o`04ooooo`03o`000?n_/mco[k?L02Ko[k?L00?o0000ooooooooool07Oooool01?l0003ooooooooo
ool0000Fooooo`005_ooool00ol0003oooooo`00000Oooooo`03o`000?n_/mco[k?L02Ko[k?L00?o
0000ooooooooool01?ooool00ol0003o[k?Lojncg00Vojncg003o`000?oooooooooo01gooooo00?o
0000ooooool000005oooool001Kooooo00?o0000ooooool000008?ooool00ol0003o[k?Lojncg00U
ojncg003o`000?oooooooooo00Cooooo00?o0000ojncg?n_/m`09_n_/m`00ol0003oooooooooo`0M
ooooo`03o`000?oooooo000001Oooooo000Fooooo`03o`000?oooooo0000023ooooo00?o0000ojnc
g?n_/m`09On_/m`00ol0003oooooooooo`04ooooo`03o`000?n_/mco[k?L02Ko[k?L00?o0000oooo
ooooool07Oooool00ol0003oooooo`00000Gooooo`005_ooool00ol0003oooooo`00000Pooooo`03
o`000?n_/mco[k?L02Go[k?L00?o0000ooooooooool01?ooool00ol0003o[k?Lojncg00Vojncg003
o`000?oooooooooo01kooooo0_l0000Gooooo`005_ooool2o`00027ooooo00?o0000ojncg?n_/m`0
9_l00006ooooob[o00008?ooool2o`0001Oooooo000Fooooo`;o0000V_ooool2o`0001Oooooo000F
ooooo`;o0000V_ooool2o`0001Oooooo000Fooooo`03o`000?oooooooooo09[ooooo00?o0000oooo
ooooool05Oooool001KoooooW_l0000Gooooo`00\
\>"],
  ImageRangeCache->{{{0, 202.375}, {417.312, 0}} -> {0.277322, -0.00110357, \
0.00220063, 0.00220063}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Export as a state-space to Matlab/Simulink", "Text"],

Cell["Calculate[Stage2]", "Input"],

Cell["domatlabexport = True;", "Input"],

Cell[TextData[{
  "If[domatlabexport,\n\tMatlabExport[\n\t\t\"",
  StyleBox["twowiresimpleblades_\"<>modelcase<>\"",
    FontFamily->"Lucida Grande",
    FontWeight->"Plain"],
  ".m\",\n\t\t\
{\"mbtwsbA\",ssAspoiler[potentialmatrices2,kineticmatrix,1.0,0]},\n\t\t\
{\"mbtwsbB\",ssB[coupling2,kineticmatrix,1.0]},\n\t\t{\"mbtwsbC\",ssC},\n\t\t\
{\"mbtwsbD\",ssD}\n\t]\n]"
}], "Input"]
}, Open  ]]
},
FrontEndVersion->"5.0 for Macintosh",
ScreenRectangle->{{0, 1440}, {0, 874}},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{935, 715},
WindowMargins->{{22, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"]}, {None, Inherited, None}},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {36, 36}},
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False},
CellLabelAutoDelete->True,
DockedCells -> FEPrivate`FrontEndResource[ "FEExpressions", \
"CompatibilityToolbar"],
StyleDefinitions -> "Default.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 106, 3, 69, "Section"],

Cell[CellGroupData[{
Cell[1907, 60, 58, 0, 38, "Subsection"],
Cell[1968, 62, 118, 3, 32, "Text"],
Cell[2089, 67, 284, 8, 87, "Input"],

Cell[CellGroupData[{
Cell[2398, 79, 210, 4, 50, "Text"],
Cell[2611, 85, 105, 1, 27, "Input"],
Cell[2719, 88, 106, 3, 27, "Input"],
Cell[2828, 93, 1162, 22, 282, "Input"],
Cell[3993, 117, 45, 4, 57, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4075, 126, 193, 4, 50, "Text"],
Cell[4271, 132, 576, 10, 123, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[4884, 147, 174, 3, 47, "Text"],
Cell[5061, 152, 804, 13, 171, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[5902, 170, 43, 0, 29, "Text"],
Cell[5948, 172, 32, 0, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[6017, 177, 54, 0, 29, "Text"],
Cell[6074, 179, 40, 0, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[6151, 184, 61, 0, 29, "Text"],
Cell[6215, 186, 28, 0, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[6280, 191, 40, 0, 29, "Text"],
Cell[6323, 193, 220, 4, 42, "Input"],
Cell[6546, 199, 161, 3, 42, "Input"],
Cell[6710, 204, 109, 3, 27, "Input"],
Cell[6822, 209, 235, 4, 57, "Input"],
Cell[7060, 215, 151, 3, 42, "Input"],
Cell[7214, 220, 338, 6, 72, "Input"],
Cell[7555, 228, 299, 5, 57, "Input"],
Cell[7857, 235, 134, 3, 42, "Input"],
Cell[7994, 240, 155, 3, 42, "Input"],
Cell[8152, 245, 118, 3, 27, "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8319, 254, 37, 0, 38, "Subsection"],
Cell[8359, 256, 71, 0, 32, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[8467, 261, 68, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[8560, 265, 45, 0, 28, "Subsubsection"],
Cell[8608, 267, 2240, 58, 212, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10885, 330, 71, 0, 28, "Subsubsection"],
Cell[10959, 332, 1213, 25, 140, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12209, 362, 86, 1, 28, "Subsubsection"],
Cell[12298, 365, 380, 7, 50, "Text"],
Cell[12681, 374, 2662, 68, 248, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15380, 447, 52, 0, 28, "Subsubsection"],
Cell[15435, 449, 341, 6, 50, "Text"],
Cell[15779, 457, 1261, 30, 140, "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[17089, 493, 35, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[17149, 497, 136, 3, 32, "Text"],
Cell[17288, 502, 91, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17416, 508, 112, 3, 32, "Text"],
Cell[17531, 513, 939, 16, 219, "Input"],
Cell[18473, 531, 124, 2, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[18634, 538, 98, 2, 29, "Text"],
Cell[18735, 542, 86, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18858, 548, 171, 3, 32, "Text"],
Cell[19032, 553, 111, 3, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19180, 561, 59, 0, 32, "Text"],
Cell[19242, 563, 120, 6, 102, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[19399, 574, 114, 3, 29, "Text"],
Cell[19516, 579, 56, 0, 70, "Input"],
Cell[19575, 581, 58, 0, 70, "Input"],
Cell[19636, 583, 58, 0, 70, "Input"],
Cell[19697, 585, 58, 0, 70, "Input"],
Cell[19758, 587, 62, 0, 70, "Input"],
Cell[19823, 589, 56, 0, 70, "Input"],
Cell[19882, 591, 68, 0, 70, "Input"],
Cell[19953, 593, 60, 0, 70, "Input"],
Cell[20016, 595, 62, 0, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[20115, 600, 38, 0, 29, "Text"],
Cell[20156, 602, 57, 0, 27, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[20252, 607, 27, 0, 27, "Input"],

Cell[CellGroupData[{
Cell[20304, 611, 59, 0, 38, "Subsection"],
Cell[20366, 613, 35, 0, 27, "Input"],

Cell[CellGroupData[{
Cell[20426, 617, 74, 1, 32, "Text"],

Cell[CellGroupData[{
Cell[20525, 622, 136, 4, 27, "Input"],
Cell[20664, 628, 205, 3, 27, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[20918, 637, 54, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[20997, 641, 196, 12, 177, "Input"],
Cell[21196, 655, 582, 15, 133, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[21827, 676, 47, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[21899, 680, 214, 12, 70, "Input"],
Cell[22116, 694, 293, 9, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[22458, 709, 34, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[22517, 713, 108, 3, 70, "Input"],
Cell[22628, 718, 50, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22715, 724, 108, 3, 70, "Input"],
Cell[22826, 729, 50, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22913, 735, 94, 2, 70, "Input"],
Cell[23010, 739, 42, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23089, 745, 96, 2, 70, "Input"],
Cell[23188, 749, 42, 1, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[23279, 756, 51, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[23355, 760, 58, 0, 27, "Input"],
Cell[23416, 762, 76, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23529, 768, 58, 0, 27, "Input"],
Cell[23590, 770, 74, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23701, 776, 46, 0, 27, "Input"],
Cell[23750, 778, 55, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23842, 784, 48, 0, 27, "Input"],
Cell[23893, 786, 54, 1, 27, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[23996, 793, 50, 0, 32, "Text"],
Cell[24049, 795, 168, 6, 70, "Input"],
Cell[24220, 803, 129, 3, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[24386, 811, 41, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[24452, 815, 18, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[24495, 819, 27, 0, 27, "Input"],
Cell[24525, 821, 53, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24615, 827, 93, 1, 27, "Input"],
Cell[24711, 830, 465, 12, 53, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25213, 847, 245, 4, 27, "Input"],
Cell[25461, 853, 33101, 734, 278, 6767, 404, "GraphicsData", "PostScript", \
"Graphics"],
Cell[58565, 1589, 132, 3, 27, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[58746, 1598, 18, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[58789, 1602, 27, 0, 27, "Input"],
Cell[58819, 1604, 53, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[58909, 1610, 93, 1, 27, "Input"],
Cell[59005, 1613, 467, 12, 53, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[59509, 1630, 363, 6, 59, "Input"],
Cell[59875, 1638, 6852, 410, 294, 6729, 406, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[66730, 2050, 132, 3, 27, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[66911, 2059, 18, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[66954, 2063, 27, 0, 27, "Input"],
Cell[66984, 2065, 53, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[67074, 2071, 93, 1, 27, "Input"],
Cell[67170, 2074, 461, 12, 53, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[67668, 2091, 184, 3, 43, "Input"],
Cell[67855, 2096, 7845, 453, 296, 7724, 449, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[75749, 2555, 18, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[75792, 2559, 27, 0, 27, "Input"],
Cell[75822, 2561, 53, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[75912, 2567, 93, 1, 27, "Input"],
Cell[76008, 2570, 413, 11, 53, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[76458, 2586, 184, 3, 43, "Input"],
Cell[76645, 2591, 7786, 452, 296, 7661, 448, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[84480, 3049, 18, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[84523, 3053, 27, 0, 27, "Input"],
Cell[84553, 3055, 52, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[84642, 3061, 93, 1, 27, "Input"],
Cell[84738, 3064, 416, 11, 53, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[85191, 3080, 196, 4, 59, "Input"],
Cell[85390, 3086, 1512, 113, 296, 1391, 109, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[86951, 3205, 18, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[86994, 3209, 27, 0, 27, "Input"],
Cell[87024, 3211, 51, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[87112, 3217, 93, 1, 27, "Input"],
Cell[87208, 3220, 466, 12, 53, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[87711, 3237, 196, 4, 43, "Input"],
Cell[87910, 3243, 49743, 934, 296, 6534, 396, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[137726, 4185, 58, 0, 38, "Subsection"],
Cell[137787, 4187, 34, 0, 27, "Input"],

Cell[CellGroupData[{
Cell[137846, 4191, 74, 1, 32, "Text"],

Cell[CellGroupData[{
Cell[137945, 4196, 133, 3, 27, "Input"],
Cell[138081, 4201, 204, 3, 27, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[138334, 4210, 54, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[138413, 4214, 194, 12, 177, "Input"],
Cell[138610, 4228, 581, 15, 133, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[139240, 4249, 47, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[139312, 4253, 212, 12, 177, "Input"],
Cell[139527, 4267, 293, 9, 39, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[139869, 4282, 34, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[139928, 4286, 107, 3, 70, "Input"],
Cell[140038, 4291, 50, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[140125, 4297, 107, 3, 70, "Input"],
Cell[140235, 4302, 50, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[140322, 4308, 93, 2, 70, "Input"],
Cell[140418, 4312, 42, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[140497, 4318, 95, 2, 70, "Input"],
Cell[140595, 4322, 42, 1, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[140686, 4329, 51, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[140762, 4333, 57, 0, 70, "Input"],
Cell[140822, 4335, 74, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[140933, 4341, 57, 0, 70, "Input"],
Cell[140993, 4343, 75, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[141105, 4349, 45, 0, 70, "Input"],
Cell[141153, 4351, 55, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[141245, 4357, 47, 0, 70, "Input"],
Cell[141295, 4359, 54, 1, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[141398, 4366, 41, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[141464, 4370, 18, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[141507, 4374, 26, 0, 27, "Input"],
Cell[141536, 4376, 52, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[141625, 4382, 92, 1, 27, "Input"],
Cell[141720, 4385, 464, 12, 53, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[142221, 4402, 171, 3, 43, "Input"],
Cell[142395, 4407, 6314, 377, 791, 6188, 373, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[148758, 4790, 18, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[148801, 4794, 26, 0, 27, "Input"],
Cell[148830, 4796, 53, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[148920, 4802, 92, 1, 27, "Input"],
Cell[149015, 4805, 466, 12, 53, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[149518, 4822, 171, 3, 43, "Input"],
Cell[149692, 4827, 6718, 402, 417, 6592, 398, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[156459, 5235, 18, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[156502, 5239, 26, 0, 27, "Input"],
Cell[156531, 5241, 52, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[156620, 5247, 92, 1, 27, "Input"],
Cell[156715, 5250, 462, 12, 53, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[157214, 5267, 179, 3, 43, "Input"],
Cell[157396, 5272, 7564, 436, 810, 7437, 432, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[165009, 5714, 18, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[165052, 5718, 26, 0, 27, "Input"],
Cell[165081, 5720, 53, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[165171, 5726, 92, 1, 27, "Input"],
Cell[165266, 5729, 413, 11, 53, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[165716, 5745, 179, 3, 43, "Input"],
Cell[165898, 5750, 7787, 452, 792, 7661, 448, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[173734, 6208, 18, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[173777, 6212, 26, 0, 27, "Input"],
Cell[173806, 6214, 52, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[173895, 6220, 92, 1, 27, "Input"],
Cell[173990, 6223, 416, 11, 53, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[174443, 6239, 191, 4, 43, "Input"],
Cell[174637, 6245, 1518, 113, 810, 1391, 109, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[176204, 6364, 18, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[176247, 6368, 26, 0, 27, "Input"],
Cell[176276, 6370, 52, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[176365, 6376, 92, 1, 27, "Input"],
Cell[176460, 6379, 466, 12, 53, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[176963, 6396, 191, 4, 43, "Input"],
Cell[177157, 6402, 71406, 1201, 427, 6554, 396, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[248636, 7611, 58, 0, 32, "Text"],
Cell[248697, 7613, 34, 0, 27, "Input"],
Cell[248734, 7615, 39, 0, 27, "Input"],
Cell[248776, 7617, 383, 9, 149, "Input"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

