(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    496098,      10780]*)
(*NotebookOutlinePosition[    497366,      10819]*)
(*  CellTagsIndexPosition[    497322,      10815]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
The recalculation of the two-wire simple model with blades - V3.0- LOS values\
\
\>", "Section"],

Cell[CellGroupData[{

Cell["Switches, version numbers, paths etc", "Subsection"],

Cell["\<\
Switches to enable loading of previously saved results instead of \
recalculating from scratch\
\>", "Text"],

Cell["\<\
useprecomputed = False; (* set to True to use saved results from precomputed \
subdirectory *)
If[useprecomputed,
\texceptdamping = False, (* False by default, True to recalculate just \
damping-dependent stuff *)
\texceptdamping = True (* DON\"T CHANGE *)
];\
\>", "Input"],

Cell[CellGroupData[{

Cell["\<\
Definition of the current case - label, descriptive comment, and \
specification in terms of overrides relative to the default parameters
**** EDIT THIS SECTION TO DEFINE A NEW CASE ****\
\>", "Text"],

Cell["modelcase = \"IBS\";", "Input",
  CellChangeTimes -> {{3.451735605084487*^9, 3.451735610137718*^9}}],

Cell["\<\
modelcasecomment = \"LIGO-I ETM, SOS with blades creating the \
Undulators....\";\
\>", "Input"],

Cell["\<\
overrides = {
\ttx -> 0.0127,              (* thickness of optic, 1inch *)
\ttr -> (68.2*10^-3)/2,     (* radius of optic, 3inch diameter *)
\tm0 -> 124*10^-3,          (* mass of the compound 2\" mirror and holder *)
\tl0 -> 0.140,               (* wire length *)
\tr0 -> (127*10^-6)/2,      (* radius of wire, not critical can be adjusted
\t\t\t\t\t available diameters: 101um, 113um, 127um, 143um, 160um, 
\t\t\t\t\t\t\t\t\t180um, 202um, 310um, 355um, 370um *)

\tdpitch -> 1.5*10^-3,        (* height of wire break-off above c.o.m. *)
\tdyaw1 -> 35*10^-3,        (* y-separation of wires at structure *)
\tdyaw2 -> 76.2*10^-3,  (* y-separation of wires at optic, 
\t\t\t\t\t\t\t\toptic diameter + 2*1mm standoffs *)
\tkbz -> 159,\t\t\t\t  (* per-blade elastic constant in N/m *)
\tI0y -> 48.6*10^-6,        (* moment of inertia (longitudinal, pitch) *)
\tI0z -> 50.9*10^-6,         (* moment of inertia (yaw) *)
\tI0x -> 91.5*10^-6\t\t\t(* moment of inertia (roll) *)
};\
\>", "Input",
  CellChangeTimes -> {{3.451735653241503*^9, 3.451735656671795*^9}, \
{3.451736835316125*^9, 3.451736838490003*^9}, {3.451736880785919*^9, \
3.45173688180026*^9}}],

Cell["\<\
nonoptvars = {
\t
};\
\>", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The path in which the core model definition and model-specific support files \
are installed. 
**** EDIT THE PATHS AND/OR ADD CLAUSES FOR NEW SYSTEMS AS APPROPRIATE ****\
\>", "Text"],

Cell[BoxData[
    \(\(modeldirectory\  = \ 
        Switch[\[IndentingNewLine]$System, \[IndentingNewLine]"\<Power \
Macintosh\>", \
"\<Boadicea:Users:mbarton:Work:LIGO:analysis:AdvLIGOModel:twowiresimpleblades:\
current\>", \[IndentingNewLine]"\<Mac OS X x86 (32-bit)\>", \
"\</Users/slagmolen/Documents/mathematica/pendmodels/TwoWireSimpleBlades/\
current\>", \[IndentingNewLine]"\<Microsoft Windows\>", \
"\<C:\winslagmolen\mathematica\pendmodels\TwoWireSimpleBlades\current\>"\
\[IndentingNewLine]];\)\)], "Input",
  CellChangeTimes -> {{3.4517175049427156`*^9, 3.451717517645606*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
The path in which custom packages are installed (if different from above). 
**** EDIT THE PATHS AND/OR ADD CLAUSES FOR NEW SYSTEMS AS APPROPRIATE ****\
\>", "Text"],

Cell[BoxData[
    \(\(modelsupportdirectory\  = \ 
        Switch[\[IndentingNewLine]$System, \[IndentingNewLine]"\<Power \
Macintosh\>", "\<Boadicea:Users:mbarton:Work:MathLib\>", \[IndentingNewLine]"\
\<Mac OS X\>", "\</Users/slagmolen/Documents/pendtoolkit/v60\>", \
\[IndentingNewLine]"\<Mac OS X x86 (32-bit)\>", \
"\</Users/slagmolen/Documents/mathematica/pendtoolkit/v60\>", \
\[IndentingNewLine]"\<Solaris\>", "\</home/mbarton/MathLib\>", \
\[IndentingNewLine]"\<Linux\>", "\</home/mbarton/MathLib\>", \
\[IndentingNewLine]"\<Linux x86 (64 bit)\>", "\</home/mbarton/MathLib\>", \
\[IndentingNewLine]"\<Microsoft Windows\>", \
"\<C:\winslagmolen\mathematica\pendtoolkit\v50\>"\[IndentingNewLine]];\)\)], \
"Input",
  CellChangeTimes -> {{3.4517370857194138`*^9, 3.451737105314629*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Enable the mode shape plots", "Text"],

Cell["doplots = True;", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Enable export of state space to Matlab", "Text"],

Cell["domatlabexport = False;", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["The number of interesting low frequency modes", "Text"],

Cell["noofLF = 6;", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Usage notes for switches", "Text"],

Cell["\<\
useprecomputed::usage = \"useprecomputed is a switch variable which, when set \
to True, causes results to be read in from files in the data subdirectory \
rather than being calculated afresh.\";\
\>", "Input"],

Cell["\<\
domatlabexport::usage = \"domatlabexport is a switch variable which enables \
the calculation of the state space matrices for Matlab.\";\
\>", "Input"],

Cell["\<\
doplots::usage = \"doplots is a switch variable which enables mode shape \
plots.\";\
\>", "Input"],

Cell["\<\
modelcase::usage = \"modelcase is a string that serves as a label for the \
case of the model currently being calculated, as well as as a name for the \
subdirectory where the files for that case are stored.\";\
\>", "Input"],

Cell["\<\
modelcasecomment::usage = \"modelcasecomment is a string that describes the \
case of the model currently being calculated.\";\
\>", "Input"],

Cell["\<\
modeldirectory::usage = \"modeldirectory is a string (in the format \
appropriate for the local filesystem) that specifies the directory where the \
model definition files (ASUS3ModelDefn.nb and ASUS3ModelDefn.m) is stored. \
The files for particular cases will be stored in subdirectories of this \
directory.\";\
\>", "Input"],

Cell["\<\
modelsupportdirectory::usage = \"modelsupportdirectory is a string (in the \
format appropriate for the local filesystem) that specifies the directory \
where additional support files (e.g., StatusWindow.nb/StatusWindow.m) are \
stored (if different from modeldirectory).\";\
\>", "Input"],

Cell["\<\
overrides::usage = \"overrides is a list of substitutions that modify or \
replace those in defaultvalues.\";\
\>", "Input"],

Cell["\<\
nonoptvars::usage = \"nonoptvars is a list of variables that should be held \
frozen for debugging purpose in the optimization.\";\
\>", "Input"],

Cell["\<\
noofLF::usage = \"noofLF should be set to the number of interesting low \
frequency modes.\";\
\>", "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Version history", "Subsection"],

Cell["See matching ASUS4ModelDefn.nb in directory above this.", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Instructions", "Subsection"]], "Subsection"],

Cell[CellGroupData[{

Cell["Initial installation", "Subsubsection"],

Cell[TextData[{
  "1. Check the assignment to ",
  StyleBox["modelcase",
    FontFamily->"Courier"],
  " in the Switches sextion above. It should correspond to the name of the \
directory in which this copy of ",
  StyleBox["ASUS4ModelCalcXXX.nb",
    FontFamily->"Courier"],
  " is installed.\n2. Check the assignment to ",
  StyleBox["modeldirectory",
    FontFamily->"Courier"],
  " in the Switches section above. Check that there is a case in the ",
  StyleBox["Switch[]", "Program"],
  " statement corresponding to the value of ",
  StyleBox["$System", "Program"],
  " for your version of ",
  StyleBox["Mathematica,",
    FontSlant->"Italic"],
  " and if not, create one. The value returned for that case should be a \
string giving an absolute path to the root directory for the quad pendulum \
model. The model root directory will be the parent of the one containing this \
copy of ASUS4ModelCalc.nb and contains the factory version of ",
  StyleBox["A",
    FontFamily->"Courier"],
  "SUS4",
  StyleBox["ModelDefn.nb",
    FontFamily->"Courier"],
  ", ",
  StyleBox["A",
    FontFamily->"Courier"],
  "SUS4",
  StyleBox["ModelDefn.m",
    FontFamily->"Courier"],
  ", and various other definition and support files. The path string should \
be in the particular standard syntax for your OS (e.g., slash-delimited for \
Unix, colon-delimited for Mac, etc).\n3. Check the assignment to ",
  StyleBox["modelsupportdirectory",
    FontFamily->"Courier"],
  " in the Switches section above. Check that there is a case in the Switch[] \
statement corresponding to the value of $System for your version of ",
  StyleBox["Mathematica,",
    FontSlant->"Italic"],
  " and if not, create one. The value returned for that case should be a \
string giving an absolute path to the directory where you have placed the \
custom packages  ",
  StyleBox["RotationsXYZ.nb",
    FontFamily->"Courier"],
  ", ",
  StyleBox["RotationsXYZ.m",
    FontFamily->"Courier"],
  ", ",
  StyleBox["MyShapes.nb",
    FontFamily->"Courier"],
  " and ",
  StyleBox["MyShapes.m",
    FontFamily->"Courier"],
  ".  The path string should be in the particular standard syntax for your OS \
(e.g., slash-delimited for Unix, colon-delimited for Mac, etc)."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["To do calculations with the precomputed values", "Subsubsection"],

Cell[TextData[{
  "1. Check sure that this directory contains a ",
  StyleBox["precomputed",
    FontFamily->"Courier"],
  " subdirectory with various saved results (",
  StyleBox["allparams.m",
    FontFamily->"Courier"],
  " etc). If the directory is empty, there are no precomputed results and you \
will need to do the full calculation.\n2. If there are precomputed results, \
look for an assignment statement to the variable ",
  StyleBox["precomputed",
    FontFamily->"Courier"],
  " at the very beginning of this file and make sure that it is set to ",
  StyleBox["True",
    FontFamily->"Courier"],
  ". (Otherwise set it to ",
  StyleBox["False",
    FontFamily->"Courier"],
  " to force the full calculation)\n3. Evaluate cells in this notebook in \
order from the top. If the wire bending elasticity is not of interest, you \
can stop after the sections \"Stage 0 of the computation\" and \"Listings and \
plots with Stage 0 data\". The final two sections, \"Stages 1 and 2\" and \
\"Listings and plots with Stage 2 data\" take much longer to run.\n4. View \
the output in the \"Listings and plots\" sections. Add commands for new \
listings and plots using the examples there as a guide."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["To try different values with the same basic model structure", \
"Subsubsection"],

Cell[TextData[{
  "Many interesting variations can be implemented by just defining overrides \
to some or all of the default values of constants in the substitution list ",
  StyleBox["defaultvalues",
    FontFamily->"Courier"],
  ".Use this method where possible so that differences are confined to one \
well-defined spot in the code.To do this, proceed as follows:"
}], "Text"],

Cell[TextData[{
  "1. If you want to preserve the results from the current variation, (i) \
duplicate the entire directory containing containing this file, (ii) give the \
new directory a name reflecting the variation you're going to try, e.g., ",
  StyleBox["heavieroptic",
    FontFamily->"Courier"],
  ",  (iii) rename the new copy of this file to include some or all of the \
case name (e.g., ",
  StyleBox["A",
    FontFamily->"Courier"],
  "SUS4",
  StyleBox["ModelCalcDefault.nb",
    FontFamily->"Courier"],
  " -> ",
  StyleBox["A",
    FontFamily->"Courier"],
  "SUS4",
  StyleBox["ModelCalcHeavierOptic.nb",
    FontFamily->"Courier"],
  "), (iv) close this file and continue from here new copy in the new \
directory, (iv) (you should be in the new copy now) edit the assignment to ",
  StyleBox["modelcase",
    FontFamily->"Courier"],
  " in the Switches section above to correspond to the new directory name, \
and (v) edit the assignment to ",
  StyleBox["modelcasecomment",
    FontFamily->"Courier"],
  " in the Switches section to describe the new case.\n2. Edit the assignment \
to ",
  StyleBox["overrides",
    FontFamily->"Courier"],
  " in the Switches section above, adding, removing or changing overrides to \
reflect whatever new configuration you want. For example, ",
  StyleBox["m3->80",
    FontFamily->"Courier"],
  " will set the optic mass to 80 kg, ",
  StyleBox["m3->scale[2",
    FontFamily->"Courier"],
  "] will double it from what ever it was, and ",
  StyleBox["m3->increment[5",
    FontFamily->"Courier"],
  "] will add 5 kg.\n3. Edit the assignment to ",
  StyleBox["useprecomputed",
    FontFamily->"Courier"],
  " in the Switches section above to make it set ",
  StyleBox["useprecomputed",
    FontFamily->"Courier"],
  " to ",
  StyleBox["False",
    FontFamily->"Courier"],
  ".\n4. Delete all the saved result files in the ",
  StyleBox["precomputed",
    FontFamily->"Courier"],
  " subdirectory (of the new copy!).\n5. Select all the cells in this \
notebook and evaluate them.WARNING: recomputing the whole notebook takes \
several hours. Stage 0 is about 3 minutes, Stage 1 is about an hour, Stage 2 \
is about two hours, and the full collection of listings and plots at the end \
are a few minutes. Depending on what precision you want, you might be able to \
get away with evaluating only Stages 0 and 1, or only Stage 0.\n6. Edit the \
assignment to ",
  StyleBox["useprecomputed",
    FontFamily->"Courier"],
  " in the Switches section above to make it set ",
  StyleBox["useprecomputed",
    FontFamily->"Courier"],
  " to ",
  StyleBox["True", "Program"],
  ". Evaluate it. Save the file."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["To hack the model structure", "Subsubsection"],

Cell["\<\
Some changes, such as adding asymmetries, are too radical to be implemented \
by overriding values. And sometimes, as in starting a design for a new optic, \
you want to make a new set of default values to avoid having to override \
ridiculous numbers of them. In such cases the model definition needs to be \
hacked.\
\>", "Text"],

Cell[TextData[{
  "1. Duplicate the entire directory containing this file and edit the \
assignments to ",
  StyleBox["modelcase",
    FontFamily->"Courier"],
  " and ",
  StyleBox["modelcasecomment", "Program"],
  " in the new copy of this file as explained in \"To try different values \
with the same basic model structure\", step 1, above.\n2. Make a local copy \
of ",
  StyleBox["A",
    FontFamily->"Courier"],
  "SUS4",
  StyleBox["ModelDefn.nb",
    FontFamily->"Courier"],
  " in the new directory (e.g., by copying it from the factory version in the \
model root directory one level above).\n3. Hack the local copy to change the \
structure of the model as desired (this is left as an exercise for the \
reader).\n4. PUT CONSPICUOUS COMMENTS AT THE TOP OF THE NEW MODEL SAYING HOW \
IT DIFFERS FROM THE FACTORY VERSION!\n5. Continue from Step 2 of \"To try \
different values with the same basic model structure\" above. ",
  StyleBox["ASUS4ModelCalc.nb",
    FontFamily->"Courier"],
  " will find the customized version of ",
  StyleBox["ASUS4ModelDefn.m",
    FontFamily->"Courier"],
  " because it looks in its own directory (specified by ",
  StyleBox["modelcase",
    FontFamily->"Courier"],
  ") before checking the root directory."
}], "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Preliminaries", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
The directory in which this copy of ASUSModelCalc.nb and the other files \
associated with this case are stored.\
\>", "Text"],

Cell[BoxData[
    \(\(SetDirectory[ToFileName[{modeldirectory, modelcase}]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The path in which the model definition and model-specific support files are \
installed.\
\>", "Text"],

Cell[BoxData[
    \( (*Clear[$Path]\[IndentingNewLine]$Path = \
{"\</Applications/Mathematica.app/SystemFiles/Links\>", \
"\</Users/slagmolen/Library/Mathematica/Kernel\>", \
"\</Users/slagmolen/Library/Mathematica/Autoload\>", \
"\</Users/slagmolen/Library/Mathematica/Applications\>", \
"\</Library/Mathematica/Kernel\>", "\</Library/Mathematica/Autoload\>", \
"\</Library/Mathematica/Applications\>", "\<.\>", "\</Users/slagmolen\>", \
"\</Applications/Mathematica.app/AddOns/Packages\>", \
"\</Applications/Mathematica.app/AddOns/LegacyPackages\>", \
"\</Applications/Mathematica.app/SystemFiles/Autoload\>", \
"\</Applications/Mathematica.app/AddOns/Autoload\>", \
"\</Applications/Mathematica.app/AddOns/Applications\>", \
"\</Applications/Mathematica.app/AddOns/ExtraPackages\>", \
"\</Applications/Mathematica.app/SystemFiles/Kernel/Packages\>", \
"\</Applications/Mathematica.app/Documentation/English/System\>"}*) \)], \
"Input"],

Cell[BoxData[
    \(\($Path\  = \ Append[$Path, modeldirectory];\)\)], "Input",
  CellChangeTimes -> {3.451736698892377*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
The path in which custom packages are installed (if different from above).\
\>", "Text"],

Cell[BoxData[
    \(\($Path\  = \ Append[$Path, modelsupportdirectory];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Read in the model definition. First look for a customized model in the \
current directory, then look for the factory model in the directory above.\
\>", "Text"],

Cell["\<\
Get[\"TwoWireSimpleBladesDefn.m\",Path->{Directory[],ParentDirectory[\
Directory[]]}];\
\>", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Check that core model is loaded and correct", "Text"],

Cell["\<\
If[
\tmodelcomment!=\"Two-wire simple pendulum with blades\"
\t||modelversion<3.0,
\tAbort[]
];\
\>", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Archive some stuff that doesn't get recomputed here, just in case it's useful \
to look at\
\>", "Text"],

Cell["saveprecomputed[\"allvars.m\",allvars];", "Input"],

Cell["saveprecomputed[\"startpos.m\",startpos];", "Input"],

Cell["saveprecomputed[\"gravlist.m\",gravlist];", "Input"],

Cell["saveprecomputed[\"wirelist.m\",wirelist];", "Input"],

Cell["saveprecomputed[\"springlist.m\",springlist];", "Input"],

Cell["saveprecomputed[\"kinetic.m\",kinetic];", "Input"],

Cell["saveprecomputed[\"defaultvalues.m\",defaultvalues];", "Input"],

Cell["saveprecomputed[\"overrides.m\",overrides];", "Input"],

Cell["saveprecomputed[\"nonoptvars.m\",nonoptvars];", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Open the status window", "Text"],

Cell["OpenStatusWindow[WindowSize->{500,300}];", "Input"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell["Reset[All]", "Input"],

Cell[CellGroupData[{

Cell["Listings and plots with Stage 0A Data", "Subsection"],

Cell["Calculate[Stage0A]", "Input"],

Cell[CellGroupData[{

Cell["View the eigenfrequencies", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
Table[{Length[allvars]-index+1, Hz0A[[index]]}, {index, 1, \
Length[allvars]}]\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \({{6, 11.312817296034872`}, {5, 8.016261417411778`}, {4, 
        1.7072638005392924`}, {3, 1.3476233573742042`}, {2, 
        1.3326725539662065`}, {1, 0.9693745454743622`}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["View the important low-frequency modes", "Text"],

Cell[CellGroupData[{

Cell["\<\
Join[\t
\t{{\"N\",\"f\",\"type\"}},
\tTable[
\t\tJoin[
\t\t\t{i},
\t\t\t{Hz0A[[-i]]},
\t\t\timportant[e2ni.eigenvectors0A[[-i]],0.7]
\t\t],
\t\t{i,noofLF}
\t]
]//TableForm\
\>", "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"N\"\>", "\<\"f\"\>", "\<\"type\"\>"},
          {"1", "0.9693745454743622`", "pitch0"},
          {"2", "1.3326725539662065`", "roll0"},
          {"3", "1.3476233573742042`", "pitch0"},
          {"4", "1.7072638005392924`", "yaw0"},
          {"5", "8.016261417411778`", "z0"},
          {"6", "11.312817296034872`", "roll0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["View the higher frequency modes", "Text"],

Cell[CellGroupData[{

Cell["\<\
Join[\t
\t{{\"N\",\"f\",\"type\"}},
\tTable[
\t\tJoin[
\t\t\t{i},
\t\t\t{Hz0A[[-i]]},
\t\t\timportant[e2ni.eigenvectors0A[[-i]],0.7]
\t\t],
\t\t{i,noofLF+1,Length[allvars]}
\t]
]//TableForm\
\>", "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"N\"\>", "\<\"f\"\>", "\<\"type\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Classify the modes", "Text"],

Cell[CellGroupData[{

Cell["\<\
longpitchmodes0 = \
Select[Range[-noofLF,-1],longpitchQ[e2ni.eigenvectors0A[[#]]]&]\
\>", "Input"],

Cell[BoxData[
    \({\(-3\), \(-1\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
transrollmodes0 = \
Select[Range[-noofLF,-1],transrollQ[e2ni.eigenvectors0A[[#]]]&]\
\>", "Input"],

Cell[BoxData[
    \({\(-6\), \(-2\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
yawmodes0 = Select[Range[-noofLF,-1],yawQ[e2ni.eigenvectors0A[[#]]]&]\
\>", "Input"],

Cell[BoxData[
    \({\(-4\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
vertmodes0 = Select[Range[-noofLF,-1],vertQ[e2ni.eigenvectors0A[[#]]]&]\
\>", "Input"],

Cell[BoxData[
    \({\(-5\)}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["View the mode frequencies by groups", "Text"],

Cell[CellGroupData[{

Cell["longpitchfreqs0 = Hz0A[[longpitchmodes0]]", "Input"],

Cell[BoxData[
    \({1.3476233573742042`, 0.9693745454743622`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["transrollfreqs0 = Hz0A[[transrollmodes0]]", "Input"],

Cell[BoxData[
    \({11.312817296034872`, 1.3326725539662065`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["yawfreqs0 = Hz0A[[yawmodes0]]", "Input"],

Cell[BoxData[
    \({1.7072638005392924`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["vertfreqs0 = Hz0A[[vertmodes0]]", "Input"],

Cell[BoxData[
    \({8.016261417411778`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Export stuff for Matlab comparison", "Text"],

Cell["\<\
longpitchfreqs00 = longpitchfreqs0;
transrollfreqs00 = transrollfreqs0;
yawfreqs00 = yawfreqs0;
vertfreqs00 = vertfreqs0;
constval0 = constval;\
\>", "Input"],

Cell["\<\
saveprecomputed[\"matlabcomp0.m\",longpitchfreqs00,transrollfreqs00,\
yawfreqs00,vertfreqs00,constval0];\
\>", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Mode shape listings/plots", "Text"],

Cell[CellGroupData[{

Cell["#1", "Text"],

Cell[CellGroupData[{

Cell["Hz0A[[-1]]", "Input"],

Cell[BoxData[
    \(0.9693745454743622`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pretty[Chop[e2ni . eigenvectors0A[\([\(-1\)]\)], 10^\(-4\)]]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
          {"\<\"optic\"\>", "0.003148991491153311`", "0", "0", 
            "0", \(-0.999995041914003`\), "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DoWithStatus["\<Plotting stage 0A mode 1\>", \ 
      eigenplot[eigenvectors0A[\([\(-1\)]\)],  .1, {0, \(-1\), 0}, \ 
        floatmatrix0A]]\)], "Input",
  CellChangeTimes -> {{3.4517357002801437`*^9, 3.451735738493672*^9}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 7.1936 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-3.0968 7.1936 0 7.1936 [
[ 0 0 0 0 ]
[ 1 7.1936 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 7.1936 L
s
0 7.1936 m
.17254 5.95241 L
s
.17254 5.95241 m
.17254 1.24119 L
s
.17254 1.24119 m
0 0 L
s
1 0 m
.82746 1.24119 L
s
.82746 1.24119 m
.82746 5.95241 L
s
.82746 5.95241 m
1 7.1936 L
s
1 7.1936 m
1 0 L
s
0 0 m
0 7.1936 L
s
0 7.1936 m
1 7.1936 L
s
1 7.1936 m
1 0 L
s
1 0 m
0 0 L
s
.17254 1.24119 m
.82746 1.24119 L
s
.82746 1.24119 m
.82746 5.95241 L
s
.82746 5.95241 m
.17254 5.95241 L
s
.17254 5.95241 m
.17254 1.24119 L
s
0 0 m
1 0 L
1 7.1936 L
0 7.1936 L
closepath
clip
newpath
.5 Mabswid
.71 .499 .602 r
.36894 3.72521 m .60367 3.74876 L .62255 3.55423 L p F P
0 g
s
.50294 3.63487 m
.50301 3.57043 L
s
.71 .499 .602 r
.62255 3.55423 m .38909 3.53081 L .36894 3.72521 L p F P
0 g
s
.69 .644 .798 r
.38909 3.53081 m .62255 3.55423 L .64276 3.35924 L p F P
0 g
s
.69 .644 .798 r
.64276 3.35924 m .40802 3.33568 L .38909 3.53081 L p F P
0 g
s
.707 .577 .707 r
.5 6.14181 m .77857 6.14181 L p .22143 5.86324 L F P
0 g
s
.707 .577 .707 r
.77857 6.14181 m .77857 5.86324 L .22143 5.86324 L p F P
0 g
s
.707 .577 .707 r
.22143 5.86324 m .22143 6.14181 L .5 6.14181 L p F P
0 g
s
.745 .608 .039 r
.22143 6.14181 m .22143 5.86324 L .19121 6.10908 L p F P
0 g
s
0 0 .039 r
.77857 5.86324 m .77857 6.14181 L .7929 6.27274 L p F P
0 g
s
0 0 .039 r
.80879 6.10908 m .77857 5.86324 L p .7929 6.27274 L F P
0 g
s
.288 0 0 r
.77857 5.86324 m .80879 6.10908 L .19121 6.10908 L p F P
0 g
s
.50223 4.2691 m
.50282 3.73864 L
s
.288 0 0 r
.19121 6.10908 m .22143 5.86324 L .77857 5.86324 L p F P
0 g
s
.5 6.27274 m
.50018 6.10908 L
s
.50035 5.96174 m
.50223 4.2691 L
s
.745 .608 .039 r
.2071 6.27274 m .22143 6.14181 L p .19121 6.10908 L F P
0 g
s
.674 .314 .356 r
.34893 3.90579 m .58743 3.92972 L .60367 3.74876 L p F P
0 g
s
.674 .314 .356 r
.60367 3.74876 m .36894 3.72521 L .34893 3.90579 L p F P
0 g
s
.617 .738 .932 r
.40802 3.33568 m .64276 3.35924 L .66296 3.1769 L p F P
0 g
s
.617 .738 .932 r
.66296 3.1769 m .42446 3.15297 L .40802 3.33568 L p F P
0 g
s
.582 .101 .077 r
.33047 4.05903 m .57509 4.08357 L .58743 3.92972 L p F P
0 g
s
.582 .101 .077 r
.58743 3.92972 m .34893 3.90579 L .33047 4.05903 L p F P
0 g
s
.495 .775 .994 r
.42446 3.15297 m .66296 3.1769 L .68172 3.02082 L p F P
0 g
s
.495 .775 .994 r
.68172 3.02082 m .4371 2.99628 L .42446 3.15297 L p F P
0 g
s
.439 0 0 r
.31514 4.17087 m .56793 4.19624 L .57509 4.08357 L p F P
0 g
s
.439 0 0 r
.57509 4.08357 m .33047 4.05903 L .31514 4.17087 L p F P
0 g
s
.33 .749 .976 r
.4371 2.99628 m .68172 3.02082 L .69746 2.90518 L p F P
0 g
s
.33 .749 .976 r
.69746 2.90518 m .44467 2.87981 L .4371 2.99628 L p F P
0 g
s
.01 w
.37666 2.87738 Mdot
.5 Mabswid
.745 .608 .039 r
.19121 6.10908 m .19121 6.41787 L .2071 6.27274 L p F P
0 g
s
0 0 .039 r
.7929 6.27274 m .80879 6.41787 L .80879 6.10908 L p F P
0 g
s
.131 .659 .874 r
.44467 2.87981 m .69746 2.90518 L .70852 2.84409 L p F P
0 g
s
.131 .659 .874 r
.70852 2.84409 m .44601 2.81775 L .44467 2.87981 L p F P
0 g
s
.254 0 0 r
.30457 4.22744 m .56708 4.25378 L .56793 4.19624 L p F P
0 g
s
.254 0 0 r
.56793 4.19624 m .31514 4.17087 L .30457 4.22744 L p F P
0 g
s
.707 .577 .707 r
.5 6.41787 m .19121 6.41787 L .19121 6.10908 L p F P
0 g
s
.707 .577 .707 r
.80879 6.10908 m .80879 6.41787 L .5 6.41787 L p F P
0 g
s
.707 .577 .707 r
.19121 6.10908 m .80879 6.10908 L p .5 6.41787 L F P
0 g
s
.087 0 0 r
.44601 2.81775 m .70852 2.84409 L .71325 2.84987 L p F P
0 g
s
.087 0 0 r
.71325 2.84987 m .44025 2.82248 L .44601 2.81775 L p F P
0 g
s
0 .542 .734 r
.30035 4.21678 m .57336 4.24417 L .56708 4.25378 L p F P
0 g
s
0 .542 .734 r
.56708 4.25378 m .30457 4.22744 L .30035 4.21678 L p F P
0 g
s
.707 .577 .707 r
.5 6.46981 m .81448 6.46981 L p .18552 6.15533 L F P
0 g
s
.707 .577 .707 r
.81448 6.46981 m .81448 6.15533 L .18552 6.15533 L p F P
0 g
s
.707 .577 .707 r
.18552 6.15533 m .18552 6.46981 L .5 6.46981 L p F P
0 g
s
.745 .608 .039 r
.16714 6.63777 m .18552 6.46981 L p .14647 6.47306 L F P
0 g
s
.745 .608 .039 r
.18552 6.46981 m .18552 6.15533 L .14647 6.47306 L p F P
0 g
s
0 0 .039 r
.81448 6.15533 m .81448 6.46981 L .83286 6.63777 L p F P
0 g
s
0 0 .039 r
.85353 6.47306 m .81448 6.15533 L p .83286 6.63777 L F P
0 g
s
.288 0 0 r
.81448 6.15533 m .85353 6.47306 L .14647 6.47306 L p F P
0 g
s
.288 0 0 r
.14647 6.47306 m .18552 6.15533 L .81448 6.15533 L p F P
0 g
s
.306 0 0 r
.44025 2.82248 m .71325 2.84987 L .7104 2.92993 L p F P
0 g
s
.306 0 0 r
.7104 2.92993 m .42718 2.90152 L .44025 2.82248 L p F P
0 g
s
.187 .689 .91 r
.30372 4.13197 m .58694 4.16038 L .57336 4.24417 L p F P
0 g
s
.187 .689 .91 r
.57336 4.24417 m .30035 4.21678 L .30372 4.13197 L p F P
0 g
s
.745 .608 .039 r
.14647 6.47306 m .14647 6.82659 L .16714 6.63777 L p F P
0 g
s
0 0 .039 r
.83286 6.63777 m .85353 6.82659 L .85353 6.47306 L p F P
0 g
s
.5 6.63777 m
.50021 6.47306 L
s
.01 w
.35823 2.7699 Mdot
.64177 2.7699 Mdot
.5 Mabswid
.502 0 0 r
.42718 2.90152 m .7104 2.92993 L .69944 3.08291 L p F P
0 g
s
.502 0 0 r
.69944 3.08291 m .40755 3.05362 L .42718 2.90152 L p F P
0 g
s
.4 .767 .993 r
.31511 3.97496 m .607 4.00424 L .58694 4.16038 L p F P
0 g
s
.4 .767 .993 r
.58694 4.16038 m .30372 4.13197 L .31511 3.97496 L p F P
0 g
s
.644 .232 .248 r
.40755 3.05362 m .69944 3.08291 L .68108 3.29547 L p F P
0 g
s
.644 .232 .248 r
.68108 3.29547 m .38334 3.26559 L .40755 3.05362 L p F P
0 g
s
.574 .76 .966 r
.33376 3.75968 m .6315 3.78955 L .607 4.00424 L p F P
0 g
s
.574 .76 .966 r
.607 4.00424 m .31511 3.97496 L .33376 3.75968 L p F P
0 g
s
.5004 6.32867 m
.50342 4.00045 L
s
.50342 4.00045 m
.50369 3.78971 L
s
.708 .476 .57 r
.38334 3.26559 m .68108 3.29547 L .65738 3.54213 L p F P
0 g
s
.708 .476 .57 r
.65738 3.54213 m .35757 3.51205 L .38334 3.26559 L p F P
0 g
s
.683 .66 .821 r
.35757 3.51205 m .65738 3.54213 L .6315 3.78955 L p F P
0 g
s
.683 .66 .821 r
.6315 3.78955 m .33376 3.75968 L .35757 3.51205 L p F P
0 g
s
.50369 3.78971 m
.50398 3.56192 L
s
.707 .577 .707 r
.5 6.82659 m .14647 6.82659 L .14647 6.47306 L p F P
0 g
s
.707 .577 .707 r
.85353 6.47306 m .85353 6.82659 L .5 6.82659 L p F P
0 g
s
.707 .577 .707 r
.14647 6.47306 m .85353 6.47306 L p .5 6.82659 L F P
0 g
s
.25 Mabswid
0 0 m
0 7.1936 L
s
0 7.1936 m
1 7.1936 L
s
1 7.1936 m
1 0 L
s
1 0 m
0 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{37.4375, 269.25},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40000U00013B000`400?l00000o`00003o9@3oool0
02D0oooo000U0?ooo`009@00000000030000003oool0oooo0240oooo0@00000000030000003oool0
oooo0240oooo0@00000000030000003oool0oooo0240oooo0@000000008000008@3oool200000000
0P00000Q0?ooo`800000000200000240oooo0P000000008000008@3oool2000000000P00000Q0?oo
o`800000000200000240oooo0P000000008000008@3oool2000000000P00000Q0?ooo`8000000000
0`000000oooo0000000O0?ooo`4000000@3oool10000000000<000000?ooo`0000007`3oool10000
0040oooo0@00000000030000003oool0000001l0oooo0@0000010?ooo`40000000000`000000oooo
0000000O0?ooo`4000000@3oool10000000000<000000?ooo`0000007`3oool100000040oooo0@00
000000030000003oool0000001l0oooo0@0000010?ooo`40000000000`000000oooo0000000O0?oo
o`4000000@3oool10000000000<000000?ooo`0000007`3oool100000040oooo0@00000000040000
003oool0oooo000001d0oooo00<000000?ooo`3oool00@00000000040000003oool0oooo000001d0
oooo00<000000?ooo`3oool00@00000000040000003oool0oooo000001d0oooo00<000000?ooo`3o
ool00@00000000040000003oool0oooo000001d0oooo00<000000?ooo`3oool00@00000000040000
003oool0oooo000001d0oooo00<000000?ooo`3oool00@00000000040000003oool0oooo000001d0
oooo00<000000?ooo`3oool00@00000000040000003oool0oooo000001d0oooo00<000000?ooo`3o
ool00@00000000050000003oool0oooo0?ooo`0000006`3oool010000000oooo0?ooo`3oool10000
000000D000000?ooo`3oool0oooo0000000K0?ooo`040000003oool0oooo0?ooo`40000000001@00
0000oooo0?ooo`3oool0000001/0oooo00@000000?ooo`3oool0oooo0@00000000050000003oool0
oooo0?ooo`0000006`3oool010000000oooo0?ooo`3oool10000000000D000000?ooo`3oool0oooo
0000000K0?ooo`040000003oool0oooo0?ooo`40000000001@000000oooo0?ooo`3oool0000001/0
oooo00@000000?ooo`3oool0oooo0@00000000050000003oool0oooo0?ooo`0000006`3oool01000
0000oooo0?ooo`3oool10000000000D000000?ooo`3oool0oooo0000000K0?ooo`040000003oool0
oooo0?ooo`40000000000`000000oooo0?ooo`020?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool00P3oool10000000000<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo0080oooo0@00000000030000003oool0oooo0080oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`020?ooo`40000000000`000000oooo0?ooo`020?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool00P3oool10000000000<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0080oooo0@00000000030000003oool0
oooo0080oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`020?ooo`40000000000`00
0000oooo0?ooo`020?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool00P3oool10000
000000<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0080
oooo0@00000000030000003oool0oooo00<0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool00`3oool10000000000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo00<0oooo0@00000000030000003oool0oooo00<0oooo6@0000050?oo
o`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool00`3oool10000000000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo00<0oooo0@00000000030000003oool0oooo00<0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool00`3oool10000000000<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo00<0oooo0@00000000030000003oool0oooo00<0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`030?ooo`40000000000`000000oooo
0?ooo`030?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00`3oool10000000000<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00<0oooo0@00
000000030000003oool0oooo00<0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`03
0?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool00`3oool10000000000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo00<0oooo0@00000000030000003oool0oooo00<0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool00`3oool10000000000<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00<0oooo0@00000000030000003oool0oooo
00<0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`030?ooo`40000000000`000000
oooo0?ooo`030?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00`3oool100000000
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00<0oooo
0@00000000030000003oool0oooo00<0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`030?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool00`3oool10000000000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo00<0oooo0@00000000030000003oool0oooo00<0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool00`3oool10000000000<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00<0oooo0@00000000030000003oool0
oooo00<0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`030?ooo`40000000000`00
0000oooo0?ooo`030?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00`3oool10000
000000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00<0
oooo0@00000000030000003oool0oooo00<0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool00`3oool10000000000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo00<0oooo0@00000000030000003oool0oooo00<0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool00`3oool10000000000<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00<0oooo0@00000000030000003o
ool0oooo00<0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`030?ooo`4000000000
0`000000oooo0?ooo`030?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00`3oool1
0000000000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
00<0oooo0@00000000030000003oool0oooo00<0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool00`3oool10000000000<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo00<0oooo0@00000000030000003oool0oooo00<0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool00`3oool10000000000<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00<0oooo0@00000000030000
003oool0oooo00<0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`030?ooo`400000
00000`000000oooo0?ooo`030?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00`3o
ool10000000000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo00<0oooo0@00000000030000003oool0oooo00<0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool00`3oool10000000000<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo00<0oooo0@00000000030000003oool0oooo00<0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`03
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00`3oool10000000000<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00<0oooo0@0000000003
0000003oool0oooo00<0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`030?ooo`40
000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
0`3oool10000000000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo00<0oooo0@00000000030000003oool0oooo00<0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00<0oooo0@00000000030000003oool0oooo00<0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo
1@0000090?ooo`030000003oool0oooo00<0oooo0@00000000030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01`3oool00`000000CP0004h0000204h000D00000103oool00`000000oooo0?oo
o`030?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo0P000009
04h000030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool10000000000<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`060?ooo`D000001@1>00000`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo0@00000000030000003oool0oooo00<0oooo00<000000?ooo`3o
ool01P3oool00`000000P00008000002080000H00000103oool00`000000oooo0?ooo`030?ooo`40
000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<00000080000200000
1`2000000`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0@00000000030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000P00008000008080000030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool10000000000<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`050?ooo`03000000200000P00000P0P00000<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo
00D0oooo00<00000080000200000202000000`000000oooo0?ooo`020?ooo`030000003oool0oooo
00<0oooo0@00000000030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool6000000D0
P00000<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`40000000000`000000oooo
0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000:@k?`2T>cl00`2T>cl6000000@0oooo
00<000000?ooo`3oool00`3oool10000000000<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`050?ooo`030000002T>cl0Y3/o00P0Y3/o00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`030?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<00000
0:@k?`2T>cl0202T>cl00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0@000000
00030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000Y3/o0:@k?`090:@k
?`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool10000000000<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030000002T>cl0Y3/o00P0Y3/o00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?ooo`030000
003oool0oooo00@0oooo00<000000:@k?`2T>cl0202T>cl00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo0@00000000030000003oool0oooo00<0oooo00<000000?ooo`3oool0103o
ool6000000D0Y3/o00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`4000000000
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000;EiT@2eNI400`2eNI46
000000D0oooo00<000000?ooo`3oool00`3oool10000000000<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`040?ooo`030000002eNI40]GVA00P0]GVA00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0
oooo00<000000;EiT@2eNI40202eNI400`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo0@00000000030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000]GVA
0;EiT@080;EiT@030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool10000000000<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000002eNI40]GVA00P0]GVA00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00@0oooo00<000000;EiT@2eNI401`2eNI400`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00<0oooo0@00000000030000003oool0oooo00<0oooo00<000000?oo
o`3oool0103oool00`000000]GVA0;EiT@070;EiT@030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool10000000000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`03
0000002eNI40]GVA00L0]GVA00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`40
000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo1@0000050;EiT@030000
003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool10000000000<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`040?ooo`030000002^Z=80[ZSB0080[ZSB1P0000060?ooo`030000003o
ool0oooo00<0oooo0@00000000030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool0
0`000000[ZSB0:jXdP020:jXdP030000002^Z=80[ZSB0080[ZSB00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo
00@0oooo00<000000:jXdP2^Z=800P2^Z=800`000000[ZSB0:jXdP020:jXdP030000003oool0oooo
00@0oooo00<000000?ooo`3oool00`3oool10000000000<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`040?ooo`030000002^Z=80[ZSB0080[ZSB00<000000:jXdP2^Z=800P2^Z=800`000000
oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo0@00000000030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000[ZSB0:jXdP030:jXdP030000002^Z=80[ZSB0080[ZSB
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`40000000000`000000oooo0?oo
o`030?ooo`030000003oool0oooo00<0oooo00<000000:jXdP2^Z=800`2^Z=800`000000[ZSB0:jX
dP020:jXdP030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool10000000000<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000002^Z=80[ZSB00<0[ZSB00<00000
0:jXdP2^Z=800P2^Z=800`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo0@000000
00030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000[ZSB0:jXdP030:jX
dP030000002^Z=80[ZSB0080[ZSB00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?oo
o`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo1`0000040:jXdP03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool10000000000<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`030?ooo`030000002B`_L0T/;g00<0T/;g1P0000060?ooo`030000
003oool0oooo00<0oooo0@00000000030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000T/;g09;2m`0309;2m`030000002B`_L0T/;g0080T/;g00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<0000009;2m`2B`_L00`2B`_L00`000000T/;g09;2m`0209;2m`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00`3oool10000000000<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`030000002B`_L0T/;g00@0T/;g00<0000009;2m`2B`_L00P2B`_L00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo0@00000000030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool00`000000T/;g09;2m`0409;2m`050000002B`_L0T/;g09;2
m`0000001`3oool00`000000oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00<0000009;2m`2B`_L0102B`_L01@000000T/;g09;2m`2B`_L00000
00L0oooo00<000000?ooo`3oool00`3oool10000000000<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`030000002B`_L0T/;g00@0T/;g00D0000009;2m`2B`_L0T/;g000000070?oo
o`030000003oool0oooo00<0oooo0@00000000030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P3oool60000000309;2m`000000T/;g0080T/;g00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo
00<0000006K4oP1Va?h00`1Va?h6000000L0oooo00<000000?ooo`3oool00`3oool10000000000<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000001Va?h0I/Cn00@0I/Cn00D0
000006K4oP1Va?h0I/Cn000000070?ooo`030000003oool0oooo00<0oooo0@00000000030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000I/Cn06K4oP0406K4oP050000001V
a?h0I/Cn06K4oP0000001`3oool00`000000oooo0?ooo`030?ooo`40000000000`000000oooo0?oo
o`030?ooo`030000003oool0oooo0080oooo00<0000006K4oP1Va?h0101Va?h010000000I/Cn06K4
oP0000080?ooo`030000003oool0oooo00<0oooo0@00000000030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00P3oool00`000000I/Cn06K4oP0406K4oP040000001Va?h0I/Cn000000P0oooo
00<000000?ooo`3oool00`3oool10000000000<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`D000000P1Va?h010000000I/Cn06K4oP0000080?ooo`030000003oool0oooo00<0oooo
0@00000000030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000;k3X02n`
j00202n`j0H00000203oool00`000000oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`03
0?ooo`050000003oool0oooo0?ooo`0000001`0_/>P010000000;k3X02n`j00000080?ooo`030000
003oool0oooo00<0oooo0@00000000030000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo
1@00000302n`j0030000000_/>P0000000T0oooo00<000000?ooo`3oool00`3oool10000000000<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`H000002@3oool00`000000oooo0?oo
o`030?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?oo
o`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`400000
00000`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`40000000000`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`40000000000`000000oooo
0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`03
0?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`40
000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`4000000000
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`40000000000`000000
oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`40000000000`000000oooo0?oo
o`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`030?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?oo
o`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`400000
00000`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`40000000000`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`40000000000`000000oooo
0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`03
0?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`40
000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`4000000000
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`40000000000`000000
oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`40000000000`000000oooo0?oo
o`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`030?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?oo
o`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`400000
00000`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`40000000000`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`40000000000`000000oooo
0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`03
0?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`40
000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`4000000000
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`40000000000`000000
oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0000001@00000
00<0oooo0000003oool0103oool10000000000<000000?ooo`3oool00`3oool00`000000oooo0000
000904T00003000000190000B@0000L0B@0000<000000?ooo`0000001@3oool10000000000<00000
0?ooo`3oool00`3oool00`000000oooo0000000904T00003000000190000B@0000L0B@0000<00000
0?ooo`0000001@3oool10000000000<000000?ooo`3oool00`3oool2000000X0B@0000<0000004T0
001900001`190003000000D0oooo0@00000000030000003oool0oooo00<0oooo0P00000:04T00003
000000190000B@0000L0B@0000<000000?ooo`0000001@3oool10000000000<000000?ooo`3oool0
0`3oool2000000X0B@0000<0000004T00019000020190002000000D0oooo0@00000000030000003o
ool0oooo00<0oooo0P00000:04T00003000000190000B@0000P0B@000P0000050?ooo`4000000000
0`000000oooo0?ooo`020?ooo`8000002`1900000`000000B@0004T0000804T000030000003oool0
000000@0oooo0@00000000030000003oool0oooo0080oooo0P00000;04T00003000000190000B@00
00P0B@0000<000000?ooo`000000103oool10000000000<000000?ooo`3oool00P3ooolI00000003
0?ooo`000000oooo00<0oooo0@00000000030000003oool0oooo0080oooo0P00000;0;BC]0030000
002dTk@0]9>d00P0]9>d00<000000?ooo`000000103oool10000000000<000000?ooo`3oool00P3o
oolI000000030?ooo`000000oooo00<0oooo0@00000000030000003oool0oooo0080oooo0P00000;
04T00003000000190000B@0000P0B@0000<000000?ooo`000000103oool10000000000<000000?oo
o`3oool00P3oool2000000/0B@0000<0000004T000190000201900000`000000oooo000000040?oo
o`40000000000`000000oooo0?ooo`020?ooo`8000002`1900000`000000B@0004T0000904T00080
0000103oool10000000000L000000?ooo`3oool0oooo0000003oool0000000/0B@0000<0000004T0
001900002@1900000`000000oooo000000030?ooo`40000000001`000000oooo0?ooo`3oool00000
0?ooo`0000002`1900000`000000B@0004T0000904T000030000003oool0000000<0oooo0@000000
00040000003oool0oooo0?ooo`800000301900000`000000B@0004T0000904T000030000003oool0
000000<0oooo0@00000000040000003oool0oooo0?ooo`800000601900000`000000oooo00000003
0?ooo`400000000010000000oooo0?ooo`3oool2000001P0B@0000<000000?ooo`0000000`3oool1
0000000000@000000?ooo`3oool0oooo0P00000I04T0008000000`3oool10000000000@000000?oo
o`3oool0oooo0P00000I04T0008000000`3oool10000000000D000000?ooo`3oool000000?ooo`0K
000000040?ooo`000000oooo0?ooo`40000000001P000000oooo0?ooo`000000oooo000001T0]9>d
00<000000?ooo`0000000P3oool10000000000H000000?ooo`3oool000000?ooo`00000I0;BC]003
0000003oool000000080oooo0@00000000060000003oool0oooo0000003oool000006@2dTk@00`00
0000oooo000000020?ooo`40000000001P000000oooo0?ooo`000000oooo000001T0]9>d00<00000
0?ooo`0000000P3oool10000000000H000000?ooo`3oool000000?ooo`00000I0;BC]0030000003o
ool000000080oooo0@00000000060000003oool0oooo0000003oool000006@2dTk@00`000000oooo
000000020?ooo`40000000001P000000oooo0?ooo`000000oooo000001T0]9>d00<000000?ooo`00
00000P3oool10000000000<000000?ooo`0000000P3oool00`000000]9>d0;BC]00G0;BC]0050000
003oool0oooo0000003oool00@00000000030000003oool000000080oooo00<000000;BC]02dTk@0
5`2dTk@01@000000oooo0?ooo`000000oooo0040000000000`000000oooo000000020?ooo`030000
002dTk@0]9>d01L0]9>d00D000000?ooo`3oool000000?ooo`010000000000<000000?ooo`000000
0P3oool00`000000]9>d0;BC]00G0;BC]0050000003oool0oooo0000003oool00@00000000030000
003oool000000080oooo00<000000;BC]02dTk@05`2dTk@01@000000oooo0?ooo`000000oooo0040
000000000`000000oooo000000020?oooa/000000P3oool100000040oooo0@00000000030000003o
ool0000001l0oooo0@0000010?ooo`400000000200000240oooo0P000000008000008@3oool20000
00000P00000Q0?ooo`800000000200000240oooo0P000000008000008@3oool2000000000P00000Q
0?ooo`800000000200000240oooo0P000000008000008@3oool20000000000<000000?ooo`3oool0
8@3oool10000000000<000000?ooo`3oool08@3oool10000000000<000000?ooo`3oool08@3oool1
000000009@00000002D0oooo000U0?ooo`009@3oool00001\
\>"],
  ImageRangeCache->{{{0, 36.4375}, {268.25, 0}} -> {0.430493, -0.0117045, \
0.00381513, 0.00381513}}],

Cell[BoxData[
    RowBox[{"DoWithStatus", "[", 
      RowBox[{"\<\"Plotting stage 0A mode 1\"\>", ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
          False,
          Editable->False]}], "]"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#2", "Text"],

Cell[CellGroupData[{

Cell["Hz0A[[-2]]", "Input"],

Cell[BoxData[
    \(1.3326725539662065`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pretty[Chop[e2ni . eigenvectors0A[\([\(-2\)]\)], 10^\(-4\)]]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
          {"\<\"optic\"\>", "0", \(-0.24200782916440827`\), "0", "0", 
            "0", \(-0.9702742965899542`\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(DoWithStatus["\<Plotting stage 0A mode 2\>", \ 
      eigenplot[eigenvectors0A[\([\(-2\)]\)],  .1, {\(-1\), 0, 0}, \ 
        floatmatrix0A]]\), "\[IndentingNewLine]", 
    \( (*Status["\<Plotting stage 0A mode 2\>"]\ ; 
      eigenplot[eigenvectors0A[\([\(-2\)]\)],  .1, {\(-1\), 0, 0}, \ 
        floatmatrix0A]\ \ ; Done[]*) \)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 2.39787 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.698933 2.39787 0 2.39787 [
[ 0 0 0 0 ]
[ 1 2.39787 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
1 0 m
1 2.39787 L
s
1 2.39787 m
0 2.39787 L
s
0 2.39787 m
0 0 L
s
0 0 m
1 0 L
s
.93501 .15584 m
.06499 .15584 L
s
.06499 .15584 m
.06499 2.24203 L
s
.06499 2.24203 m
.93501 2.24203 L
s
.93501 2.24203 m
.93501 .15584 L
s
1 0 m
1 2.39787 L
s
1 2.39787 m
.93501 2.24203 L
s
.93501 2.24203 m
.93501 .15584 L
s
.93501 .15584 m
1 0 L
s
0 0 m
.06499 .15584 L
s
.06499 .15584 m
.06499 2.24203 L
s
.06499 2.24203 m
0 2.39787 L
s
0 2.39787 m
0 0 L
s
0 0 m
1 0 L
1 2.39787 L
0 2.39787 L
closepath
clip
newpath
.5 Mabswid
.707 .577 .707 r
.36402 2.25665 m .4807 2.25665 L .4807 2.13996 L p F P
0 g
s
.707 .577 .707 r
.4807 2.13996 m .24915 2.13996 L p .36402 2.25665 L F P
0 g
s
.287 0 0 r
.24915 2.13996 m .4807 2.13996 L .47847 2.24893 L p F P
0 g
s
.785 .641 .083 r
.24915 2.25665 m .24915 2.13996 L .22011 2.24893 L p F P
0 g
s
.707 .577 .707 r
.24915 2.13996 m .24915 2.25665 L .36402 2.25665 L p F P
0 g
s
.287 0 0 r
.47847 2.24893 m .22011 2.24893 L .24915 2.13996 L p F P
0 g
s
.714 .583 .006 r
.4807 2.13996 m .4807 2.25665 L .47966 2.31405 L p F P
0 g
s
.714 .583 .006 r
.47847 2.24893 m .4807 2.13996 L p .47966 2.31405 L F P
0 g
s
.785 .641 .083 r
.23554 2.31405 m .24915 2.25665 L p .22011 2.24893 L F P
0 g
s
0 0 .083 r
.75085 2.14178 m .75085 2.25665 L .76469 2.31501 L p F P
0 g
s
0 0 .083 r
.77989 2.25096 m .75085 2.14178 L p .76469 2.31501 L F P
0 g
s
.707 .577 .707 r
.63598 2.25665 m .75085 2.25665 L .75085 2.14178 L p F P
0 g
s
.707 .577 .707 r
.75085 2.14178 m .5193 2.14178 L p .63598 2.25665 L F P
0 g
s
.288 0 0 r
.5193 2.14178 m .75085 2.14178 L .77989 2.25096 L p F P
0 g
s
.707 .577 .707 r
.5193 2.14178 m .5193 2.25665 L .63598 2.25665 L p F P
0 g
s
.288 0 0 r
.77989 2.25096 m .52153 2.25096 L .5193 2.14178 L p F P
0 g
s
0 0 .006 r
.52036 2.31501 m .5193 2.25665 L p .52153 2.25096 L F P
0 g
s
0 0 .006 r
.5193 2.25665 m .5193 2.14178 L .52153 2.25096 L p F P
0 g
s
.132 .679 .79 r
.64046 .89693 m .6341 .91061 L .71884 .90552 L p F P
0 g
s
.132 .679 .79 r
.71884 .90552 m .72922 .8916 L .64046 .89693 L p F P
0 g
s
0 .497 .785 r
.72922 .8916 m .71884 .90552 L .801 .92686 L p F P
0 g
s
0 .497 .785 r
.801 .92686 m .81527 .91395 L .72922 .8916 L p F P
0 g
s
0 .275 .711 r
.81527 .91395 m .801 .92686 L .87254 .97254 L p F P
0 g
s
0 .275 .711 r
.87254 .97254 m .89021 .9618 L .81527 .91395 L p F P
0 g
s
0 .034 .578 r
.89021 .9618 m .87254 .97254 L .92647 1.0381 L p F P
0 g
s
.501 .854 .597 r
.48904 .98592 m .48954 .99557 L .55509 .94164 L p F P
0 g
s
.501 .854 .597 r
.55509 .94164 m .5577 .92944 L .48904 .98592 L p F P
0 g
s
.328 .802 .726 r
.5577 .92944 m .55509 .94164 L .6341 .91061 L p F P
0 g
s
.328 .802 .726 r
.6341 .91061 m .64046 .89693 L .5577 .92944 L p F P
0 g
s
0 .034 .578 r
.92647 1.0381 m .9467 1.03047 L .89021 .9618 L p F P
0 g
s
0 0 .398 r
.92647 1.0381 m .95471 1.11001 L .95657 1.10965 L p F P
0 g
s
0 0 .398 r
.9467 1.03047 m .92647 1.0381 L p .95657 1.10965 L F P
0 g
s
.712 .727 .206 r
.41884 1.14692 m .42251 1.14927 L .44385 1.06711 L p F P
0 g
s
.712 .727 .206 r
.44385 1.06711 m .44119 1.06086 L .41884 1.14692 L p F P
0 g
s
.633 .827 .418 r
.44119 1.06086 m .44385 1.06711 L .48954 .99557 L p F P
0 g
s
.633 .827 .418 r
.48954 .99557 m .48904 .98592 L .44119 1.06086 L p F P
0 g
s
0 0 0 r
.96808 1.23316 m .95471 1.23218 L .94125 1.284 L p F P
0 g
s
.73 .561 0 r
.42417 1.23567 m .42761 1.23401 L .42251 1.14927 L p F P
0 g
s
.73 .561 0 r
.42251 1.14927 m .41884 1.14692 L .42417 1.23567 L p F P
0 g
s
.01 w
.34843 .90424 Mdot
.5 Mabswid
0 0 0 r
.94125 1.284 m .96218 1.28804 L p .96808 1.23316 L F P
0 g
s
0 0 0 r
.96218 1.28804 m .94125 1.284 L .89557 1.35555 L p F P
0 g
s
0 0 0 r
.89557 1.35555 m .91433 1.36297 L .96218 1.28804 L p F P
0 g
s
0 0 0 r
.91433 1.36297 m .89557 1.35555 L .83001 1.40947 L p F P
0 g
s
.579 .107 0 r
.51316 1.3871 m .51256 1.37857 L .45864 1.31302 L p F P
0 g
s
.579 .107 0 r
.45864 1.31302 m .45667 1.31843 L .51316 1.3871 L p F P
0 g
s
.684 .347 0 r
.45667 1.31843 m .45864 1.31302 L .42761 1.23401 L p F P
0 g
s
.684 .347 0 r
.42761 1.23401 m .42417 1.23567 L .45667 1.31843 L p F P
0 g
s
0 0 0 r
.83001 1.40947 m .84567 1.41946 L .91433 1.36297 L p F P
0 g
s
0 0 0 r
.84567 1.41946 m .83001 1.40947 L .751 1.4405 L p F P
0 g
s
0 0 0 r
.751 1.4405 m .76291 1.45196 L .84567 1.41946 L p F P
0 g
s
.04 0 0 r
.76291 1.45196 m .751 1.4405 L .66627 1.4456 L p F P
0 g
s
.04 0 0 r
.66627 1.4456 m .67416 1.4573 L .76291 1.45196 L p F P
0 g
s
.241 0 0 r
.67416 1.4573 m .66627 1.4456 L .58411 1.42426 L p F P
0 g
s
.241 0 0 r
.58411 1.42426 m .5881 1.43495 L .67416 1.4573 L p F P
0 g
s
.427 0 0 r
.5881 1.43495 m .58411 1.42426 L .51256 1.37857 L p F P
0 g
s
.427 0 0 r
.51256 1.37857 m .51316 1.3871 L .5881 1.43495 L p F P
0 g
s
0 0 .398 r
.95657 1.10965 m .97628 1.1058 L .9467 1.03047 L p F P
0 g
s
.714 .583 .006 r
.47966 2.31405 m .47847 2.37912 L .47847 2.24893 L p F P
0 g
s
.785 .641 .083 r
.22011 2.24893 m .22011 2.37912 L .23554 2.31405 L p F P
0 g
s
.36066 2.19146 m
.38713 1.15712 L
s
.35754 2.31357 m
.35919 2.24893 L
s
.68272 2.19338 m
.76458 1.94509 L
s
.64278 2.31453 m
.66374 2.25096 L
s
.9547 1.36839 m
.96525 1.33639 L
s
.76458 1.94509 m
.9547 1.36839 L
s
0 0 .083 r
.76469 2.31501 m .77989 2.37912 L .77989 2.25096 L p F P
0 g
s
0 0 .006 r
.52153 2.25096 m .52153 2.37912 L .52036 2.31501 L p F P
0 g
s
0 0 0 r
.96218 1.28804 m .97628 1.23376 L .96808 1.23316 L p F P
0 g
s
.01 w
.65876 .89026 Mdot
.34124 .89026 Mdot
.5 Mabswid
.707 .577 .707 r
.34827 2.37912 m .22011 2.37912 L p .47847 2.24893 L F P
0 g
s
.707 .577 .707 r
.22011 2.37912 m .22011 2.24893 L .47847 2.24893 L p F P
0 g
s
.707 .577 .707 r
.47847 2.24893 m .47847 2.37912 L .34827 2.37912 L p F P
0 g
s
.707 .577 .707 r
.65173 2.37912 m .52153 2.37912 L p .77989 2.25096 L F P
0 g
s
.707 .577 .707 r
.52153 2.37912 m .52153 2.25096 L .77989 2.25096 L p F P
0 g
s
.707 .577 .707 r
.77989 2.25096 m .77989 2.37912 L .65173 2.37912 L p F P
0 g
s
.25 Mabswid
1 0 m
1 2.39787 L
s
1 2.39787 m
0 2.39787 L
s
0 2.39787 m
0 0 L
s
0 0 m
1 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{119, 285.313},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40001g00017B000`400?l00000o`00003oM`3oool0
07L0000000000`000000oooo0?ooo`1c0?ooo`4000000002000007<0oooo0P00000000800000L`3o
ool20000000000<000000?ooo`000000L@3oool100000040oooo0@00000000030000003oool00000
0740oooo0@0000010?ooo`40000000000`000000oooo0000001`0?ooo`030000003oool0oooo0040
0000000010000000oooo0?ooo`00001_0?ooo`030000003oool0oooo00400000000010000000oooo
0?ooo`00001^0?ooo`040000003oool0oooo0?ooo`400000000010000000oooo0?ooo`00001^0?oo
o`040000003oool0oooo0?ooo`40000000001@000000oooo0?ooo`3oool0000006d0oooo00@00000
0?ooo`3oool0oooo0@00000000050000003oool0oooo0?ooo`000000K03oool00`000000oooo0?oo
o`020?ooo`40000000000`000000oooo0?ooo`020?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool00P3oool10000000000<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1X0?oo
o`030000003oool0oooo00<0oooo0@00000000030000003oool0oooo0080oooo00<000000?ooo`3o
ool0J03oool00`000000oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?ooo`030000
003oool0oooo06H0oooo00<000000?ooo`3oool0103oool10000000000<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo00@0oooo0@00000000030000003oool0
oooo00@0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`40000000000`00
0000oooo0?ooo`040?ooofP000001`3oool10000000000<000000?ooo`3oool0103oool00`000000
oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo
00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?oo
o`040?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool01@3oool10000000000<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo0@000000
00030000003oool0oooo00@0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`050?oo
o`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3o
ool01@3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`1T0?ooo`030000
003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0I03o
ool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0
oooo06@0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0
oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo
0?ooo`040?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool01@3oool10000000000<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo0@00
000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`05
0?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo06@0oooo00<000000?oo
o`3oool01@3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`1T0?ooo`03
0000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0
I03oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003o
ool0oooo06@0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo
00@0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`40000000000`000000
oooo0?ooo`040?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool01@3oool100000000
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo
0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?oo
o`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo06@0oooo00<00000
0?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`1T0?oo
o`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0I03oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000
003oool0oooo06@0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0
oooo00@0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`40000000000`00
0000oooo0?ooo`040?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool01@3oool10000
000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00D0
oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0I03oool00`000000oooo
0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo06@0oooo00<0
00000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`1T
0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<000000?oo
o`3oool0I03oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`03
0000003oool0oooo06@0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0
103oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo0@00000000030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`4000000000
0`000000oooo0?ooo`040?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool01@3oool1
0000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo
00D0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0I03oool00`000000
oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo06@0oooo
00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?oo
o`1T0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?oo
o`030000003oool0oooo06@0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo0@00000000030000
003oool0oooo00@0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`400000
00000`000000oooo0?ooo`040?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool01@3o
ool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`1T0?ooo`030000003oool0
oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0I03oool00`00
0000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo06@0
oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103oool00`000000oooo
0?ooo`1T0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`04
0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool01@3oool10000000000<000000?oo
o`3oool0103oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo0@0000000003
0000003oool0oooo00@0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`40
000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0
1@3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`1T0?ooo`030000003o
ool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0I03oool0
0`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo
06@0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103oool00`000000
oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo
00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?oo
o`040?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool01@3oool10000000000<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo0@000000
00030000003oool0oooo00@0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`050?oo
o`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3o
ool01@3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`1T0?ooo`030000
003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0I03o
ool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0
oooo06@0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0
oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo
0?ooo`040?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool01@3oool10000000000<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo0@00
000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`05
0?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo06@0oooo00<000000?oo
o`3oool01@3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`1T0?ooo`03
0000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0
I03oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003o
ool0oooo06@0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo
00@0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`40000000000`000000
oooo0?ooo`040?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool01@3oool100000000
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00D0oooo
0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?oo
o`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo06@0oooo00<00000
0?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`1T0?oo
o`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool01@3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`170?ooo`L00000
5P3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool07P3oool7000000@08Jg:00<00000001ob000OlP00`00
000C0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0?P3oool?000000@007o81000000?0?ooo`030000003oool0oooo00D0oooo0@000000
00030000003oool0oooo00@0oooo00<000000?ooo`3oool0>`3oool4000000h0oooo1@000003001o
b08000003@3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`03
0000003oool0oooo03T0oooo1000000E0?ooo`@0000000<004Jf0000000000002`3oool00`000000
oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo03L0oooo
1000000J0?ooo`0400000000A[H004Jf0016]P8000002@3oool00`000000oooo0?ooo`050?ooo`40
000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo03H0oooo0`00000M0?ooo`800000
0`00A[H2000000L0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0d0?ooo`<000008@3oool00`00000004Jf0016]P020016]P8000001@3o
ool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0
oooo03<0oooo0`00000S0?ooo`0300000000A[H004Jf00<004Jf00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo
0380oooo0P00000V0?ooo`80000000D004Jf00000000000000RC000000030?ooo`030000003oool0
oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0<03oool30000
02T0oooo00D000000008T`0029<000RC000000030?ooo`030000003oool0oooo00D0oooo0@000000
00030000003oool0oooo00@0oooo00<000000?ooo`3oool0;`3oool3000002/0oooo00D000000008
T`0029<000RC000000020?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo
00@0oooo00<000000?ooo`3oool0;P3oool2000002h0oooo00L000000008T`0029<000RC0000003o
ool0000000L0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`0^0?ooo`040000000029<000RC0008T`8000001`3oool10000000000<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0]0?ooo`800000<@3oool00`00000000RC0008T`02
000000L0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0;@3oool00`00
0000oooo0?ooo`0a0?ooo`040000000029<000RC000000L0oooo0@00000000030000003oool0oooo
00@0oooo00<000000?ooo`3oool0;03oool2000003@0oooo00@000000008T`0029<000001P3oool1
0000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo
03@0oooo0`0000060?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo02/0
oooo0P00000f0?ooo`040000000006D0001U000000D0oooo0@00000000030000003oool0oooo00@0
oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0f0?ooo`80001U00<000000?ooo`3o
ool00`3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0Z0?ooo`800000
>03oool30000I@030000003oool0oooo0080oooo0@00000000030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`0g0?ooo`040000000006D0001U000000@0oooo
0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0:@3oool2000003T0oooo00D0
00000000I@0006D0001U000000030?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool0>03oool01@000000001U0000I@0006D0000000<0oooo
0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`0h0?ooo`8000000`0006D00`000000oooo0?ooo`010000000000<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0X0?ooo`800000>P3oool010000000oooo0000I@0006D200000080oooo0@00
000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0i
0?ooo`040000003oool00000000000@0oooo0@00000000030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00D0oooo0@000000
00030000003oool0oooo00@0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00D0oooo0@00000000030000
003oool0oooo00@0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0j0?ooo`030000
003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool08`3o
ool01@000000oooo0?ooo`3oool0000003`0oooo00<000000?ooo`3oool01@3oool10000000000<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0S0?ooo`050000003oool0oooo0?ooo`000000
?03oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003o
ool0oooo02<0oooo00D000000?ooo`3oool0oooo0000000l0?ooo`030000003oool0oooo00D0oooo
0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool08`3oool01@000000oooo0?oo
o`3oool0000003`0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0S0?ooo`050000003oool0oooo0?ooo`000000?03oool00`000000oooo
0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00D0oooo0@00
000000030000003oool0oooo00@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool01@3oool10000000000<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0>@3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0i0?ooo`03
0000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03T0oooo00<000000?ooo`000000
0`0000020?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0000000<000000P3o
ool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo0080oooo0P00000j0?ooo`030000003oool00000008000000`3oool10000000000<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0>03oool5000000<0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`030?ooo`800000>@3oool5000000<0oooo0@00000000030000
003oool0oooo00@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`030?ooo`800000
>@3oool5000000<0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03L0oooo100000040?ooo`4000000000
0`000000oooo0?ooo`040?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0103oool2
000003P0oooo100000040?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool0103oool2000003P0oooo0`0000050?ooo`40000000000`000000
oooo0?ooo`040?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool01@3oool2000003H0
oooo100000050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool01@3oool2000003D0oooo100000060?ooo`40000000000`000000oooo0?oo
o`040?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool01P3oool2000003@0oooo0`00
00070?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0a0?ooo`@000001`3oool10000000000<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00P0oooo0P00000a0?oo
o`D000000P3oool00`000000oooo0?ooo`020?ooo`40000000000`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool02@3oool200000300oooo0`0000001@3oool0
00000?ooo`3oool0000000@0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`0:0?ooo`800000;P3oool4000000040?ooo`000000oooo0000
00D0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo02/0oooo100000020?ooo`030000003oool0000000D0
oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`0;0?ooo`800000:P3oool5000000<0oooo00<000000?ooo`0000001@3oool10000000000<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00`0oooo0P00
000X0?ooo`D00000103oool2000000H0oooo0@00000000030000003oool0oooo00@0oooo00<00000
0?ooo`3oool08P3oool00`000000oooo0?ooo`0=0?ooo`030000001]0000000002D0oooo10000006
0?ooo`8000001P3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo00h0oooo0`00000R0?ooo`D000001`3oool2000000H0oooo0@0000000003
0000003oool0oooo00@0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0@0?ooo`<0
00007P3oool6000000P0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0180oooo0`00000J0?ooo`H00000
2P3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool0503oool4000001D0oooo1P00000<0?ooo`030000003o
ool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`0F0?ooo`L000003P3oool6000000d0oooo0P0000070?ooo`40000000000`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0603oool30000
0080?@004P00000?0?ooo`8000001`3oool10000000000<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo01/0oooo1@00000600X000L000004@3oool2000000L0
oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`0O0?ooo`L000005`3oool00`000000oooo000000070?ooo`40000000000`000000oooo0?oo
o`040?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0?@3oool00`000000oooo0000
00070?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool0?@3oool00`000000oooo000000070?ooo`40000000000`000000oooo0?ooo`040?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool0?03oool010000000oooo0?ooo`000007
0?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool0?03oool010000000oooo0?ooo`0000070?ooo`40000000000`000000oooo0?ooo`040?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool0?03oool010000000oooo0?ooo`000007
0?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool0>`3oool01@000000oooo0?ooo`3oool0000000L0oooo0@00000000030000003oool0oooo
00@0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0k0?ooo`050000003oool0oooo
0?ooo`0000001`3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo03/0oooo00D000000?ooo`3oool0oooo000000070?ooo`40000000000`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0>`3oool01@00
0000oooo0?ooo`3oool0000000L0oooo0@00000000030000003oool0oooo00@0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01@3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo03X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`40
000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
>P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo0@00000000030000003o
ool0oooo00@0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0i0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo
0280oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00D0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool100000000
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo03P0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?oo
o`040?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0>03oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<00000
0?ooo`3oool08P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo03L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?oo
o`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool0=`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo0@00000000030000
003oool0oooo00@0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0f0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`0f0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool10000
000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo03H0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo
0?ooo`040?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0=P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`05
0?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool0=@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo0@0000000003
0000003oool0oooo00@0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0240oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool1
0000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
03<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`40000000000`000000
oooo0?ooo`040?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0<`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool0<P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00D0oooo0@000000
00030000003oool0oooo00@0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0a0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01@3o
ool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo0300oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`40000000000`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0<03oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool0;`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo0@00
000000030000003oool0oooo00@0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01@3oool10000000000<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo02h0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0240oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
1@3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`050?ooo`4000000000
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo
00@0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00D0oooo
0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?oo
o`0/0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool01@3oool10000000000<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo02/0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3o
ool08@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool01@3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`050?ooo`400000
00000`000000oooo0?ooo`040?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0:P3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0
oooo00@0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo0200
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0
oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool10000000000<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool01@3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`050?ooo`40
000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo0@00000000030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
00D0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0803oool00`000000
oooo0?ooo`0W0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool100000000
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?oo
o`040?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0C0?oo
oa`000006@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo0@0000000003
0000003oool0oooo00@0oooo00<000000?ooo`3oool04`3oool00`000000B@0004T0000:04T00003
000000190000B@0000/0B@0000<000000?ooo`3oool00P3ooolL000001D0oooo00<000000?ooo`3o
ool01@3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0B0?ooo`030000
00190000B@0000/0B@0000<0000004T0001900002`1900000`000000oooo0?ooo`020?ooo`030000
00190000B@000180B@0000<0000004T0001900000`1900000`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool04P3o
ool00`000000B@0004T0000;04T00003000000190000B@0000/0B@0000<000000?ooo`3oool00P3o
ool00`000000B@0004T0000A04T00003000000190000B@0000D0B@0000<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0
oooo0180oooo00<0000004T0001900002`1900000`000000B@0004T0000;04T000030000003oool0
oooo0080oooo00<0000004T0001900004@1900000`000000B@0004T0000504T000030000003oool0
oooo0180oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0A0?ooo`03000000190000B@0000`0B@0000<0000004T0001900002`1900000`00
0000oooo0?ooo`020?ooo`03000000190000B@000140B@0000<0000004T0001900001@1900000`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0
oooo00<000000?ooo`3oool04@3oool00`000000B@0004T0000<04T00003000000190000B@0000/0
B@0000<000000?ooo`3oool00P3oool00`000000B@0004T0000@04T00003000000190000B@0000L0
B@0000<000000?ooo`3oool04@3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo
0?ooo`040?ooo`030000003oool0oooo0140oooo00<0000004T0001900006P1900000`000000oooo
0?ooo`020?ooo`03000000190000B@000100B@0000<0000004T0001900001`1900000`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<0
00000?ooo`3oool04@3oool00`000000B@0004T0000J04T000030000003oool0oooo0080oooo00<0
000004T0001900006P1900000`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00D0oooo0@00
000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0403oool00`000000B@0004T0000K
04T000030000003oool0oooo0080oooo00<0000004T0001900006`1900000`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<000000?oo
o`3oool0403oool00`000000B@0004T0000K04T000030000003oool0oooo0080oooo00<0000004T0
001900006`1900000`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo0@0000000003
0000003oool0oooo00@0oooo00<000000?ooo`3oool0403oool00`000000B@0004T0000K04T00003
0000003oool0oooo0080oooo00<0000004T0001900006`1900000`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo4`00000N04T000H00000
7P19000C000000L0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool03`3o
oolP000000@0oooo8000000A0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0
oooo00<0oooo00<000000?ooo`3oool0403oool00`000000]9>d0;BC]00L0;BC]0030000003oool0
oooo0080oooo00<000000;BC]02dTk@0702dTk@00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo00@0oooo0@00000000030000003oool0oooo00<0oooo00<000000?ooo`3oool0403oool00`00
0000]9>d0;BC]00L0;BC]0030000003oool0oooo0080oooo00<000000;BC]02dTk@0702dTk@00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo0@00000000030000003oool0oooo00<0
oooo00<000000?ooo`3oool0403oool00`000000]9>d0;BC]00L0;BC]0030000003oool0oooo0080
oooo00<000000;BC]02dTk@0702dTk@00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00<0
oooo0@00000000030000003oool0oooo0080oooo00<000000?ooo`3oool04@3oool00`000000]9>d
0;BC]00L0;BC]0030000003oool0oooo0080oooo00<000000;BC]02dTk@0702dTk@00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo00<0oooo0@00000000030000003oool0oooo0080oooo00<0
00000?ooo`3oool04@3oool00`000000]9>d0;BC]00L0;BC]0030000003oool0oooo0080oooo00<0
00000;BC]02dTk@0702dTk@00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo0@00
000000050000003oool0oooo0?ooo`000000503oool00`000000]9>d0;BC]00L0;BC]0030000003o
ool0oooo0080oooo00<000000;BC]02dTk@0702dTk@00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo0080oooo0@00000000050000003oool0oooo0?ooo`000000503oool00`000000]9>d0;BC
]00L0;BC]0030000003oool0oooo0080oooo00<000000;BC]02dTk@0702dTk@00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo0080oooo0@00000000050000003oool0oooo0?ooo`000000503o
ool00`000000]9>d0;BC]00L0;BC]0030000003oool0oooo0080oooo00<000000;BC]02dTk@0702d
Tk@00`000000oooo0?ooo`0C0?ooo`040000003oool0oooo0?ooo`400000000010000000oooo0?oo
o`00000E0?ooo`030000002dTk@0]9>d01`0]9>d00<000000?ooo`3oool00P3oool00`000000]9>d
0;BC]00L0;BC]0030000003oool0oooo01<0oooo00@000000?ooo`3oool0oooo0@00000000040000
003oool0oooo000001D0oooo00<000000;BC]02dTk@0702dTk@00`000000oooo0?ooo`020?ooo`03
0000002dTk@0]9>d01`0]9>d00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0100000000
00@000000?ooo`3oool000005@3oool00`000000]9>d0;BC]00L0;BC]0030000003oool0oooo0080
oooo00<000000;BC]02dTk@0702dTk@00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0040
000000000`000000oooo0000000F0?ooo`030000002dTk@0]9>d01`0]9>d00<000000?ooo`3oool0
0P3oool00`000000]9>d0;BC]00L0;BC]0030000003oool0oooo01@0oooo00<000000?ooo`3oool0
0@00000000030000003oool0000001H0oooo00<000000;BC]02dTk@0702dTk@00`000000oooo0?oo
o`020?ooo`030000002dTk@0]9>d01`0]9>d00<000000?ooo`3oool05@3oool100000040oooo0@00
0000008000005`3oool00`000000]9>d0;BC]00L0;BC]0030000003oool0oooo0080oooo00<00000
0;BC]02dTk@0702dTk@00`000000oooo0?ooo`0E0?ooo`4000000@3oool1000000000P00000G0?oo
o`030000002dTk@0]9>d01`0]9>d00<000000?ooo`3oool00P3oool00`000000]9>d0;BC]00L0;BC
]0030000003oool0oooo01H0oooo0P000000008000005`3ooolP000000@0oooo8000000H0?ooo`80
000000000`000000oooo0?ooo`1c0?ooo`400000001g00000000\
\>"],
  ImageRangeCache->{{{0, 118}, {284.313, 0}} -> {0.291479, -0.00241507, \
0.00353425, 0.00353425}}],

Cell[BoxData[
    RowBox[{"DoWithStatus", "[", 
      RowBox[{"\<\"Plotting stage 0A mode 2\"\>", ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
          False,
          Editable->False]}], "]"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#3", "Text"],

Cell[CellGroupData[{

Cell["Hz0A[[-3]]", "Input"],

Cell[BoxData[
    \(1.3476233573742042`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pretty[Chop[e2ni . eigenvectors0A[\([\(-3\)]\)], 10^\(-4\)]]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
          {"\<\"optic\"\>", "0.1235102172884428`", "0", "0", "0", 
            "0.9923433005897514`", "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Status["\<Plotting stage 0A mode 3\>"]\ ; 
    eigenplot[eigenvectors0A[\([\(-3\)]\)],  .1, {0, \(-1\), \(- .25\)}, \ 
      floatmatrix0A]\ \ ; Done[]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 5.99483 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.6256 6.25121 1.28586e-016 6.25121 [
[ 0 0 0 0 ]
[ 1 5.99483 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
.12768 5.99483 L
s
.12768 5.99483 m
.23891 4.75775 L
s
.23891 4.75775 m
.18195 .67458 L
s
.18195 .67458 m
0 0 L
s
1 0 m
.81805 .67458 L
s
.81805 .67458 m
.76109 4.75775 L
s
.76109 4.75775 m
.87232 5.99483 L
s
.87232 5.99483 m
1 0 L
s
0 0 m
.12768 5.99483 L
s
.12768 5.99483 m
.87232 5.99483 L
s
.87232 5.99483 m
1 0 L
s
1 0 m
0 0 L
s
.18195 .67458 m
.81805 .67458 L
s
.81805 .67458 m
.76109 4.75775 L
s
.76109 4.75775 m
.23891 4.75775 L
s
.23891 4.75775 m
.18195 .67458 L
s
0 0 m
1 0 L
1 5.99483 L
0 5.99483 L
closepath
clip
newpath
.5 Mabswid
.691 .687 .841 r
.5 4.95773 m .71974 4.95773 L p .27793 4.76168 L F P
0 g
s
.691 .687 .841 r
.71974 4.95773 m .72207 4.76168 L .27793 4.76168 L p F P
0 g
s
.691 .687 .841 r
.27793 4.76168 m .28026 4.95773 L .5 4.95773 L p F P
0 g
s
.745 .608 .039 r
.27065 5.09348 m .28026 4.95773 L p .25738 5.03076 L F P
0 g
s
.745 .608 .039 r
.28026 4.95773 m .27793 4.76168 L .25738 5.03076 L p F P
0 g
s
0 0 .039 r
.72207 4.76168 m .71974 4.95773 L .72935 5.09348 L p F P
0 g
s
0 0 .039 r
.74262 5.03076 m .72207 4.76168 L p .72935 5.09348 L F P
0 g
s
.412 0 0 r
.72207 4.76168 m .74262 5.03076 L .25738 5.03076 L p F P
0 g
s
.412 0 0 r
.25738 5.03076 m .27793 4.76168 L .72207 4.76168 L p F P
0 g
s
.745 .608 .039 r
.25738 5.03076 m .26016 5.24166 L .27065 5.09348 L p F P
0 g
s
0 0 .039 r
.72935 5.09348 m .73984 5.24166 L .74262 5.03076 L p F P
0 g
s
.52079 4.87043 m
.69927 2.95594 L
s
.5 5.09348 m
.50585 5.03076 L
s
.688 .696 .853 r
.5 5.24166 m .26016 5.24166 L .25738 5.03076 L p F P
0 g
s
.688 .696 .853 r
.74262 5.03076 m .73984 5.24166 L .5 5.24166 L p F P
0 g
s
.688 .696 .853 r
.25738 5.03076 m .74262 5.03076 L p .5 5.24166 L F P
0 g
s
.665 .431 .556 r
.80702 3.10804 m .61394 3.12668 L .63009 3.29464 L p F P
0 g
s
.695 .612 .759 r
.61394 3.12668 m .80702 3.10804 L .80761 2.99838 L p F P
0 g
s
.695 .612 .759 r
.80761 2.99838 m .80179 2.93598 L p .61394 3.12668 L F P
0 g
s
.695 .612 .759 r
.80179 2.93598 m .59741 2.95587 L .61394 3.12668 L p F P
0 g
s
.665 .431 .556 r
.80715 3.11759 m .80702 3.10804 L p .63009 3.29464 L F P
0 g
s
.665 .431 .556 r
.63009 3.29464 m .80935 3.27748 L .80715 3.11759 L p F P
0 g
s
.674 .748 .906 r
.59741 2.95587 m .80179 2.93598 L .78873 2.77343 L p F P
0 g
s
.674 .748 .906 r
.78873 2.77343 m .58163 2.79375 L .59741 2.95587 L p F P
0 g
s
.585 .215 .308 r
.80935 3.27748 m .63009 3.29464 L .64476 3.44815 L p F P
0 g
s
.687 .698 .855 r
.5 5.29411 m .74356 5.29411 L p .25358 5.08052 L F P
0 g
s
.687 .698 .855 r
.74356 5.29411 m .74642 5.08052 L .25358 5.08052 L p F P
0 g
s
.687 .698 .855 r
.25358 5.08052 m .25644 5.29411 L .5 5.29411 L p F P
0 g
s
.745 .608 .039 r
.24458 5.46167 m .25644 5.29411 L p .22802 5.41523 L F P
0 g
s
.745 .608 .039 r
.25644 5.29411 m .25358 5.08052 L .22802 5.41523 L p F P
0 g
s
0 0 .039 r
.74642 5.08052 m .74356 5.29411 L .75542 5.46167 L p F P
0 g
s
.585 .215 .308 r
.81008 3.29803 m .80935 3.27748 L p .64476 3.44815 L F P
0 g
s
.585 .215 .308 r
.64476 3.44815 m .81486 3.43199 L .81008 3.29803 L p F P
0 g
s
.601 .829 .987 r
.58163 2.79375 m .78873 2.77343 L .7796 2.63121 L p F P
0 g
s
.601 .829 .987 r
.7796 2.63121 m .56775 2.65214 L .58163 2.79375 L p F P
0 g
s
0 0 .039 r
.77198 5.41523 m .74642 5.08052 L p .75542 5.46167 L F P
0 g
s
.412 0 0 r
.74642 5.08052 m .77198 5.41523 L .22802 5.41523 L p F P
0 g
s
.412 0 0 r
.22802 5.41523 m .25358 5.08052 L .74642 5.08052 L p F P
0 g
s
.455 0 .028 r
.81486 3.43199 m .64476 3.44815 L .65678 3.5752 L p F P
0 g
s
.455 0 .028 r
.81646 3.45614 m .81486 3.43199 L p .65678 3.5752 L F P
0 g
s
.455 0 .028 r
.65678 3.5752 m .82331 3.55948 L .81646 3.45614 L p F P
0 g
s
.477 .845 .99 r
.56775 2.65214 m .7796 2.63121 L .77536 2.52164 L p F P
0 g
s
.477 .845 .99 r
.77536 2.52164 m .55695 2.54334 L .56775 2.65214 L p F P
0 g
s
.282 0 0 r
.82331 3.55948 m .65678 3.5752 L .66499 3.66347 L p F P
0 g
s
.282 0 0 r
.82573 3.57898 m .82331 3.55948 L p .66499 3.66347 L F P
0 g
s
.745 .608 .039 r
.22802 5.41523 m .2315 5.6464 L .24458 5.46167 L p F P
0 g
s
0 0 .039 r
.75542 5.46167 m .7685 5.6464 L .77198 5.41523 L p F P
0 g
s
.52351 5.26464 m
.677 3.97831 L
s
.5 5.46167 m
.50554 5.41523 L
s
.282 0 0 r
.66499 3.66347 m .83425 3.64756 L .82573 3.57898 L p F P
0 g
s
.306 .789 .906 r
.55695 2.54334 m .77536 2.52164 L .77684 2.4571 L p F P
0 g
s
.306 .789 .906 r
.77684 2.4571 m .55044 2.47965 L .55695 2.54334 L p F P
0 g
s
.01 w
.38937 2.41909 Mdot
.61063 2.41909 Mdot
.5 Mabswid
.075 0 0 r
.83425 3.64756 m .66499 3.66347 L .66825 3.7011 L p F P
0 g
s
.677 3.97831 m
.699 3.79399 L
s
.075 0 0 r
.83715 3.65593 m .83425 3.64756 L p .66825 3.7011 L F P
0 g
s
.075 0 0 r
.66825 3.7011 m .84697 3.68434 L .83715 3.65593 L p F P
0 g
s
.098 .654 .731 r
.55044 2.47965 m .77684 2.4571 L .78453 2.44869 L p F P
0 g
s
.098 .654 .731 r
.78453 2.44869 m .54933 2.47213 L .55044 2.47965 L p F P
0 g
s
.682 .71 .869 r
.5 5.6464 m .2315 5.6464 L .22802 5.41523 L p F P
0 g
s
.682 .71 .869 r
.77198 5.41523 m .7685 5.6464 L .5 5.6464 L p F P
0 g
s
.682 .71 .869 r
.22802 5.41523 m .77198 5.41523 L p .5 5.6464 L F P
0 g
s
.146 .691 .782 r
.84697 3.68434 m .66825 3.7011 L .66567 3.67852 L p F P
0 g
s
.146 .691 .782 r
.84978 3.67929 m .84697 3.68434 L p .66567 3.67852 L F P
0 g
s
.146 .691 .782 r
.66567 3.67852 m .86039 3.66024 L .84978 3.67929 L p F P
0 g
s
.129 0 0 r
.54933 2.47213 m .78453 2.44869 L .79832 2.50389 L p F P
0 g
s
.129 0 0 r
.79832 2.50389 m .55435 2.52814 L .54933 2.47213 L p F P
0 g
s
.359 .811 .942 r
.86039 3.66024 m .66567 3.67852 L .65687 3.59126 L p F P
0 g
s
.359 .811 .942 r
.86256 3.64497 m .86039 3.66024 L p .65687 3.59126 L F P
0 g
s
.359 .811 .942 r
.65687 3.59126 m .8731 3.57087 L .86256 3.64497 L p F P
0 g
s
.699 3.79399 m
.71822 3.6329 L
s
.348 0 0 r
.55435 2.52814 m .79832 2.50389 L .81727 2.62329 L p F P
0 g
s
.348 0 0 r
.81727 2.62329 m .5656 2.64816 L .55435 2.52814 L p F P
0 g
s
.535 .843 .999 r
.8731 3.57087 m .65687 3.59126 L .64227 3.44324 L p F P
0 g
s
.535 .843 .999 r
.87429 3.5535 m .8731 3.57087 L p .64227 3.44324 L F P
0 g
s
.535 .843 .999 r
.64227 3.44324 m .88346 3.42033 L .87429 3.5535 L p F P
0 g
s
.71822 3.6329 m
.73779 3.46891 L
s
.53 .11 .189 r
.5656 2.64816 m .81727 2.62329 L .83945 2.79765 L p F P
0 g
s
.53 .11 .189 r
.83945 2.79765 m .58223 2.82285 L .5656 2.64816 L p F P
0 g
s
.01 w
.37334 2.50103 Mdot
.62666 2.50103 Mdot
.5 Mabswid
.651 .778 .941 r
.88346 3.42033 m .64227 3.44324 L .62331 3.24888 L p F P
0 g
s
.651 .778 .941 r
.88376 3.41092 m .88346 3.42033 L p .62331 3.24888 L F P
0 g
s
.651 .778 .941 r
.88212 3.22405 m .88754 3.29582 L .88376 3.41092 L p F P
0 g
s
.651 .778 .941 r
.62331 3.24888 m .88212 3.22405 L p .88376 3.41092 L F P
0 g
s
.73779 3.46891 m
.75935 3.28824 L
s
.65 .389 .511 r
.58223 2.82285 m .83945 2.79765 L .8621 3.00712 L p F P
0 g
s
.65 .389 .511 r
.8621 3.00712 m .60235 3.03231 L .58223 2.82285 L p F P
0 g
s
.692 .621 .773 r
.88212 3.22405 m .62331 3.24888 L .60235 3.03231 L p F P
0 g
s
.692 .621 .773 r
.60235 3.03231 m .8621 3.00712 L .88212 3.22405 L p F P
0 g
s
.25 Mabswid
0 0 m
.12768 5.99483 L
s
.12768 5.99483 m
.87232 5.99483 L
s
.87232 5.99483 m
1 0 L
s
1 0 m
0 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{48, 287.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40000`00017b000`400?l00000o`00003o<03oool0
0300oooo000`0000000000<000000?ooo`3oool0;03oool10000000000<000000?ooo`3oool0:`3o
ool2000000000P00000/0?ooo`8000000002000002`0oooo0P00000000800000;03oool200000000
0P00000[0?ooo`4000000@3oool10000000000<000000?ooo`000000:P3oool100000040oooo0@00
000000030000003oool0000002X0oooo0@0000010?ooo`40000000000`000000oooo0000000Y0?oo
o`030000003oool0oooo0040000000000`000000oooo0000000Y0?ooo`030000003oool0oooo0040
0000000010000000oooo0?ooo`00000X0?ooo`030000003oool0oooo00400000000010000000oooo
0?ooo`00000X0?ooo`030000003oool0oooo00400000000010000000oooo0?ooo`00000W0?ooo`04
0000003oool0oooo0?ooo`400000000010000000oooo0?ooo`00000W0?ooo`040000003oool0oooo
0?ooo`40000000001@000000oooo0?ooo`3oool0000002H0oooo00@000000?ooo`3oool0oooo0@00
000000050000003oool0oooo0?ooo`0000009@3oool00`000000oooo0?ooo`020?ooo`4000000000
1@000000oooo0?ooo`3oool0000002D0oooo00<000000?ooo`3oool00P3oool10000000000D00000
0?ooo`3oool0oooo0000000U0?ooo`030000003oool0oooo0080oooo0@00000000030000003oool0
oooo0080oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`020?ooo`40000000000`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool00`3oool10000
000000<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00<0
oooo0@00000000030000003oool0oooo0080oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool00`3oool10000000000<0oooo0000003oool00`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo00<0oooo0@0000010?ooo`0000<0oooo0000003oool00`3oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo00<0oooo0@0000010?ooo`0000<0oooo0000003o
ool00`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00<0oooo0@0000010?ooo`00
00<0oooo0000003oool0103oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00@0oooo
0@0000010?ooo`0000<0oooo0000003oool0103oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo00@0oooo0@0000010?ooo`0000<0oooo0000003oool0103oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo00@0oooo0@0000010?ooo`0000<0oooo0000003oool0103oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo00@0oooo0@0000010?ooo`0000<0oooo0000003o
ool01@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`00
00<0oooo0000003oool01@3ooolO000000L0oooo0@0000010?ooo`0000<0oooo0000003oool01@3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo
0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@000001
0?ooo`0000<0oooo0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo
0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@000001
0?ooo`0000<0oooo0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo
0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@000001
0?ooo`0000<0oooo0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo
0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@000001
0?ooo`0000<0oooo0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo
0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@000001
0?ooo`0000<0oooo0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo
0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@000001
0?ooo`0000<0oooo0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo
0000003oool01@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo0@000001
0?ooo`0000<0oooo0000003oool01P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
00H0oooo0@0000010?ooo`0000<0oooo0000003oool01P3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo00H0oooo0@0000010?ooo`0000<0oooo0000003oool01P3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo00H0oooo0@0000010?ooo`0000<0oooo0000003oool01P3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo0@0000010?ooo`0000<0oooo
0000003oool01P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo0@000001
0?ooo`0000<0oooo0000003oool01P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
00H0oooo0@0000010?ooo`000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool01@3oool100000040oooo0@3oool00080oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`40oooo
00020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`050?ooo`4000000@3oool10?ooo`000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool01@3oool100000040oooo0@3oool00080oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo0@0000010?oo
o`40oooo00020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`050?ooo`4000000@3oool10?ooo`000P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool100000040oooo0@3oool00080oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo0@00
00010?ooo`40oooo00020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`050?ooo`4000000@3oool10?ooo`000P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool100000040oooo0@3oool00080
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0
oooo0@0000010?ooo`40oooo00020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`050?ooo`4000000@3oool10?ooo`000P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool100000040oooo0@3o
ool00080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo00D0oooo0@0000010?ooo`40oooo00020?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`050?ooo`4000000@3oool10?ooo`000P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool100000040
oooo0@3oool00080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo00D0oooo0@0000010?ooo`40oooo00020?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`050?ooo`4000000@3oool10?ooo`000P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool1
00000040oooo0@3oool00080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo00D0oooo0@0000010?ooo`40oooo00020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`050?ooo`4000000@3oool10?ooo`00
0P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
1@3oool100000040oooo0@3oool00080oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`40oooo00020?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`050?ooo`4000000@3oool1
0?ooo`000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool01@3oool100000040oooo0@3oool00080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`40oooo00020?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`050?ooo`400000
0@3oool10?ooo`000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool01@3oool100000040oooo0@3oool00080oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`40oooo00020?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`050?oo
o`4000000@3oool10?ooo`000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool01@3oool100000040oooo0@3oool00080oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`40oooo
00020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`050?ooo`4000000@3oool10?ooo`000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool01@3oool100000040oooo0@3oool00080oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo0@0000010?oo
o`40oooo00020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`050?ooo`4000000@3oool10?ooo`000P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool100000040oooo0@3oool00080oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo0@00
00010?ooo`40oooo00020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`050?ooo`4000000@3oool10?ooo`000P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool100000040oooo0@3oool00080
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0
oooo0@0000010?ooo`40oooo00020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`050?ooo`4000000@3oool10?ooo`000P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool100000040oooo0@3o
ool00080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`4000000@3oool1
0?ooo`000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01<0oooo1`0000070?oo
o`4000000@3oool10?ooo`000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0
oooo1P0000050240008000001`3oool100000040oooo0@3oool00080oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00D000000240000Q0000
8@0000000007024000030000003oool0oooo00D0oooo0@0000010?ooo`40oooo00030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool2000000D08@001P0000060?ooo`030000
003oool0oooo0040oooo00030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03P3o
ool6000000D0F@0000<000000?ooo`3oool0103oool00`000000oooo0?ooo`010?ooo`000`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<0000005T0001I0000201I0000
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0040oooo00030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool03P3oool00`000000F@0005T0000805T000030000003oool0oooo
00@0oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0>0?ooo`030000001I0000F@0000T0F@0000<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo
00<0000005T0001I00002@1I00000`000000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo
00030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03P3oool00`000000F@0005T0
000405T000H000001@3oool00`000000oooo0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00h0oooo1`00000508LL<0030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?oo
o`03000000277300Qa``00T0Qa``00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`010?oo
o`000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<0000008LL<027
73002@2773000`000000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo00030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool03P3oool00`000000Qa``08LL<00908LL<0030000
003oool0oooo00<0oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0=0?ooo`03000000277300Qa``00X0Qa``00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00h0oooo00<0000008LL<02773002@2773000`000000oooo0?ooo`020?ooo`030000003oool0
oooo0040oooo00030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03P3oool00`00
0000Qa``08LL<00908LL<0030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool000<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`03000000277300Qa``00@0
Qa``1P0000040?ooo`030000003oool0oooo0040oooo00030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool03P3oool7000000D0YV>200<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00h0oooo00<0
00000:ISPP2VHh802@2VHh800`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo0003
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03P3oool00`000000YV>20:ISPP09
0:ISPP030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000002VHh80YV>200T0YV>200<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00h0oooo00<000000:ISPP2VHh802@2VHh800`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0040oooo00030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
3P3oool00`000000YV>20:ISPP0:0:ISPP050000003oool0oooo0?ooo`0000000`3oool000<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?ooo`030000002VHh80YV>200T0YV>2
00D000000?ooo`3oool0oooo000000030?ooo`000`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00l0oooo00<000000:ISPP2VHh802@2VHh801@000000oooo0?ooo`3oool0000000<0
oooo00030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03`3oool00`000000YV>2
0:ISPP090:ISPP050000003oool0oooo0?ooo`0000000`3oool000<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0?0?ooo`030000002VHh80YV>200@0YV>21P0000030?ooo`030000
003oool0oooo0040oooo00030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03`3o
ool7000000D0/Ik500D000000?ooo`3oool0oooo000000030?ooo`000`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00l0oooo00<000000;6Na@2aW/D02@2aW/D01@000000oooo0?oo
o`3oool0000000<0oooo00030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03`3o
ool00`000000/Ik50;6Na@090;6Na@050000003oool0oooo0?ooo`0000000`3oool000<0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?ooo`030000002aW/D0/Ik500T0/Ik500D0
00000?ooo`3oool0oooo000000030?ooo`000`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00l0oooo00<000000;6Na@2aW/D02@2aW/D01@000000oooo0?ooo`3oool0000000<0oooo
00030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03`3oool00`000000/Ik50;6N
a@0:0;6Na@040000003oool0oooo000000<0oooo00030?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool03`3oool2000000/0/Ik500@000000?ooo`3oool000000`3oool000<0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?ooo`8000002`2aW/D010000000oooo0?oo
o`0000030?ooo`000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo0P00
000;0;6Na@040000003oool0oooo000000<0oooo00030?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0403oool00`000000/Ik50;6Na@040;6Na@H000000P3oool00`000000oooo0?oo
o`010?ooo`000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0100oooo1`000005
0:K7l0040000003oool0oooo000000<0oooo00030?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0403oool00`000000Y/O`0:K7l0090:K7l0040000003oool0oooo000000<0oooo0003
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0403oool00`000000Y/O`0:K7l003
0:K7l0030000002Vao00Y/O`00<0Y/O`00@000000?ooo`3oool000000`3oool000<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0@0?ooo`030000002Vao00Y/O`00<0Y/O`00<00000
0:K7l02Vao000`2Vao0010000000oooo0?ooo`0000030?ooo`000`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0100oooo00<000000:K7l02Vao000`2Vao000`000000Y/O`0:K7l003
0:K7l0040000003oool0oooo000000<0oooo00030?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0403oool2000000@0Y/O`00<000000:K7l02Vao000`2Vao0010000000oooo0?ooo`00
00030?ooo`000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0140oooo00D00000
0:K7l02Vao00Y/O`000000060:K7l0040000003oool0oooo000000<0oooo00030?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool04@3oool01@000000Y/O`0:K7l02Vao00000000H0Y/O`
00@000000?ooo`3oool000000`3oool000<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0A0?ooo`060000002Vao00Y/O`0:K7l0000000Y/O`1P0000020?ooo`030000003oool0oooo
0040oooo00030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04@3oool6000000D0
R=Oo00@000000?ooo`3oool000000`3oool000<0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0A0?ooo`0500000028eol0R=Oo08SGo`0000001P28eol010000000oooo0?ooo`000003
0?ooo`000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0140oooo00D0000008SG
o`28eol0R=Oo0000000608SGo`040000003oool0oooo000000<0oooo00040?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool04@3oool01@000000R=Oo08SGo`28eol0000000H0R=Oo00<0
00000?ooo`000000103oool000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0A
0?ooo`0500000028eol0R=Oo08SGo`0000001P28eol00`000000oooo000000040?ooo`00103oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0140oooo00@0000008SGo`28eol000001`28
eol00`000000oooo000000040?ooo`00103oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0100oooo0P00000208SGo`0300000028eol0R=Oo00H0000000<0oooo0000003oool00`3oool0
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0@0?ooo`L000001@1Kco400`00
0000oooo000000040?ooo`00103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0100
oooo0P00000205_?l@030000001Kco40Floa00@0Floa00@000000?ooo`3oool00000103oool000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0@0?ooo`8000000P1Kco400`000000
Floa05_?l@0405_?l@040000003oool0oooo000000@0oooo00040?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0403oool01@000000oooo0000001Kco4000000080Floa1@0000020?oo
o`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0403oool00`000000oooo00000004000000<09K3800D000000?ooo`3oool0oooo000000040?oo
o`00103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0100oooo00<000000?ooo`00
00001@0000060?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0403oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0@0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0100oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080
oooo00040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0403oool010000000oooo
0?ooo`0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool000@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0?0?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool03`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00l0oooo00D000000?ooo`3oool0oooo000000030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0?0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool03`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0?0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00l0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080
oooo00040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03`3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool000@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00l0oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool03`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0>0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0080oooo00040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
3P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080
oooo00040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03@3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool000@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool03@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0=0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080
oooo00040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03@3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool000@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3oool000001@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0303oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0<0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo
00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080
oooo00040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0303oool010000000oooo
0?ooo`0000050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool000@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000000D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3oool000001@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0303oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`020?ooo`00103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`0000001P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo0004
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0303oool00`000000oooo00000006
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool000D0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0000000H0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00/0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool02`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0;0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?oo
o`001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo00@000000?ooo`3o
ool000001P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00050?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool02`3oool010000000oooo0?ooo`0000060?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0000000L0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00<0oooo00050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo000000070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
000000L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`001@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo00<000000?ooo`0000001`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool02`3oool00`000000oooo000000070?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3oool00`3ooolI000000H0oooo
00<000000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000
000:06T000040000001Y0000J@00000000D0J@0000<000000?ooo`0000001P3oool00`000000oooo
0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000X0J@0000@0
000006T0001Y000000001@1Y00000`000000oooo000000060?ooo`030000003oool0oooo00<0oooo
00050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000002P1Y00000`000000J@000000
000606T000030000003oool0000000H0oooo00<000000?ooo`3oool00`3oool000D0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0000000:06T000030000001Y0000000000H0J@0000<00000
0?ooo`0000001P3oool00`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0000000X0J@0000<0000006T0000000001P1Y000010000000oooo0?ooo`000005
0?ooo`030000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool00000301Y00000`000000J@0006T0000406T000040000003oool0oooo000000D0oooo00<0
00000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000=
06T000030000001Y0000J@0000D0J@0000<000000?ooo`0000001@3oool00`000000oooo0?ooo`03
0?ooo`001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000d0J@0000<0000006T0
001Y00001@1Y00000`000000oooo000000050?ooo`030000003oool0oooo00<0oooo00050?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`0000003@1Y00000`000000J@0006T0000506T00003
0000003oool0000000D0oooo00<000000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0000000=06T000030000001Y0000J@0000D0J@0000<000000?ooo`000000
1@3oool00`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0000000`0J@0000<0000006T0001Y00001P1Y00000`000000oooo000000050?ooo`030000003o
ool0oooo00<0oooo00050?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000301Y0000
0`000000J@0006T0000606T000030000003oool0000000D0oooo00<000000?ooo`3oool00`3oool0
00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000F000000030?ooo`000000oooo
00@0oooo00<000000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0000000<0;2bfP030000002`/]X0/;;J00H0/;;J00<000000?ooo`0000001@3oool00`000000
oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`020?oooaX0000000<0oooo0000003oool0
0`3oool00`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`020?ooo`8000003@1Y
00000`000000J@0006T0000706T000030000003oool0000000@0oooo00<000000?ooo`3oool00`3o
ool000D0oooo00<000000?ooo`3oool00P3oool2000000d0J@0000<0000006T0001Y00001`1Y0000
0`000000oooo000000040?ooo`030000003oool0oooo00<0oooo00050?ooo`070000003oool0oooo
0?ooo`000000oooo0000000=06T000030000001Y0000J@0000L0J@0000<000000?ooo`000000103o
ool00`000000oooo0?ooo`030?ooo`001@3oool01`000000oooo0?ooo`3oool000000?ooo`000000
3@1Y00000`000000J@0006T0000706T000030000003oool0000000@0oooo00<000000?ooo`3oool0
0`3oool000D0oooo00L000000?ooo`3oool0oooo0000003oool0000000`0J@0000<0000006T0001Y
0000201Y00000`000000oooo000000040?ooo`030000003oool0oooo00<0oooo00050?ooo`070000
003oool0oooo0?ooo`000000oooo0000000<06T000030000001Y0000J@0000P0J@0000<000000?oo
o`000000103oool00`000000oooo0?ooo`030?ooo`001@3oool01`000000oooo0?ooo`3oool00000
0?ooo`000000301Y00000`000000J@0006T0000806T000030000003oool0000000@0oooo00<00000
0?ooo`3oool00`3oool000D0oooo00@000000?ooo`3oool0oooo0P00000=06T000030000001Y0000
J@0000P0J@0000<000000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`001@3oool01000
0000oooo0?ooo`3oool2000000d0J@0000<0000006T0001Y00002@1Y0002000000@0oooo00<00000
0?ooo`3oool00`3oool000D0oooo00@000000?ooo`3oool0oooo0P00000I06T000030000003oool0
000000<0oooo00<000000?ooo`3oool00`3oool000D0oooo00@000000?ooo`3oool0oooo0P00000I
06T000030000003oool0000000<0oooo00<000000?ooo`3oool00`3oool000D0oooo00@000000?oo
o`3oool0oooo0P00000I06T000030000003oool0000000<0oooo00<000000?ooo`3oool00`3oool0
00D0oooo00@000000?ooo`3oool0oooo0P00000I06T000030000003oool0000000<0oooo00<00000
0?ooo`3oool00`3oool000D0oooo00H000000?ooo`3oool000000?ooo`00000I06T000030000003o
ool0000000<0oooo00<000000?ooo`3oool00`3oool000D0oooo00H000000?ooo`3oool000000?oo
o`00000I06T000030000003oool0000000<0oooo00<000000?ooo`3oool00`3oool000D0oooo00D0
00000?ooo`3oool000000?ooo`0K000000030?ooo`000000oooo0080oooo00<000000?ooo`3oool0
0`3oool000D0oooo00H000000?ooo`3oool000000?ooo`00000I0:jegP030000003oool0000000<0
oooo00<000000?ooo`3oool00`3oool000D0oooo00H000000?ooo`3oool000000?ooo`00000I0:je
gP030000003oool0000000<0oooo00<000000?ooo`3oool00`3oool000D0oooo00H000000?ooo`3o
ool000000?ooo`00000I0:jegP040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3o
ool000H0oooo00D000000?ooo`000000oooo0000000I0:jegP060000003oool0oooo0000003oool0
00001P3oool000H0oooo00D000000?ooo`000000oooo0000000I0:jegP060000003oool0oooo0000
003oool000001P3oool000H0oooo00D000000?ooo`000000oooo0000000I0:jegP060000003oool0
oooo0000003oool000001P3oool000H0oooo00D000000?ooo`000000oooo0000000I0:jegP060000
003oool0oooo0000003oool000001P3oool000H0oooo00D000000?ooo`000000oooo0000000I0:je
gP060000003oool0oooo0000003oool000001P3oool000H0oooo00D000000?ooo`000000oooo0000
000I0:jegP060000003oool0oooo0000003oool000001P3oool000H0oooo0P0000020?ooo`030000
002^]Mh0[[GN01L0[[GN00H000000?ooo`3oool000000?ooo`0000060?ooo`001P3oool200000080
oooo6`0000020?ooo`030000003oool0000000H0oooo00060?ooo`8000007`3oool00`000000oooo
000000060?ooo`001P3oool200000200oooo0P0000060?ooo`001P3oool200000200oooo0P000006
0?ooo`001P3oool200000200oooo0P0000060?ooo`001P3oool200000200oooo0P0000060?ooo`00
1P3oool200000200oooo0P0000060?ooo`001P3oool200000200oooo0P0000060?ooo`001P3oool2
00000200oooo0P0000060?ooo`001P3oool200000200oooo0P0000060?ooo`001P3oool200000200
oooo0P0000060?ooo`001P3oool00`000000oooo0?ooo`0O0?ooo`8000001P3oool000H0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo00@0oooo00060?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool0103oool000H0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`040?ooo`00
1P3ooolT000000H0oooo000`0?ooo`00<03oool00001\
\>"],
  ImageRangeCache->{{{0, 47}, {286.75, 0}} -> {0.420014, -0.00850194, \
0.00340363, 0.00340363}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#4", "Text"],

Cell[CellGroupData[{

Cell["Hz0A[[-4]]", "Input"],

Cell[BoxData[
    \(1.7072638005392924`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pretty[Chop[e2ni . eigenvectors0A[\([\(-4\)]\)], 10^\(-4\)]]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
          {"\<\"optic\"\>", "0", "0", "0", "1.`", "0", "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Status["\<Plotting stage 0A mode 4\>"]\ ; 
    eigenplot[eigenvectors0A[\([\(-4\)]\)],  .5, {0, \(-3\), \(- .25\)}, \ 
      floatmatrix0A]\ \ ; Done[]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 7.06045 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-3.10065 7.20129 -0.140839 7.20129 [
[ 0 0 0 0 ]
[ 1 7.06045 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
.0146 7.06045 L
s
.0146 7.06045 m
.07649 6.39036 L
s
.07649 6.39036 m
.06541 .2361 L
s
.06541 .2361 m
0 0 L
s
1 0 m
.93459 .2361 L
s
.93459 .2361 m
.92351 6.39036 L
s
.92351 6.39036 m
.9854 7.06045 L
s
.9854 7.06045 m
1 0 L
s
0 0 m
.0146 7.06045 L
s
.0146 7.06045 m
.9854 7.06045 L
s
.9854 7.06045 m
1 0 L
s
1 0 m
0 0 L
s
.06541 .2361 m
.93459 .2361 L
s
.93459 .2361 m
.92351 6.39036 L
s
.92351 6.39036 m
.07649 6.39036 L
s
.07649 6.39036 m
.06541 .2361 L
s
0 0 m
1 0 L
1 7.06045 L
0 7.06045 L
closepath
clip
newpath
.5 Mabswid
.707 .593 .726 r
.5 6.52002 m .8429 6.52002 L p .1566 6.1822 L F P
0 g
s
.707 .593 .726 r
.8429 6.52002 m .8434 6.1822 L .1566 6.1822 L p F P
0 g
s
.707 .593 .726 r
.1566 6.1822 m .1571 6.52002 L .5 6.52002 L p F P
0 g
s
.745 .608 .039 r
.15109 6.60256 m .1571 6.52002 L p .14435 6.33843 L F P
0 g
s
.745 .608 .039 r
.1571 6.52002 m .1566 6.1822 L .14435 6.33843 L p F P
0 g
s
0 0 .039 r
.8434 6.1822 m .8429 6.52002 L .84891 6.60256 L p F P
0 g
s
0 0 .039 r
.85565 6.33843 m .8434 6.1822 L p .84891 6.60256 L F P
0 g
s
.405 0 0 r
.8434 6.1822 m .85565 6.33843 L .14435 6.33843 L p F P
0 g
s
.405 0 0 r
.14435 6.33843 m .1566 6.1822 L .8434 6.1822 L p F P
0 g
s
.15256 3.93932 m
.454 6.24998 L
s
.46554 6.33843 m
.5 6.60256 L
s
.816 .649 .675 r
.05609 3.53518 m .05599 3.58493 L p .25046 3.3286 L F P
0 g
s
.07729 3.36239 m
.09451 3.49435 L
s
.816 .649 .675 r
.05599 3.58493 m .26883 3.57467 L .25046 3.3286 L p F P
0 g
s
.10601 3.58252 m
.15256 3.93932 L
s
.816 .649 .675 r
.25046 3.3286 m .05652 3.33664 L .05609 3.53518 L p F P
0 g
s
.816 .715 .753 r
.05652 3.33664 m .25046 3.3286 L .26836 3.08722 L p F P
0 g
s
.804 .572 .586 r
.05948 3.81807 m .32193 3.80376 L .26883 3.57467 L p F P
0 g
s
.804 .572 .586 r
.26883 3.57467 m .05599 3.58493 L .05379 3.79302 L p F P
0 g
s
.804 .572 .586 r
.05379 3.79302 m .05948 3.81807 L p .26883 3.57467 L F P
0 g
s
.816 .715 .753 r
.05617 3.27863 m .05652 3.33664 L p .26836 3.08722 L F P
0 g
s
.816 .715 .753 r
.26836 3.08722 m .05507 3.09467 L .05617 3.27863 L p F P
0 g
s
.803 .778 .829 r
.05507 3.09467 m .26836 3.08722 L .32123 2.87199 L p F P
0 g
s
.745 .608 .039 r
.14435 6.33843 m .14488 6.68805 L .15109 6.60256 L p F P
0 g
s
0 0 .039 r
.84891 6.60256 m .85512 6.68805 L .85565 6.33843 L p F P
0 g
s
.774 .467 .466 r
.14171 4.01101 m .40542 3.99522 L .32193 3.80376 L p F P
0 g
s
.774 .467 .466 r
.32193 3.80376 m .05948 3.81807 L .14171 4.01101 L p F P
0 g
s
.803 .778 .829 r
.05457 3.06184 m .05507 3.09467 L p .32123 2.87199 L F P
0 g
s
.803 .778 .829 r
.32123 2.87199 m .05774 2.87966 L p .05457 3.06184 L F P
0 g
s
.763 .842 .911 r
.05774 2.87966 m .32123 2.87199 L .4049 2.70279 L p F P
0 g
s
.803 .778 .829 r
.05774 2.87966 m .05212 2.90323 L .05457 3.06184 L p F P
0 g
s
.7 .292 .271 r
.24688 4.14774 m .51232 4.13081 L .40542 3.99522 L p F P
0 g
s
.7 .292 .271 r
.40542 3.99522 m .14171 4.01101 L .24688 4.14774 L p F P
0 g
s
.763 .842 .911 r
.4049 2.70279 m .13975 2.70931 L .05774 2.87966 L p F P
0 g
s
.643 .89 .985 r
.13975 2.70931 m .4049 2.70279 L .5124 2.59648 L p F P
0 g
s
.01 w
.35003 2.55072 Mdot
.64997 2.55072 Mdot
.5 Mabswid
.481 0 0 r
.36578 4.21387 m .63324 4.19627 L .51232 4.13081 L p F P
0 g
s
.481 0 0 r
.51232 4.13081 m .24688 4.14774 L .36578 4.21387 L p F P
0 g
s
.707 .593 .726 r
.5 6.68805 m .14488 6.68805 L .14435 6.33843 L p F P
0 g
s
.707 .593 .726 r
.85565 6.33843 m .85512 6.68805 L .5 6.68805 L p F P
0 g
s
.707 .593 .726 r
.14435 6.33843 m .85565 6.33843 L p .5 6.68805 L F P
0 g
s
.643 .89 .985 r
.5124 2.59648 m .24524 2.60228 L .13975 2.70931 L p F P
0 g
s
.253 .758 .878 r
.24524 2.60228 m .5124 2.59648 L .63416 2.56514 L p F P
0 g
s
.707 .593 .726 r
.5 6.71723 m .85725 6.71723 L p .14222 6.36556 L F P
0 g
s
.707 .593 .726 r
.85725 6.71723 m .85778 6.36556 L .14222 6.36556 L p F P
0 g
s
.707 .593 .726 r
.14222 6.36556 m .14275 6.71723 L .5 6.71723 L p F P
0 g
s
.745 .608 .039 r
.13623 6.80689 m .14275 6.71723 L p .1289 6.5354 L F P
0 g
s
.745 .608 .039 r
.14275 6.71723 m .14222 6.36556 L .1289 6.5354 L p F P
0 g
s
0 0 .039 r
.85778 6.36556 m .85725 6.71723 L .86377 6.80689 L p F P
0 g
s
0 0 .039 r
.8711 6.5354 m .85778 6.36556 L p .86377 6.80689 L F P
0 g
s
.405 0 0 r
.85778 6.36556 m .8711 6.5354 L .1289 6.5354 L p F P
0 g
s
.405 0 0 r
.1289 6.5354 m .14222 6.36556 L .85778 6.36556 L p F P
0 g
s
.09 .649 .741 r
.48731 4.20071 m .75693 4.18301 L .63324 4.19627 L p F P
0 g
s
.09 .649 .741 r
.63324 4.19627 m .36578 4.21387 L .48731 4.20071 L p F P
0 g
s
.253 .758 .878 r
.63416 2.56514 m .36485 2.57077 L .24524 2.60228 L p F P
0 g
s
.383 0 0 r
.36485 2.57077 m .63416 2.56514 L .75862 2.61437 L p F P
0 g
s
.596 .902 .985 r
.59941 4.10691 m .87107 4.08972 L .75693 4.18301 L p F P
0 g
s
.596 .902 .985 r
.75693 4.18301 m .48731 4.20071 L .59941 4.10691 L p F P
0 g
s
.745 .608 .039 r
.1289 6.5354 m .12947 6.89989 L .13623 6.80689 L p F P
0 g
s
0 0 .039 r
.86377 6.80689 m .87053 6.89989 L .8711 6.5354 L p F P
0 g
s
.54816 6.45872 m
.86554 4.16414 L
s
.5 6.80689 m
.53755 6.5354 L
s
.383 0 0 r
.75862 2.61437 m .48723 2.62043 L .36485 2.57077 L p F P
0 g
s
.682 .24 .195 r
.48723 2.62043 m .75862 2.61437 L .87318 2.74176 L p F P
0 g
s
.76 .867 .927 r
.69018 3.93962 m .9636 3.92353 L .87107 4.08972 L p F P
0 g
s
.76 .867 .927 r
.87107 4.08972 m .59941 4.10691 L .69018 3.93962 L p F P
0 g
s
.86554 4.16414 m
.87403 4.1027 L
s
.682 .24 .195 r
.87318 2.74176 m .59997 2.74885 L .48723 2.62043 L p F P
0 g
s
.777 .45 .434 r
.59997 2.74885 m .87318 2.74176 L .96552 2.9362 L p F P
0 g
s
.81 .796 .839 r
.97011 3.8995 m .9636 3.92353 L p .74944 3.7146 L F P
0 g
s
.81 .796 .839 r
.9636 3.92353 m .69018 3.93962 L .74944 3.7146 L p F P
0 g
s
.81 .796 .839 r
.74944 3.7146 m .97341 3.70279 L .97011 3.8995 L p F P
0 g
s
.87403 4.1027 m
.92547 3.73082 L
s
.707 .594 .727 r
.5 6.89989 m .12947 6.89989 L .1289 6.5354 L p F P
0 g
s
.707 .594 .727 r
.8711 6.5354 m .87053 6.89989 L .5 6.89989 L p F P
0 g
s
.707 .594 .727 r
.1289 6.5354 m .8711 6.5354 L p .5 6.89989 L F P
0 g
s
.01 w
.34294 2.58599 Mdot
.65706 2.58599 Mdot
.5 Mabswid
.777 .45 .434 r
.96552 2.9362 m .69097 2.94483 L .59997 2.74885 L p F P
0 g
s
.812 .57 .572 r
.96552 2.9362 m .97196 2.96229 L .97402 3.14251 L p F P
0 g
s
.812 .57 .572 r
.69097 2.94483 m .96552 2.9362 L p .97402 3.14251 L F P
0 g
s
.825 .727 .756 r
.97374 3.65147 m .97341 3.70279 L p .77025 3.45504 L F P
0 g
s
.825 .727 .756 r
.97341 3.70279 m .74944 3.7146 L .77025 3.45504 L p F P
0 g
s
.825 .727 .756 r
.77025 3.45504 m .97505 3.44571 L .97374 3.65147 L p F P
0 g
s
.92547 3.73082 m
.95829 3.49352 L
s
.812 .57 .572 r
.97402 3.14251 m .97445 3.18026 L p .69097 2.94483 L F P
0 g
s
.812 .57 .572 r
.97445 3.18026 m .74999 3.18884 L .69097 2.94483 L p F P
0 g
s
.825 .655 .671 r
.74999 3.18884 m .97445 3.18026 L .97491 3.38185 L p F P
0 g
s
.825 .655 .671 r
.97491 3.38185 m .97505 3.44571 L p .74999 3.18884 L F P
0 g
s
.825 .655 .671 r
.97505 3.44571 m .77025 3.45504 L .74999 3.18884 L p F P
0 g
s
.25 Mabswid
0 0 m
.0146 7.06045 L
s
.0146 7.06045 m
.9854 7.06045 L
s
.9854 7.06045 m
1 0 L
s
1 0 m
0 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{40.75, 287.688},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40000X00017b000`400?l00000o`00003o:03oool0
02P0oooo000X0?ooo`00:000000000030000003oool0oooo02@0oooo0@00000000030000003oool0
oooo02@0oooo0@00000000800000903oool2000000000P00000T0?ooo`8000000002000002@0oooo
0P00000000800000903oool20000000000<000000?ooo`0000008P3oool100000040oooo0@000000
00030000003oool000000280oooo0@0000010?ooo`40000000000`000000oooo0000000S00000040
oooo0@00000000030000003oool000000280oooo0@0000010?ooo`40000000000`000000oooo0000
000R0?ooo`4000000@3oool10000000000<000000?ooo`0000008P3oool100000040oooo0@000000
00030000003oool000000280oooo0@0000010?ooo`40000000000`000000oooo0000000R0?ooo`40
00000@3oool10000000000<000000?ooo`0000008P3oool100000040oooo0@00000000030000003o
ool000000280oooo0@0000010?ooo`40000000000`000000oooo0000000R0?ooo`4000000@3oool1
0000000000<000000?ooo`0000008P3oool100000040oooo0@00000000030000003oool000000280
oooo0@0000010?ooo`40000000000`000000oooo0000000R0?ooo`4000000@3oool10000000000<0
00000?ooo`0000008P3oool100000040oooo0@00000000030000003oool000000280oooo0@000001
0?ooo`40000000000`000000oooo0000000R0?ooo`4000000@3oool10000000000<000000?ooo`00
00008P3oool100000040oooo0@00000000030000003oool000000280oooo0@0000010?ooo`400000
00000`000000oooo0000000R0?ooo`4000000@3oool10000000000<000000?ooo`0000008P3oool1
00000040oooo0@00000000030000003oool000000280oooo0@0000010?ooo`40000000000`000000
oooo0000000R0?ooo`4000000@3oool10000000000<000000?ooo`0000008P3oool100000040oooo
0@00000000030000003oool000000280oooo0@0000010?ooo`40000000000`000000oooo0000000R
0?ooo`4000000@3oool10000000000<000000?ooo`0000008P3oool100000040oooo0@0000000003
0000003oool000000280oooo0@0000010?ooo`40000000000`000000oooo0000000R0?ooo`400000
0@3oool10000000000<000000?ooo`0000008P3oool100000040oooo0@00000000030000003oool0
00000280oooo0@0000010?ooo`40000000000`000000oooo0000000R0?ooo`4000000@3oool10000
000000<000000?ooo`0000008P3oool100000040oooo0@00000000030000003oool000000280oooo
0@0000010?ooo`40000000000`000000oooo0000000R0?ooo`4000000@3oool10000000000<00000
0?ooo`0000008P3oool100000040oooo0@00000000030000003oool000000280oooo0@0000010?oo
o`40000000000`000000oooo0000000R0?ooo`4000000@3oool10000000000<000000?ooo`000000
8P3oool100000040oooo0@00000000030000003oool000000280oooo0@0000010?ooo`4000000000
0`000000oooo0000000R0?ooo`4000000@3oool10000000000<000000?ooo`0000008P3oool10000
0040oooo0@00000000030000003oool000000280oooo0@0000010?ooo`40000000000`000000oooo
0000000R0?ooo`4000000@3oool10000000000<000000?ooo`0000008P3oool100000040oooo0@00
000000030000003oool000000280oooo0@0000010?ooo`40000000000`000000oooo0000000R0?oo
o`4000000@3oool10000000000<000000?ooo`0000008P3oool100000040oooo0@00000000030000
003oool000000280oooo0@0000010?ooo`40000000000`000000oooo0000000R0?ooo`4000000@3o
ool10000000000<000000?ooo`0000008P3oool100000040oooo0@00000000030000003oool00000
0280oooo0@0000010?ooo`40000000000`000000oooo0000000R0?ooo`4000000@3oool100000000
00<000000?ooo`0000008P3oool100000040oooo0@00000000030000003oool000000280oooo0@00
00010?ooo`40000000000`000000oooo0000000R0?ooo`4000000@3oool10000000000<000000?oo
o`0000008P3oool100000040oooo0@00000000030000003oool000000280oooo0@0000010?ooo`40
000000000`000000oooo0000000R0?ooo`4000000@3oool10000000000<000000?ooo`0000008P3o
ool100000040oooo0@00000000030000003oool000000280oooo0@0000010?ooo`40000000000`00
0000oooo0000000R0?ooo`4000000@3oool10000000000<000000?ooo`0000008P3oool100000040
oooo0@00000000030000003oool000000280oooo0@0000010?ooo`40000000000`000000oooo0000
000R0?ooo`4000000@3oool10000000000<000000?ooo`0000008P3oool100000040oooo0@000000
00030000003oool000000280oooo0@0000010?ooo`40000000000`000000oooo0000000R0?ooo`40
00000@3oool10000000000<000000?ooo`0000008P3oool100000040oooo0@00000000030000003o
ool000000280oooo0@0000010?ooo`40000000000`000000oooo0000000R0?ooo`4000000@3oool1
0000000000<000000?ooo`0000008P3oool100000040oooo0@00000000030000003oool000000280
oooo0@0000010?ooo`40000000000`000000oooo0000000R0?ooo`4000000@3oool10000000000<0
00000?ooo`0000008P3oool100000040oooo0@00000000030000003oool000000280oooo0@000001
0?ooo`40000000000`000000oooo0000000R0?ooo`4000000@3oool10000000000<000000?ooo`00
00008P3oool100000040oooo0@00000000030000003oool000000280oooo0@0000010?ooo`400000
00000`000000oooo0000000R0?ooo`4000000@3oool10000000000<000000?ooo`0000008P3oool1
00000040oooo0@00000000030000003oool000000280oooo0@0000010?ooo`40000000000`000000
oooo0000000R0?ooo`4000000@3oool10000000000<000000?ooo`0000008P3oool100000040oooo
0@00000000030000003oool000000280oooo0@0000010?ooo`40000000000`000000oooo0000000R
0?ooo`4000000@3oool10000000000<000000?ooo`0000008P3oool100000040oooo0@0000000003
0000003oool000000280oooo0@0000010?ooo`40000000000`000000oooo0000000R0?ooo`400000
0@3oool10000000000<000000?ooo`0000008P3oool100000040oooo0@00000000030000003oool0
00000280oooo0@0000010?ooo`40000000000`000000oooo0000000R0?ooo`4000000@3oool10000
000000<000000?ooo`0000008P3oool100000040oooo0@00000000030000003oool000000280oooo
0@0000010?ooo`40000000000`000000oooo0000000;0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0203oool100000040oooo0@00000000030000003oool0000000T0oooo3`00000:
0?ooo`4000000@3oool10000000000<000000?ooo`0000001P3oool9000000T0HP000P0000080?oo
o`4000000@3oool10000000000<000000?ooo`0000001@3oool00`000000Y>?l0:CSo0070:CSo0d0
00001P3oool100000040oooo0@00000000030000003oool0000000@0oooo00<000000:CSo02Tho`0
202Tho`00`000000oooo0000000:0:hm<@030000003oool0oooo00<0oooo0@0000010?ooo`400000
00000`000000oooo000000040?ooo`030000002Tho`0Y>?l00L0Y>?l00D000000?ooo`3oool0oooo
0000000:0:hm<@030000003oool0oooo0080oooo0@0000010?ooo`40000000000`000000oooo0000
00030?ooo`030000002Tho`0Y>?l0080Y>?l1P0000040?ooo`030000002^?C40[Sda00P0[Sda00<0
00000?ooo`3oool00P3oool100000040oooo0@00000000030000003oool000000080oooo1P000004
0<?Gj@030000003oool0oooo00@0oooo00<000000:hm<@2^?C40202^?C401P000000oooo0?ooo`3o
ool000000?ooo`40000000001@000000oooo0000003oool0000000X0`mOY00<000000?ooo`3oool0
1@3oool<00000080oooo0@0000010?ooo`40000000001@000000oooo0000003oool0000000T0`mOY
00<000000?ooo`3oool01P3oool00`000000aW=_0<IcK`080<IcK`050000003oool0oooo0000003o
ool00@00000000040000003oool00000000000X0`mOY00<000000?ooo`3oool01`3oool00`000000
aW=_0<IcK`080<IcK`040000003oool000000?ooo`400000000010000000oooo0000000000090<?G
j@030000003oool0oooo00P0oooo00<000000<IcK`36Lfl02036Lfl010000000oooo0000003oool1
0000000000<000000?ooo`0000002P33enT00`000000oooo0?ooo`090?ooo`0300000036Lfl0aW=_
00P0aW=_0P0000010?ooo`40000000000`000000oooo0000000:000000`0oooo00<000000<IcK`36
Lfl02036Lfl200000040oooo0@00000000030000003oool0000000T0cLOD00<000000?ooo`3oool0
2`3oool00`000000aW=_0<IcK`080<IcK`4000000@3oool10000000000<000000?ooo`0000002@3=
am@00`000000oooo0?ooo`0;0?ooo`0300000036Lfl0aW=_00P0aW=_0@0000010?ooo`4000000000
0`000000oooo000000080<g7e0030000003oool0oooo00d0oooo3@00000000030000003oool00000
00P0cLOD00<000000?ooo`3oool03@3oool00`000000ci6B0<nATP080<nATP80000000000`000000
oooo000000080<g7e0030000003oool0oooo00d0oooo00<000000<nATP3?TI80203?TI8200000000
00<000000?ooo`000000203=am@00`000000oooo0?ooo`0>0?ooo`030000003?TI80ci6B00L0ci6B
0P00000000030000003oool0000000L0cLOD00<000000?ooo`3oool03`3oool00`000000ci6B0<nA
TP070<nATP80000000000`000000oooo000000070<g7e0030000003oool0oooo00l0oooo00<00000
0<nATP3?TI801`3?TI820000000000<000000?ooo`0000002000000A0?ooo`030000003?TI80ci6B
00L0ci6B0P00000000030000003oool0000000L0d;O000<000000?ooo`3oool03`3oool00`000000
ci6B0<nATP070<nATP80000000000`000000oooo000000070=2g`0030000003oool0oooo0100oooo
00<000000<nATP3?TI801P3?TI820000000000<000000?ooo`0000001`3@]l000`000000oooo0?oo
o`0@0?ooo`030000003?TI80ci6B0080ci6B1P00000000030000003oool0000000L0d;O000<00000
0?ooo`3oool0403oool5000000@0djN[0P00000000030000003oool0000000H0d;O000<000000?oo
o`3oool04@3oool00`000000djN[0=>WZ`060=>WZ`80000000000`000000oooo000000060=2g`003
0000003oool0oooo0140oooo00<000000=>WZ`3CYj/01P3CYj/20000000000<000000?ooo`000000
1P3@]l000`000000oooo0?ooo`0A0?ooo`030000003CYj/0djN[00H0djN[0P00000000030000003o
ool0000000H0d;O000<000000?ooo`3oool04@3oool00`000000djN[0=>WZ`060=>WZ`8000000000
0`000000oooo00000007000001<0oooo00<000000=>WZ`3CYj/01P3CYj/20000000000<000000?oo
o`0000001P3@YZ`00`000000oooo0?ooo`0B0?ooo`030000003CYj/0djN[00D0djN[0P0000000003
0000003oool0000000H0d:J/00<000000?ooo`3oool04P3oool00`000000djN[0=>WZ`050=>WZ`80
000000000`000000oooo000000060=2V[0030000003oool0oooo0180oooo00<000000=>WZ`3CYj/0
1@3CYj/20000000000<000000?ooo`0000001P3@YZ`00`000000oooo0?ooo`0B0?ooo`030000003C
Yj/0djN[00D0djN[0P00000000030000003oool0000000H0d:J/00<000000?ooo`3oool04P3oool:
0000000000<000000?ooo`0000001`3@YZ`00`000000oooo0?ooo`0A0?ooo`030000003C^/40dk[1
00D0dk[10P00000000040000003oool00000000000H0d:J/00<000000?ooo`3oool04@3oool00`00
0000dk[10=>j`@050=>j`@80000000000`000000oooo000000070=2V[0030000003oool0oooo0140
oooo00<000000=>j`@3C^/401@3C^/420000000000<000000?ooo`0000001`3@YZ`00`000000oooo
0?ooo`0A0?ooo`030000003C^/40dk[100D0dk[10P00000000030000003oool0000000P000004P3o
ool00`000000dk[10=>j`@050=>j`@<0000000000`000000oooo000000070<fBUP030000003oool0
oooo0100oooo00<000000=>j`@3C^/401@3C^/430000000000<000000?ooo`0000001`3=TYH00`00
0000oooo0?ooo`0@0?ooo`030000003C^/40dk[100D0dk[10`00000000030000003oool0000000P0
cI:F00<000000?ooo`3oool03`3oool00`000000dk[10=>j`@050=>j`@<0000000000`000000oooo
000000080<fBUP030000003oool0oooo00l0oooo00<000000=>j`@3C^/40103C^/400`000000dk[1
000000010000000000<000000?ooo`000000203=TYH00`000000oooo0?ooo`0?0?ooo`/000000000
0`000000oooo000000080<fBUP030000003oool0oooo00l0oooo00<000000<o;eP3?bmH0103?bmH0
0`000000cl_F000000010000000000<000000?ooo`0000002@3=TYH00`000000oooo0?ooo`0>0?oo
o`030000003?bmH0cl_F00@0cl_F00<000000<o;eP0000000@00000000030000003oool0000000T0
cI:F00<000000?ooo`3oool03@3oool00`000000cl_F0<o;eP050<o;eP030000003?bmH000000040
000000000`000000oooo000000050<fBUPD000003`3oool00`000000cl_F0<o;eP050<o;eP030000
003?bmH000000040000000000`000000oooo00000005000000@0aWMg00<000000?ooo`3oool03@3o
ool00`000000cl_F0<o;eP040<o;eP030000003?bmH0cl_F0080000000000`000000oooo0000000:
0<IgM`030000003oool0oooo00`0oooo00<000000<o;eP3?bmH0103?bmH00`000000cl_F0<o;eP02
0000000000@000000?ooo`3oool000002@36MgL00`000000oooo0?ooo`0;0?ooo`030000003?bmH0
cl_F00D0cl_F00<000000<o;eP3?bmH00P00000000040000003oool0oooo000000X0aWMg00<00000
0?ooo`3oool02P3oool00`000000cl_F0<o;eP050<o;eP030000003?bmH0cl_F0080000000000`00
0000oooo0?ooo`02000000T0aWMg00<000000?ooo`3oool02P3oool=0000000000<000000?ooo`3o
ool00P00000:0<IgM`030000003oool0oooo00P0oooo00<000000<;Mk@32gNd01P32gNd010000000
`]g]0000003oool10000000000H000000?ooo`3oool000000?ooo`0000090<IgM`030000003oool0
oooo00P0oooo00<000000<;Mk@32gNd01P32gNd010000000`]g]0000003oool10000000000D00000
0?ooo`3oool000000?ooo`0<000000P0oooo00<000000<;Mk@32gNd01`32gNd200000080oooo0@00
000000040000003oool0oooo00000080oooo00<000000;=:A@2cBTD0202cBTD00`000000oooo0?oo
o`050?ooo`0300000032gNd0`]g]00H0`]g]0`0000020?ooo`400000000010000000oooo0?ooo`00
00020?ooo`030000002cBTD0/dY500T0/dY500<000000?ooo`3oool00`3oool00`000000`]g]0<;M
k@070<;Mk@<000000P3oool10000000000@000000?ooo`3oool000000`3oool00`000000/dY50;=:
A@080;=:A@030000003oool0oooo00<0oooo00<000000<;Mk@32gNd00P32gNd6000000040?ooo`00
0000oooo0?ooo`400000000010000000oooo0?ooo`0000030?ooo`8000002P2cBTD010000000oooo
0?ooo`3oool6000000@0V>Kl0P000000103oool000000?ooo`3oool10000000000@000000?ooo`3o
ool000000`3oool2000000H0/dY51P0000000`3oool0000009SVo00809SVo0050000003oool00000
0?ooo`0000000P3oool10000000000@000000?ooo`3oool000000`3oool00`000000oooo00000005
000000H0N`0000<0000009SVo02Hi_`01`2Hi_`01P000000oooo0?ooo`000000oooo00000080oooo
0@00000000040000003oool0oooo000000<0oooo00@000000?ooo`3oool0oooo0P00000707/00003
0000002Hi_`0V>Kl0080V>Kl1P0000030?ooo`030000003oool000000080oooo0@00000000040000
003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool?000000H0oooo00<000000?ooo`00
00000P3oool10000000000@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool000000080oooo0@00000000040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool05P3oool010000000oooo0?ooo`0000020?ooo`400000000010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo01H0oooo00@000000?ooo`3oool000000P3oool10000000000@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`0F0?ooo`040000003oool0oooo00000080oooo0@00
000000040000003oool0oooo000000@0oooo00<000000?ooo`3oool05P3oool010000000oooo0?oo
o`0000020?ooo`400000000010000000oooo0?ooo`0000040?ooo`030000003oool0oooo01H0oooo
00@000000?ooo`3oool000000P3oool10000000000@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`0F0?ooo`040000003oool0oooo00000080oooo0@00000000040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool05P3oool010000000oooo0?ooo`0000020?ooo`40000000001000
0000oooo0?ooo`0000050?ooo`030000003oool0oooo01@0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`400000000010000000oooo0?ooo`0000050?ooo`030000003oool0oooo01@0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`400000000010000000oooo0?ooo`0000050?ooo`030000
003oool0oooo01@0oooo00D000000?ooo`3oool0oooo000000020?ooo`400000000010000000oooo
0?ooo`0000050?ooo`030000003oool0oooo01@0oooo00D000000?ooo`3oool0oooo000000020?oo
o`400000000010000000oooo0?ooo`0000050?ooo`030000003oool0oooo01@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`400000000010000000oooo0?ooo`0000050?ooo`030000003oool0
oooo01@0oooo00D000000?ooo`3oool0oooo000000020?ooo`400000000010000000oooo0?ooo`00
00050?ooo`030000003oool0oooo01@0oooo00D000000?ooo`3oool0oooo000000020?ooo`400000
000010000000oooo0?ooo`0000060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`010000000000@000000?ooo`3oool000001P3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@00000000040000003o
ool0oooo000000H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00400000000010000000oooo0?ooo`0000060?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`010000000000@000000?ooo`3oool00000
1P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0@00000000040000003oool0oooo000000H0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00400000000010000000oooo0?ooo`0000060?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`010000000000@0
00000?ooo`3oool000001P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00@00000000040000003oool0oooo000000L0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00400000000010000000oooo0?oo
o`0000070?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`010000000000@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00@00000000040000003oool0oooo000000L0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00400000
000010000000oooo0?ooo`0000070?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`010000000000@000000?ooo`3oool000001`3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00@00000000040000003o
ool0oooo000000L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00400000000010000000oooo0?ooo`0000070?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`010000000000@000000?ooo`3oool00000
203oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0@00000000040000003oool0oooo000000P0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00400000000010000000oooo0?ooo`0000080?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`010000000000@0
00000?ooo`3oool00000203oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00@00000000040000003oool0oooo000000P0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00400000000010000000oooo0?oo
o`0000080?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`010000000000@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00@00000000040000003oool0oooo000000T0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00400000
000010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`010000000000@000000?ooo`3oool000002@3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@00000000040000003o
ool0oooo000000T0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00400000000010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`010000000000@000000?ooo`3oool00000
2@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0@00000000040000003oool0oooo000000T0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00400000000010000000oooo0?ooo`0000090?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`010000000000@0
00000?ooo`3oool000002P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00@00000000040000003oool0oooo000000X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00400000000010000000oooo0?oo
o`00000:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`010000000000@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00@00000000040000003oool0oooo000000X0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00400000
000010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`010000000000@000000?ooo`3oool000002P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00@00000000040000003o
ool0oooo000000X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00400000000010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`010000000000@000000?ooo`3oool00000
2`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
0@00000000040000003oool0oooo000000/0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00400000000010000000oooo0?ooo`00000;0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`010000000000@0
00000?ooo`3oool000002`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool00@00000000040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00400000000010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`010000000000@000000?ooo`3oool00000303oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool00@00000000040000003oool0oooo000000`0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00400000
000010000000oooo0?ooo`00000<0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`010000000000@000000?ooo`3oool00000303oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00@00000000040000003o
ool0oooo000000`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00400000000010000000oooo0?ooo`00000<0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`010000000000@000000?ooo`3oool00000
303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
0@00000000040000003oool0oooo000000`0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00400000000010000000oooo0?ooo`00000=0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`010000000000@0
00000?ooo`3oool000003@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool00@00000000040000003oool0oooo000000d0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00400000000010000000oooo0?oo
o`00000=0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`010000000000@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool00@00000000040000003oool0oooo000000d0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00400000
000010000000oooo0?ooo`00000=0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`010000000000@000000?ooo`3oool000003@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00@00000000040000003o
ool0oooo000000h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00400000000010000000oooo0?ooo`0000020?oooa`000000P3oool00`000000oooo
0?ooo`010000000000@000000?ooo`3oool000000P3oool00`000000I`0006L0000906L000050000
001W0000I`0006L0000000002P1W000010000000oooo0?ooo`0000020?ooo`400000000010000000
oooo0?ooo`0000020?ooo`030000001W0000I`0000T0I`0000D0000006L0001W0000I`000000000:
06L000040000003oool0oooo00000080oooo0@00000000060000003oool0oooo0000003oool00000
401W00000`000000I`0006L0000806L000040000003oool0oooo00000080oooo0@00000000060000
003oool0oooo0000003oool00000401W00000`000000I`0006L0000906L000030000003oool00000
0080oooo0@00000000060000003oool0oooo0000003oool00000401W00000`000000I`0006L00009
06L000030000003oool000000080oooo0@00000000050000003oool0oooo0000003oool07P000000
103oool000000?ooo`3oool10000000000D000000?ooo`3oool000000?ooo`0N000000040?ooo`00
0000oooo0?ooo`40000000000`000000oooo0?ooo`03000000l0I`0000<0000006L0001W00002P1W
000300000080oooo0@00000000060000003oool0oooo0000003oool000003`1W00000`000000I`00
06L0000:06L000030000003oool000000080oooo0@00000000060000003oool0oooo0000003oool0
00003`1W00000`000000I`0006L0000:06L000030000003oool000000080oooo0@00000000060000
003oool0oooo0000003oool000003`1W00000`000000I`0006L0000:06L000030000003oool00000
0080oooo0@00000000060000003oool0oooo0000003oool00000701W00000`000000oooo00000002
0?ooo`40000000000`000000oooo000000020?ooo`030000001W0000I`0001X0I`0000D000000?oo
o`3oool000000?ooo`010000000000<000000?ooo`0000000P3ooolN00000080oooo0@0000010?oo
o`40000000000`000000oooo000000020?ooo`030000002dV;X0]9Rj01X0]9Rj00D000000?ooo`3o
ool000000?ooo`010000000000<000000?ooo`0000000P3oool00`000000]9Rj0;BH^P0J0;BH^P05
0000003oool0oooo0000003oool00@00000000030000003oool000000080oooo00<000000;BH^P2d
V;X06P2dV;X01@000000oooo0?ooo`000000oooo0040000000000`000000oooo000000020?ooo`03
0000002dV;X0]9Rj01X0]9Rj00D000000?ooo`3oool000000?ooo`010000000000<000000?ooo`00
00000P3oool00`000000]9Rj0;BH^P0J0;BH^P050000003oool0oooo0000003oool00@0000000003
0000003oool000000080oooo00<000000;BH^P2dV;X06P2dV;X01@000000oooo0?ooo`000000oooo
004000000002000000<0oooo00<000000;BH^P2dV;X06P2dV;X01@000000oooo0?ooo`000000oooo
004000000002000000<0oooo00<000000;BH^P2dV;X06P2dV;X010000000oooo0?ooo`3oool20000
00000P0000030?ooo`030000002dV;X0]9Rj01X0]9Rj00@000000?ooo`3oool0oooo0P0000000080
00000`3oool00`000000]9Rj0;BH^P0J0;BH^P040000003oool0oooo0?ooo`8000000002000000<0
oooo00<000000;BH^P2dV;X06P2dV;X010000000oooo0?ooo`3oool2000000000P0000030?ooo`03
0000002dV;X0]9Rj01X0]9Rj00@000000?ooo`3oool0oooo0P000000008000000`3oool00`000000
]9Rj0;BH^P0J0;BH^P040000003oool0oooo0?ooo`8000000002000000<0oooo7P0000030?ooo`80
00000002000002@0oooo0P00000000030000003oool0oooo02@0oooo0@00000000030000003oool0
oooo02@0oooo0@00000000030000003oool0oooo02@0oooo0@00000000030000003oool0oooo02@0
oooo0@00000002P00000000X0?ooo`00:03oool002P0oooo0000\
\>"],
  ImageRangeCache->{{{0, 39.75}, {286.688, 0}} -> {0.430568, 0.0090117, \
0.00349347, 0.00349347}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#5", "Text"],

Cell[CellGroupData[{

Cell["Hz0A[[-5]]", "Input"],

Cell[BoxData[
    \(8.016261417411778`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pretty[Chop[e2ni . eigenvectors0A[\([\(-5\)]\)], 10^\(-4\)]]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
          {"\<\"optic\"\>", "0", "0", \(-1.`\), "0", "0", "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Status["\<Plotting stage 0A mode 5\>"]\ ; 
    eigenplot[
      eigenvectors0A[\([\(-5\)]\)], \(- .2\), {0, \(-1\), \(- .25\)}, \ 
      floatmatrix0A]\ \ ; Done[]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 5.99483 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.6256 6.25121 1.28586e-016 6.25121 [
[ 0 0 0 0 ]
[ 1 5.99483 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
.12768 5.99483 L
s
.12768 5.99483 m
.23891 4.75775 L
s
.23891 4.75775 m
.18195 .67458 L
s
.18195 .67458 m
0 0 L
s
1 0 m
.81805 .67458 L
s
.81805 .67458 m
.76109 4.75775 L
s
.76109 4.75775 m
.87232 5.99483 L
s
.87232 5.99483 m
1 0 L
s
0 0 m
.12768 5.99483 L
s
.12768 5.99483 m
.87232 5.99483 L
s
.87232 5.99483 m
1 0 L
s
1 0 m
0 0 L
s
.18195 .67458 m
.81805 .67458 L
s
.81805 .67458 m
.76109 4.75775 L
s
.76109 4.75775 m
.23891 4.75775 L
s
.23891 4.75775 m
.18195 .67458 L
s
0 0 m
1 0 L
1 5.99483 L
0 5.99483 L
closepath
clip
newpath
.01 w
.40334 5.07891 Mdot
.59666 5.07891 Mdot
.39133 5.47992 Mdot
.60867 5.47992 Mdot
.38937 2.41909 Mdot
.61063 2.41909 Mdot
.37334 2.50103 Mdot
.62666 2.50103 Mdot
.25 Mabswid
0 0 m
.12768 5.99483 L
s
.12768 5.99483 m
.87232 5.99483 L
s
.87232 5.99483 m
1 0 L
s
1 0 m
0 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{48, 287.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40000`00017b000`400?l00000o`00003o<03oool0
0300oooo000`0000000000<000000?ooo`3oool0;03oool10000000000<000000?ooo`3oool0:`3o
ool2000000000P00000/0?ooo`8000000002000002`0oooo0P00000000800000;03oool200000000
0P00000[0?ooo`4000000@3oool10000000000<000000?ooo`000000:P3oool100000040oooo0@00
000000030000003oool0000002X0oooo0@0000010?ooo`40000000000`000000oooo0000000Y0?oo
o`030000003oool0oooo0040000000000`000000oooo0000000Y0?ooo`030000003oool0oooo0040
0000000010000000oooo0?ooo`00000X0?ooo`030000003oool0oooo00400000000010000000oooo
0?ooo`00000X0?ooo`030000003oool0oooo00400000000010000000oooo0?ooo`00000W0?ooo`04
0000003oool0oooo0?ooo`400000000010000000oooo0?ooo`00000W0?ooo`040000003oool0oooo
0?ooo`40000000001@000000oooo0?ooo`3oool0000002H0oooo00@000000?ooo`3oool0oooo0@00
000000050000003oool0oooo0?ooo`0000009@3oool00`000000oooo0?ooo`020?ooo`4000000000
1@000000oooo0?ooo`3oool0000002D0oooo00<000000?ooo`3oool00P3oool10000000000D00000
0?ooo`3oool0oooo0000000U0?ooo`030000003oool0oooo0080oooo0@00000000030000003oool0
oooo0080oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`020?ooo`40000000000`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool00`3oool10000
000000<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00<0
oooo0@00000000030000003oool0oooo0080oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool00`3oool10000000000<0oooo0000003oool00`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo00<0oooo0@0000010?ooo`0000<0oooo0000003oool00`3oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo00<0oooo0@0000010?ooo`0000<0oooo0000003o
ool00`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00<0oooo0@0000010?ooo`00
00<0oooo0000003oool0103oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00@0oooo
0@0000010?ooo`0000<0oooo0000003oool0103oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo00@0oooo0@0000010?ooo`0000<0oooo0000003oool0103oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo00@0oooo0@0000010?ooo`0000<0oooo0000003oool0103oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo00@0oooo0@0000010?ooo`0000<0oooo0000003o
ool01@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`00
00<0oooo0000003oool01@3ooolO000000L0oooo0@0000010?ooo`0000<0oooo0000003oool01@3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo
0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@000001
0?ooo`0000<0oooo0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo
0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@000001
0?ooo`0000<0oooo0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo
0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@000001
0?ooo`0000<0oooo0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo
0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@000001
0?ooo`0000<0oooo0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo
0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@000001
0?ooo`0000<0oooo0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo
0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@000001
0?ooo`0000<0oooo0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo
0000003oool01@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo0@000001
0?ooo`0000<0oooo0000003oool01P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
00H0oooo0@0000010?ooo`0000<0oooo0000003oool01P3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo00H0oooo0@0000010?ooo`0000<0oooo0000003oool01P3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo00H0oooo0@0000010?ooo`0000<0oooo0000003oool01P3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo0@0000010?ooo`0000<0oooo
0000003oool01P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo0@000001
0?ooo`0000<0oooo0000003oool01P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
00H0oooo0@0000010?ooo`000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool01@3oool100000040oooo0@3oool00080oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`40oooo
00020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`050?ooo`4000000@3oool10?ooo`000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool01@3oool100000040oooo0@3oool00080oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo0@0000010?oo
o`40oooo00020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`050?ooo`4000000@3oool10?ooo`000P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool100000040oooo0@3oool00080oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo0@00
00010?ooo`40oooo00020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`050?ooo`4000000@3oool10?ooo`000P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool100000040oooo0@3oool00080
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0
oooo0@0000010?ooo`40oooo00020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`050?ooo`4000000@3oool10?ooo`000P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool100000040oooo0@3o
ool00080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo00D0oooo0@0000010?ooo`40oooo00020?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`050?ooo`4000000@3oool10?ooo`000P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool100000040
oooo0@3oool00080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo00D0oooo0@0000010?ooo`40oooo00020?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`050?ooo`4000000@3oool10?ooo`000P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool1
00000040oooo0@3oool00080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo00D0oooo0@0000010?ooo`40oooo00020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`050?ooo`4000000@3oool10?ooo`00
0P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
1@3oool100000040oooo0@3oool00080oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`40oooo00020?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`050?ooo`4000000@3oool1
0?ooo`000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool01@3oool100000040oooo0@3oool00080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`40oooo00020?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`050?ooo`400000
0@3oool10?ooo`000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool01@3oool100000040oooo0@3oool00080oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`40oooo00020?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`050?oo
o`4000000@3oool10?ooo`000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool01@3oool100000040oooo0@3oool00080oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`40oooo
00020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`050?ooo`4000000@3oool10?ooo`000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool01@3oool100000040oooo0@3oool00080oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo0@0000010?oo
o`40oooo00020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`050?ooo`4000000@3oool10?ooo`000P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool100000040oooo0@3oool00080oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo0@00
00010?ooo`40oooo00020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`050?ooo`4000000@3oool10?ooo`000P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool100000040oooo0@3oool00080
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0
oooo0@0000010?ooo`40oooo00020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`050?ooo`4000000@3oool10?ooo`000P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool100000040oooo0@3o
ool00080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`4000000@3oool1
0?ooo`000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool01@3oool100000040oooo0@3oool00080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`40oooo00020?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool100000040oooo0@3oool000<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00@3oool000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0@3oool000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool0
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool000<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool000<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool00@3oool000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3o
ool000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool000<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool000<0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool00@3oool000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0@3oool000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool0
00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool000<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool000<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool00@3oool000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3o
ool000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool000<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool000<0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool00@3oool000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0@3oool000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool0
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool000@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool000@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00P3oool000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3o
ool000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool000@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00P3oool000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0P3oool000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool0
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool000@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool000@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00P3oool000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3o
ool000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool000@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool000@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool00P3oool000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0P3oool000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool0
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool000@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool000@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool00P3oool000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool000D0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool000D0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool000D0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0`3oool000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3oool00`3ooolI
000000H0oooo00<000000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool000D0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool000D0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool000D0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool000D0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool000D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00050?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00050?ooo`050000
003oool0oooo0?ooo`0000006`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00050?ooo`050000003oool0oooo0?ooo`0000006`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00<0oooo00050?ooo`050000003oool0oooo0?ooo`0000006`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00050?ooo`050000003oool0oooo0?ooo`00
00006`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00050?ooo`050000
003oool0oooo0?ooo`0000006`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00050?ooo`050000003oool0oooo0?ooo`0000006`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00<0oooo00050?ooo`050000003oool0oooo0?ooo`0000006`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00050?ooo`050000003oool0oooo0?ooo`00
0000703oool01@000000oooo0?ooo`3oool0000000D0oooo00050?ooo`050000003oool0oooo0?oo
o`000000703oool01@000000oooo0?ooo`3oool0000000D0oooo00050?ooo`050000003oool0oooo
0?ooo`000000703oool01@000000oooo0?ooo`3oool0000000D0oooo00050?ooo`050000003oool0
oooo0?ooo`000000703oool01@000000oooo0?ooo`3oool0000000D0oooo00050?ooo`040000003o
ool0oooo000001d0oooo00D000000?ooo`3oool0oooo000000050?ooo`001@3oool010000000oooo
0?ooo`00000M0?ooo`050000003oool0oooo0?ooo`0000001@3oool000D0oooo00@000000?ooo`3o
ool000007@3oool01@000000oooo0?ooo`3oool0000000D0oooo00050?ooo`040000003oool0oooo
000001d0oooo00D000000?ooo`3oool0oooo000000050?ooo`001@3oool010000000oooo0?ooo`00
00090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool01@000000oooo0?oo
o`3oool0000000D0oooo00050?ooo`040000003oool0oooo000001h0oooo00@000000?ooo`3oool0
00001@3oool000H0oooo00<000000?ooo`0000007P3oool00`000000oooo000000060?ooo`001P3o
ool00`000000oooo0000000N0?ooo`030000003oool0000000H0oooo00060?ooo`030000003oool0
000001h0oooo00<000000?ooo`0000001P3oool000H0oooo00<000000?ooo`0000007P3oool00`00
0000oooo000000060?ooo`001P3oool00`000000oooo0000000N0?ooo`030000003oool0000000H0
oooo00060?ooo`030000003oool0000001h0oooo00<000000?ooo`0000001P3oool000H0oooo0P00
000O0?ooo`030000003oool0000000H0oooo00060?ooo`8000007`3oool00`000000oooo00000006
0?ooo`001P3oool2000001l0oooo00<000000?ooo`0000001P3oool000H0oooo0P00000P0?ooo`80
00001P3oool000H0oooo0P00000P0?ooo`8000001P3oool000H0oooo0P00000P0?ooo`8000001P3o
ool000H0oooo0P00000P0?ooo`8000001P3oool000H0oooo0P00000P0?ooo`8000001P3oool000H0
oooo0P00000P0?ooo`8000001P3oool000H0oooo0P00000P0?ooo`8000001P3oool000H0oooo0P00
000P0?ooo`8000001P3oool000H0oooo0P00000P0?ooo`8000001P3oool000H0oooo00<000000?oo
o`3oool07`3oool2000000H0oooo00060?ooo`030000003oool0oooo0200oooo00<000000?ooo`3o
ool0103oool000H0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`040?ooo`001P3o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00@0oooo00060?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool0103oool000H0oooo900000060?ooo`00<03oool00300oooo
0000\
\>"],
  ImageRangeCache->{{{0, 47}, {286.75, 0}} -> {0.420014, -0.00850194, \
0.00340363, 0.00340363}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#6", "Text"],

Cell[CellGroupData[{

Cell["Hz0A[[-6]]", "Input"],

Cell[BoxData[
    \(11.312817296034872`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pretty[Chop[e2ni . eigenvectors0A[\([\(-6\)]\)], 10^\(-4\)]]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
          {"\<\"optic\"\>", "0", "0.0029584390002106806`", "0", "0", 
            "0", \(-0.9999956238097655`\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Status["\<Plotting stage 0A mode 6\>"]\ ; 
    eigenplot[
      eigenvectors0A[\([\(-6\)]\)], \(- .2\), {\(-1\), 0, \(- .25\)}, \ 
      floatmatrix0A]\ \ ; Done[]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 2.05714 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.622713 2.24543 -8.9013e-017 2.24543 [
[ 0 0 0 0 ]
[ 1 2.05714 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
1 0 m
.88819 2.05714 L
s
.88819 2.05714 m
.11181 2.05714 L
s
.11181 2.05714 m
0 0 L
s
0 0 m
1 0 L
s
.93098 .0853 m
.06902 .0853 L
s
.06902 .0853 m
.15474 1.89797 L
s
.15474 1.89797 m
.84526 1.89797 L
s
.84526 1.89797 m
.93098 .0853 L
s
1 0 m
.88819 2.05714 L
s
.88819 2.05714 m
.84526 1.89797 L
s
.84526 1.89797 m
.93098 .0853 L
s
.93098 .0853 m
1 0 L
s
0 0 m
.06902 .0853 L
s
.06902 .0853 m
.15474 1.89797 L
s
.15474 1.89797 m
.11181 2.05714 L
s
.11181 2.05714 m
0 0 L
s
0 0 m
1 0 L
1 2.05714 L
0 2.05714 L
closepath
clip
newpath
.5 Mabswid
.689 .692 .848 r
.4399 1.9132 m .48472 1.9132 L .48463 1.87377 L p F P
0 g
s
.714 .583 .006 r
.48463 1.87377 m .48472 1.9132 L .48363 2.0056 L p F P
0 g
s
.785 .641 .083 r
.28715 2.0056 m .30132 1.9132 L p .28083 1.99584 L F P
0 g
s
.785 .641 .083 r
.30132 1.9132 m .30025 1.87377 L .28083 1.99584 L p F P
0 g
s
.689 .692 .848 r
.30025 1.87377 m .30132 1.9132 L .4399 1.9132 L p F P
0 g
s
.689 .692 .848 r
.48463 1.87377 m .30025 1.87377 L p .4399 1.9132 L F P
0 g
s
0 0 .083 r
.70204 1.78986 m .69868 1.9132 L .70305 1.94171 L p F P
0 g
s
.689 .692 .848 r
.51554 1.78986 m .51528 1.9132 L .5601 1.9132 L p F P
0 g
s
0 0 .006 r
.51562 1.94171 m .51528 1.9132 L p .51707 1.90521 L F P
0 g
s
0 0 .006 r
.51528 1.9132 m .51554 1.78986 L .51707 1.90521 L p F P
0 g
s
.689 .692 .848 r
.5601 1.9132 m .69868 1.9132 L .70204 1.78986 L p F P
0 g
s
.689 .692 .848 r
.70204 1.78986 m .51554 1.78986 L p .5601 1.9132 L F P
0 g
s
.423 0 0 r
.30025 1.87377 m .48463 1.87377 L .48314 1.99584 L p F P
0 g
s
.423 0 0 r
.48314 1.99584 m .28083 1.99584 L .30025 1.87377 L p F P
0 g
s
.714 .583 .006 r
.48314 1.99584 m .48463 1.87377 L p .48363 2.0056 L F P
0 g
s
0 0 .083 r
.72193 1.90521 m .70204 1.78986 L p .70305 1.94171 L F P
0 g
s
.401 0 0 r
.51554 1.78986 m .70204 1.78986 L .72193 1.90521 L p F P
0 g
s
.401 0 0 r
.72193 1.90521 m .51707 1.90521 L .51554 1.78986 L p F P
0 g
s
0 0 .083 r
.70305 1.94171 m .71788 2.03836 L .72193 1.90521 L p F P
0 g
s
0 0 .006 r
.51707 1.90521 m .51676 2.03836 L .51562 1.94171 L p F P
0 g
s
.27449 1.35831 m
.37427 1.93197 L
s
.62852 1.84483 m
.7266 1.32037 L
s
.61257 1.93008 m
.61722 1.90521 L
s
.714 .583 .006 r
.48363 2.0056 m .48324 2.03836 L .48314 1.99584 L p F P
0 g
s
.785 .641 .083 r
.28083 1.99584 m .28212 2.03836 L .28715 2.0056 L p F P
0 g
s
.685 .703 .861 r
.43409 2.03836 m .28212 2.03836 L p .48314 1.99584 L F P
0 g
s
.685 .703 .861 r
.28212 2.03836 m .28083 1.99584 L .48314 1.99584 L p F P
0 g
s
.685 .703 .861 r
.48314 1.99584 m .48324 2.03836 L .43409 2.03836 L p F P
0 g
s
.685 .703 .861 r
.56591 2.03836 m .51676 2.03836 L p .72193 1.90521 L F P
0 g
s
.685 .703 .861 r
.51676 2.03836 m .51707 1.90521 L .72193 1.90521 L p F P
0 g
s
.685 .703 .861 r
.72193 1.90521 m .71788 2.03836 L .56591 2.03836 L p F P
0 g
s
.218 0 0 r
.55242 1.34412 m .55024 1.31389 L .47755 1.31685 L p F P
0 g
s
.218 0 0 r
.47755 1.31685 m .47658 1.34719 L .55242 1.34412 L p F P
0 g
s
.424 0 0 r
.47658 1.34719 m .47755 1.31685 L .40726 1.29836 L p F P
0 g
s
0 0 0 r
.62395 1.319 m .61877 1.28973 L .55024 1.31389 L p F P
0 g
s
0 0 0 r
.55024 1.31389 m .55242 1.34412 L .62395 1.319 L p F P
0 g
s
.424 0 0 r
.40726 1.29836 m .40322 1.32796 L .47658 1.34719 L p F P
0 g
s
.599 .036 0 r
.40322 1.32796 m .40726 1.29836 L .34575 1.25994 L p F P
0 g
s
0 0 0 r
.68464 1.2739 m .67689 1.24637 L .61877 1.28973 L p F P
0 g
s
0 0 0 r
.61877 1.28973 m .62395 1.319 L .68464 1.2739 L p F P
0 g
s
.599 .036 0 r
.34575 1.25994 m .339 1.28802 L .40322 1.32796 L p F P
0 g
s
.727 .253 0 r
.339 1.28802 m .34575 1.25994 L .29879 1.20485 L p F P
0 g
s
0 0 0 r
.72872 1.21265 m .71905 1.1875 L .67689 1.24637 L p F P
0 g
s
.75809 1.15201 m
.77538 1.05956 L
s
0 0 0 r
.67689 1.24637 m .68464 1.2739 L .72872 1.21265 L p F P
0 g
s
.727 .253 0 r
.29879 1.20485 m .28993 1.23071 L .339 1.28802 L p F P
0 g
s
.793 .455 0 r
.28993 1.23071 m .29879 1.20485 L .27111 1.13793 L p F P
0 g
s
0 0 0 r
.75165 1.14066 m .74092 1.11837 L .71905 1.1875 L p F P
0 g
s
0 0 0 r
.71905 1.1875 m .72872 1.21265 L .75165 1.14066 L p F P
0 g
s
.7266 1.32037 m
.75809 1.15201 L
s
.793 .455 0 r
.27111 1.13793 m .26094 1.16103 L .28993 1.23071 L p F P
0 g
s
.24083 1.1648 m
.27449 1.35831 L
s
.792 .623 .063 r
.26094 1.16103 m .27111 1.13793 L .26583 1.06532 L p F P
0 g
s
0 0 .11 r
.75065 1.06462 m .73986 1.0454 L .74092 1.11837 L p F P
0 g
s
0 0 .11 r
.74092 1.11837 m .75165 1.14066 L .75065 1.06462 L p F P
0 g
s
.792 .623 .063 r
.26583 1.06532 m .25532 1.08538 L .26094 1.16103 L p F P
0 g
s
.722 .739 .224 r
.25532 1.08538 m .26583 1.06532 L .28406 .99404 L p F P
0 g
s
0 0 .27 r
.72516 .992 m .71539 .97577 L .73986 1.0454 L p F P
0 g
s
0 0 .27 r
.73986 1.0454 m .75065 1.06462 L .72516 .992 L p F P
0 g
s
.722 .739 .224 r
.28406 .99404 m .27429 1.01107 L .25532 1.08538 L p F P
0 g
s
0 0 0 r
.27429 1.01107 m .28406 .99404 L .32457 .93137 L p F P
0 g
s
.577 .119 0 r
.67714 .93031 m .6694 .91665 L .71539 .97577 L p F P
0 g
s
.577 .119 0 r
.71539 .97577 m .72516 .992 L .67714 .93031 L p F P
0 g
s
0 0 0 r
.32457 .93137 m .31656 .94567 L .27429 1.01107 L p F P
0 g
s
0 0 0 r
.31656 .94567 m .32457 .93137 L .38364 .88398 L p F P
0 g
s
.452 0 0 r
.61112 .88621 m .60624 .87442 L .6694 .91665 L p F P
0 g
s
.452 0 0 r
.6694 .91665 m .67714 .93031 L .61112 .88621 L p F P
0 g
s
0 0 0 r
.3783 .89619 m .38364 .88398 L .45539 .8571 L p F P
0 g
s
0 0 0 r
.38364 .88398 m .3783 .89619 L .31656 .94567 L p F P
0 g
s
.271 0 0 r
.5338 .86466 m .53231 .85379 L .60624 .87442 L p F P
0 g
s
.271 0 0 r
.60624 .87442 m .61112 .88621 L .5338 .86466 L p F P
0 g
s
0 0 0 r
.45539 .8571 m .45333 .86812 L .3783 .89619 L p F P
0 g
s
.053 0 0 r
.45333 .86812 m .45539 .8571 L .53231 .85379 L p F P
0 g
s
.053 0 0 r
.53231 .85379 m .5338 .86466 L .45333 .86812 L p F P
0 g
s
.01 w
.63753 .85219 Mdot
.36247 .85219 Mdot
.64387 .86298 Mdot
.35613 .86298 Mdot
.25 Mabswid
1 0 m
.88819 2.05714 L
s
.88819 2.05714 m
.11181 2.05714 L
s
.11181 2.05714 m
0 0 L
s
0 0 m
1 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{140, 287.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002<00017b000`400?l00000o`00003oS0000000
00800000R03oool2000000000P0000270?ooo`4000000@3oool10000000000<000000?ooo`000000
Q@3oool00`000000oooo0?ooo`010000000000@000000?ooo`3oool00000Q03oool00`000000oooo
0?ooo`010000000000D000000?ooo`3oool0oooo000000220?ooo`040000003oool0oooo0?ooo`40
000000001@000000oooo0?ooo`3oool000000840oooo00<000000?ooo`3oool00P3oool100000000
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo00<0oooo
0@00000000030000003oool0oooo00<0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?oo
o`040?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo07T0oooo00<00000
0?ooo`3oool0103oool100000040oooo00000`3oool000000?ooo`040?ooo`030000003oool0oooo
07T0oooo00<000000?ooo`3oool0103oool100000040oooo00000`3oool000000?ooo`050?ooo`03
0000003oool0oooo07L0oooo00<000000?ooo`3oool01@3oool100000040oooo00000`3oool00000
0?ooo`060?ooogT00000203oool100000040oooo00000`3oool000000?ooo`060?ooo`030000003o
ool0oooo07D0oooo00<000000?ooo`3oool01P3oool100000040oooo00000`3oool000000?ooo`06
0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool01P3oool100000040oooo00000`3o
ool000000?ooo`060?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool01P3oool10000
0040oooo00000`3oool000000?ooo`060?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3o
ool01P3oool100000040oooo00000`3oool000000?ooo`060?ooo`030000003oool0oooo07D0oooo
00<000000?ooo`3oool01P3oool100000040oooo00000`3oool000000?ooo`060?ooo`030000003o
ool0oooo07D0oooo00<000000?ooo`3oool01P3oool100000040oooo00000`3oool000000?ooo`06
0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool01P3oool100000040oooo00000`3o
ool000000?ooo`060?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool01P3oool10000
0040oooo00000`3oool000000?ooo`060?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3o
ool01P3oool100000040oooo00000`3oool000000?ooo`060?ooo`030000003oool0oooo07D0oooo
00<000000?ooo`3oool01P3oool100000040oooo00000`3oool000000?ooo`070?ooo`030000003o
ool0oooo07<0oooo00<000000?ooo`3oool01`3oool100000040oooo00000`3oool000000?ooo`07
0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool01`3oool100000040oooo00000`3o
ool000000?ooo`070?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool01`3oool10000
0040oooo00000`3oool000000?ooo`070?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3o
ool01`3oool100000040oooo00000`3oool000000?ooo`070?ooo`030000003oool0oooo07<0oooo
00<000000?ooo`3oool01P3oool100000040oooo0@3oool000030?ooo`000000oooo00L0oooo00<0
00000?ooo`3oool0L`3oool00`000000oooo0?ooo`060?ooo`4000000@3oool10?ooo`000P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool01P3oool1
00000040oooo0@3oool00080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1c0?oo
o`030000003oool0oooo00H0oooo0@0000010?ooo`40oooo00020?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`060?ooo`4000000@3oool10?ooo`00
0P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0
1P3oool100000040oooo0@3oool00080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`1c0?ooo`030000003oool0oooo00H0oooo0@0000010?ooo`40oooo00020?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`060?ooo`4000000@3oool1
0?ooo`000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo07<0oooo00<000000?oo
o`3oool01P3oool100000040oooo0@3oool00080oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`1c0?ooo`030000003oool0oooo00H0oooo0@0000010?ooo`40oooo00020?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`060?ooo`400000
0@3oool10?ooo`000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo07<0oooo00<0
00000?ooo`3oool01P3oool100000040oooo0@3oool00080oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`1c0?ooo`030000003oool0oooo00H0oooo0@0000010?ooo`40oooo00020?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`060?oo
o`4000000@3oool10?ooo`000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo07<0
oooo00<000000?ooo`3oool01P3oool100000040oooo0@3oool00080oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo00H0oooo0@0000010?ooo`40oooo
00020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?oo
o`060?ooo`4000000@3oool10?ooo`000P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0740oooo00<000000?ooo`3oool01`3oool100000040oooo0@3oool00080oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool00@3oool00080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1a0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool00@3oool00080oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0@3oool000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1a0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`1a0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00@3oool0
00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`1a0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00@3oool000<0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`1a0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00@3oool000<0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1a0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00@3oool000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1a0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00@3o
ool000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`1a0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00@3oool000<0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`1a0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00@3oool000<0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00P3oool000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1a
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool000<0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool00P3oool000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1_0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0P3oool000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1_0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`1_0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool0
00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`1_0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool000@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`1_0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool000@0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1_0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00P3oool000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1_0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`1_0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool000@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00`3oool000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`1_0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool000@0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00`3oool000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1_
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool000@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool00`3oool000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1]0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0`3oool000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1]0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool0
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`1]0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool000D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`1]0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool000D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool00`3oool000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1]0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00`3oool000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1]0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3o
ool000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`1]0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool000D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`1]0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool000D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1]
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0103oool000H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1]0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
103oool000H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1[0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`1[0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool0
00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`1[0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool000H0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`1[0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool000H0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1[0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0103oool000H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1[0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0:0?ooo`d000003P3oool0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0[0?ooo`@000001@0=000:0000
02d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo02P0oooo300000070?ooo`L00000:@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool09P3oool700000140oooo100000000`15000000000?ooo`0V0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0T0?ooo`H00000603oool4000002D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo02<0oooo1@00000L0?ooo`@000008`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool08P3oool30000
0240oooo1000000Q0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool000L0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0Q0?ooo`8000009@3oool010000000
L`0000000000000O0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool000L0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0O0?ooo`<000009`3oool200000003
07<000000000oooo01d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`00
1`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01d0oooo0`00000Z0?ooo`<00000
703oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0703oool3000002d0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool06`3oool200000300oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool06P3oool200000340oooo0P00000J0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0I0?ooo`800000<`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0603oool2000003D0oooo0P00000H0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0G
0?ooo`800000=`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01P3oool000L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0F0?oo
o`800000>@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01P3oool000L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0F0?ooo`80
0000>@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01P3oool000L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0E0?ooo`800000
>`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1P3oool000L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0503oool2
000003`0oooo0P00000E0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool0
00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00H0oooo00070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`0l0?ooo`800000503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0
oooo00070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0m0?ooo`800000503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo
00080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`0n0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`060?ooo`00203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0?P3oool2000001<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`06
0?ooo`00203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0180oooo0P0000100?oo
o`8000004`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00080?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0o0?ooo`<0
00000P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01P3oool000P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo03l0oooo00<000000000700000000P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool000P0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo03l0oooo00<000000000700000000P3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool000P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0@0?ooo`800000@@3oool0
0`000000000L000000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`060?ooo`00203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0100oooo0P0000110?ooo`050000000001`000000?ooo`0000003`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo00080?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0403oool200000440oooo00D00000000070000000oooo0000000?0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0@0?ooo`800000@@3oool01@000000000L0000003oool0000000l0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0100oooo00<000000<ZO40000000@03oool01@000000000L0000003oool0
000000l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`00203oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0100oooo00<000000<ZO40000000@03oool01@00
0000000L0000003oool0000000l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`07
0?ooo`00203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0100oooo00<000000<ZO
40000000@03oool01@000000000L0000003oool0000000l0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0140oooo0P0000100?ooo`@00000403oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00L0oooo00080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool2000003l0
oooo1@00000@0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool000P0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`800000?`3oool500000100oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0140oooo00<000000<]d00000000?P3oool500000100oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0140oooo00<000000<]d00000000?@3oool4000000030?ooo`000000
oooo00l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`00203oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo00@000000?ooo`3oool000000P3;M000
0`000000oooo0?ooo`0j0?ooo`@0000000<0oooo0000003oool03`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00L0oooo00090?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool03P3oool01`000000oooo0?ooo`3oool000000<]d00000000?03oool500000140oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`002@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00h0oooo00L000000?ooo`3oool0oooo0000003;M000000003/0oooo
100000000`3oool000000?ooo`0@0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1`3oool000T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?ooo`070000003o
ool0oooo0?ooo`000000bg@00000000j0?ooo`@0000000<0oooo0000003oool0403oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00090?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool03`3oool01`000000oooo0?ooo`3oool000000<]d00000000>@3oool50000
00030?ooo`000000oooo0100oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?oo
o`002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo00D000000?ooo`3o
ool0oooo000000020<]d00030000003oool0oooo03H0oooo1@0000000`3oool000000?ooo`0@0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool000T0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000<]d0000
0000=`3oool5000000030?ooo`000000oooo0140oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`070?ooo`002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool00P3oool010000000bg@000000000000e0?ooo`H0000000<0oooo0000003o
ool04@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00090?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`040000
002j@000^T00000003@0oooo1@0000020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`080?ooo`002@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool01@000000^T000;Y0002j@00000000380
oooo1@0000030?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`080?ooo`002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool00`3oool01@000000^T000;Y0002j@00000000340oooo1@0000020?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`00
2@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
103oool01@000000^T000;Y0002j@000000002l0oooo1@0000030?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`002@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01@3oool01@000000^T00
0;Y0002j@000000002d0oooo1@0000040?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`080?ooo`002@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool01@3oool00`000000^T000;Y000020;Y000030000
003oool0oooo02P0oooo1P0000050?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`080?ooo`002@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool01@3oool010000000^T000;Y0002j@002000002P0oooo
1`0000050?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`080?ooo`002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool01P3oool00`000000^T000000000209T9008000009@3oool7000000D0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo0009
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`07
0?ooo`800000102I2@000`000000oooo0?ooo`0P0?ooo`P000001P3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool000T0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00P0oooo00<0000009T9
002I2@000`2I2@000`000000oooo0?ooo`0M0?ooo`P00000203oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool000T0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00T0oooo0P00000409T90080
00006`3oool9000000T0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00P0oooo00090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0:0?ooo`030000002I2@00V@T000<0V@T00`00000E0?ooo`X00000
2`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
203oool000X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo00/0oooo0P00000309T900030000001/0000K00000D000003P3oool;000000/0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo000:
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0=
0?ooo`040000002I2@00V@T0000000L0K0005`00000=0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`002P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool03P3oool3000000T0K00000<00000
03L0000g00001`0g0009000000l0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00P0oooo000:0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`<000001`1/00000`000000=`0003L0000703L0
00L000004@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0203oool000X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo01<0oooo1@00000206`000030000000g0000=`0000L0=`001000000D0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`00
2P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
5`3oool>000001D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00P0oooo000:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0>@3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool000X0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03P0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo000:
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0h
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`09
0?ooo`002P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool0>03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool02@3oool000X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo03P0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`002`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0=P3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool000/0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo03H0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo
000;0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`0f0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`090?ooo`002`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool02@3oool000/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo03@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00T0oooo000;0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0:0?ooo`002`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool02P3oool000/0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo000;0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0c0?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`002`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0<P3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02P3oool000/0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0380
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0
oooo000;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`0b0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0:0?ooo`002`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool0<P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool02P3oool000/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00X0oooo000;0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`002`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool02P3oool000/0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo000;0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0`0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`002`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0<03oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02P3oool0
00`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
02l0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00X0oooo000<0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0^0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0:0?ooo`00303oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool02P3oool000`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00X0oooo000<0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`00303oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool02`3oool000`0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo000<0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0/0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`00303o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0;03o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02`3o
ool000`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00/0oooo000<0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`0/0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0;0?ooo`00303oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool02`3oool000`0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00/0oooo000<0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`00303oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02`3oool000`0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo000<0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`00
303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
2`3oool000`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00/0oooo000=0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0;0?ooo`003@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool02`3oool000d0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo000=0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0303oool000d0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo000=0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?oo
o`003@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0303oool000d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool0503ooolK000001@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool04`3oool00`000000IP0006H0000>06H000030000001V0000IP00
00H0IP0000<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00`0oooo000=0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`0C0?ooo`030000001V0000IP0000h0IP0000<0000006H0001V00001P1V00000`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0303oool000d0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01<0oooo
00<0000006H0001V00003P1V00000`000000IP0006H0000706H000030000003oool0oooo0140oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool04`3oool00`000000IP0006H0
000>06H000030000001V0000IP0000L0IP0000<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`0C0?ooo`030000001V0000IP0000d0IP0000<00000
06H0001V0000201V00000`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo0180oooo00<0000006H0001V00003@1V00000`000000IP0006H0000806H0
00030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0<0?oo
o`003@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool04P3oool00`000000IP0006H0000=06H000030000001V0000IP0000P0IP0000<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0B0?ooo`030000
001V0000IP0001P0IP0000<000000?ooo`3oool0403oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00`0oooo000>0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0B0?ooo`030000001V0000IP0001T0IP0000<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00`0oooo000>0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0B0?ooo`030000001V0000
IP0001T0IP0000<000000?ooo`3oool03`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00`0oooo000>0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`0B0?ooo`030000001V0000IP0001T0IP0000<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo000>0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool04@3ooolK000000<0oooo00<0000006H0001V00006@1V00000`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03@3oool000h0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0A0?ooo`030000001/0000K00000L0K000
00<0000006`0001/00003@1/00001@000000oooo0?ooo`3oool0000001/0IP0000<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo000>0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool04@3oool00`000000K00006`0000706`000030000
001/0000K00000d0K00000D000000?ooo`3oool0oooo0000000L06H000030000003oool0oooo00h0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0=0?ooo`003P3oool00`000000oooo
0?ooo`040?oooaD000002@1/00000`000000K00006`0000=06`000D00000701V000B000000H0oooo
00<000000?ooo`3oool03@3oool000h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0@0?ooo`030000001/0000K00000P0K00000<0000006`0001/00003@1/000010000000oooo0?oo
o`3ooolN00000100oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0=0?ooo`003P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0140oooo00<0000006`0001/0000201/
00000`000000K00006`0000=06`000050000003oool0oooo0?ooo`000000702_/m`00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool000h0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0A0?ooo`030000001/0000K00000T0K00000<0
000006`0001/0000301/00001@000000oooo0?ooo`3oool0000001`0[k?L00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo000>0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool04@3oool00`000000K00006`0000906`000030000001/
0000K00000`0K00000D000000?ooo`3oool0oooo0000000L0:ncg0030000003oool0oooo00l0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`003P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0140oooo00<0000006`0001/00002@1/00000`000000K00006`0
000<06`000050000003oool0oooo0?ooo`000000702_/m`00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool000h0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0B0?ooo`030000001/0000K00001P0K00000D000000?ooo`3oool0oooo
0000000L0:ncg0030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0=0?ooo`003P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0180oooo00<0
000006`0001/0000601/00001@000000oooo0?ooo`3oool0000001`0[k?L00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo000>0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool04P3oool00`000000K00006`0000H06`000050000003o
ool0oooo0?ooo`000000702_/m`00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool03@3oool000h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0A0?ooo`030000001/0000K00001T0K00000D000000?ooo`3oool0oooo0000000L0:ncg0030000
003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`003P3o
ool01@000000oooo0?ooo`3oool0000001@0oooo00<0000006`0001/00006@1/00001@000000oooo
0?ooo`3oool0000001/0[k?L00<000000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool00000
00l0oooo000>0?ooo`050000003oool0oooo0?ooo`000000503oool00`000000K00006`0000I06`0
00050000003oool0oooo0?ooo`0000006`2_/m`00`000000oooo0?ooo`0B0?ooo`050000003oool0
oooo0?ooo`0000003`3oool000h0oooo00D000000?ooo`3oool0oooo0000000D0?ooo`030000001/
0000K00001T0K00000D000000?ooo`3oool0oooo0000000K0:ncg0030000003oool0oooo0180oooo
00D000000?ooo`3oool0oooo0000000?0?ooo`003`3oool00`000000oooo0000000E0?oooad00000
0`3oool00`000000[k?L0:ncg00I0:ncg0030000003oool0oooo01<0oooo00@000000?ooo`3oool0
00003`3oool000l0oooo00<000000?ooo`0000005@3oool00`000000[k?L0:ncg00I0:ncg0050000
003oool0oooo0?ooo`0000006`2_/m`00`000000oooo0?ooo`0C0?ooo`030000003oool000000100
oooo000?0?ooo`030000003oool0000001D0oooo00<000000:ncg02_/m`06@2_/m`01@000000oooo
0?ooo`3oool0000001/0[k?L00<000000?ooo`3oool04`3oool00`000000oooo0000000@0?ooo`00
3`3oool00`000000oooo0000000E0?ooo`030000002_/m`0[k?L01T0[k?L00D000000?ooo`3oool0
oooo0000000K0:ncg0030000003oool0oooo01<0oooo00<000000?ooo`000000403oool000l0oooo
0P00000F0?ooo`030000002_/m`0[k?L01T0[k?L00D000000?ooo`3oool0oooo0000000K0:ncg003
0000003oool0oooo01@0oooo0P00000@0?ooo`003`3oool2000001H0oooo00<000000:ncg02_/m`0
6@2_/m`01@000000oooo0?ooo`3oool0000001/0[k?L00<000000?ooo`3oool0503oool200000100
oooo000?0?ooo`8000005P3ooolM000000<0oooo7@00000F0?ooo`800000403oool000l0oooo0P00
001Y0?ooo`800000403oool000l0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0>
0?ooo`003`3ooom]00000100oooo0000\
\>"],
  ImageRangeCache->{{{0, 139}, {286.938, 0}} -> {0.277322, -0.00159863, \
0.00320398, 0.00320398}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Listings and plots with Stage 2 Data", "Subsection"],

Cell["Calculate[Stage2]", "Input"],

Cell[CellGroupData[{

Cell["View the eigenfrequencies", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
Table[{Length[allvars]-index+1, Hz2[[index]]}, {index, 1, Length[allvars]}]\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \({{6, 11.342534019381276`}, {5, 8.016261425044293`}, {4, 
        1.7374645454176607`}, {3, 1.5338724090239664`}, {2, 
        1.3434839300035832`}, {1, 1.2862586599432548`}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["View the important low-frequency modes", "Text"],

Cell[CellGroupData[{

Cell["\<\
Join[\t
\t{{\"N\",\"f\",\"type\"}},
\tTable[
\t\tJoin[
\t\t\t{i},
\t\t\t{Hz2[[-i]]},
\t\t\timportant[e2ni.eigenvectors2[[-i]],0.7]
\t\t],
\t\t{i,noofLF}
\t]
]//TableForm\
\>", "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"N\"\>", "\<\"f\"\>", "\<\"type\"\>"},
          {"1", "1.2862586599432548`", "pitch0"},
          {"2", "1.3434839300035832`", "roll0"},
          {"3", "1.5338724090239664`", "pitch0"},
          {"4", "1.7374645454176607`", "yaw0"},
          {"5", "8.016261425044293`", "z0"},
          {"6", "11.342534019381276`", "roll0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["View the higher frequency modes", "Text"],

Cell[CellGroupData[{

Cell["\<\
Join[\t
\t{{\"N\",\"f\",\"type\"}},
\tTable[
\t\tJoin[
\t\t\t{i},
\t\t\t{Hz2[[-i]]},
\t\t\timportant[e2ni.eigenvectors2[[-i]],0.7]
\t\t],
\t\t{i,noofLF+1,Length[allvars]}
\t]
]//TableForm\
\>", "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"N\"\>", "\<\"f\"\>", "\<\"type\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Classify the modes", "Text"],

Cell[CellGroupData[{

Cell["\<\
longpitchmodes2 = \
Select[Range[-noofLF,-1],longpitchQ[e2ni.eigenvectors2[[#]]]&]\
\>", "Input"],

Cell[BoxData[
    \({\(-3\), \(-1\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
transrollmodes2 = \
Select[Range[-noofLF,-1],transrollQ[e2ni.eigenvectors2[[#]]]&]\
\>", "Input"],

Cell[BoxData[
    \({\(-6\), \(-2\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
yawmodes2 = Select[Range[-noofLF,-1],yawQ[e2ni.eigenvectors2[[#]]]&]\
\>", "Input"],

Cell[BoxData[
    \({\(-4\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
vertmodes2 = Select[Range[-noofLF,-1],vertQ[e2ni.eigenvectors2[[#]]]&]\
\>", "Input"],

Cell[BoxData[
    \({\(-5\)}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["View the mode frequencies by groups", "Text"],

Cell[CellGroupData[{

Cell["longpitchfreqs2 = Hz2[[longpitchmodes2]]", "Input"],

Cell[BoxData[
    \({1.5338724090239664`, 1.2862586599432548`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["transrollfreqs2 = Hz2[[transrollmodes2]]", "Input"],

Cell[BoxData[
    \({11.342534019381276`, 1.3434839300035832`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["yawfreqs2 = Hz2[[yawmodes2]]", "Input"],

Cell[BoxData[
    \({1.7374645454176607`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["vertfreqs2 = Hz2[[vertmodes2]]", "Input"],

Cell[BoxData[
    \({8.016261425044293`}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Mode shape listings/plots", "Text"],

Cell[CellGroupData[{

Cell["#1", "Text"],

Cell[CellGroupData[{

Cell["Hz2[[-1]]", "Input"],

Cell[BoxData[
    \(1.2862586599432548`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pretty[Chop[e2ni . eigenvectors2[\([\(-1\)]\)], 10^\(-4\)]]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
          {"\<\"optic\"\>", \(-0.032511734110243766`\), "0", "0", "0", 
            "0.9994713538391907`", "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Status["\<Plotting stage 2 mode 1\>"]\ ; 
    eigenplot[eigenvectors2[\([\(-1\)]\)],  .5, {0, \(-1\), 0}, \ 
      floatmatrix2]\ ; Done[]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 7.1936 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-3.0968 7.1936 0 7.1936 [
[ 0 0 0 0 ]
[ 1 7.1936 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 7.1936 L
s
0 7.1936 m
.17254 5.95241 L
s
.17254 5.95241 m
.17254 1.24119 L
s
.17254 1.24119 m
0 0 L
s
1 0 m
.82746 1.24119 L
s
.82746 1.24119 m
.82746 5.95241 L
s
.82746 5.95241 m
1 7.1936 L
s
1 7.1936 m
1 0 L
s
0 0 m
0 7.1936 L
s
0 7.1936 m
1 7.1936 L
s
1 7.1936 m
1 0 L
s
1 0 m
0 0 L
s
.17254 1.24119 m
.82746 1.24119 L
s
.82746 1.24119 m
.82746 5.95241 L
s
.82746 5.95241 m
.17254 5.95241 L
s
.17254 5.95241 m
.17254 1.24119 L
s
0 0 m
1 0 L
1 7.1936 L
0 7.1936 L
closepath
clip
newpath
.5 Mabswid
.653 .462 .613 r
.1883 3.77055 m .39536 3.6575 L .30264 3.4863 L p F P
0 g
s
.21663 3.56723 m
.22767 3.67267 L
s
.653 .462 .613 r
.30264 3.4863 m .14805 3.5707 L .147 3.69307 L p F P
0 g
s
.653 .462 .613 r
.147 3.69307 m .1883 3.77055 L p .30264 3.4863 L F P
0 g
s
.747 .68 .786 r
.14718 3.46928 m .14805 3.5707 L p .20777 3.31389 L F P
0 g
s
.747 .68 .786 r
.14805 3.5707 m .30264 3.4863 L .20777 3.31389 L p F P
0 g
s
.747 .68 .786 r
.20777 3.31389 m .14613 3.34755 L .14718 3.46928 L p F P
0 g
s
.707 .577 .707 r
.5 6.14181 m .77857 6.14181 L p .22143 5.86324 L F P
0 g
s
.707 .577 .707 r
.77857 6.14181 m .77857 5.86324 L .22143 5.86324 L p F P
0 g
s
.707 .577 .707 r
.22143 5.86324 m .22143 6.14181 L .5 6.14181 L p F P
0 g
s
.745 .608 .039 r
.22143 6.14181 m .22143 5.86324 L .19121 6.10908 L p F P
0 g
s
0 0 .039 r
.77857 5.86324 m .77857 6.14181 L .7929 6.27274 L p F P
0 g
s
0 0 .039 r
.80879 6.10908 m .77857 5.86324 L p .7929 6.27274 L F P
0 g
s
.288 0 0 r
.77857 5.86324 m .80879 6.10908 L .19121 6.10908 L p F P
0 g
s
.23524 3.74492 m
.28989 4.26672 L
s
.288 0 0 r
.19121 6.10908 m .22143 5.86324 L .77857 5.86324 L p F P
0 g
s
.48286 6.10908 m
.5 6.27274 L
s
.28989 4.26672 m
.46743 5.96176 L
s
.745 .608 .039 r
.2071 6.27274 m .22143 6.14181 L p .19121 6.10908 L F P
0 g
s
.503 .201 .386 r
.26927 3.93082 m .47966 3.81595 L .39536 3.6575 L p F P
0 g
s
.503 .201 .386 r
.39536 3.6575 m .1883 3.77055 L .26927 3.93082 L p F P
0 g
s
.784 .844 .897 r
.14613 3.34755 m .20777 3.31389 L .14201 3.19639 L closepath p F P
0 g
s
.307 0 .121 r
.33333 4.06756 m .54912 3.94975 L .47966 3.81595 L p F P
0 g
s
.307 0 .121 r
.47966 3.81595 m .26927 3.93082 L .33333 4.06756 L p F P
0 g
s
.079 0 0 r
.3742 4.16833 m .59719 4.04659 L .54912 3.94975 L p F P
0 g
s
.079 0 0 r
.54912 3.94975 m .33333 4.06756 L .3742 4.16833 L p F P
0 g
s
.01 w
.37666 2.87738 Mdot
.62334 2.87738 Mdot
.5 Mabswid
.745 .608 .039 r
.19121 6.10908 m .19121 6.41787 L .2071 6.27274 L p F P
0 g
s
0 0 .039 r
.7929 6.27274 m .80879 6.41787 L .80879 6.10908 L p F P
0 g
s
0 0 0 r
.38598 4.22073 m .61754 4.09431 L .59719 4.04659 L p F P
0 g
s
0 0 0 r
.59719 4.04659 m .3742 4.16833 L .38598 4.22073 L p F P
0 g
s
.707 .577 .707 r
.5 6.41787 m .19121 6.41787 L .19121 6.10908 L p F P
0 g
s
.707 .577 .707 r
.80879 6.10908 m .80879 6.41787 L .5 6.41787 L p F P
0 g
s
.707 .577 .707 r
.19121 6.10908 m .80879 6.10908 L p .5 6.41787 L F P
0 g
s
.389 .823 .67 r
.36414 4.21403 m .60496 4.08255 L .61754 4.09431 L p F P
0 g
s
.389 .823 .67 r
.61754 4.09431 m .38598 4.22073 L .36414 4.21403 L p F P
0 g
s
.707 .577 .707 r
.5 6.46981 m .81448 6.46981 L p .18552 6.15533 L F P
0 g
s
.707 .577 .707 r
.81448 6.46981 m .81448 6.15533 L .18552 6.15533 L p F P
0 g
s
.707 .577 .707 r
.18552 6.15533 m .18552 6.46981 L .5 6.46981 L p F P
0 g
s
.745 .608 .039 r
.16714 6.63777 m .18552 6.46981 L p .14647 6.47306 L F P
0 g
s
.745 .608 .039 r
.18552 6.46981 m .18552 6.15533 L .14647 6.47306 L p F P
0 g
s
0 0 .039 r
.81448 6.15533 m .81448 6.46981 L .83286 6.63777 L p F P
0 g
s
0 0 .039 r
.85353 6.47306 m .81448 6.15533 L p .83286 6.63777 L F P
0 g
s
.288 0 0 r
.81448 6.15533 m .85353 6.47306 L .14647 6.47306 L p F P
0 g
s
.288 0 0 r
.14647 6.47306 m .18552 6.15533 L .81448 6.15533 L p F P
0 g
s
.582 .944 .842 r
.30703 4.14185 m .55687 4.00545 L .60496 4.08255 L p F P
0 g
s
.582 .944 .842 r
.60496 4.08255 m .36414 4.21403 L .30703 4.14185 L p F P
0 g
s
.745 .608 .039 r
.14647 6.47306 m .14647 6.82659 L .16714 6.63777 L p F P
0 g
s
0 0 .039 r
.83286 6.63777 m .85353 6.82659 L .85353 6.47306 L p F P
0 g
s
.47995 6.47306 m
.5 6.63777 L
s
.01 w
.35823 2.7699 Mdot
.64177 2.7699 Mdot
.5 Mabswid
.719 .97 .932 r
.21763 4.00558 m .47511 3.86501 L .55687 4.00545 L p F P
0 g
s
.719 .97 .932 r
.55687 4.00545 m .30703 4.14185 L .21763 4.00558 L p F P
0 g
s
.18242 4.02847 m
.46238 6.32863 L
s
.782 .892 .923 r
.10464 3.81719 m .36728 3.6738 L .47511 3.86501 L p F P
0 g
s
.782 .892 .923 r
.47511 3.86501 m .21763 4.00558 L .10464 3.81719 L p F P
0 g
s
.43 .089 .284 r
.05304 3.22828 m .05761 3.10198 L .12933 3.23796 L p F P
0 g
s
.43 .089 .284 r
.12933 3.23796 m .05115 3.28064 L .05304 3.22828 L p F P
0 g
s
.635 .428 .584 r
.04964 3.41677 m .05115 3.28064 L p .24655 3.4549 L F P
0 g
s
.635 .428 .584 r
.05115 3.28064 m .12933 3.23796 L .24655 3.4549 L p F P
0 g
s
.756 .707 .806 r
.04856 3.61215 m .04803 3.56329 L p .36728 3.6738 L F P
0 g
s
.756 .707 .806 r
.04803 3.56329 m .24655 3.4549 L .36728 3.6738 L p F P
0 g
s
.756 .707 .806 r
.10464 3.81719 m .04975 3.7196 L .04856 3.61215 L p F P
0 g
s
.756 .707 .806 r
.36728 3.6738 m .10464 3.81719 L p .04856 3.61215 L F P
0 g
s
.13917 3.67309 m
.18242 4.02847 L
s
.707 .577 .707 r
.5 6.82659 m .14647 6.82659 L .14647 6.47306 L p F P
0 g
s
.707 .577 .707 r
.85353 6.47306 m .85353 6.82659 L .5 6.82659 L p F P
0 g
s
.707 .577 .707 r
.14647 6.47306 m .85353 6.47306 L p .5 6.82659 L F P
0 g
s
.635 .428 .584 r
.24655 3.4549 m .04803 3.56329 L .04964 3.41677 L p F P
0 g
s
.12512 3.55768 m
.13917 3.67309 L
s
.25 Mabswid
0 0 m
0 7.1936 L
s
0 7.1936 m
1 7.1936 L
s
1 7.1936 m
1 0 L
s
1 0 m
0 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{40, 287.688},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40000X00017b000`400?l00000o`00003o:03oool0
02P0oooo000X0?ooo`00:000000000030000003oool0oooo02@0oooo0@00000000030000003oool0
oooo02@0oooo0@00000000030000003oool0oooo02@0oooo0@00000000030000003oool0oooo02<0
oooo0P00000000800000903oool2000000000P00000T0?ooo`8000000002000002@0oooo0P000000
00800000903oool2000000000P00000T0?ooo`8000000002000002@0oooo0P000000008000008`3o
ool100000040oooo0@000000008000008`3oool100000040oooo0@00000000030000003oool00000
0280oooo0@0000010?ooo`40000000000`000000oooo0000000R0?ooo`4000000@3oool100000000
00<000000?ooo`0000008P3oool100000040oooo0@00000000030000003oool000000280oooo0@00
00010?ooo`40000000000`000000oooo0000000R0?ooo`4000000@3oool10000000000<000000?oo
o`0000008@3oool00`000000oooo0?ooo`010000000000<000000?ooo`0000008@3oool00`000000
oooo0?ooo`010000000000<000000?ooo`0000008@3oool00`000000oooo0?ooo`010000000000@0
00000?ooo`3oool00000803oool00`000000oooo0?ooo`010000000000@000000?ooo`3oool00000
803oool00`000000oooo0?ooo`010000000000@000000?ooo`3oool00000803oool00`000000oooo
0?ooo`010000000000@000000?ooo`3oool000007`3oool010000000oooo0?ooo`3oool100000000
00@000000?ooo`3oool000007`3oool010000000oooo0?ooo`3oool10000000000@000000?ooo`3o
ool000007`3oool010000000oooo0?ooo`3oool10000000000@000000?ooo`3oool000007`3oool0
10000000oooo0?ooo`3oool10000000000@000000?ooo`3oool000007`3oool010000000oooo0?oo
o`3oool10000000000D000000?ooo`3oool0oooo0000000N0?ooo`040000003oool0oooo0?ooo`40
000000001@000000oooo0?ooo`3oool0000001h0oooo00@000000?ooo`3oool0oooo0@0000000005
0000003oool0oooo0?ooo`0000007@3oool00`000000oooo0?ooo`020?ooo`40000000001@000000
oooo0?ooo`3oool0000001d0oooo00<000000?ooo`3oool00P3oool10000000000D000000?ooo`3o
ool0oooo0000000M0?ooo`030000003oool0oooo0080oooo0@00000000050000003oool0oooo0?oo
o`0000007@3oool00`000000oooo0?ooo`020?ooo`40000000001@000000oooo0?ooo`3oool00000
01d0oooo00<000000?ooo`3oool00P3oool10000000000D000000?ooo`3oool0oooo0000000M0?oo
o`030000003oool0oooo0080oooo0@00000000030000003oool0oooo0080oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`020?ooo`40000000000`000000oooo0?ooo`020?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool00`3oool10000000000<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00<0oooo0@00000000030000003oool0
oooo0080oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`030?ooo`40000000000`00
0000oooo0?ooo`020?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool00`3oool10000
000000<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00<0
oooo0@00000000030000003oool0oooo0080oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`030?ooo`40000000000`000000oooo0?ooo`020?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool00`3oool10000000000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo00@0oooo0@00000000030000003oool0oooo00<0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`040?ooo`40000000000`000000oooo0?ooo`030?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool0103oool10000000000<000000?ooo`3oool0
0`3ooolK000000H0oooo0@00000000030000003oool0oooo00<0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`040?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool0103oool10000000000<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo00@0oooo0@00000000030000003oool0oooo00<0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`040?ooo`40000000000`000000oooo
0?ooo`030?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0103oool10000000000<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00@0oooo0@00
000000030000003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`04
0?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool0103oool10000000000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo00@0oooo0@00000000030000003oool0oooo00<0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`040?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool0103oool10000000000<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00@0oooo0@00000000030000003oool0oooo
00<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`040?ooo`40000000000`000000
oooo0?ooo`030?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0103oool100000000
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00@0oooo
0@00000000030000003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`040?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool0103oool10000000000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo00@0oooo0@00000000030000003oool0oooo00<0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`040?ooo`40000000000`000000oooo0?ooo`030?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool0103oool10000000000<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00@0oooo0@00000000030000003oool0
oooo00<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`040?ooo`40000000000`00
0000oooo0?ooo`030?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0103oool10000
000000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00@0
oooo0@00000000030000003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`040?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool0103oool10000000000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo00@0oooo0@00000000030000003oool0oooo00<0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`040?ooo`40000000000`000000oooo0?ooo`030?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool0103oool10000000000<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00@0oooo0@00000000030000003o
ool0oooo00<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`040?ooo`4000000000
0`000000oooo0?ooo`030?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0103oool1
0000000000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
00@0oooo0@00000000030000003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`040?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool0103oool10000000000<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo00@0oooo0@00000000030000003oool0oooo00<0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`040?ooo`40000000000`000000oooo0?ooo`030?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool0103oool10000000000<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00@0oooo0@00000000030000
003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`040?ooo`400000
00000`000000oooo0?ooo`030?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0103o
ool10000000000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo00@0oooo0@00000000030000003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`040?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool0103oool10000000000<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo00@0oooo0@00000000030000003oool0oooo00<0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`040?ooo`40000000000`000000oooo0?ooo`03
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0103oool10000000000<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00@0oooo0@0000000003
0000003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`040?ooo`40
000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
103oool10000000000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo00@0oooo0@00000000030000003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`040?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool0103oool10000000000<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo00@0oooo0@00000000030000003oool0oooo00<0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`040?ooo`40000000000`000000oooo0?oo
o`030?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0103oool10000000000<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00@0oooo0@000000
00030000003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`040?oo
o`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0103oool10000000000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`400000
00000`000000oooo0?ooo`030?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0103o
ool10000000000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo00@0oooo0@00000000030000003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`040?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0
oooo0@00000000030000003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`040?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool0103oool10000000000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo00@0oooo0@00000000030000003oool0oooo00<0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`040?ooo`40000000000`000000oooo0?ooo`030?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool0103oool10000000000<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00@0oooo0@00000000030000003o
ool0oooo00<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`040?ooo`4000000000
0`000000oooo0?ooo`030?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0103oool1
0000000000<000000?ooo`0000000`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
00@0oooo0@00000000040000003oool0000000000080oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`040?ooo`400000000010000000oooo0000000000020?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool0103oool10000000000L000000?ooo`000000KQI80000003oool0
000001T0oooo00<000000?ooo`3oool0103oool10000000000@000000?ooo`000000KQI80`00000I
0?ooo`030000003oool0oooo00@0oooo0@00000000030000003oool000000080KQI80P00000I0?oo
o`030000003oool0oooo00@0oooo0@0000000080000000<0KQI80000000000000P00000I0?ooo`03
0000003oool0oooo00@0oooo0@00000000<000000`2RKID2000001P0oooo00<000000?ooo`3oool0
103oool1000000000P0000040:9]U@<000005`3oool00`000000oooo0?ooo`040?ooo`4000000002
000000D0XVfE0P00000G0?ooo`030000003oool0oooo00@0oooo0@000000008000001@2RKID00`00
0000_jk90000000F0?ooo`030000003oool0oooo00@0oooo0@000000008000001P2RKID2000001H0
oooo00<000000?ooo`3oool0103oool1000000000P0000060:9]U@030000002o[/T0000001D0oooo
00<000000?ooo`3oool0103oool1000000000P0000070:9]U@8000005@3oool00`000000oooo0?oo
o`040?ooo`4000000002000000L0XVfE00<000000;n^b@000000503oool00`000000oooo0?ooo`04
0?ooo`4000000002000000D0XVfE0P0000000`31]<h000000000000D0?ooo`030000003oool0oooo
00@0oooo0@000000008000000`2RKID2000000<0`KC>00<000000:MfW00000004`3oool00`000000
oooo0?ooo`040?ooo`4000000002000000030:9]U@000000000000H0`KC>0P00000C0?ooo`030000
003oool0oooo00@0oooo0@00000000<0000000<0`KC>00000031]<h01@31]<h00`000000YgJL0000
000B0?ooo`030000003oool0oooo00@0oooo0@000000008000000P31]<h00`000000`KC>0<6dcP05
0<6dcP8000004P3oool00`000000oooo0?ooo`040?ooo`400000000200000080`KC>00<000000<6d
cP31]<h01P31]<h200000140oooo00<000000?ooo`3oool0103oool1000000000P0000030<6dcP03
00000031]<h0`KC>00D0`KC>0P00000A0?ooo`030000003oool0oooo00@0oooo0@00000000800000
0`31]<h00`000000`KC>0<6dcP060<6dcP800000403oool00`000000oooo0?ooo`040?ooo`400000
0002000000<0`KC>00<000000<6dcP31]<h01031]<h400000100oooo00<000000?ooo`3oool0103o
ool1000000000P0000030<6dcP0300000031]<h0`KC>0080`KC>0P0000030<STk08000003`3oool0
0`000000oooo0?ooo`040?ooo`40000000000`000000oooo000000020<6dcP0500000031]<h0`KC>
0<6dcP0000001@38i>`2000000l0oooo00<000000?ooo`3oool0103oool10000000000<000000?oo
o`0000000`31]<h3000000L0b>C/0P00000>0?ooo`030000003oool0oooo00@0oooo0@0000000005
0000003oool0oooo00000031]<h00P0000090<STk08000003P3oool00`000000oooo0?ooo`040?oo
o`40000000001`000000oooo0?ooo`3oool000000<STk00000002P38i>`2000000d0oooo00<00000
0?ooo`3oool0103oool10000000000<000000?ooo`3oool00P3oool2000000X0b>C/00<0000004h0
7P000000303oool00`000000oooo0?ooo`040?ooo`40000000000`000000oooo0?ooo`020?ooo`80
00002`38i>`2000000`0oooo00<000000?ooo`3oool0103oool10000000000<000000?ooo`3oool0
0`3oool00`000000b>C/0<STk0070<STk080000000<0^?S^0000000000002`3oool00`000000oooo
0?ooo`040?ooo`40000000000`000000oooo0?ooo`030?ooo`0300000038i>`0b>C/00D0b>C/0P00
00030;ShkP8000002`3oool00`000000oooo0?ooo`040?ooo`40000000000`000000oooo0?ooo`03
0?ooo`8000001038i>`2000000H0^?S^0P00000:0?ooo`030000003oool0oooo00@0oooo0@000000
00030000003oool0oooo00<0oooo0P0000020<STk0800000202hn>h2000000X0oooo00<000000?oo
o`3oool0103oool10000000000<000000?ooo`3oool00`3oool4000000/0^?S^0P0000090?ooo`03
0000003oool0oooo00@0oooo0@00000000030000003oool0oooo00<0oooo0P0000000`3oool00000
0;ShkP080;ShkP80000000<0U?7G0000003oool0203oool00`000000oooo0?ooo`040?ooo`400000
00000`000000oooo0?ooo`030?ooo`80000000<0oooo0000002hn>h01P2hn>h2000000<0U?7G0P00
00080?ooo`030000003oool0oooo00@0oooo0@00000000030000003oool0oooo00<0oooo0P000002
0?ooo`030000002hn>h0^?S^0080^?S^0P00000609Cae`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0103oool10000000000<000000?ooo`3oool00`3oool200000080oooo00<000000;Sh
kP2hn>h00P00000609Cae`@000001`3oool00`000000oooo0?ooo`040?ooo`40000000000`000000
oooo0?ooo`030?ooo`8000000P3oool3000000H0U?7G100000090?ooo`030000003oool0oooo00@0
oooo0@00000000030000003oool0oooo00<0oooo00<000000?ooo`0000000P3oool2000000@0U?7G
1000000;0?ooo`030000003oool0oooo00@0oooo0@00000000030000003oool0oooo00<0oooo00<0
00000?ooo`0000000P3oool010000000oooo0000002DlML4000000d0oooo00<000000?ooo`3oool0
103oool10000000000<000000?ooo`3oool00`3oool00`000000oooo000000020?ooo`030000003o
ool0oooo00<000003`3oool00`000000oooo0?ooo`040?ooo`40000000000`000000oooo0?ooo`03
0?ooo`030000003oool000000080oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`04
0?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`040?ooo`40000000000`000000oooo0?ooo`030?ooo`03
0000003oool000000080oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`40
000000000`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`040?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003o
ool000000080oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`4000000000
0`000000oooo0?ooo`030?ooo`060000003oool0oooo0000003oool00000503oool00`000000oooo
0?ooo`040?ooo`40000000000`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`040?ooo`40000000000`000000oooo0?oo
o`030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`040?ooo`40000000000`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`040?ooo`40000000000`000000oooo0?oo
o`030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`040?ooo`40000000000`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`040?ooo`40000000000`000000oooo0?oo
o`030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`040?ooo`40000000000`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`040?ooo`40000000000`000000oooo0?oo
o`030?ooo`070000003oool0oooo0?ooo`000000oooo0000000C0?ooo`030000003oool0oooo00@0
oooo0@00000000030000003oool0oooo00<0oooo00L000000?ooo`3oool0oooo0000003oool00000
01<0oooo00<000000?ooo`3oool0103oool10000000000<000000?ooo`3oool00`3oool01`000000
oooo0?ooo`3oool000000?ooo`0000004`3oool00`000000oooo0?ooo`040?ooo`40000000000`00
0000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00@0oooo0@00000000030000003oool0oooo00<0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool1
0000000000<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`40000000000`000000oooo0?ooo`030?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo00@0oooo0@00000000030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool10000000000<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool000000180oooo00<000000?oo
o`3oool0103oool10000000000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool000000180oooo00<000000?ooo`3oool0103oool10000000000<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool000000180oooo00<000000?ooo`3oool0
103oool10000000000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool000000180oooo00<000000?ooo`3oool0103oool10000000000<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool0103o
ool10000000000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo00000140oooo00<000000?ooo`3oool0103oool10000000000<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool0103o
ool10000000000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo00000140oooo00<000000?ooo`3oool0103oool10000000000<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool000000140oooo00<000000?ooo`3oool0103oool1
0000000000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool00000
0140oooo00<000000?ooo`3oool0103oool10000000000<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`030?ooo`030000003oool000000140oooo00<000000?ooo`3oool0103oool100000000
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool000000140oooo
00<000000?ooo`3oool0103oool10000000000<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`030?ooo`030000003oool000000140oooo00<000000?ooo`3oool0103oool10000000000<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool000000140oooo00<00000
0?ooo`3oool0103oool10000000000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000100oooo00<000000?ooo`3oool0103oool10000000000<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000100oooo00<00000
0?ooo`3oool0103oool10000000000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000100oooo00<000000?ooo`3oool0103oool10000000000<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool000000100oooo00<000000?oo
o`3oool0103oool10000000000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool000000100oooo00<000000?ooo`3oool0103oool10000000000<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`040?ooo`030000003oool000000100oooo00<000000?ooo`3oool0
103oool10000000000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool000000100oooo00<000000?ooo`3oool0103oool10000000000<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool000000100oooo00<000000?ooo`3oool0103oool1
0000000000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool00000
0100oooo00<000000?ooo`3oool0103oool10000000000<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`040?ooo`040000003oool0oooo000000l0oooo00<000000?ooo`3oool0103oool10000
000000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo0000
00l0oooo00<000000?ooo`3oool0103oool10000000000<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`050?ooo`030000003oool0000000l0oooo00<000000?ooo`3oool0103oool100000000
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0000000l0oooo
00<000000?ooo`3oool0103oool10000000000<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0000000l0oooo00<000000?ooo`3oool0103oool10000000000<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0000000l0oooo00<00000
0?ooo`3oool0103oool10000000000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0000000l0oooo00<000000?ooo`3oool0103oool10000000000<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0000000l0oooo00<000000?ooo`3o
ool0103oool10000000000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0000000l0oooo00<000000?ooo`3oool0103oool10000000000<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`050?ooo`040000003oool0oooo000000h0oooo00<000000?ooo`3oool0
103oool10000000000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0000000h0oooo00<000000?ooo`3oool0103oool10000000000<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0000000h0oooo00<000000?ooo`3oool0103oool1
0000000000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool00000
00h0oooo00<000000?ooo`3oool0103oool10000000000<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0000000h0oooo00<000000?ooo`3oool0103oool100000000
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0000000h0oooo
00<000000?ooo`3oool0103oool10000000000<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0000000h0oooo00<000000?ooo`3oool0103oool10000000000<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0000000h0oooo00<00000
0?ooo`3oool0103oool10000000000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0000000h0oooo00<000000?ooo`3oool0103oool10000000000<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`070?ooo`8000003P3oool00`000000oooo0?ooo`040?ooo`40
000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`000000
3@3oool00`000000oooo0?ooo`040?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003o
ool0000001H0000000<0oooo0000003oool01@3oool10000000000<000000?ooo`3oool00`3oool0
0`000000oooo0000000704T00003000000190000000000/0B@0000<000000?ooo`0000001P3oool1
0000000000<000000?ooo`3oool00`3oool00`000000oooo0000000704T000030000001900000000
00/0B@0000<000000?ooo`0000001P3oool10000000000<000000?ooo`3oool00`3oool3000000L0
B@0000<0000004T0000000002`190003000000H0oooo0@00000000030000003oool0oooo00<0oooo
00<000000?ooo`0000001`1900000`000000B@0004T0000;04T000030000003oool0000000H0oooo
0@00000000030000003oool0oooo00<0oooo0P00000804T00003000000190000B@0000`0B@000P00
00060?ooo`40000000000`000000oooo0?ooo`030?ooo`8000002@1900000`000000B@0004T0000;
04T0008000001P3oool10000000000<000000?ooo`3oool00P3oool00`000000oooo0000000904T0
0003000000190000B@0000/0B@0000<000000?ooo`0000001@3oool10000000000<000000?ooo`3o
ool00P3oool00`000000oooo0000000904T00003000000190000B@0000/0B@0000<000000?ooo`00
00001@3oool10000000000<000000?ooo`3oool00P3oool00`000000oooo0000000H000000030?oo
o`000000oooo00@0oooo0@00000000030000003oool0oooo0080oooo00<000000?ooo`0000002@2d
Tk@00`000000]9>d0;BC]00;0;BC]0030000003oool0000000D0oooo0@00000000030000003oool0
oooo0080oooo00<000000?ooo`000000600000000`3oool000000?ooo`040?ooo`40000000000`00
0000oooo0?ooo`020?ooo`030000003oool0000000T0B@0000<0000004T0001900002`1900000`00
0000oooo000000050?ooo`40000000000`000000oooo0?ooo`020?ooo`030000003oool0000000T0
B@0000<0000004T0001900002`1900000`000000oooo000000050?ooo`40000000000`000000oooo
0?ooo`020?ooo`8000002`1900000`000000B@0004T0000:04T000040000003oool0oooo000000@0
oooo0@00000000070000003oool0oooo0?ooo`000000oooo0000000;04T00003000000190000B@00
00/0B@0000<000000?ooo`000000103oool10000000000L000000?ooo`3oool0oooo0000003oool0
000000/0B@0000<0000004T0001900002`1900000`000000oooo000000040?ooo`40000000001`00
0000oooo0?ooo`3oool000000?ooo`0000002`1900000`000000B@0004T0000;04T000030000003o
ool0000000@0oooo0@00000000070000003oool0oooo0?ooo`000000oooo0000000;04T000030000
00190000B@0000/0B@0000<000000?ooo`000000103oool10000000000L000000?ooo`3oool0oooo
0000003oool0000001T0B@0000<000000?ooo`000000103oool10000000000@000000?ooo`3oool0
oooo0P00000J04T000030000003oool0000000@0oooo0@00000000040000003oool0oooo0?ooo`80
00006`1900000`000000oooo000000030?ooo`400000000010000000oooo0?ooo`3oool2000001/0
B@0000<000000?ooo`0000000`3oool10000000000D000000?ooo`3oool000000?ooo`0M00000003
0?ooo`000000oooo0080oooo0@00000000060000003oool0oooo0000003oool000006`2dTk@00`00
0000oooo000000030?ooo`40000000001P000000oooo0?ooo`000000oooo000001/0]9>d00<00000
0?ooo`0000000`3oool10000000000H000000?ooo`3oool000000?ooo`00000K0;BC]0030000003o
ool0000000<0oooo0@00000000060000003oool0oooo0000003oool000006`2dTk@00`000000oooo
000000030?ooo`40000000001P000000oooo0?ooo`000000oooo000001/0]9>d00@000000?ooo`3o
ool000000P3oool10000000000H000000?ooo`3oool000000?ooo`00000K0;BC]0040000003oool0
oooo00000080oooo0@00000000060000003oool0oooo0000003oool000006`2dTk@010000000oooo
0?ooo`0000020?ooo`40000000000`000000oooo000000020?ooo`030000002dTk@0]9>d01T0]9>d
00@000000?ooo`3oool000000P3oool10000000000<000000?ooo`0000000P3oool00`000000]9>d
0;BC]00I0;BC]0040000003oool0oooo00000080oooo0@00000000030000003oool000000080oooo
00<000000;BC]02dTk@06@2dTk@010000000oooo0?ooo`0000020?ooo`40000000000`000000oooo
000000020?ooo`030000002dTk@0]9>d01T0]9>d00H000000?ooo`3oool0oooo0000003oool10000
000000<000000?ooo`0000000P3oool00`000000]9>d0;BC]00I0;BC]0060000003oool0oooo0?oo
o`000000oooo0@00000000030000003oool000000080oooo00<000000;BC]02dTk@06@2dTk@01P00
0000oooo0?ooo`3oool000000?ooo`40000000000`000000oooo000000020?oooad000000`3oool1
00000040oooo0@00000000030000003oool000000280oooo0@0000010?ooo`4000000002000002<0
oooo0@0000010?ooo`4000000002000002<0oooo0@0000010?ooo`4000000002000002@0oooo0P00
000000800000903oool2000000000P00000T0?ooo`8000000002000002@0oooo0P00000000800000
903oool2000000000P00000T0?ooo`80000000000`000000oooo0?ooo`0S0?ooo`80000000000`00
0000oooo0?ooo`0T0?ooo`40000000000`000000oooo0?ooo`0T0?ooo`40000000000`000000oooo
0?ooo`0T0?ooo`400000000X00000000:03oool002P0oooo000X0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 39}, {286.688, 0}} -> {0.430493, -0.0109427, \
0.00356446, 0.00356446}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#2", "Text"],

Cell[CellGroupData[{

Cell["Hz2[[-2]]", "Input"],

Cell[BoxData[
    \(1.3434839300035832`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pretty[Chop[e2ni . eigenvectors2[\([\(-2\)]\)], 10^\(-4\)]]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
          {"\<\"optic\"\>", "0", \(-0.24098239208097993`\), "0", "0", 
            "0", \(-0.9705294878090664`\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Status["\<Plotting stage 2 mode 2\>"]\ ; 
    eigenplot[eigenvectors2[\([\(-2\)]\)],  .1, {\(-1\), 0, 0}, \ 
      floatmatrix2]\ ; Done[]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 2.39787 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.698933 2.39787 0 2.39787 [
[ 0 0 0 0 ]
[ 1 2.39787 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
1 0 m
1 2.39787 L
s
1 2.39787 m
0 2.39787 L
s
0 2.39787 m
0 0 L
s
0 0 m
1 0 L
s
.93501 .15584 m
.06499 .15584 L
s
.06499 .15584 m
.06499 2.24203 L
s
.06499 2.24203 m
.93501 2.24203 L
s
.93501 2.24203 m
.93501 .15584 L
s
1 0 m
1 2.39787 L
s
1 2.39787 m
.93501 2.24203 L
s
.93501 2.24203 m
.93501 .15584 L
s
.93501 .15584 m
1 0 L
s
0 0 m
.06499 .15584 L
s
.06499 .15584 m
.06499 2.24203 L
s
.06499 2.24203 m
0 2.39787 L
s
0 2.39787 m
0 0 L
s
0 0 m
1 0 L
1 2.39787 L
0 2.39787 L
closepath
clip
newpath
.5 Mabswid
.707 .577 .707 r
.36389 2.25665 m .4807 2.25665 L .4807 2.13983 L p F P
0 g
s
.707 .577 .707 r
.4807 2.13983 m .24915 2.13983 L p .36389 2.25665 L F P
0 g
s
.287 0 0 r
.24915 2.13983 m .4807 2.13983 L .47847 2.24879 L p F P
0 g
s
.785 .641 .083 r
.24915 2.25665 m .24915 2.13983 L .22011 2.24879 L p F P
0 g
s
.707 .577 .707 r
.24915 2.13983 m .24915 2.25665 L .36389 2.25665 L p F P
0 g
s
.287 0 0 r
.47847 2.24879 m .22011 2.24879 L .24915 2.13983 L p F P
0 g
s
.714 .583 .006 r
.4807 2.13983 m .4807 2.25665 L .47966 2.31399 L p F P
0 g
s
.714 .583 .006 r
.47847 2.24879 m .4807 2.13983 L p .47966 2.31399 L F P
0 g
s
.785 .641 .083 r
.23555 2.31399 m .24915 2.25665 L p .22011 2.24879 L F P
0 g
s
0 0 .083 r
.75085 2.1419 m .75085 2.25665 L .76471 2.31508 L p F P
0 g
s
0 0 .083 r
.77989 2.2511 m .75085 2.1419 L p .76471 2.31508 L F P
0 g
s
.707 .577 .707 r
.63611 2.25665 m .75085 2.25665 L .75085 2.1419 L p F P
0 g
s
.707 .577 .707 r
.75085 2.1419 m .5193 2.1419 L p .63611 2.25665 L F P
0 g
s
.288 0 0 r
.5193 2.1419 m .75085 2.1419 L .77989 2.2511 L p F P
0 g
s
.707 .577 .707 r
.5193 2.1419 m .5193 2.25665 L .63611 2.25665 L p F P
0 g
s
.288 0 0 r
.77989 2.2511 m .52153 2.2511 L .5193 2.1419 L p F P
0 g
s
0 0 .006 r
.52036 2.31508 m .5193 2.25665 L p .52153 2.2511 L F P
0 g
s
0 0 .006 r
.5193 2.25665 m .5193 2.1419 L .52153 2.2511 L p F P
0 g
s
.01 w
.34843 .90424 Mdot
.5 Mabswid
0 0 0 r
.84481 1.41946 m .82919 1.40948 L .75018 1.4405 L p F P
0 g
s
0 0 0 r
.75018 1.4405 m .76205 1.45196 L .84481 1.41946 L p F P
0 g
s
.04 0 0 r
.76205 1.45196 m .75018 1.4405 L .66545 1.4456 L p F P
0 g
s
.04 0 0 r
.66545 1.4456 m .67329 1.4573 L .76205 1.45196 L p F P
0 g
s
.241 0 0 r
.67329 1.4573 m .66545 1.4456 L .58329 1.42425 L p F P
0 g
s
.241 0 0 r
.58329 1.42425 m .58724 1.43494 L .67329 1.4573 L p F P
0 g
s
.427 0 0 r
.58724 1.43494 m .58329 1.42425 L .51174 1.37857 L p F P
0 g
s
0 0 0 r
.91347 1.36298 m .89475 1.35555 L .82919 1.40948 L p F P
0 g
s
0 0 0 r
.82919 1.40948 m .84481 1.41946 L .91347 1.36298 L p F P
0 g
s
.427 0 0 r
.51174 1.37857 m .5123 1.38709 L .58724 1.43494 L p F P
0 g
s
.579 .107 0 r
.5123 1.38709 m .51174 1.37857 L .45782 1.31301 L p F P
0 g
s
0 0 0 r
.96133 1.28804 m .94043 1.28401 L .89475 1.35555 L p F P
0 g
s
0 0 0 r
.89475 1.35555 m .91347 1.36298 L .96133 1.28804 L p F P
0 g
s
.579 .107 0 r
.45782 1.31301 m .45582 1.31842 L .5123 1.38709 L p F P
0 g
s
.684 .348 0 r
.45582 1.31842 m .45782 1.31301 L .42679 1.234 L p F P
0 g
s
0 0 0 r
.96892 1.22998 m .95471 1.22904 L .94043 1.28401 L p F P
0 g
s
0 0 0 r
.94043 1.28401 m .96133 1.28804 L p .96892 1.22998 L F P
0 g
s
.684 .348 0 r
.42679 1.234 m .42332 1.23566 L .45582 1.31842 L p F P
0 g
s
.73 .561 0 r
.42332 1.23566 m .42679 1.234 L .4217 1.14927 L p F P
0 g
s
0 0 .397 r
.92566 1.0381 m .95471 1.11209 L .95602 1.11184 L p F P
0 g
s
.73 .561 0 r
.4217 1.14927 m .41798 1.14691 L .42332 1.23566 L p F P
0 g
s
.712 .727 .206 r
.41798 1.14691 m .4217 1.14927 L .44304 1.06711 L p F P
0 g
s
.712 .727 .206 r
.44304 1.06711 m .44034 1.06085 L .41798 1.14691 L p F P
0 g
s
.634 .828 .419 r
.44034 1.06085 m .44304 1.06711 L .48872 .99556 L p F P
0 g
s
0 .034 .578 r
.88936 .9618 m .87173 .97254 L .92566 1.0381 L p F P
0 g
s
0 .034 .578 r
.92566 1.0381 m .94585 1.03047 L .88936 .9618 L p F P
0 g
s
0 0 .397 r
.94585 1.03047 m .92566 1.0381 L p .95602 1.11184 L F P
0 g
s
.634 .828 .419 r
.48872 .99556 m .48819 .98592 L .44034 1.06085 L p F P
0 g
s
.501 .854 .598 r
.48819 .98592 m .48872 .99556 L .55428 .94164 L p F P
0 g
s
0 .275 .711 r
.81443 .91395 m .80019 .92686 L .87173 .97254 L p F P
0 g
s
0 .275 .711 r
.87173 .97254 m .88936 .9618 L .81443 .91395 L p F P
0 g
s
.501 .854 .598 r
.55428 .94164 m .55686 .92943 L .48819 .98592 L p F P
0 g
s
.328 .803 .726 r
.55686 .92943 m .55428 .94164 L .63329 .91061 L p F P
0 g
s
0 .497 .785 r
.72837 .8916 m .71803 .90552 L .80019 .92686 L p F P
0 g
s
0 .497 .785 r
.80019 .92686 m .81443 .91395 L .72837 .8916 L p F P
0 g
s
.132 .679 .79 r
.63962 .89693 m .63329 .91061 L .71803 .90552 L p F P
0 g
s
.132 .679 .79 r
.71803 .90552 m .72837 .8916 L .63962 .89693 L p F P
0 g
s
.328 .803 .726 r
.63329 .91061 m .63962 .89693 L .55686 .92943 L p F P
0 g
s
0 0 .397 r
.95602 1.11184 m .97628 1.10798 L .94585 1.03047 L p F P
0 g
s
.714 .583 .006 r
.47966 2.31399 m .47847 2.37912 L .47847 2.24879 L p F P
0 g
s
.785 .641 .083 r
.22011 2.24879 m .22011 2.37912 L .23555 2.31399 L p F P
0 g
s
.36057 2.19133 m
.38629 1.15711 L
s
.35754 2.31344 m
.35914 2.24879 L
s
.68262 2.19351 m
.76458 1.94432 L
s
.64282 2.31453 m
.66369 2.2511 L
s
.954 1.36834 m
.96525 1.33415 L
s
.76458 1.94432 m
.954 1.36834 L
s
0 0 .083 r
.76471 2.31508 m .77989 2.37912 L .77989 2.2511 L p F P
0 g
s
0 0 .006 r
.52153 2.2511 m .52153 2.37912 L .52036 2.31508 L p F P
0 g
s
0 0 0 r
.96133 1.28804 m .97628 1.23047 L .96892 1.22998 L p F P
0 g
s
.01 w
.65876 .89026 Mdot
.34124 .89026 Mdot
.5 Mabswid
.707 .577 .707 r
.34813 2.37912 m .22011 2.37912 L p .47847 2.24879 L F P
0 g
s
.707 .577 .707 r
.22011 2.37912 m .22011 2.24879 L .47847 2.24879 L p F P
0 g
s
.707 .577 .707 r
.47847 2.24879 m .47847 2.37912 L .34813 2.37912 L p F P
0 g
s
.707 .577 .707 r
.65187 2.37912 m .52153 2.37912 L p .77989 2.2511 L F P
0 g
s
.707 .577 .707 r
.52153 2.37912 m .52153 2.2511 L .77989 2.2511 L p F P
0 g
s
.707 .577 .707 r
.77989 2.2511 m .77989 2.37912 L .65187 2.37912 L p F P
0 g
s
.25 Mabswid
1 0 m
1 2.39787 L
s
1 2.39787 m
0 2.39787 L
s
0 2.39787 m
0 0 L
s
0 0 m
1 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{120.063, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40001h00017b000`400?l00000o`00003oN0000000
00030000003oool0oooo07@0oooo0@00000000800000M03oool2000000000P00001d0?ooo`800000
0002000007<0oooo0@0000010?ooo`40000000000`000000oooo0000001b0?ooo`4000000@3oool1
0000000000<000000?ooo`000000L@3oool00`000000oooo0?ooo`010000000000@000000?ooo`3o
ool00000L03oool00`000000oooo0?ooo`010000000000@000000?ooo`3oool00000L03oool00`00
0000oooo0?ooo`010000000000@000000?ooo`3oool00000K`3oool010000000oooo0?ooo`3oool1
0000000000D000000?ooo`3oool0oooo0000001^0?ooo`040000003oool0oooo0?ooo`4000000000
1@000000oooo0?ooo`3oool0000006d0oooo00<000000?ooo`3oool00P3oool10000000000D00000
0?ooo`3oool0oooo0000001]0?ooo`030000003oool0oooo0080oooo0@00000000030000003oool0
oooo0080oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`020?ooo`40000000000`00
0000oooo0?ooo`020?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool00`3oool10000
000000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo00<0
oooo0@00000000030000003oool0oooo00<0oooo00<000000?ooo`3oool0I`3oool00`000000oooo
0?ooo`040?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo06L0oooo00<0
00000?ooo`3oool0103oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`1U
0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0ooooJ@0000070?oo
o`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3o
ool01@3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`1U0?ooo`030000
003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0I@3o
ool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0
oooo06D0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`1U0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0
oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo
0?ooo`040?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool01@3oool10000000000<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo00D0oooo0@00
000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`05
0?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo06D0oooo00<000000?oo
o`3oool01@3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`1U0?ooo`03
0000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0
I@3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003o
ool0oooo06D0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`1U0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo
00@0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`050?ooo`40000000000`000000
oooo0?ooo`040?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool01@3oool100000000
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo00D0oooo
0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?oo
o`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo06D0oooo00<00000
0?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`1U0?oo
o`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0I@3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000
003oool0oooo06D0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0
oooo00@0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`050?ooo`40000000000`00
0000oooo0?ooo`040?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool01@3oool10000
000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo00D0
oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0I@3oool00`000000oooo
0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo06D0oooo00<0
00000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`1U
0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<000000?oo
o`3oool0I@3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`03
0000003oool0oooo06D0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0
103oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo00D0oooo0@00000000030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`050?ooo`4000000000
0`000000oooo0?ooo`040?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool01@3oool1
0000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo
00D0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0I@3oool00`000000
oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo06D0oooo
00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?oo
o`1U0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0I@3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?oo
o`030000003oool0oooo06D0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo00D0oooo0@00000000030000
003oool0oooo00@0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`050?ooo`400000
00000`000000oooo0?ooo`040?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool01@3o
ool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`1U0?ooo`030000003oool0
oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo06D0
oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103oool00`000000oooo
0?ooo`1U0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0I@3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`04
0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool01@3oool10000000000<000000?oo
o`3oool0103oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo00D0oooo0@0000000003
0000003oool0oooo00@0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`050?ooo`40
000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0
1@3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`1U0?ooo`030000003o
ool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0I@3oool0
0`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo
06D0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103oool00`000000
oooo0?ooo`1U0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo
00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?oo
o`040?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool01@3oool10000000000<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo00D0oooo0@000000
00030000003oool0oooo00@0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`050?oo
o`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3o
ool01@3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`1U0?ooo`030000
003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0I@3o
ool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0
oooo06D0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`1U0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0
oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo
0?ooo`040?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool01@3oool10000000000<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo00D0oooo0@00
000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`05
0?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo06D0oooo00<000000?oo
o`3oool01@3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`1U0?ooo`03
0000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0
I@3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003o
ool0oooo06D0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`1U0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo
00@0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`050?ooo`40000000000`000000
oooo0?ooo`040?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool01@3oool100000000
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo00D0oooo
0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?oo
o`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo06D0oooo00<00000
0?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`1U0?oo
o`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0I@3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000
003oool0oooo06D0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0
oooo00@0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`050?ooo`40000000000`00
0000oooo0?ooo`040?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool01@3oool10000
000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo
0?ooo`040?ooo`030000003oool0oooo04P0oooo1P00000G0?ooo`030000003oool0oooo00D0oooo
0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`0O0?ooo`L000000`0Q[LX00`00000007o8001ob003000001@0oooo00<000000?ooo`3oool01@3o
ool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0o0?ooo`<000001@0Q[LX6
000000@007o81000000@0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo
00@0oooo00<000000?ooo`3oool0?03oool300000080Dlfi1P0000060?ooo`<000001@00OlP20000
00h0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0j0?ooo`80000000@0Dlfi0000000000000000403oool400000003001ob000000004Jf
00800000303oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`03
0000003oool0oooo03P0oooo1@00000G0?ooo`8000000`00A[H00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0
=`3oool2000001d0oooo0P0000020016]P8000002@3oool00`000000oooo0?ooo`050?ooo`400000
00000`000000oooo0?ooo`040?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool07`3o
ool01@00000004Jf0016]P00A[H0000000P0oooo00<000000?ooo`3oool01@3oool10000000000<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0240oooo0P00
00020016]P8000001P3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`04
0?ooo`030000003oool0oooo03<0oooo0P00000V0?ooo`0500000000A[H004Jf0016]P0000001@3o
ool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0
oooo0380oooo0P00000Y0?ooo`80000000<000RC0000003oool00`3oool00`000000oooo0?ooo`05
0?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo0340oooo0P00000[0?oo
o`040000000029<000RC000000<0oooo00<000000?ooo`3oool01@3oool10000000000<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0`0?ooo`800000;@3oool01000000000RC0008T`000002
0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<000000?oo
o`3oool0;`3oool2000002l0oooo00<000000008T`0000000P3oool00`000000oooo0?ooo`050?oo
o`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3o
ool0;P3oool01P00000000RC0008T`000000oooo000000L0oooo0@00000000030000003oool0oooo
00@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0`0?ooo`030000000029<000RC
008000001`3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0]0?ooo`80
0000<`3oool01000000000RC0008T`0000070?ooo`40000000000`000000oooo0?ooo`040?ooo`03
0000003oool0oooo02d0oooo00<000000?ooo`3oool0<`3oool01000000000RC0008T`0000060?oo
o`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3o
ool0=@3oool3000000H0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`0f0?ooo`040000000006D0001U000000D0oooo0@00000000030000
003oool0oooo00@0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0g0?ooo`80001U
00<000000?ooo`3oool00`3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0Z0?ooo`030000003oool0oooo03P0oooo0`0006D00`000000oooo0?ooo`020?ooo`4000000000
0`000000oooo0?ooo`040?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0>03oool0
10000000001U0000I@0000040?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0
oooo02T0oooo0P00000j0?ooo`050000000006D0001U0000I@0000000`3oool10000000000<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo03T0oooo00D00000
0000I@0006D0001U000000030?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool0>@3oool2000000<0001U00<000000?ooo`3oool00@000000
00030000003oool0oooo00@0oooo00<000000?ooo`3oool0:03oool2000003/0oooo00@000000?oo
o`0006D0001U0P0000020?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo
02P0oooo0P00000k0?ooo`040000003oool00000000000@0oooo0@00000000030000003oool0oooo
00@0oooo00<000000?ooo`3oool0:03oool2000003/0oooo00<000000?ooo`3oool01@3oool10000
000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo03X0
oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0W0?ooo`800000?03oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?oo
o`040?ooo`030000003oool0oooo02L0oooo0P00000l0?ooo`030000003oool0oooo00D0oooo0@00
000000030000003oool0oooo00@0oooo00<000000?ooo`3oool08`3oool010000000oooo0?ooo`3o
ool2000003`0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0S0?ooo`040000003oool0oooo0?ooo`800000?03oool00`000000oooo0?oo
o`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo02<0oooo00@00000
0?ooo`3oool0oooo0P00000l0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0
oooo00@0oooo00<000000?ooo`3oool08`3oool010000000oooo0?ooo`3oool2000003`0oooo00<0
00000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0S
0?ooo`040000003oool0oooo0?ooo`800000?03oool00`000000oooo0?ooo`050?ooo`4000000000
0`000000oooo0?ooo`040?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo
00@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
03X0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0>P3oool00`000000
oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00D0oooo
0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo03X0oooo00<000000?ooo`0000000`0000020?ooo`4000000000
0`000000oooo0?ooo`040?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0j0?ooo`030000003oool0000000<000000P3oool10000000000<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0>@3oool5000000<0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03T0oooo1@0000030?ooo`40
000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0h0?ooo`D000000`3oool10000000000<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0>03o
ool5000000<0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo03P0oooo100000040?ooo`40000000000`00
0000oooo0?ooo`040?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0f0?ooo`D00000103oool10000000000<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0=P3oool4000000D0
oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo03@0oooo1@0000050?ooo`40000000000`000000oooo0?oo
o`040?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0d0?ooo`@000001P3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0<P3oool4000000L0oooo0@000000
00030000003oool0oooo00@0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`080?oo
o`800000<`3oool400000080oooo00<000000?ooo`3oool00P3oool10000000000<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00T0oooo0P00000a0?ooo`D0
00000P3oool00`000000oooo0?ooo`020?ooo`40000000000`000000oooo0?ooo`040?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0_0?ooo`<00000
00@0oooo0000003oool000001@3oool10000000000<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0;@3oool4000000040?oo
o`000000oooo000000D0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`0;0?ooo`800000;@3oool400000080oooo00<000000?ooo`000000
1@3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo00`0oooo0P00000Z0?ooo`D000000`3oool00`000000oooo000000050?ooo`4000000000
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool03@3oool0
0`000000K@000000000W0?ooo`D00000103oool2000000H0oooo0@00000000030000003oool0oooo
00@0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0>0?ooo`<000009@3oool40000
00H0oooo0P0000060?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool0403oool300000240oooo1@0000070?ooo`8000001P3oool100000000
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0140oooo
0`00000N0?ooo`H00000203oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?oo
o`040?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool04`3oool3000001X0oooo1P00
000:0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<00000
0?ooo`3oool08P3oool00`000000oooo0?ooo`0D0?ooo`D000005@3oool6000000`0oooo00<00000
0?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo01H0oooo0P0000000`0m0000000000000003000000h0oooo1P00000=0?oo
o`8000001`3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo01P0oooo1000000203d001400000403oool2000000L0oooo0@00000000030000
003oool0oooo00@0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0L0?ooo`D00000
1P0:000600000180oooo0P0000070?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool0803oool7000001L0oooo00<000000?ooo`0000001`3o
ool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo03h0oooo00<000000?ooo`0000001`3oool10000000000<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`0000001`3oool10000
000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo03h0
oooo00<000000?ooo`0000001`3oool10000000000<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo03d0oooo00@000000?ooo`3oool000001`3oool100000000
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo03d0oooo
00@000000?ooo`3oool000001`3oool10000000000<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo03d0oooo00@000000?ooo`3oool000001`3oool100000000
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo03`0oooo
00D000000?ooo`3oool0oooo000000070?ooo`40000000000`000000oooo0?ooo`040?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool0?03oool01@000000oooo0?ooo`3oool0000000L0
oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`0l0?ooo`050000003oool0oooo0?ooo`0000001`3oool10000000000<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool1
0000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
03X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`40000000000`000000
oooo0?ooo`040?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0>P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool0>@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo0@000000
00030000003oool0oooo00@0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo03L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`40000000000`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0=`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo0@00
000000030000003oool0oooo00@0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool10000000000<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0240oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
1@3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo03H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`4000000000
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0=@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo
00@0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo
0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool10000000000<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3o
ool08@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool01@3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo03<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`050?ooo`400000
00000`000000oooo0?ooo`040?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0<P3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0
oooo00@0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0
oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`0a0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool10000000000<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0340oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool01@3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo0300oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`40
000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0
<03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo0@00000000030000003o
ool0oooo00@0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0_0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo
0240oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
00D0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`0^0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool100000000
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo02h0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?oo
o`040?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0Q0?oo
o`030000003oool0oooo02d0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`050?oo
o`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00D0oooo0@00000000030000
003oool0oooo00@0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0/0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool01@3oool10000
000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo02/0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo
0?ooo`040?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0:`3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`05
0?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo0@0000000003
0000003oool0oooo00@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0200oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01@3oool1
0000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`050?ooo`40000000000`000000
oooo0?ooo`040?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo
00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0P0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo0@000000
00030000003oool0oooo00@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool04`3o
oolM000000<0oooo7@00000E0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0
oooo00@0oooo00<000000?ooo`3oool04`3oool00`000000B@0004T0000:04T00003000000190000
B@0000`0B@0000D000000?ooo`3oool0oooo0000000E04T00003000000190000B@0000<0B@0000<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`04
0?ooo`030000003oool0oooo01<0oooo00<0000004T0001900002P1900000`000000B@0004T0000<
04T000050000003oool0oooo0?ooo`000000501900000`000000B@0004T0000404T000030000003o
ool0oooo01<0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0B0?ooo`03000000190000B@0000/0B@0000<0000004T00019000030190000
1@000000oooo0?ooo`3oool0000001@0B@0000<0000004T0001900001@1900000`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<00000
0?ooo`3oool04P3oool00`000000B@0004T0000;04T00003000000190000B@0000`0B@0000D00000
0?ooo`3oool0oooo0000000D04T00003000000190000B@0000D0B@0000<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0
oooo0180oooo00<0000004T0001900002`1900000`000000B@0004T0000<04T000050000003oool0
oooo0?ooo`0000004`1900000`000000B@0004T0000604T000030000003oool0oooo0180oooo00<0
00000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0B
0?ooo`03000000190000B@0000/0B@0000<0000004T000190000301900001@000000oooo0?ooo`3o
ool0000001<0B@0000<0000004T0001900001P1900000`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool04@3oool0
0`000000B@0004T0000J04T0008000000`3oool2000001`0B@0000<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo
0140oooo00<0000004T0001900006P190002000000<0oooo0P00000L04T000030000003oool0oooo
0140oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0A0?ooo`03000000190000B@0001X0B@000P0000030?ooo`800000701900000`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo
00<000000?ooo`3oool04@3oool00`000000B@0004T0000J04T0008000000`3oool2000001`0B@00
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?oo
o`040?ooo`030000003oool0oooo0100oooo00<0000004T0001900006`190002000000<0oooo0P00
000M04T000030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool10000000000<00000
0?ooo`3oool0103ooolD000001d0B@001`00000M04T001@000001`3oool10000000000<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0@0?ooob0000000`3ooolP00000180oooo00<000000?oo
o`3oool01@3oool10000000000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0A0?ooo`03
0000002dTk@0]9>d01/0]9>d0P0000030?ooo`8000007@2dTk@00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo00@0oooo0@00000000030000003oool0oooo00<0oooo00<000000?ooo`3oool0
4@3oool00`000000]9>d0;BC]00K0;BC]08000000`3oool2000001d0]9>d00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`040?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0140oooo00<000000;BC]02dTk@06`2dTk@2000000<0oooo0P00000M0;BC]0030000003o
ool0oooo0180oooo00<000000?ooo`3oool00`3oool10000000000<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0B0?ooo`030000002dTk@0]9>d01/0]9>d0P0000030?ooo`8000007@2dTk@0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00<0oooo0@00000000030000003oool0oooo
0080oooo00<000000?ooo`3oool04P3oool00`000000]9>d0;BC]00K0;BC]08000000`3oool20000
01d0]9>d00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`40000000001@000000
oooo0?ooo`3oool0000001D0oooo00<000000;BC]02dTk@06`2dTk@2000000<0oooo0P00000M0;BC
]0030000003oool0oooo01<0oooo00<000000?ooo`3oool00P3oool10000000000D000000?ooo`3o
ool0oooo0000000E0?ooo`030000002dTk@0]9>d01/0]9>d0P0000030?ooo`8000007@2dTk@00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo0@00000000050000003oool0oooo0?oo
o`0000005@3oool00`000000]9>d0;BC]00K0;BC]08000000`3oool2000001d0]9>d00<000000?oo
o`3oool0503oool010000000oooo0?ooo`3oool10000000000@000000?ooo`3oool000005P3oool0
0`000000]9>d0;BC]00K0;BC]08000000`3oool2000001d0]9>d00<000000?ooo`3oool0503oool0
10000000oooo0?ooo`3oool10000000000@000000?ooo`3oool000005P3oool00`000000]9>d0;BC
]00K0;BC]08000000`3oool2000001d0]9>d00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`010000000000@000000?ooo`3oool000005P3oool00`000000]9>d0;BC]00K0;BC]08000000`3o
ool2000001d0]9>d00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`010000000000<00000
0?ooo`0000005`3oool00`000000]9>d0;BC]00K0;BC]0030000003oool0oooo0080oooo0P00000M
0;BC]0030000003oool0oooo01D0oooo00<000000?ooo`3oool00@00000000030000003oool00000
01L0oooo00<000000;BC]02dTk@06`2dTk@00`000000oooo0?ooo`030?ooo`030000002dTk@0]9>d
01/0]9>d00<000000?ooo`3oool05P3oool100000040oooo0@00000000800000603oool00`000000
]9>d0;BC]00K0;BC]0030000003oool0oooo00<0oooo00<000000;BC]02dTk@06`2dTk@00`000000
oooo0?ooo`0F0?ooo`4000000@3oool1000000000P00000H0?ooo`030000002dTk@0]9>d01/0]9>d
00<000000?ooo`3oool00`3oool00`000000]9>d0;BC]00K0;BC]0030000003oool0oooo01L0oooo
0P00000000800000603ooolO000000D0oooo7`00000I0?ooo`80000000000`000000oooo0?ooo`1d
0?ooo`400000001h00000000\
\>"],
  ImageRangeCache->{{{0, 119.063}, {286.875, 0}} -> {0.291479, -0.00241942, \
0.00350271, 0.00350271}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#3", "Text"],

Cell[CellGroupData[{

Cell["Hz2[[-3]]", "Input"],

Cell[BoxData[
    \(1.5338724090239664`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pretty[Chop[e2ni . eigenvectors2[\([\(-3\)]\)], 10^\(-4\)]]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
          {"\<\"optic\"\>", "0.012047953394874744`", "0", "0", "0", 
            "0.9999274207756256`", "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Status["\<Plotting stage 2 mode 2\>"]\ ; 
    eigenplot[eigenvectors2[\([\(-3\)]\)],  .5, {0, \(-1\), \(- .25\)}, \ 
      floatmatrix2]\ ; Done[]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 5.99483 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.6256 6.25121 1.28586e-016 6.25121 [
[ 0 0 0 0 ]
[ 1 5.99483 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
.12768 5.99483 L
s
.12768 5.99483 m
.23891 4.75775 L
s
.23891 4.75775 m
.18195 .67458 L
s
.18195 .67458 m
0 0 L
s
1 0 m
.81805 .67458 L
s
.81805 .67458 m
.76109 4.75775 L
s
.76109 4.75775 m
.87232 5.99483 L
s
.87232 5.99483 m
1 0 L
s
0 0 m
.12768 5.99483 L
s
.12768 5.99483 m
.87232 5.99483 L
s
.87232 5.99483 m
1 0 L
s
1 0 m
0 0 L
s
.18195 .67458 m
.81805 .67458 L
s
.81805 .67458 m
.76109 4.75775 L
s
.76109 4.75775 m
.23891 4.75775 L
s
.23891 4.75775 m
.18195 .67458 L
s
0 0 m
1 0 L
1 5.99483 L
0 5.99483 L
closepath
clip
newpath
.5 Mabswid
.691 .687 .841 r
.5 4.95773 m .71974 4.95773 L p .27793 4.76168 L F P
0 g
s
.691 .687 .841 r
.71974 4.95773 m .72207 4.76168 L .27793 4.76168 L p F P
0 g
s
.691 .687 .841 r
.27793 4.76168 m .28026 4.95773 L .5 4.95773 L p F P
0 g
s
.745 .608 .039 r
.27065 5.09348 m .28026 4.95773 L p .25738 5.03076 L F P
0 g
s
.745 .608 .039 r
.28026 4.95773 m .27793 4.76168 L .25738 5.03076 L p F P
0 g
s
0 0 .039 r
.72207 4.76168 m .71974 4.95773 L .72935 5.09348 L p F P
0 g
s
0 0 .039 r
.74262 5.03076 m .72207 4.76168 L p .72935 5.09348 L F P
0 g
s
.412 0 0 r
.72207 4.76168 m .74262 5.03076 L .25738 5.03076 L p F P
0 g
s
.412 0 0 r
.25738 5.03076 m .27793 4.76168 L .72207 4.76168 L p F P
0 g
s
.745 .608 .039 r
.25738 5.03076 m .26016 5.24166 L .27065 5.09348 L p F P
0 g
s
0 0 .039 r
.72935 5.09348 m .73984 5.24166 L .74262 5.03076 L p F P
0 g
s
.5112 4.87045 m
.60751 2.95319 L
s
.5 5.09348 m
.50315 5.03076 L
s
.688 .696 .853 r
.5 5.24166 m .26016 5.24166 L .25738 5.03076 L p F P
0 g
s
.688 .696 .853 r
.74262 5.03076 m .73984 5.24166 L .5 5.24166 L p F P
0 g
s
.688 .696 .853 r
.25738 5.03076 m .74262 5.03076 L p .5 5.24166 L F P
0 g
s
.552 .365 .581 r
.76908 3.04968 m .58852 3.14505 L .66322 3.29559 L p F P
0 g
s
.657 .589 .768 r
.58852 3.14505 m .76908 3.04968 L .68781 2.89768 L p F P
0 g
s
.657 .589 .768 r
.68781 2.89768 m .50727 2.99395 L .58852 3.14505 L p F P
0 g
s
.713 .771 .898 r
.50727 2.99395 m .68781 2.89768 L .60732 2.75438 L p F P
0 g
s
.713 .771 .898 r
.60732 2.75438 m .42493 2.85252 L .50727 2.99395 L p F P
0 g
s
.552 .365 .581 r
.80928 3.12864 m .76908 3.04968 L p .66322 3.29559 L F P
0 g
s
.406 .111 .348 r
.81025 3.21864 m .66322 3.29559 L .72601 3.43512 L p F P
0 g
s
.552 .365 .581 r
.66322 3.29559 m .81025 3.21864 L .80928 3.12864 L p F P
0 g
s
.687 .698 .855 r
.5 5.29411 m .74356 5.29411 L p .25358 5.08052 L F P
0 g
s
.687 .698 .855 r
.74356 5.29411 m .74642 5.08052 L .25358 5.08052 L p F P
0 g
s
.687 .698 .855 r
.25358 5.08052 m .25644 5.29411 L .5 5.29411 L p F P
0 g
s
.745 .608 .039 r
.24458 5.46167 m .25644 5.29411 L p .22802 5.41523 L F P
0 g
s
.745 .608 .039 r
.25644 5.29411 m .25358 5.08052 L .22802 5.41523 L p F P
0 g
s
0 0 .039 r
.74642 5.08052 m .74356 5.29411 L .75542 5.46167 L p F P
0 g
s
.406 .111 .348 r
.81175 3.26673 m .81025 3.21864 L p .72601 3.43512 L F P
0 g
s
.717 .897 .961 r
.42493 2.85252 m .60732 2.75438 L .53332 2.63021 L p F P
0 g
s
.717 .897 .961 r
.53332 2.63021 m .34727 2.73112 L .42493 2.85252 L p F P
0 g
s
.406 .111 .348 r
.72601 3.43512 m .81554 3.38867 L .81175 3.26673 L p F P
0 g
s
0 0 .039 r
.77198 5.41523 m .74642 5.08052 L p .75542 5.46167 L F P
0 g
s
.412 0 0 r
.74642 5.08052 m .77198 5.41523 L .22802 5.41523 L p F P
0 g
s
.412 0 0 r
.22802 5.41523 m .25358 5.08052 L .74642 5.08052 L p F P
0 g
s
.223 0 .081 r
.81554 3.38867 m .72601 3.43512 L .77161 3.55273 L p F P
0 g
s
.223 0 .081 r
.82093 3.47758 m .81554 3.38867 L p .77161 3.55273 L F P
0 g
s
.663 .955 .947 r
.34727 2.73112 m .53332 2.63021 L .47188 2.53589 L p F P
0 g
s
.663 .955 .947 r
.47188 2.53589 m .28053 2.64031 L .34727 2.73112 L p F P
0 g
s
.223 0 .081 r
.77161 3.55273 m .82385 3.52582 L .82093 3.47758 L p F P
0 g
s
.016 0 0 r
.82385 3.52582 m .77161 3.55273 L .7949 3.63709 L p F P
0 g
s
.016 0 0 r
.83233 3.59636 m .82385 3.52582 L p .7949 3.63709 L F P
0 g
s
.745 .608 .039 r
.22802 5.41523 m .2315 5.6464 L .24458 5.46167 L p F P
0 g
s
0 0 .039 r
.75542 5.46167 m .7685 5.6464 L .77198 5.41523 L p F P
0 g
s
.5 5.46167 m
.50299 5.41523 L
s
.549 .93 .849 r
.28053 2.64031 m .47188 2.53589 L .42933 2.4821 L p F P
0 g
s
.549 .93 .849 r
.42933 2.4821 m .23133 2.59054 L .28053 2.64031 L p F P
0 g
s
.01 w
.38937 2.41909 Mdot
.61063 2.41909 Mdot
.5 Mabswid
.016 0 0 r
.7949 3.63709 m .83477 3.61665 L .83233 3.59636 L p F P
0 g
s
0 0 0 r
.83477 3.61665 m .7949 3.63709 L .7915 3.67714 L p F P
0 g
s
0 0 0 r
.84423 3.64008 m .83477 3.61665 L p .7915 3.67714 L F P
0 g
s
.378 .816 .665 r
.23133 2.59054 m .42933 2.4821 L .41173 2.47832 L p F P
0 g
s
.378 .816 .665 r
.41173 2.47832 m .20622 2.59095 L .23133 2.59054 L p F P
0 g
s
.682 .71 .869 r
.5 5.6464 m .2315 5.6464 L .22802 5.41523 L p F P
0 g
s
.682 .71 .869 r
.77198 5.41523 m .7685 5.6464 L .5 5.6464 L p F P
0 g
s
.682 .71 .869 r
.22802 5.41523 m .77198 5.41523 L p .5 5.6464 L F P
0 g
s
0 0 0 r
.7915 3.67714 m .8476 3.64843 L .84423 3.64008 L p F P
0 g
s
.406 .845 .726 r
.8476 3.64843 m .7915 3.67714 L .75869 3.66377 L p F P
0 g
s
.406 .845 .726 r
.8557 3.6264 m .8476 3.64843 L p .75869 3.66377 L F P
0 g
s
0 0 0 r
.20622 2.59095 m .41173 2.47832 L .42385 2.53078 L p F P
0 g
s
0 0 0 r
.42385 2.53078 m .21064 2.6473 L .20622 2.59095 L p F P
0 g
s
.406 .845 .726 r
.75869 3.66377 m .86129 3.61119 L .8557 3.6264 L p F P
0 g
s
.573 .939 .897 r
.86129 3.61119 m .75869 3.66377 L .69681 3.59238 L p F P
0 g
s
.573 .939 .897 r
.86631 3.569 m .86129 3.61119 L p .69681 3.59238 L F P
0 g
s
.076 0 0 r
.21064 2.6473 m .42385 2.53078 L .4676 2.63962 L p F P
0 g
s
.076 0 0 r
.4676 2.63962 m .24735 2.75923 L .21064 2.6473 L p F P
0 g
s
.573 .939 .897 r
.69681 3.59238 m .87441 3.50089 L .86631 3.569 L p F P
0 g
s
.677 .928 .971 r
.87441 3.50089 m .69681 3.59238 L .61051 3.46582 L p F P
0 g
s
.677 .928 .971 r
.87587 3.47708 m .87441 3.50089 L p .61051 3.46582 L F P
0 g
s
.677 .928 .971 r
.83631 3.3485 m .87949 3.41804 L .87587 3.47708 L p F P
0 g
s
.677 .928 .971 r
.61051 3.46582 m .83631 3.3485 L p .87587 3.47708 L F P
0 g
s
.308 0 .238 r
.24735 2.75923 m .4676 2.63962 L .54045 2.79643 L p F P
0 g
s
.308 0 .238 r
.54045 2.79643 m .31476 2.91784 L .24735 2.75923 L p F P
0 g
s
.01 w
.37334 2.50103 Mdot
.62666 2.50103 Mdot
.5 Mabswid
.701 .808 .932 r
.83631 3.3485 m .61051 3.46582 L .5092 3.29637 L p F P
0 g
s
.701 .808 .932 r
.5092 3.29637 m .73791 3.17621 L .83631 3.3485 L p F P
0 g
s
.505 .304 .542 r
.31476 2.91784 m .54045 2.79643 L .63462 2.98349 L p F P
0 g
s
.505 .304 .542 r
.63462 2.98349 m .40594 3.1051 L .31476 2.91784 L p F P
0 g
s
.641 .591 .783 r
.73791 3.17621 m .5092 3.29637 L .40594 3.1051 L p F P
0 g
s
.62396 3.53312 m
.63993 3.28472 L
s
.51267 5.26461 m
.62396 3.53312 L
s
.641 .591 .783 r
.40594 3.1051 m .63462 2.98349 L .73791 3.17621 L p F P
0 g
s
.25 Mabswid
0 0 m
.12768 5.99483 L
s
.12768 5.99483 m
.87232 5.99483 L
s
.87232 5.99483 m
1 0 L
s
1 0 m
0 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{48, 287.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40000`00017b000`400?l00000o`00003o<03oool0
0300oooo000`0000000000<000000?ooo`3oool0;03oool10000000000<000000?ooo`3oool0:`3o
ool2000000000P00000/0?ooo`8000000002000002`0oooo0P00000000800000;03oool200000000
0P00000[0?ooo`4000000@3oool10000000000<000000?ooo`000000:P3oool100000040oooo0@00
000000030000003oool0000002X0oooo0@0000010?ooo`40000000000`000000oooo0000000Y0?oo
o`030000003oool0oooo0040000000000`000000oooo0000000Y0?ooo`030000003oool0oooo0040
0000000010000000oooo0?ooo`00000X0?ooo`030000003oool0oooo00400000000010000000oooo
0?ooo`00000X0?ooo`030000003oool0oooo00400000000010000000oooo0?ooo`00000W0?ooo`04
0000003oool0oooo0?ooo`400000000010000000oooo0?ooo`00000W0?ooo`040000003oool0oooo
0?ooo`40000000001@000000oooo0?ooo`3oool0000002H0oooo00@000000?ooo`3oool0oooo0@00
000000050000003oool0oooo0?ooo`0000009@3oool00`000000oooo0?ooo`020?ooo`4000000000
1@000000oooo0?ooo`3oool0000002D0oooo00<000000?ooo`3oool00P3oool10000000000D00000
0?ooo`3oool0oooo0000000U0?ooo`030000003oool0oooo0080oooo0@00000000030000003oool0
oooo0080oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`020?ooo`40000000000`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool00`3oool10000
000000<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00<0
oooo0@00000000030000003oool0oooo0080oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool00`3oool10000000000<0oooo0000003oool00`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo00<0oooo0@0000010?ooo`0000<0oooo0000003oool00`3oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo00<0oooo0@0000010?ooo`0000<0oooo0000003o
ool00`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00<0oooo0@0000010?ooo`00
00<0oooo0000003oool0103oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00@0oooo
0@0000010?ooo`0000<0oooo0000003oool0103oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo00@0oooo0@0000010?ooo`0000<0oooo0000003oool0103oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo00@0oooo0@0000010?ooo`0000<0oooo0000003oool0103oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo00@0oooo0@0000010?ooo`0000<0oooo0000003o
ool01@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`00
00<0oooo0000003oool01@3ooolO000000L0oooo0@0000010?ooo`0000<0oooo0000003oool01@3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo
0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@000001
0?ooo`0000<0oooo0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo
0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@000001
0?ooo`0000<0oooo0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo
0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@000001
0?ooo`0000<0oooo0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo
0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@000001
0?ooo`0000<0oooo0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo
0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@000001
0?ooo`0000<0oooo0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo
0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@000001
0?ooo`0000<0oooo0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo
0000003oool01@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo0@000001
0?ooo`0000<0oooo0000003oool01P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
00H0oooo0@0000010?ooo`0000<0oooo0000003oool01P3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo00H0oooo0@0000010?ooo`0000<0oooo0000003oool01P3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo00H0oooo0@0000010?ooo`0000<0oooo0000003oool01P3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo0@0000010?ooo`0000<0oooo
0000003oool01P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo0@000001
0?ooo`0000<0oooo0000003oool01P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
00H0oooo0@0000010?ooo`000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool01@3oool100000040oooo0@3oool00080oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`40oooo
00020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`050?ooo`4000000@3oool10?ooo`000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool01@3oool100000040oooo0@3oool00080oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo0@0000010?oo
o`40oooo00020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`050?ooo`4000000@3oool10?ooo`000P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool100000040oooo0@3oool00080oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo0@00
00010?ooo`40oooo00020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`050?ooo`4000000@3oool10?ooo`000P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool100000040oooo0@3oool00080
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0
oooo0@0000010?ooo`40oooo00020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`050?ooo`4000000@3oool10?ooo`000P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool100000040oooo0@3o
ool00080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo00D0oooo0@0000010?ooo`40oooo00020?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`050?ooo`4000000@3oool10?ooo`000P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool100000040
oooo0@3oool00080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo00D0oooo0@0000010?ooo`40oooo00020?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`050?ooo`4000000@3oool10?ooo`000P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool1
00000040oooo0@3oool00080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo00D0oooo0@0000010?ooo`40oooo00020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`050?ooo`4000000@3oool10?ooo`00
0P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
1@3oool100000040oooo0@3oool00080oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`40oooo00020?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`050?ooo`4000000@3oool1
0?ooo`000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool01@3oool100000040oooo0@3oool00080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`40oooo00020?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`050?ooo`400000
0@3oool10?ooo`000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool01@3oool100000040oooo0@3oool00080oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`40oooo00020?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`050?oo
o`4000000@3oool10?ooo`000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool01@3oool100000040oooo0@3oool00080oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`40oooo
00020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`050?ooo`4000000@3oool10?ooo`000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool01@3oool100000040oooo0@3oool00080oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo0@0000010?oo
o`40oooo00020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`050?ooo`4000000@3oool10?ooo`000P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool100000040oooo0@3oool00080oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo0@00
00010?ooo`40oooo00020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`050?ooo`4000000@3oool10?ooo`000P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool100000040oooo0@3oool00080
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0
oooo0@0000010?ooo`40oooo00020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`050?ooo`4000000@3oool10?ooo`000P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool100000040oooo0@3o
ool00080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`4000000@3oool1
0?ooo`000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool01@3oool100000040oooo0@3oool00080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`40oooo00020?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool010000000oooo0000000000080?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool100000040oooo0@3oool000<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`<0000000<0S>kI0000003oool0
3P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0040oooo00030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00`3oool500000080S>kI00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0040oooo00030?ooo`030000003oool0
oooo00<0oooo00@000000?ooo`3oool0oooo2@0000000`2Ym?8000000?ooo`0<0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo00000005000000<04`0000@000000:WdlP2Ym?8000003@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0040oooo00030?ooo`030000003oool0oooo00<0oooo1P000005
01<000050000002Ym?80ZOCb0:WdlP000000303oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0040oooo00030?ooo`030000003oool0oooo00<0oooo1@00000701<000040000002Ym?80
ZOCb000000`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`010?ooo`000`3oool0
0`000000oooo0?ooo`030?ooo`<000002@0C00001@000000ZOCb0:WdlP2Ym?80000000/0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`03
0?ooo`030000000C00004`0000L04`000`000000102Ym?80000000000000000;0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool00`3oool0
0`0000004`0001<0000501<0008000000`1>03`01@000000]nGf0;OUmP2giOH0000000X0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`03
0?ooo`8000001@0C00000`000000CP0l04h0?00304h0?0050000002giOH0]nGf0;OUmP0000002P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0040oooo00030?ooo`030000003oool0
oooo00<0oooo0P00000301<0008000001`1>03`01@000000]nGf0;OUmP2giOH0000000P0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`04
0?ooo`@000002@1>03`01@000000]nGf0;OUmP2giOH0000000P0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`040?ooo`800000301>03`0
0`000000]nGf0;OUmP02000000L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`01
0?ooo`000`3oool00`000000oooo0?ooo`040?ooo`800000301>03`300000080]/GU00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0040oooo00030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`0000002`1>03`2000000<0]/GU00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0040oooo00030?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`0000002@1>03`200000003085=RP000000]/GU00<0]/GU
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0040oooo
00030?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool000001P1>03`2000000@0PDf:
00<000000;K5i@2faND00P2faND00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool0103oool010000000oooo0?oo
o`00000404h0?08000001P21CHX00`000000]/GU0;K5i@020;K5i@030000003oool0oooo0080oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`010?ooo`000`3oool00`000000oooo0?oo
o`040?ooo`060000003oool0oooo0?ooo`000000CP0l0P000009085=RP030000002faND0]/GU0080
]/GU00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo0040oooo00030?ooo`03
0000003oool0oooo00@0oooo00@000000?ooo`3oool0oooo0P00000;085=RP030000002faND0]/GU
00<000000`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0040oooo00030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000PDf:085=RP0:085=RP80
00000`2XU/@010000000oooo0?ooo`0000070?ooo`030000003oool0oooo0040oooo00030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000PDf:085=RP0:085=RP03
0000002XU/@0Z9K40080Z9K400@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`010?oo
o`000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<00000085=RP21
CHX02P21CHX00`000000Z9K40:RFa0020:RFa0030000003oool0000000L0oooo00<000000?ooo`3o
ool00@3oool000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000
0021CHX0PDf:00P0PDf:0`0000040:RFa0030000003oool0000000L0oooo00<000000?ooo`3oool0
0@3oool000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`0300000021
CHX0PDf:00D0PDf:0P0000030:BGb0030000002XU/@0Z9K40080Z9K40P0000070?ooo`030000003o
ool0oooo0040oooo00030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000PDf:085=RP04085=RP030000002TUlP0Y9O800<0Y9O800<000000:RFa02XU/@00P2XU/@2
000000L0oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`050?ooo`0400000021CHX0PDf:085=RP8000001`2TUlP010000000Z9K40:RFa02X
U/@2000000L0oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`050?ooo`0400000021CHX00000000000T0Y9O800@000000:RFa00000000000
0P2=GI@00`000000oooo0?ooo`040?ooo`030000003oool0oooo0040oooo00030?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000Y9O80:BGb00:0:BGb0030000002=
GI@0SEfD0080SEfD00<000000?ooo`3oool0103oool00`000000oooo0?ooo`010?ooo`000`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000:BGb02TUlP02P2TUlP0
0`000000SEfD08eMU00308eMU0030000003oool0oooo00<0oooo00<000000?ooo`3oool00@3oool0
00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000002TUlP0Y9O8
00X0Y9O800<0000008eMU02=GI@00P2=GI@00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0040oooo00030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000
Y9O80:BGb00:0:BGb0030000002=GI@0SEfD0080SEfD00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo
00<000000:BGb02TUlP02@2TUlP2000000<0SEfD00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<0
00000:BGb02TUlP01`2TUlP200000080/lk^00@0000008eMU02=GI@000001@3oool00`000000oooo
0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<0
00000:BGb02TUlP0102TUlP2000000@0/lk^00@0000008eMU000000000001@3oool00`000000oooo
0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<0
00000:BGb02TUlP00P2TUlP2000000L0/lk^00<0000006LLF@0000001@3oool00`000000oooo0?oo
o`010?ooo`000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo00@00000
0:BGb000000000002@2cc^h00`000000IaaI000000050?ooo`030000003oool0oooo0040oooo0003
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02P3oool2000000D0/lk^00<00000
0;?>kP2cc^h0102cc^h2000000D0oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0;0?ooo`030000002cc^h0/lk^00<0/lk^00<000000;?>
kP2cc^h01@2cc^h00`000000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo00030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool02`3oool00`000000/lk^0;?>kP030;?>kP03
0000002cc^h0/lk^00D0/lk^00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`010?ooo`00
0`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo00<000000;?>kP2cc^h0
0P2cc^h00`000000/lk^0;?>kP050;?>kP800000103oool00`000000oooo0?ooo`010?ooo`000`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo00<000000;?>kP2cc^h00P2c
c^h00`000000/lk^0;?>kP030;?>kP8000000P2]kOP01@000000oooo0?ooo`3oool0000000<0oooo
00030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03@3oool01@000000/lk^0;?>
kP2cc^h0000000<0/lk^0P0000040:g]n0050000003oool0oooo0?ooo`0000000`3oool000<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000002cc^h000000080/lk^
0P0000070:g]n0040000003oool0oooo000000<0oooo00030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool03P3oool00`000000/lk^00000002000000T0[Ngh00@000000?ooo`3oool0
00000`3oool000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`<00000
2`2]kOP010000000oooo0?ooo`0000030?ooo`000`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`0000002`2]kOP010000000oooo0?ooo`0000030?ooo`00
103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<000000?ooo`000000
2P2]kOP2000000030?ooo`000000oooo00<0oooo00040?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool03P3oool010000000oooo0000000000070:g]n080000000@0T_3U0000003oool0
0000103oool000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`050000
003oool000000?ooo`000000102]kOP200000080T_3U00@000000?ooo`3oool00000103oool000@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`050000003oool000000?oo
o`0000000P2]kOP2000000@0T_3U00@000000?ooo`3oool00000103oool000@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool000000080oooo0P00000609;`
i@040000003oool0oooo000000@0oooo00040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool03P3oool00`000000oooo000000030?ooo`030000002Bl>D0T_3U00<0T_3U0P0000020?oo
o`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo000000040?ooo`030000002Bl>D0T_3U0080000000D0ImRi0000003o
ool0oooo000000040?ooo`00103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`0000001@3oool200000080ImRi00D000000?ooo`3oool0oooo000000040?oo
o`00103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3o
ool000001P3oool3000000@0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000000H0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0080oooo00040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo000000070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0P3oool000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0000000L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`00103oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo00<000000?ooo`0000001`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool03@3oool00`000000oooo000000070?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`0000001`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo
00040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0000
00070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool000@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0000000L0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo000000070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00P3oool000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0000000L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`00103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo00<000000?ooo`0000001`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool03@3oool00`000000oooo000000070?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080
oooo00040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool2000000P0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00d0oooo0P0000070?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<
0?ooo`8000001`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0303oool2000000L0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00`0oooo0P0000070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool00P3oool000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0000000L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`00103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo00<000000?ooo`0000001`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool02`3oool00`000000oooo000000070?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080
oooo00040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02`3oool00`000000oooo
000000070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool000@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`030000003oool0000000L0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool02`3oool00`000000oooo000000070?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool00P3oool000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0000000L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`00
103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo00<000000?ooo`000000
1`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool02`3oool2000000P0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00/0oooo0P0000080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool0
00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`800000203oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool02`3oool2000000P0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo
0P0000080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool000D0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0;0?ooo`800000203oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool02`3oool2000000P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`03
0?ooo`001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo0P0000080?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0;0?ooo`800000203oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
2`3oool2000000P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`001@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo0P0000080?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0000000P0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`000000203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00<0oooo00050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000
oooo000000080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool000D0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0000000P0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`000000203oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo000000080?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00`3oool000D0oooo00<000000?ooo`3oool00`3ooolI000000H0oooo00<000000?oo
o`3oool00`3oool000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000000:06T00080
00001`1Y00000`000000oooo000000060?ooo`030000003oool0oooo00<0oooo00050?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`0000002P1Y0002000000L0J@0000<000000?ooo`000000
1P3oool00`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0000000X0J@000P00000706T000030000003oool0000000H0oooo00<000000?ooo`3oool00`3o
ool000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000000:06T0008000001`1Y0000
0`000000oooo000000060?ooo`030000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`0000002P1Y0002000000L0J@0000@000000?ooo`3oool000001@3oool0
0`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000000/0J@0000<0000006T0001Y00001@1Y000010000000oooo0?ooo`0000050?ooo`030000003o
ool0oooo00<0oooo00050?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000301Y0000
0`000000J@0006T0000606T000030000003oool0000000D0oooo00<000000?ooo`3oool00`3oool0
00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000<06T000030000001Y0000J@00
00H0J@0000<000000?ooo`0000001@3oool00`000000oooo0?ooo`030?ooo`001@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0000000`0J@0000<0000006T0001Y00001P1Y00000`000000
oooo000000050?ooo`030000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo0080oooo
00<000000?ooo`000000301Y00000`000000J@0006T0000606T000030000003oool0000000D0oooo
00<000000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000
000<06T000030000001Y0000J@0000H0J@0000<000000?ooo`0000001@3oool00`000000oooo0?oo
o`030?ooo`001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000`0J@0000<00000
06T0001Y00001P1Y00000`000000oooo000000050?ooo`030000003oool0oooo00<0oooo00050?oo
o`030000003oool0oooo0080oooo00<000000?ooo`0000005P0000000`3oool000000?ooo`040?oo
o`030000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo0080oooo00<000000?ooo`00
0000302`/]X00`000000/;;J0;2bfP060;2bfP030000003oool0000000D0oooo00<000000?ooo`3o
ool00`3oool000D0oooo00<000000?ooo`3oool00P3ooolJ000000030?ooo`000000oooo00<0oooo
00<000000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3oool00P3oool2000000`0J@0000<0
000006T0001Y0000201Y00000`000000oooo000000040?ooo`030000003oool0oooo00<0oooo0005
0?ooo`030000003oool0oooo0080oooo0P00000<06T000030000001Y0000J@0000P0J@0000<00000
0?ooo`000000103oool00`000000oooo0?ooo`030?ooo`001@3oool01`000000oooo0?ooo`3oool0
00000?ooo`000000301Y00000`000000J@0006T0000806T000030000003oool0000000@0oooo00<0
00000?ooo`3oool00`3oool000D0oooo00L000000?ooo`3oool0oooo0000003oool0000000`0J@00
00<0000006T0001Y0000201Y00000`000000oooo000000040?ooo`030000003oool0oooo00<0oooo
00050?ooo`070000003oool0oooo0?ooo`000000oooo0000000<06T000030000001Y0000J@0000P0
J@0000<000000?ooo`000000103oool00`000000oooo0?ooo`030?ooo`001@3oool01`000000oooo
0?ooo`3oool000000?ooo`000000301Y00000`000000J@0006T0000806T000030000003oool00000
00@0oooo00<000000?ooo`3oool00`3oool000D0oooo00L000000?ooo`3oool0oooo0000003oool0
000000`0J@0000<0000006T0001Y0000201Y00000`000000oooo000000040?ooo`030000003oool0
oooo00<0oooo00050?ooo`040000003oool0oooo0?ooo`8000003@1Y00000`000000J@0006T00008
06T000030000003oool0000000@0oooo00<000000?ooo`3oool00`3oool000D0oooo00@000000?oo
o`3oool0oooo0P00000=06T000030000001Y0000J@0000T0J@000P0000040?ooo`030000003oool0
oooo00<0oooo00050?ooo`040000003oool0oooo0?ooo`8000006@1Y00000`000000oooo00000003
0?ooo`030000003oool0oooo00<0oooo00050?ooo`040000003oool0oooo0?ooo`8000006@1Y0000
0`000000oooo000000030?ooo`030000003oool0oooo00<0oooo00050?ooo`040000003oool0oooo
0?ooo`8000006@1Y00000`000000oooo000000030?ooo`030000003oool0oooo00<0oooo00050?oo
o`040000003oool0oooo0?ooo`8000006@1Y00000`000000oooo000000030?ooo`030000003oool0
oooo00<0oooo00050?ooo`060000003oool0oooo0000003oool000006@1Y00000`000000oooo0000
00030?ooo`030000003oool0oooo00<0oooo00050?ooo`060000003oool0oooo0000003oool00000
6@1Y00000`000000oooo000000030?ooo`030000003oool0oooo00<0oooo00050?ooo`050000003o
ool0oooo0000003oool06`0000000`3oool000000?ooo`020?ooo`030000003oool0oooo00<0oooo
00050?ooo`060000003oool0oooo0000003oool000006@2^]Mh00`000000oooo000000030?ooo`03
0000003oool0oooo00<0oooo00050?ooo`060000003oool0oooo0000003oool000006@2^]Mh00`00
0000oooo000000030?ooo`030000003oool0oooo00<0oooo00050?ooo`060000003oool0oooo0000
003oool000006@2^]Mh010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo0006
0?ooo`050000003oool000000?ooo`0000006@2^]Mh01P000000oooo0?ooo`000000oooo000000H0
oooo00060?ooo`050000003oool000000?ooo`0000006@2^]Mh01P000000oooo0?ooo`000000oooo
000000H0oooo00060?ooo`050000003oool000000?ooo`0000006@2^]Mh01P000000oooo0?ooo`00
0000oooo000000H0oooo00060?ooo`050000003oool000000?ooo`0000006@2^]Mh01P000000oooo
0?ooo`000000oooo000000H0oooo00060?ooo`050000003oool000000?ooo`0000006@2^]Mh01P00
0000oooo0?ooo`000000oooo000000H0oooo00060?ooo`050000003oool000000?ooo`0000006@2^
]Mh01P000000oooo0?ooo`000000oooo000000H0oooo00060?ooo`8000000P3oool00`000000[[GN
0:jegP0G0:jegP060000003oool0oooo0000003oool000001P3oool000H0oooo0P0000020?oooa/0
00000P3oool00`000000oooo000000060?ooo`001P3oool2000001l0oooo00<000000?ooo`000000
1P3oool000H0oooo0P00000P0?ooo`8000001P3oool000H0oooo0P00000P0?ooo`8000001P3oool0
00H0oooo0P00000P0?ooo`8000001P3oool000H0oooo0P00000P0?ooo`8000001P3oool000H0oooo
0P00000P0?ooo`8000001P3oool000H0oooo0P00000P0?ooo`8000001P3oool000H0oooo0P00000P
0?ooo`8000001P3oool000H0oooo0P00000P0?ooo`8000001P3oool000H0oooo0P00000P0?ooo`80
00001P3oool000H0oooo00<000000?ooo`3oool07`3oool2000000H0oooo00060?ooo`030000003o
ool0oooo0200oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
00@0oooo00060?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0103oool000H0oooo
900000060?ooo`00<03oool00300oooo0000\
\>"],
  ImageRangeCache->{{{0, 47}, {286.75, 0}} -> {0.420014, -0.00850194, \
0.00340363, 0.00340363}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#4", "Text"],

Cell[CellGroupData[{

Cell["Hz2[[-4]]", "Input"],

Cell[BoxData[
    \(1.7374645454176607`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pretty[Chop[e2ni . eigenvectors2[\([\(-4\)]\)], 10^\(-4\)]]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
          {"\<\"optic\"\>", "0", "0", "0", "1.`", "0", "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Status["\<Plotting stage 2 mode 4\>"]\ ; 
    eigenplot[eigenvectors2[\([\(-4\)]\)],  .5, {0, \(-3\), \(- .25\)}, \ 
      floatmatrix2]\ ; Done[]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 7.06045 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-3.10065 7.20129 -0.140839 7.20129 [
[ 0 0 0 0 ]
[ 1 7.06045 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
.0146 7.06045 L
s
.0146 7.06045 m
.07649 6.39036 L
s
.07649 6.39036 m
.06541 .2361 L
s
.06541 .2361 m
0 0 L
s
1 0 m
.93459 .2361 L
s
.93459 .2361 m
.92351 6.39036 L
s
.92351 6.39036 m
.9854 7.06045 L
s
.9854 7.06045 m
1 0 L
s
0 0 m
.0146 7.06045 L
s
.0146 7.06045 m
.9854 7.06045 L
s
.9854 7.06045 m
1 0 L
s
1 0 m
0 0 L
s
.06541 .2361 m
.93459 .2361 L
s
.93459 .2361 m
.92351 6.39036 L
s
.92351 6.39036 m
.07649 6.39036 L
s
.07649 6.39036 m
.06541 .2361 L
s
0 0 m
1 0 L
1 7.06045 L
0 7.06045 L
closepath
clip
newpath
.5 Mabswid
.707 .593 .726 r
.5 6.52002 m .8429 6.52002 L p .1566 6.1822 L F P
0 g
s
.707 .593 .726 r
.8429 6.52002 m .8434 6.1822 L .1566 6.1822 L p F P
0 g
s
.707 .593 .726 r
.1566 6.1822 m .1571 6.52002 L .5 6.52002 L p F P
0 g
s
.745 .608 .039 r
.15109 6.60256 m .1571 6.52002 L p .14435 6.33843 L F P
0 g
s
.745 .608 .039 r
.1571 6.52002 m .1566 6.1822 L .14435 6.33843 L p F P
0 g
s
0 0 .039 r
.8434 6.1822 m .8429 6.52002 L .84891 6.60256 L p F P
0 g
s
0 0 .039 r
.85565 6.33843 m .8434 6.1822 L p .84891 6.60256 L F P
0 g
s
.405 0 0 r
.8434 6.1822 m .85565 6.33843 L .14435 6.33843 L p F P
0 g
s
.405 0 0 r
.14435 6.33843 m .1566 6.1822 L .8434 6.1822 L p F P
0 g
s
.15256 3.93932 m
.454 6.24998 L
s
.46554 6.33843 m
.5 6.60256 L
s
.816 .649 .675 r
.05609 3.53518 m .05599 3.58493 L p .25046 3.3286 L F P
0 g
s
.07729 3.36239 m
.09451 3.49435 L
s
.816 .649 .675 r
.05599 3.58493 m .26883 3.57467 L .25046 3.3286 L p F P
0 g
s
.10601 3.58252 m
.15256 3.93932 L
s
.816 .649 .675 r
.25046 3.3286 m .05652 3.33664 L .05609 3.53518 L p F P
0 g
s
.816 .715 .753 r
.05652 3.33664 m .25046 3.3286 L .26836 3.08722 L p F P
0 g
s
.804 .572 .586 r
.05948 3.81807 m .32193 3.80376 L .26883 3.57467 L p F P
0 g
s
.804 .572 .586 r
.26883 3.57467 m .05599 3.58493 L .05379 3.79302 L p F P
0 g
s
.804 .572 .586 r
.05379 3.79302 m .05948 3.81807 L p .26883 3.57467 L F P
0 g
s
.816 .715 .753 r
.05617 3.27863 m .05652 3.33664 L p .26836 3.08722 L F P
0 g
s
.816 .715 .753 r
.26836 3.08722 m .05507 3.09467 L .05617 3.27863 L p F P
0 g
s
.803 .778 .829 r
.05507 3.09467 m .26836 3.08722 L .32123 2.87199 L p F P
0 g
s
.745 .608 .039 r
.14435 6.33843 m .14488 6.68805 L .15109 6.60256 L p F P
0 g
s
0 0 .039 r
.84891 6.60256 m .85512 6.68805 L .85565 6.33843 L p F P
0 g
s
.774 .467 .466 r
.14171 4.01101 m .40542 3.99522 L .32193 3.80376 L p F P
0 g
s
.774 .467 .466 r
.32193 3.80376 m .05948 3.81807 L .14171 4.01101 L p F P
0 g
s
.803 .778 .829 r
.05457 3.06184 m .05507 3.09467 L p .32123 2.87199 L F P
0 g
s
.803 .778 .829 r
.32123 2.87199 m .05774 2.87966 L p .05457 3.06184 L F P
0 g
s
.763 .842 .911 r
.05774 2.87966 m .32123 2.87199 L .4049 2.70279 L p F P
0 g
s
.803 .778 .829 r
.05774 2.87966 m .05212 2.90323 L .05457 3.06184 L p F P
0 g
s
.7 .292 .271 r
.24688 4.14774 m .51232 4.13081 L .40542 3.99522 L p F P
0 g
s
.7 .292 .271 r
.40542 3.99522 m .14171 4.01101 L .24688 4.14774 L p F P
0 g
s
.763 .842 .911 r
.4049 2.70279 m .13975 2.70931 L .05774 2.87966 L p F P
0 g
s
.643 .89 .985 r
.13975 2.70931 m .4049 2.70279 L .5124 2.59648 L p F P
0 g
s
.01 w
.35003 2.55072 Mdot
.64997 2.55072 Mdot
.5 Mabswid
.481 0 0 r
.36578 4.21387 m .63324 4.19627 L .51232 4.13081 L p F P
0 g
s
.481 0 0 r
.51232 4.13081 m .24688 4.14774 L .36578 4.21387 L p F P
0 g
s
.707 .593 .726 r
.5 6.68805 m .14488 6.68805 L .14435 6.33843 L p F P
0 g
s
.707 .593 .726 r
.85565 6.33843 m .85512 6.68805 L .5 6.68805 L p F P
0 g
s
.707 .593 .726 r
.14435 6.33843 m .85565 6.33843 L p .5 6.68805 L F P
0 g
s
.643 .89 .985 r
.5124 2.59648 m .24524 2.60228 L .13975 2.70931 L p F P
0 g
s
.253 .758 .878 r
.24524 2.60228 m .5124 2.59648 L .63416 2.56514 L p F P
0 g
s
.707 .593 .726 r
.5 6.71723 m .85725 6.71723 L p .14222 6.36556 L F P
0 g
s
.707 .593 .726 r
.85725 6.71723 m .85778 6.36556 L .14222 6.36556 L p F P
0 g
s
.707 .593 .726 r
.14222 6.36556 m .14275 6.71723 L .5 6.71723 L p F P
0 g
s
.745 .608 .039 r
.13623 6.80689 m .14275 6.71723 L p .1289 6.5354 L F P
0 g
s
.745 .608 .039 r
.14275 6.71723 m .14222 6.36556 L .1289 6.5354 L p F P
0 g
s
0 0 .039 r
.85778 6.36556 m .85725 6.71723 L .86377 6.80689 L p F P
0 g
s
0 0 .039 r
.8711 6.5354 m .85778 6.36556 L p .86377 6.80689 L F P
0 g
s
.405 0 0 r
.85778 6.36556 m .8711 6.5354 L .1289 6.5354 L p F P
0 g
s
.405 0 0 r
.1289 6.5354 m .14222 6.36556 L .85778 6.36556 L p F P
0 g
s
.09 .649 .741 r
.48731 4.20071 m .75693 4.18301 L .63324 4.19627 L p F P
0 g
s
.09 .649 .741 r
.63324 4.19627 m .36578 4.21387 L .48731 4.20071 L p F P
0 g
s
.253 .758 .878 r
.63416 2.56514 m .36485 2.57077 L .24524 2.60228 L p F P
0 g
s
.383 0 0 r
.36485 2.57077 m .63416 2.56514 L .75862 2.61437 L p F P
0 g
s
.596 .902 .985 r
.59941 4.10691 m .87107 4.08972 L .75693 4.18301 L p F P
0 g
s
.596 .902 .985 r
.75693 4.18301 m .48731 4.20071 L .59941 4.10691 L p F P
0 g
s
.745 .608 .039 r
.1289 6.5354 m .12947 6.89989 L .13623 6.80689 L p F P
0 g
s
0 0 .039 r
.86377 6.80689 m .87053 6.89989 L .8711 6.5354 L p F P
0 g
s
.54816 6.45872 m
.86554 4.16414 L
s
.5 6.80689 m
.53755 6.5354 L
s
.383 0 0 r
.75862 2.61437 m .48723 2.62043 L .36485 2.57077 L p F P
0 g
s
.682 .24 .195 r
.48723 2.62043 m .75862 2.61437 L .87318 2.74176 L p F P
0 g
s
.76 .867 .927 r
.69018 3.93962 m .9636 3.92353 L .87107 4.08972 L p F P
0 g
s
.76 .867 .927 r
.87107 4.08972 m .59941 4.10691 L .69018 3.93962 L p F P
0 g
s
.86554 4.16414 m
.87403 4.1027 L
s
.682 .24 .195 r
.87318 2.74176 m .59997 2.74885 L .48723 2.62043 L p F P
0 g
s
.777 .45 .434 r
.59997 2.74885 m .87318 2.74176 L .96552 2.9362 L p F P
0 g
s
.81 .796 .839 r
.97011 3.8995 m .9636 3.92353 L p .74944 3.7146 L F P
0 g
s
.81 .796 .839 r
.9636 3.92353 m .69018 3.93962 L .74944 3.7146 L p F P
0 g
s
.81 .796 .839 r
.74944 3.7146 m .97341 3.70279 L .97011 3.8995 L p F P
0 g
s
.87403 4.1027 m
.92547 3.73082 L
s
.707 .594 .727 r
.5 6.89989 m .12947 6.89989 L .1289 6.5354 L p F P
0 g
s
.707 .594 .727 r
.8711 6.5354 m .87053 6.89989 L .5 6.89989 L p F P
0 g
s
.707 .594 .727 r
.1289 6.5354 m .8711 6.5354 L p .5 6.89989 L F P
0 g
s
.01 w
.34294 2.58599 Mdot
.65706 2.58599 Mdot
.5 Mabswid
.777 .45 .434 r
.96552 2.9362 m .69097 2.94483 L .59997 2.74885 L p F P
0 g
s
.812 .57 .572 r
.96552 2.9362 m .97196 2.96229 L .97402 3.14251 L p F P
0 g
s
.812 .57 .572 r
.69097 2.94483 m .96552 2.9362 L p .97402 3.14251 L F P
0 g
s
.825 .727 .756 r
.97374 3.65147 m .97341 3.70279 L p .77025 3.45504 L F P
0 g
s
.825 .727 .756 r
.97341 3.70279 m .74944 3.7146 L .77025 3.45504 L p F P
0 g
s
.825 .727 .756 r
.77025 3.45504 m .97505 3.44571 L .97374 3.65147 L p F P
0 g
s
.92547 3.73082 m
.95829 3.49352 L
s
.812 .57 .572 r
.97402 3.14251 m .97445 3.18026 L p .69097 2.94483 L F P
0 g
s
.812 .57 .572 r
.97445 3.18026 m .74999 3.18884 L .69097 2.94483 L p F P
0 g
s
.825 .655 .671 r
.74999 3.18884 m .97445 3.18026 L .97491 3.38185 L p F P
0 g
s
.825 .655 .671 r
.97491 3.38185 m .97505 3.44571 L p .74999 3.18884 L F P
0 g
s
.825 .655 .671 r
.97505 3.44571 m .77025 3.45504 L .74999 3.18884 L p F P
0 g
s
.25 Mabswid
0 0 m
.0146 7.06045 L
s
.0146 7.06045 m
.9854 7.06045 L
s
.9854 7.06045 m
1 0 L
s
1 0 m
0 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{40.75, 287.688},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40000X00017b000`400?l00000o`00003o:03oool0
02P0oooo000X0?ooo`00:000000000030000003oool0oooo02@0oooo0@00000000030000003oool0
oooo02@0oooo0@00000000800000903oool2000000000P00000T0?ooo`8000000002000002@0oooo
0P00000000800000903oool20000000000<000000?ooo`0000008P3oool100000040oooo0@000000
00030000003oool000000280oooo0@0000010?ooo`40000000000`000000oooo0000000S00000040
oooo0@00000000030000003oool000000280oooo0@0000010?ooo`40000000000`000000oooo0000
000R0?ooo`4000000@3oool10000000000<000000?ooo`0000008P3oool100000040oooo0@000000
00030000003oool000000280oooo0@0000010?ooo`40000000000`000000oooo0000000R0?ooo`40
00000@3oool10000000000<000000?ooo`0000008P3oool100000040oooo0@00000000030000003o
ool000000280oooo0@0000010?ooo`40000000000`000000oooo0000000R0?ooo`4000000@3oool1
0000000000<000000?ooo`0000008P3oool100000040oooo0@00000000030000003oool000000280
oooo0@0000010?ooo`40000000000`000000oooo0000000R0?ooo`4000000@3oool10000000000<0
00000?ooo`0000008P3oool100000040oooo0@00000000030000003oool000000280oooo0@000001
0?ooo`40000000000`000000oooo0000000R0?ooo`4000000@3oool10000000000<000000?ooo`00
00008P3oool100000040oooo0@00000000030000003oool000000280oooo0@0000010?ooo`400000
00000`000000oooo0000000R0?ooo`4000000@3oool10000000000<000000?ooo`0000008P3oool1
00000040oooo0@00000000030000003oool000000280oooo0@0000010?ooo`40000000000`000000
oooo0000000R0?ooo`4000000@3oool10000000000<000000?ooo`0000008P3oool100000040oooo
0@00000000030000003oool000000280oooo0@0000010?ooo`40000000000`000000oooo0000000R
0?ooo`4000000@3oool10000000000<000000?ooo`0000008P3oool100000040oooo0@0000000003
0000003oool000000280oooo0@0000010?ooo`40000000000`000000oooo0000000R0?ooo`400000
0@3oool10000000000<000000?ooo`0000008P3oool100000040oooo0@00000000030000003oool0
00000280oooo0@0000010?ooo`40000000000`000000oooo0000000R0?ooo`4000000@3oool10000
000000<000000?ooo`0000008P3oool100000040oooo0@00000000030000003oool000000280oooo
0@0000010?ooo`40000000000`000000oooo0000000R0?ooo`4000000@3oool10000000000<00000
0?ooo`0000008P3oool100000040oooo0@00000000030000003oool000000280oooo0@0000010?oo
o`40000000000`000000oooo0000000R0?ooo`4000000@3oool10000000000<000000?ooo`000000
8P3oool100000040oooo0@00000000030000003oool000000280oooo0@0000010?ooo`4000000000
0`000000oooo0000000R0?ooo`4000000@3oool10000000000<000000?ooo`0000008P3oool10000
0040oooo0@00000000030000003oool000000280oooo0@0000010?ooo`40000000000`000000oooo
0000000R0?ooo`4000000@3oool10000000000<000000?ooo`0000008P3oool100000040oooo0@00
000000030000003oool000000280oooo0@0000010?ooo`40000000000`000000oooo0000000R0?oo
o`4000000@3oool10000000000<000000?ooo`0000008P3oool100000040oooo0@00000000030000
003oool000000280oooo0@0000010?ooo`40000000000`000000oooo0000000R0?ooo`4000000@3o
ool10000000000<000000?ooo`0000008P3oool100000040oooo0@00000000030000003oool00000
0280oooo0@0000010?ooo`40000000000`000000oooo0000000R0?ooo`4000000@3oool100000000
00<000000?ooo`0000008P3oool100000040oooo0@00000000030000003oool000000280oooo0@00
00010?ooo`40000000000`000000oooo0000000R0?ooo`4000000@3oool10000000000<000000?oo
o`0000008P3oool100000040oooo0@00000000030000003oool000000280oooo0@0000010?ooo`40
000000000`000000oooo0000000R0?ooo`4000000@3oool10000000000<000000?ooo`0000008P3o
ool100000040oooo0@00000000030000003oool000000280oooo0@0000010?ooo`40000000000`00
0000oooo0000000R0?ooo`4000000@3oool10000000000<000000?ooo`0000008P3oool100000040
oooo0@00000000030000003oool000000280oooo0@0000010?ooo`40000000000`000000oooo0000
000R0?ooo`4000000@3oool10000000000<000000?ooo`0000008P3oool100000040oooo0@000000
00030000003oool000000280oooo0@0000010?ooo`40000000000`000000oooo0000000R0?ooo`40
00000@3oool10000000000<000000?ooo`0000008P3oool100000040oooo0@00000000030000003o
ool000000280oooo0@0000010?ooo`40000000000`000000oooo0000000R0?ooo`4000000@3oool1
0000000000<000000?ooo`0000008P3oool100000040oooo0@00000000030000003oool000000280
oooo0@0000010?ooo`40000000000`000000oooo0000000R0?ooo`4000000@3oool10000000000<0
00000?ooo`0000008P3oool100000040oooo0@00000000030000003oool000000280oooo0@000001
0?ooo`40000000000`000000oooo0000000R0?ooo`4000000@3oool10000000000<000000?ooo`00
00008P3oool100000040oooo0@00000000030000003oool000000280oooo0@0000010?ooo`400000
00000`000000oooo0000000R0?ooo`4000000@3oool10000000000<000000?ooo`0000008P3oool1
00000040oooo0@00000000030000003oool000000280oooo0@0000010?ooo`40000000000`000000
oooo0000000R0?ooo`4000000@3oool10000000000<000000?ooo`0000008P3oool100000040oooo
0@00000000030000003oool000000280oooo0@0000010?ooo`40000000000`000000oooo0000000R
0?ooo`4000000@3oool10000000000<000000?ooo`0000008P3oool100000040oooo0@0000000003
0000003oool000000280oooo0@0000010?ooo`40000000000`000000oooo0000000R0?ooo`400000
0@3oool10000000000<000000?ooo`0000008P3oool100000040oooo0@00000000030000003oool0
00000280oooo0@0000010?ooo`40000000000`000000oooo0000000R0?ooo`4000000@3oool10000
000000<000000?ooo`0000008P3oool100000040oooo0@00000000030000003oool000000280oooo
0@0000010?ooo`40000000000`000000oooo0000000;0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0203oool100000040oooo0@00000000030000003oool0000000T0oooo3`00000:
0?ooo`4000000@3oool10000000000<000000?ooo`0000001P3oool9000000T0HP000P0000080?oo
o`4000000@3oool10000000000<000000?ooo`0000001@3oool00`000000Y>?l0:CSo0070:CSo0d0
00001P3oool100000040oooo0@00000000030000003oool0000000@0oooo00<000000:CSo02Tho`0
202Tho`00`000000oooo0000000:0:hm<@030000003oool0oooo00<0oooo0@0000010?ooo`400000
00000`000000oooo000000040?ooo`030000002Tho`0Y>?l00L0Y>?l00D000000?ooo`3oool0oooo
0000000:0:hm<@030000003oool0oooo0080oooo0@0000010?ooo`40000000000`000000oooo0000
00030?ooo`030000002Tho`0Y>?l0080Y>?l1P0000040?ooo`030000002^?C40[Sda00P0[Sda00<0
00000?ooo`3oool00P3oool100000040oooo0@00000000030000003oool000000080oooo1P000004
0<?Gj@030000003oool0oooo00@0oooo00<000000:hm<@2^?C40202^?C401P000000oooo0?ooo`3o
ool000000?ooo`40000000001@000000oooo0000003oool0000000X0`mOY00<000000?ooo`3oool0
1@3oool<00000080oooo0@0000010?ooo`40000000001@000000oooo0000003oool0000000T0`mOY
00<000000?ooo`3oool01P3oool00`000000aW=_0<IcK`080<IcK`050000003oool0oooo0000003o
ool00@00000000040000003oool00000000000X0`mOY00<000000?ooo`3oool01`3oool00`000000
aW=_0<IcK`080<IcK`040000003oool000000?ooo`400000000010000000oooo0000000000090<?G
j@030000003oool0oooo00P0oooo00<000000<IcK`36Lfl02036Lfl010000000oooo0000003oool1
0000000000<000000?ooo`0000002P33enT00`000000oooo0?ooo`090?ooo`0300000036Lfl0aW=_
00P0aW=_0P0000010?ooo`40000000000`000000oooo0000000:000000`0oooo00<000000<IcK`36
Lfl02036Lfl200000040oooo0@00000000030000003oool0000000T0cLOD00<000000?ooo`3oool0
2`3oool00`000000aW=_0<IcK`080<IcK`4000000@3oool10000000000<000000?ooo`0000002@3=
am@00`000000oooo0?ooo`0;0?ooo`0300000036Lfl0aW=_00P0aW=_0@0000010?ooo`4000000000
0`000000oooo000000080<g7e0030000003oool0oooo00d0oooo3@00000000030000003oool00000
00P0cLOD00<000000?ooo`3oool03@3oool00`000000ci6B0<nATP080<nATP80000000000`000000
oooo000000080<g7e0030000003oool0oooo00d0oooo00<000000<nATP3?TI80203?TI8200000000
00<000000?ooo`000000203=am@00`000000oooo0?ooo`0>0?ooo`030000003?TI80ci6B00L0ci6B
0P00000000030000003oool0000000L0cLOD00<000000?ooo`3oool03`3oool00`000000ci6B0<nA
TP070<nATP80000000000`000000oooo000000070<g7e0030000003oool0oooo00l0oooo00<00000
0<nATP3?TI801`3?TI820000000000<000000?ooo`0000002000000A0?ooo`030000003?TI80ci6B
00L0ci6B0P00000000030000003oool0000000L0d;O000<000000?ooo`3oool03`3oool00`000000
ci6B0<nATP070<nATP80000000000`000000oooo000000070=2g`0030000003oool0oooo0100oooo
00<000000<nATP3?TI801P3?TI820000000000<000000?ooo`0000001`3@]l000`000000oooo0?oo
o`0@0?ooo`030000003?TI80ci6B0080ci6B1P00000000030000003oool0000000L0d;O000<00000
0?ooo`3oool0403oool5000000@0djN[0P00000000030000003oool0000000H0d;O000<000000?oo
o`3oool04@3oool00`000000djN[0=>WZ`060=>WZ`80000000000`000000oooo000000060=2g`003
0000003oool0oooo0140oooo00<000000=>WZ`3CYj/01P3CYj/20000000000<000000?ooo`000000
1P3@]l000`000000oooo0?ooo`0A0?ooo`030000003CYj/0djN[00H0djN[0P00000000030000003o
ool0000000H0d;O000<000000?ooo`3oool04@3oool00`000000djN[0=>WZ`060=>WZ`8000000000
0`000000oooo00000007000001<0oooo00<000000=>WZ`3CYj/01P3CYj/20000000000<000000?oo
o`0000001P3@YZ`00`000000oooo0?ooo`0B0?ooo`030000003CYj/0djN[00D0djN[0P0000000003
0000003oool0000000H0d:J/00<000000?ooo`3oool04P3oool00`000000djN[0=>WZ`050=>WZ`80
000000000`000000oooo000000060=2V[0030000003oool0oooo0180oooo00<000000=>WZ`3CYj/0
1@3CYj/20000000000<000000?ooo`0000001P3@YZ`00`000000oooo0?ooo`0B0?ooo`030000003C
Yj/0djN[00D0djN[0P00000000030000003oool0000000H0d:J/00<000000?ooo`3oool04P3oool:
0000000000<000000?ooo`0000001`3@YZ`00`000000oooo0?ooo`0A0?ooo`030000003C^/40dk[1
00D0dk[10P00000000040000003oool00000000000H0d:J/00<000000?ooo`3oool04@3oool00`00
0000dk[10=>j`@050=>j`@80000000000`000000oooo000000070=2V[0030000003oool0oooo0140
oooo00<000000=>j`@3C^/401@3C^/420000000000<000000?ooo`0000001`3@YZ`00`000000oooo
0?ooo`0A0?ooo`030000003C^/40dk[100D0dk[10P00000000030000003oool0000000P000004P3o
ool00`000000dk[10=>j`@050=>j`@<0000000000`000000oooo000000070<fBUP030000003oool0
oooo0100oooo00<000000=>j`@3C^/401@3C^/430000000000<000000?ooo`0000001`3=TYH00`00
0000oooo0?ooo`0@0?ooo`030000003C^/40dk[100D0dk[10`00000000030000003oool0000000P0
cI:F00<000000?ooo`3oool03`3oool00`000000dk[10=>j`@050=>j`@<0000000000`000000oooo
000000080<fBUP030000003oool0oooo00l0oooo00<000000=>j`@3C^/40103C^/400`000000dk[1
000000010000000000<000000?ooo`000000203=TYH00`000000oooo0?ooo`0?0?ooo`/000000000
0`000000oooo000000080<fBUP030000003oool0oooo00l0oooo00<000000<o;eP3?bmH0103?bmH0
0`000000cl_F000000010000000000<000000?ooo`0000002@3=TYH00`000000oooo0?ooo`0>0?oo
o`030000003?bmH0cl_F00@0cl_F00<000000<o;eP0000000@00000000030000003oool0000000T0
cI:F00<000000?ooo`3oool03@3oool00`000000cl_F0<o;eP050<o;eP030000003?bmH000000040
000000000`000000oooo000000050<fBUPD000003`3oool00`000000cl_F0<o;eP050<o;eP030000
003?bmH000000040000000000`000000oooo00000005000000@0aWMg00<000000?ooo`3oool03@3o
ool00`000000cl_F0<o;eP040<o;eP030000003?bmH0cl_F0080000000000`000000oooo0000000:
0<IgM`030000003oool0oooo00`0oooo00<000000<o;eP3?bmH0103?bmH00`000000cl_F0<o;eP02
0000000000@000000?ooo`3oool000002@36MgL00`000000oooo0?ooo`0;0?ooo`030000003?bmH0
cl_F00D0cl_F00<000000<o;eP3?bmH00P00000000040000003oool0oooo000000X0aWMg00<00000
0?ooo`3oool02P3oool00`000000cl_F0<o;eP050<o;eP030000003?bmH0cl_F0080000000000`00
0000oooo0?ooo`02000000T0aWMg00<000000?ooo`3oool02P3oool=0000000000<000000?ooo`3o
ool00P00000:0<IgM`030000003oool0oooo00P0oooo00<000000<;Mk@32gNd01P32gNd010000000
`]g]0000003oool10000000000H000000?ooo`3oool000000?ooo`0000090<IgM`030000003oool0
oooo00P0oooo00<000000<;Mk@32gNd01P32gNd010000000`]g]0000003oool10000000000D00000
0?ooo`3oool000000?ooo`0<000000P0oooo00<000000<;Mk@32gNd01`32gNd200000080oooo0@00
000000040000003oool0oooo00000080oooo00<000000;=:A@2cBTD0202cBTD00`000000oooo0?oo
o`050?ooo`0300000032gNd0`]g]00H0`]g]0`0000020?ooo`400000000010000000oooo0?ooo`00
00020?ooo`030000002cBTD0/dY500T0/dY500<000000?ooo`3oool00`3oool00`000000`]g]0<;M
k@070<;Mk@<000000P3oool10000000000@000000?ooo`3oool000000`3oool00`000000/dY50;=:
A@080;=:A@030000003oool0oooo00<0oooo00<000000<;Mk@32gNd00P32gNd6000000040?ooo`00
0000oooo0?ooo`400000000010000000oooo0?ooo`0000030?ooo`8000002P2cBTD010000000oooo
0?ooo`3oool6000000@0V>Kl0P000000103oool000000?ooo`3oool10000000000@000000?ooo`3o
ool000000`3oool2000000H0/dY51P0000000`3oool0000009SVo00809SVo0050000003oool00000
0?ooo`0000000P3oool10000000000@000000?ooo`3oool000000`3oool00`000000oooo00000005
000000H0N`0000<0000009SVo02Hi_`01`2Hi_`01P000000oooo0?ooo`000000oooo00000080oooo
0@00000000040000003oool0oooo000000<0oooo00@000000?ooo`3oool0oooo0P00000707/00003
0000002Hi_`0V>Kl0080V>Kl1P0000030?ooo`030000003oool000000080oooo0@00000000040000
003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool?000000H0oooo00<000000?ooo`00
00000P3oool10000000000@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool000000080oooo0@00000000040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool05P3oool010000000oooo0?ooo`0000020?ooo`400000000010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo01H0oooo00@000000?ooo`3oool000000P3oool10000000000@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`0F0?ooo`040000003oool0oooo00000080oooo0@00
000000040000003oool0oooo000000@0oooo00<000000?ooo`3oool05P3oool010000000oooo0?oo
o`0000020?ooo`400000000010000000oooo0?ooo`0000040?ooo`030000003oool0oooo01H0oooo
00@000000?ooo`3oool000000P3oool10000000000@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`0F0?ooo`040000003oool0oooo00000080oooo0@00000000040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool05P3oool010000000oooo0?ooo`0000020?ooo`40000000001000
0000oooo0?ooo`0000050?ooo`030000003oool0oooo01@0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`400000000010000000oooo0?ooo`0000050?ooo`030000003oool0oooo01@0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`400000000010000000oooo0?ooo`0000050?ooo`030000
003oool0oooo01@0oooo00D000000?ooo`3oool0oooo000000020?ooo`400000000010000000oooo
0?ooo`0000050?ooo`030000003oool0oooo01@0oooo00D000000?ooo`3oool0oooo000000020?oo
o`400000000010000000oooo0?ooo`0000050?ooo`030000003oool0oooo01@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`400000000010000000oooo0?ooo`0000050?ooo`030000003oool0
oooo01@0oooo00D000000?ooo`3oool0oooo000000020?ooo`400000000010000000oooo0?ooo`00
00050?ooo`030000003oool0oooo01@0oooo00D000000?ooo`3oool0oooo000000020?ooo`400000
000010000000oooo0?ooo`0000060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`010000000000@000000?ooo`3oool000001P3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@00000000040000003o
ool0oooo000000H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00400000000010000000oooo0?ooo`0000060?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`010000000000@000000?ooo`3oool00000
1P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0@00000000040000003oool0oooo000000H0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00400000000010000000oooo0?ooo`0000060?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`010000000000@0
00000?ooo`3oool000001P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00@00000000040000003oool0oooo000000L0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00400000000010000000oooo0?oo
o`0000070?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`010000000000@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00@00000000040000003oool0oooo000000L0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00400000
000010000000oooo0?ooo`0000070?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`010000000000@000000?ooo`3oool000001`3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00@00000000040000003o
ool0oooo000000L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00400000000010000000oooo0?ooo`0000070?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`010000000000@000000?ooo`3oool00000
203oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0@00000000040000003oool0oooo000000P0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00400000000010000000oooo0?ooo`0000080?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`010000000000@0
00000?ooo`3oool00000203oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00@00000000040000003oool0oooo000000P0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00400000000010000000oooo0?oo
o`0000080?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`010000000000@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00@00000000040000003oool0oooo000000T0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00400000
000010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`010000000000@000000?ooo`3oool000002@3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@00000000040000003o
ool0oooo000000T0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00400000000010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`010000000000@000000?ooo`3oool00000
2@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0@00000000040000003oool0oooo000000T0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00400000000010000000oooo0?ooo`0000090?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`010000000000@0
00000?ooo`3oool000002P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00@00000000040000003oool0oooo000000X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00400000000010000000oooo0?oo
o`00000:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`010000000000@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00@00000000040000003oool0oooo000000X0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00400000
000010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`010000000000@000000?ooo`3oool000002P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00@00000000040000003o
ool0oooo000000X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00400000000010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`010000000000@000000?ooo`3oool00000
2`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
0@00000000040000003oool0oooo000000/0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00400000000010000000oooo0?ooo`00000;0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`010000000000@0
00000?ooo`3oool000002`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool00@00000000040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00400000000010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`010000000000@000000?ooo`3oool00000303oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool00@00000000040000003oool0oooo000000`0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00400000
000010000000oooo0?ooo`00000<0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`010000000000@000000?ooo`3oool00000303oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00@00000000040000003o
ool0oooo000000`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00400000000010000000oooo0?ooo`00000<0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`010000000000@000000?ooo`3oool00000
303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
0@00000000040000003oool0oooo000000`0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00400000000010000000oooo0?ooo`00000=0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`010000000000@0
00000?ooo`3oool000003@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool00@00000000040000003oool0oooo000000d0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00400000000010000000oooo0?oo
o`00000=0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`010000000000@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool00@00000000040000003oool0oooo000000d0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00400000
000010000000oooo0?ooo`00000=0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`010000000000@000000?ooo`3oool000003@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00@00000000040000003o
ool0oooo000000h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00400000000010000000oooo0?ooo`0000020?oooa`000000P3oool00`000000oooo
0?ooo`010000000000@000000?ooo`3oool000000P3oool00`000000I`0006L0000906L000050000
001W0000I`0006L0000000002P1W000010000000oooo0?ooo`0000020?ooo`400000000010000000
oooo0?ooo`0000020?ooo`030000001W0000I`0000T0I`0000D0000006L0001W0000I`000000000:
06L000040000003oool0oooo00000080oooo0@00000000060000003oool0oooo0000003oool00000
401W00000`000000I`0006L0000806L000040000003oool0oooo00000080oooo0@00000000060000
003oool0oooo0000003oool00000401W00000`000000I`0006L0000906L000030000003oool00000
0080oooo0@00000000060000003oool0oooo0000003oool00000401W00000`000000I`0006L00009
06L000030000003oool000000080oooo0@00000000050000003oool0oooo0000003oool07P000000
103oool000000?ooo`3oool10000000000D000000?ooo`3oool000000?ooo`0N000000040?ooo`00
0000oooo0?ooo`40000000000`000000oooo0?ooo`03000000l0I`0000<0000006L0001W00002P1W
000300000080oooo0@00000000060000003oool0oooo0000003oool000003`1W00000`000000I`00
06L0000:06L000030000003oool000000080oooo0@00000000060000003oool0oooo0000003oool0
00003`1W00000`000000I`0006L0000:06L000030000003oool000000080oooo0@00000000060000
003oool0oooo0000003oool000003`1W00000`000000I`0006L0000:06L000030000003oool00000
0080oooo0@00000000060000003oool0oooo0000003oool00000701W00000`000000oooo00000002
0?ooo`40000000000`000000oooo000000020?ooo`030000001W0000I`0001X0I`0000D000000?oo
o`3oool000000?ooo`010000000000<000000?ooo`0000000P3ooolN00000080oooo0@0000010?oo
o`40000000000`000000oooo000000020?ooo`030000002dV;X0]9Rj01X0]9Rj00D000000?ooo`3o
ool000000?ooo`010000000000<000000?ooo`0000000P3oool00`000000]9Rj0;BH^P0J0;BH^P05
0000003oool0oooo0000003oool00@00000000030000003oool000000080oooo00<000000;BH^P2d
V;X06P2dV;X01@000000oooo0?ooo`000000oooo0040000000000`000000oooo000000020?ooo`03
0000002dV;X0]9Rj01X0]9Rj00D000000?ooo`3oool000000?ooo`010000000000<000000?ooo`00
00000P3oool00`000000]9Rj0;BH^P0J0;BH^P050000003oool0oooo0000003oool00@0000000003
0000003oool000000080oooo00<000000;BH^P2dV;X06P2dV;X01@000000oooo0?ooo`000000oooo
004000000002000000<0oooo00<000000;BH^P2dV;X06P2dV;X01@000000oooo0?ooo`000000oooo
004000000002000000<0oooo00<000000;BH^P2dV;X06P2dV;X010000000oooo0?ooo`3oool20000
00000P0000030?ooo`030000002dV;X0]9Rj01X0]9Rj00@000000?ooo`3oool0oooo0P0000000080
00000`3oool00`000000]9Rj0;BH^P0J0;BH^P040000003oool0oooo0?ooo`8000000002000000<0
oooo00<000000;BH^P2dV;X06P2dV;X010000000oooo0?ooo`3oool2000000000P0000030?ooo`03
0000002dV;X0]9Rj01X0]9Rj00@000000?ooo`3oool0oooo0P000000008000000`3oool00`000000
]9Rj0;BH^P0J0;BH^P040000003oool0oooo0?ooo`8000000002000000<0oooo7P0000030?ooo`80
00000002000002@0oooo0P00000000030000003oool0oooo02@0oooo0@00000000030000003oool0
oooo02@0oooo0@00000000030000003oool0oooo02@0oooo0@00000000030000003oool0oooo02@0
oooo0@00000002P00000000X0?ooo`00:03oool002P0oooo0000\
\>"],
  ImageRangeCache->{{{0, 39.75}, {286.688, 0}} -> {0.430568, 0.0090117, \
0.00349347, 0.00349347}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#5", "Text"],

Cell[CellGroupData[{

Cell["Hz2[[-5]]", "Input"],

Cell[BoxData[
    \(8.016261425044293`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pretty[Chop[e2ni . eigenvectors2[\([\(-5\)]\)], 10^\(-4\)]]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
          {"\<\"optic\"\>", "0", "0", "1.`", "0", "0", "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Status["\<Plotting stage 2 mode 5\>"]\ ; 
    eigenplot[
      eigenvectors2[\([\(-5\)]\)], \(- .2\), {0, \(-1\), \(- .25\)}, \ 
      floatmatrix2]\ ; Done[]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 5.99483 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.6256 6.25121 1.28586e-016 6.25121 [
[ 0 0 0 0 ]
[ 1 5.99483 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
.12768 5.99483 L
s
.12768 5.99483 m
.23891 4.75775 L
s
.23891 4.75775 m
.18195 .67458 L
s
.18195 .67458 m
0 0 L
s
1 0 m
.81805 .67458 L
s
.81805 .67458 m
.76109 4.75775 L
s
.76109 4.75775 m
.87232 5.99483 L
s
.87232 5.99483 m
1 0 L
s
0 0 m
.12768 5.99483 L
s
.12768 5.99483 m
.87232 5.99483 L
s
.87232 5.99483 m
1 0 L
s
1 0 m
0 0 L
s
.18195 .67458 m
.81805 .67458 L
s
.81805 .67458 m
.76109 4.75775 L
s
.76109 4.75775 m
.23891 4.75775 L
s
.23891 4.75775 m
.18195 .67458 L
s
0 0 m
1 0 L
1 5.99483 L
0 5.99483 L
closepath
clip
newpath
.01 w
.40334 5.07891 Mdot
.59666 5.07891 Mdot
.5 Mabswid
.06 0 0 r
.75191 2.24689 m .24809 2.24689 L .22131 2.28868 L p F P
0 g
s
.06 0 0 r
.22131 2.28868 m .77869 2.28868 L .75191 2.24689 L p F P
0 g
s
.691 .687 .841 r
.75191 2.24689 m .75811 1.72446 L .24189 1.72446 L p F P
0 g
s
.691 .687 .841 r
.24189 1.72446 m .24809 2.24689 L .75191 2.24689 L p F P
0 g
s
.745 .608 .039 r
.24809 2.24689 m .24189 1.72446 L .21371 1.71034 L p F P
0 g
s
.745 .608 .039 r
.21371 1.71034 m .22131 2.28868 L .24809 2.24689 L p F P
0 g
s
0 0 .039 r
.75191 2.24689 m .77869 2.28868 L .78629 1.71034 L p F P
0 g
s
0 0 .039 r
.78629 1.71034 m .75811 1.72446 L .75191 2.24689 L p F P
0 g
s
.01 w
.39133 5.47992 Mdot
.60867 5.47992 Mdot
.5 Mabswid
.019 .593 .726 r
.75811 1.72446 m .78629 1.71034 L .21371 1.71034 L p F P
0 g
s
.019 .593 .726 r
.21371 1.71034 m .24189 1.72446 L .75811 1.72446 L p F P
0 g
s
.01 w
.38937 2.41909 Mdot
.61063 2.41909 Mdot
.5 Mabswid
.5 1.71879 m
.5 1.99576 L
s
.5 .55699 m
.5 1.71034 L
s
.688 .696 .853 r
.77869 2.28868 m .22131 2.28868 L .21371 1.71034 L p F P
0 g
s
.688 .696 .853 r
.21371 1.71034 m .78629 1.71034 L .77869 2.28868 L p F P
0 g
s
.06 0 0 r
.78371 2.29652 m .21629 2.29652 L .18187 2.35024 L p F P
0 g
s
.06 0 0 r
.18187 2.35024 m .81813 2.35024 L .78371 2.29652 L p F P
0 g
s
.687 .698 .855 r
.78371 2.29652 m .7916 1.70768 L .2084 1.70768 L p F P
0 g
s
.687 .698 .855 r
.2084 1.70768 m .21629 2.29652 L .78371 2.29652 L p F P
0 g
s
.745 .608 .039 r
.21629 2.29652 m .2084 1.70768 L .17191 1.68941 L p F P
0 g
s
.745 .608 .039 r
.17191 1.68941 m .18187 2.35024 L .21629 2.29652 L p F P
0 g
s
0 0 .039 r
.78371 2.29652 m .81813 2.35024 L .82809 1.68941 L p F P
0 g
s
0 0 .039 r
.82809 1.68941 m .7916 1.70768 L .78371 2.29652 L p F P
0 g
s
.019 .593 .726 r
.7916 1.70768 m .82809 1.68941 L .17191 1.68941 L p F P
0 g
s
.019 .593 .726 r
.17191 1.68941 m .2084 1.70768 L .7916 1.70768 L p F P
0 g
s
.01 w
.37334 2.50103 Mdot
.62666 2.50103 Mdot
.5 Mabswid
.5 1.69774 m
.5 2.01498 L
s
.682 .71 .869 r
.81813 2.35024 m .18187 2.35024 L .17191 1.68941 L p F P
0 g
s
.682 .71 .869 r
.17191 1.68941 m .82809 1.68941 L .81813 2.35024 L p F P
0 g
s
.5 .2313 m
.5 1.68941 L
s
.25 Mabswid
0 0 m
.12768 5.99483 L
s
.12768 5.99483 m
.87232 5.99483 L
s
.87232 5.99483 m
1 0 L
s
1 0 m
0 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{48, 287.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40000`00017b000`400?l00000o`00003o<03oool0
0300oooo000`0000000000<000000?ooo`3oool0;03oool10000000000<000000?ooo`3oool0:`3o
ool2000000000P00000/0?ooo`8000000002000002`0oooo0P00000000800000;03oool200000000
0P00000[0?ooo`4000000@3oool10000000000<000000?ooo`000000:P3oool100000040oooo0@00
000000030000003oool0000002X0oooo0@0000010?ooo`40000000000`000000oooo0000000Y0?oo
o`030000003oool0oooo0040000000000`000000oooo0000000Y0?ooo`030000003oool0oooo0040
0000000010000000oooo0?ooo`00000C0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool00@00000000040000003oool0oooo000001<0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`010000000000@000000?ooo`3oool000004`3oool00`000000oooo0?ooo`0A0?ooo`04
0000003oool0oooo0?ooo`400000000010000000oooo0?ooo`00000C0?ooo`030000003oool0oooo
0140oooo00@000000?ooo`3oool0oooo0@00000000050000003oool0oooo0?ooo`0000004P3oool0
0`000000oooo0?ooo`0A0?ooo`040000003oool0oooo0?ooo`40000000001@000000oooo0?ooo`3o
ool000000180oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`4000000000
1@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`020?ooo`40000000001@000000oooo0?ooo`3oool000000180oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`020?ooo`40000000000`000000oooo0?ooo`020?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`40000000000`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`030?ooo`40000000000`000000oooo
0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`030?ooo`40000000000`3oool000000?ooo`03
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`03
0?ooo`4000000@3oool000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo0@0000010?ooo`0000<0oooo0000003o
ool00`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool00`3oool100000040oooo00000`3oool000000?ooo`040?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`040?ooo`4000000@3oool000030?ooo`00
0000oooo00@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00@0oooo0@0000010?ooo`0000<0oooo0000003oool0103oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0103oool100000040oooo00000`3o
ool000000?ooo`040?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`040?ooo`4000000@3oool000030?ooo`000000oooo00D0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`00
00<0oooo0000003oool01@3ooolO000000L0oooo0@0000010?ooo`0000<0oooo0000003oool01@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01@3o
ool100000040oooo00000`3oool000000?ooo`050?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`050?ooo`4000000@3oool000030?ooo`000000oooo
00D0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool01@3oool100000040oooo00000`3oool00000
0?ooo`050?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`050?ooo`4000000@3oool000030?ooo`000000oooo00D0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo
0000003oool01@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool01@3oool100000040oooo00000`3oool000000?ooo`050?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`050?ooo`4000000@3oool00003
0?ooo`000000oooo00D0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01@3oool100000040oooo
00000`3oool000000?ooo`050?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`050?ooo`4000000@3oool000030?ooo`000000oooo00D0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00D0oooo0@000001
0?ooo`0000<0oooo0000003oool01@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool01@3oool100000040oooo00000`3oool000000?ooo`050?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`050?ooo`40
00000@3oool000030?ooo`000000oooo00D0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01@3o
ool100000040oooo00000`3oool000000?ooo`050?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`050?ooo`4000000@3oool000030?ooo`000000oooo
00D0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool01@3oool100000040oooo00000`3oool00000
0?ooo`050?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`050?ooo`4000000@3oool000030?ooo`000000oooo00D0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo
0000003oool01@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool01@3oool100000040oooo00000`3oool000000?ooo`050?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`050?ooo`4000000@3oool00003
0?ooo`000000oooo00D0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01@3oool100000040oooo
00000`3oool000000?ooo`050?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`050?ooo`4000000@3oool000030?ooo`000000oooo00D0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00D0oooo0@000001
0?ooo`0000<0oooo0000003oool01@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool01@3oool100000040oooo00000`3oool000000?ooo`050?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`050?ooo`40
00000@3oool000030?ooo`000000oooo00D0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01@3o
ool100000040oooo00000`3oool000000?ooo`050?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`4000000@3oool000030?ooo`000000oooo
00H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00H0oooo0@0000010?ooo`0000<0oooo0000003oool01P3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool100000040oooo00000`3oool00000
0?ooo`060?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`060?ooo`4000000@3oool000030?ooo`000000oooo00H0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo0@0000010?ooo`0000<0oooo
0000003oool01P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool01P3oool100000040oooo00000`3oool000000?ooo`060?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`4000000@3oool00080
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool01@3oool100000040oooo0@3oool00080oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
1@3oool100000040oooo0@3oool00080oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01@3oool100000040oooo0@3o
ool00080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool01@3oool100000040oooo0@3oool00080oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool01@3oool100000040oooo0@3oool00080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01@3oool100000040
oooo0@3oool00080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool01@3oool100000040oooo0@3oool00080oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool01@3oool100000040oooo0@3oool00080oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01@3oool1
00000040oooo0@3oool00080oooo00<000000?ooo`3oool00`3ooolO000000H0oooo0@0000010?oo
o`40oooo00020?ooo`030000003oool0oooo00<0oooo00<000000:jegP2^]Mh06`2^]Mh00`000000
oooo0?ooo`040?ooo`4000000@3oool10?ooo`000P3oool00`000000oooo0?ooo`030?ooo`030000
002^]Mh0[[GN01/0[[GN00<000000?ooo`3oool0103oool100000040oooo0@3oool00080oooo00<0
00000?ooo`3oool00`3oool00`000000[[GN0:jegP0K0:jegP030000003oool0oooo00@0oooo0@00
00010?ooo`40oooo00020?ooo`030000003oool0oooo00<0oooo00<000000:jegP2^]Mh06`2^]Mh0
0`000000oooo0?ooo`040?ooo`4000000@3oool10?ooo`000P3oool00`000000oooo0?ooo`030?oo
o`030000002^]Mh0[[GN01/0[[GN00<000000?ooo`3oool0103oool100000040oooo0@3oool00080
oooo00<000000?ooo`3oool00`3oool00`000000[[GN0:jegP0K0:jegP030000003oool0oooo00@0
oooo0@0000010?ooo`40oooo00020?ooo`030000003oool0oooo00<0oooo00<000000:jegP2^]Mh0
6`2^]Mh00`000000oooo0?ooo`040?ooo`4000000@3oool10?ooo`000P3oool00`000000oooo0?oo
o`030?ooo`030000002^]Mh0[[GN01/0[[GN00<000000?ooo`3oool0103oool100000040oooo0@3o
ool00080oooo00<000000?ooo`3oool00`3oool00`000000[[GN0:jegP0K0:jegP030000003oool0
oooo00@0oooo0@0000010?ooo`40oooo00020?ooo`030000003oool0oooo00<0oooo00<000000:je
gP2^]Mh06`2^]Mh00`000000oooo0?ooo`040?ooo`4000000@3oool10?ooo`000P3oool00`000000
oooo0?ooo`030?ooo`030000002^]Mh0[[GN01/0[[GN00<000000?ooo`3oool0103oool100000040
oooo0@3oool00080oooo00<000000?ooo`3oool00`3oool00`000000[[GN0:jegP0K0:jegP030000
003oool0oooo00@0oooo0@0000010?ooo`40oooo00020?ooo`030000003oool0oooo00<0oooo00<0
00000:jegP2^]Mh06`2^]Mh00`000000oooo0?ooo`040?ooo`4000000@3oool10?ooo`000P3oool0
0`000000oooo0?ooo`030?ooo`030000002^]Mh0[[GN01/0[[GN00<000000?ooo`3oool0103oool1
00000040oooo0@3oool00080oooo00<000000?ooo`3oool00`3oool00`000000[[GN0:jegP0K0:je
gP030000003oool0oooo00@0oooo0@0000010?ooo`40oooo00020?ooo`030000003oool0oooo00<0
oooo00<000000:jegP2^]Mh06`2^]Mh00`000000oooo0?ooo`040?ooo`4000000@3oool10?ooo`00
0P3oool00`000000oooo0?ooo`030?ooo`030000002^]Mh0[[GN01/0[[GN00<000000?ooo`3oool0
103oool100000040oooo0@3oool00080oooo00<000000?ooo`3oool00`3oool00`000000[[GN0:je
gP0K0:jegP030000003oool0oooo00@0oooo0@0000010?ooo`40oooo00020?ooo`030000003oool0
oooo00<0oooo00<000000:jegP2^]Mh06`2^]Mh00`000000oooo0?ooo`040?ooo`4000000@3oool1
0?ooo`000P3oool00`000000oooo0?ooo`030?ooo`030000002^]Mh0[[GN01/0[[GN00<000000?oo
o`3oool0103oool100000040oooo0@3oool00080oooo00<000000?ooo`3oool00`3oool00`000000
[[GN0:jegP0K0:jegP030000003oool0oooo00@0oooo0@0000010?ooo`40oooo00020?ooo`030000
003oool0oooo00<0oooo00<000000:jegP2^]Mh06`2^]Mh00`000000oooo0?ooo`040?ooo`400000
0@3oool10?ooo`000P3oool00`000000oooo0?ooo`030?ooo`030000002^]Mh0[[GN01/0[[GN00<0
00000?ooo`3oool0103oool100000040oooo0@3oool00080oooo00<000000?ooo`3oool00`3oool0
0`000000[[GN0:jegP0K0:jegP030000003oool0oooo00@0oooo0@0000010?ooo`40oooo00020?oo
o`030000003oool0oooo00<0oooo00<000000:jegP2^]Mh06`2^]Mh00`000000oooo0?ooo`040?oo
o`4000000@3oool10?ooo`000P3oool00`000000oooo0?ooo`030?ooo`030000002^]Mh0[[GN01/0
[[GN00<000000?ooo`3oool0103oool100000040oooo0@3oool00080oooo00<000000?ooo`3oool0
0`3oool00`000000[[GN0:jegP0K0:jegP030000003oool0oooo00@0oooo0@0000010?ooo`40oooo
00020?ooo`030000003oool0oooo00<0oooo00<000000:jegP2^]Mh06`2^]Mh00`000000oooo0?oo
o`040?ooo`4000000@3oool10?ooo`000P3oool00`000000oooo0?ooo`030?ooo`030000002^]Mh0
[[GN01/0[[GN00<000000?ooo`3oool0103oool100000040oooo0@3oool00080oooo00<000000?oo
o`3oool00`3oool00`000000[[GN0:jegP0K0:jegP030000003oool0oooo00@0oooo0@0000010?oo
o`40oooo00020?ooo`030000003oool0oooo00<0oooo7`0000060?ooo`4000000@3oool10?ooo`00
0P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
1@3oool100000040oooo0@3oool00080oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`40oooo00020?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool100000040oooo0@3oool00080oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo0@0000010?oo
o`40oooo00020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`050?ooo`4000000@3oool10?ooo`000P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00D0oooo0@0000010?ooo`40oooo00030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0040oooo0003
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0040oooo00030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0040oooo00030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0040oooo00030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0040oooo00030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0040oooo00030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0040oooo00030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0040oooo00030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0040oooo00030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0040oooo
00030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0040oooo00030?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0040oooo00030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0040oooo00030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0040oooo00030?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0040oooo00030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0040oooo00030?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0040oooo00030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0040oooo00030?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0040
oooo00030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0040oooo00030?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0040oooo0003
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0040oooo00030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0040oooo00030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0040oooo00030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0040oooo00030?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0040oooo00030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0040oooo00030?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0040oooo00030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0040oooo00030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0040oooo
00030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0040oooo00030?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0040oooo00030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0040oooo00030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0040oooo00030?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0040oooo00030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0040oooo00030?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0040oooo00030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0040oooo00030?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0040
oooo00030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0040oooo00030?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0040oooo0003
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0040oooo00030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0040oooo00030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0040oooo00030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0040oooo00030?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0040oooo00030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0040oooo00040?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0080oooo00040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo
00040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0080oooo00040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0080oooo00040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080
oooo00040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo0004
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00040?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0080oooo00040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0080oooo00040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0080oooo00040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo
00040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0080oooo00040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0080oooo00040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080
oooo00040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo0004
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00040?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0080oooo00040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00040?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0080oooo00040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0080oooo00040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo
00040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00040?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0080oooo00040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00050?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00<0oooo00050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00050?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00<0oooo00050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0
oooo00050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo0005
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00050?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00050?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00<0oooo00050?ooo`030000003oool0oooo00<0oooo6@0000060?ooo`030000003oool0
oooo00<0oooo00050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0
oooo00050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo0005
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00050?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00050?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`001@3oool01@000000oooo0?ooo`3oool0000001/0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`001@3oool01@000000oooo
0?ooo`3oool0000001/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`00
1@3oool01@000000oooo0?ooo`3oool0000001/0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`001@3oool01@000000oooo0?ooo`3oool0000001/0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`001@3oool01@000000oooo0?ooo`3oool0000001/0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`001@3oool01@000000oooo
0?ooo`3oool0000001/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`00
1@3oool01@000000oooo0?ooo`3oool0000001/0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`001@3oool01@000000oooo0?ooo`3oool0000001`0oooo00D000000?ooo`3o
ool0oooo000000050?ooo`001@3oool01@000000oooo0?ooo`3oool0000001`0oooo00D000000?oo
o`3oool0oooo000000050?ooo`001@3oool01@000000oooo0?ooo`3oool0000001`0oooo00D00000
0?ooo`3oool0oooo000000050?ooo`001@3oool01@000000oooo0?ooo`3oool0000001`0oooo00D0
00000?ooo`3oool0oooo000000050?ooo`001@3oool010000000oooo0?ooo`00000M0?ooo`050000
003oool0oooo0?ooo`0000001@3oool000D0oooo00@000000?ooo`3oool000007@3oool01@000000
oooo0?ooo`3oool0000000D0oooo00050?ooo`040000003oool0oooo000001d0oooo00D000000?oo
o`3oool0oooo000000050?ooo`001@3oool010000000oooo0?ooo`00000M0?ooo`050000003oool0
oooo0?ooo`0000001@3oool000D0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo000000050?ooo`001@3o
ool010000000oooo0?ooo`00000N0?ooo`040000003oool0oooo000000D0oooo00060?ooo`030000
003oool0000001h0oooo00<000000?ooo`0000001P3oool000H0oooo00<000000?ooo`0000007P3o
ool00`000000oooo000000060?ooo`001P3oool00`000000oooo0000000N0?ooo`030000003oool0
000000H0oooo00060?ooo`030000003oool0000001h0oooo00<000000?ooo`0000001P3oool000H0
oooo00<000000?ooo`0000007P3oool00`000000oooo000000060?ooo`001P3oool00`000000oooo
0000000N0?ooo`030000003oool0000000H0oooo00060?ooo`8000007`3oool00`000000oooo0000
00060?ooo`001P3oool2000001l0oooo00<000000?ooo`0000001P3oool000H0oooo0P00000O0?oo
o`030000003oool0000000H0oooo00060?ooo`800000803oool2000000H0oooo00060?ooo`800000
803oool2000000H0oooo00060?ooo`800000803oool2000000H0oooo00060?ooo`800000803oool2
000000H0oooo00060?ooo`800000803oool2000000H0oooo00060?ooo`800000803oool2000000H0
oooo00060?ooo`800000803oool2000000H0oooo00060?ooo`800000803oool2000000H0oooo0006
0?ooo`800000803oool2000000H0oooo00060?ooo`030000003oool0oooo01l0oooo0P0000060?oo
o`001P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00@0oooo00060?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo00@0oooo00060?ooob@000001P3oool00300oooo000`0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 47}, {286.75, 0}} -> {0.420014, -0.00850194, \
0.00340363, 0.00340363}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#6", "Text"],

Cell[CellGroupData[{

Cell["Hz2[[-6]]", "Input"],

Cell[BoxData[
    \(11.342534019381276`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pretty[Chop[e2ni . eigenvectors2[\([\(-6\)]\)], 10^\(-4\)]]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
          {"\<\"optic\"\>", "0", "0.0029718091482958432`", "0", "0", 
            "0", \(-0.9999955841654432`\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Status["\<Plotting stage 2 mode 6\>"]\ ; 
    eigenplot[
      eigenvectors2[\([\(-6\)]\)], \(- .2\), {\(-1\), 0, \(- .25\)}, \ 
      floatmatrix2]\ ; Done[]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 2.05714 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.622713 2.24543 -8.9013e-017 2.24543 [
[ 0 0 0 0 ]
[ 1 2.05714 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
1 0 m
.88819 2.05714 L
s
.88819 2.05714 m
.11181 2.05714 L
s
.11181 2.05714 m
0 0 L
s
0 0 m
1 0 L
s
.93098 .0853 m
.06902 .0853 L
s
.06902 .0853 m
.15474 1.89797 L
s
.15474 1.89797 m
.84526 1.89797 L
s
.84526 1.89797 m
.93098 .0853 L
s
1 0 m
.88819 2.05714 L
s
.88819 2.05714 m
.84526 1.89797 L
s
.84526 1.89797 m
.93098 .0853 L
s
.93098 .0853 m
1 0 L
s
0 0 m
.06902 .0853 L
s
.06902 .0853 m
.15474 1.89797 L
s
.15474 1.89797 m
.11181 2.05714 L
s
.11181 2.05714 m
0 0 L
s
0 0 m
1 0 L
1 2.05714 L
0 2.05714 L
closepath
clip
newpath
.5 Mabswid
.689 .692 .848 r
.4399 1.9132 m .48472 1.9132 L .48463 1.87377 L p F P
0 g
s
.714 .583 .006 r
.48463 1.87377 m .48472 1.9132 L .48363 2.0056 L p F P
0 g
s
.785 .641 .083 r
.28715 2.0056 m .30132 1.9132 L p .28083 1.99584 L F P
0 g
s
.785 .641 .083 r
.30132 1.9132 m .30025 1.87377 L .28083 1.99584 L p F P
0 g
s
.689 .692 .848 r
.30025 1.87377 m .30132 1.9132 L .4399 1.9132 L p F P
0 g
s
.689 .692 .848 r
.48463 1.87377 m .30025 1.87377 L p .4399 1.9132 L F P
0 g
s
0 0 .083 r
.70204 1.78986 m .69868 1.9132 L .70305 1.9417 L p F P
0 g
s
.689 .692 .848 r
.51554 1.78986 m .51528 1.9132 L .5601 1.9132 L p F P
0 g
s
0 0 .006 r
.51562 1.9417 m .51528 1.9132 L p .51707 1.90521 L F P
0 g
s
0 0 .006 r
.51528 1.9132 m .51554 1.78986 L .51707 1.90521 L p F P
0 g
s
.689 .692 .848 r
.5601 1.9132 m .69868 1.9132 L .70204 1.78986 L p F P
0 g
s
.689 .692 .848 r
.70204 1.78986 m .51554 1.78986 L p .5601 1.9132 L F P
0 g
s
.423 0 0 r
.30025 1.87377 m .48463 1.87377 L .48314 1.99584 L p F P
0 g
s
.423 0 0 r
.48314 1.99584 m .28083 1.99584 L .30025 1.87377 L p F P
0 g
s
.714 .583 .006 r
.48314 1.99584 m .48463 1.87377 L p .48363 2.0056 L F P
0 g
s
0 0 .083 r
.72193 1.90521 m .70204 1.78986 L p .70305 1.9417 L F P
0 g
s
.401 0 0 r
.51554 1.78986 m .70204 1.78986 L .72193 1.90521 L p F P
0 g
s
.401 0 0 r
.72193 1.90521 m .51707 1.90521 L .51554 1.78986 L p F P
0 g
s
0 0 .083 r
.70305 1.9417 m .71788 2.03836 L .72193 1.90521 L p F P
0 g
s
0 0 .006 r
.51707 1.90521 m .51676 2.03836 L .51562 1.9417 L p F P
0 g
s
.27449 1.3582 m
.37427 1.93198 L
s
.62852 1.84483 m
.7266 1.32045 L
s
.61257 1.93007 m
.61722 1.90521 L
s
.714 .583 .006 r
.48363 2.0056 m .48324 2.03836 L .48314 1.99584 L p F P
0 g
s
.785 .641 .083 r
.28083 1.99584 m .28212 2.03836 L .28715 2.0056 L p F P
0 g
s
.685 .703 .861 r
.4341 2.03836 m .28212 2.03836 L p .48314 1.99584 L F P
0 g
s
.685 .703 .861 r
.28212 2.03836 m .28083 1.99584 L .48314 1.99584 L p F P
0 g
s
.685 .703 .861 r
.48314 1.99584 m .48324 2.03836 L .4341 2.03836 L p F P
0 g
s
.685 .703 .861 r
.5659 2.03836 m .51676 2.03836 L p .72193 1.90521 L F P
0 g
s
.685 .703 .861 r
.51676 2.03836 m .51707 1.90521 L .72193 1.90521 L p F P
0 g
s
.685 .703 .861 r
.72193 1.90521 m .71788 2.03836 L .5659 2.03836 L p F P
0 g
s
.218 0 0 r
.55244 1.34412 m .55026 1.31389 L .47757 1.31685 L p F P
0 g
s
.218 0 0 r
.47757 1.31685 m .4766 1.34719 L .55244 1.34412 L p F P
0 g
s
.424 0 0 r
.4766 1.34719 m .47757 1.31685 L .40728 1.29836 L p F P
0 g
s
0 0 0 r
.62397 1.319 m .61879 1.28973 L .55026 1.31389 L p F P
0 g
s
0 0 0 r
.55026 1.31389 m .55244 1.34412 L .62397 1.319 L p F P
0 g
s
.424 0 0 r
.40728 1.29836 m .40324 1.32796 L .4766 1.34719 L p F P
0 g
s
.599 .036 0 r
.40324 1.32796 m .40728 1.29836 L .34576 1.25994 L p F P
0 g
s
0 0 0 r
.68466 1.2739 m .67691 1.24637 L .61879 1.28973 L p F P
0 g
s
0 0 0 r
.61879 1.28973 m .62397 1.319 L .68466 1.2739 L p F P
0 g
s
.599 .036 0 r
.34576 1.25994 m .33902 1.28802 L .40324 1.32796 L p F P
0 g
s
.727 .253 0 r
.33902 1.28802 m .34576 1.25994 L .29881 1.20485 L p F P
0 g
s
0 0 0 r
.72874 1.21265 m .71907 1.1875 L .67691 1.24637 L p F P
0 g
s
.75811 1.15201 m
.7754 1.05956 L
s
0 0 0 r
.67691 1.24637 m .68466 1.2739 L .72874 1.21265 L p F P
0 g
s
.727 .253 0 r
.29881 1.20485 m .28995 1.23071 L .33902 1.28802 L p F P
0 g
s
.793 .455 0 r
.28995 1.23071 m .29881 1.20485 L .27113 1.13793 L p F P
0 g
s
0 0 0 r
.75167 1.14066 m .74093 1.11837 L .71907 1.1875 L p F P
0 g
s
0 0 0 r
.71907 1.1875 m .72874 1.21265 L .75167 1.14066 L p F P
0 g
s
.7266 1.32045 m
.75811 1.15201 L
s
.793 .455 0 r
.27113 1.13793 m .26096 1.16103 L .28995 1.23071 L p F P
0 g
s
.24085 1.1648 m
.27449 1.3582 L
s
.792 .623 .063 r
.26096 1.16103 m .27113 1.13793 L .26585 1.06532 L p F P
0 g
s
0 0 .11 r
.75067 1.06462 m .73988 1.0454 L .74093 1.11837 L p F P
0 g
s
0 0 .11 r
.74093 1.11837 m .75167 1.14066 L .75067 1.06462 L p F P
0 g
s
.792 .623 .063 r
.26585 1.06532 m .25534 1.08538 L .26096 1.16103 L p F P
0 g
s
.722 .739 .224 r
.25534 1.08538 m .26585 1.06532 L .28408 .99404 L p F P
0 g
s
0 0 .27 r
.72518 .992 m .71541 .97577 L .73988 1.0454 L p F P
0 g
s
0 0 .27 r
.73988 1.0454 m .75067 1.06462 L .72518 .992 L p F P
0 g
s
.722 .739 .224 r
.28408 .99404 m .27431 1.01107 L .25534 1.08538 L p F P
0 g
s
0 0 0 r
.27431 1.01107 m .28408 .99404 L .32459 .93137 L p F P
0 g
s
.577 .119 0 r
.67716 .93031 m .66942 .91665 L .71541 .97577 L p F P
0 g
s
.577 .119 0 r
.71541 .97577 m .72518 .992 L .67716 .93031 L p F P
0 g
s
0 0 0 r
.32459 .93137 m .31658 .94567 L .27431 1.01107 L p F P
0 g
s
0 0 0 r
.31658 .94567 m .32459 .93137 L .38366 .88398 L p F P
0 g
s
.452 0 0 r
.61114 .88621 m .60626 .87442 L .66942 .91665 L p F P
0 g
s
.452 0 0 r
.66942 .91665 m .67716 .93031 L .61114 .88621 L p F P
0 g
s
0 0 0 r
.37832 .89619 m .38366 .88398 L .45541 .8571 L p F P
0 g
s
0 0 0 r
.38366 .88398 m .37832 .89619 L .31658 .94567 L p F P
0 g
s
.271 0 0 r
.53382 .86466 m .53233 .85379 L .60626 .87442 L p F P
0 g
s
.271 0 0 r
.60626 .87442 m .61114 .88621 L .53382 .86466 L p F P
0 g
s
0 0 0 r
.45541 .8571 m .45335 .86812 L .37832 .89619 L p F P
0 g
s
.053 0 0 r
.45335 .86812 m .45541 .8571 L .53233 .85379 L p F P
0 g
s
.053 0 0 r
.53233 .85379 m .53382 .86466 L .45335 .86812 L p F P
0 g
s
.01 w
.63753 .85219 Mdot
.36247 .85219 Mdot
.64387 .86298 Mdot
.35613 .86298 Mdot
.25 Mabswid
1 0 m
.88819 2.05714 L
s
.88819 2.05714 m
.11181 2.05714 L
s
.11181 2.05714 m
0 0 L
s
0 0 m
1 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{140, 287.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002<00017b000`400?l00000o`00003oS0000000
00800000R03oool2000000000P0000270?ooo`4000000@3oool10000000000<000000?ooo`000000
Q@3oool00`000000oooo0?ooo`010000000000@000000?ooo`3oool00000Q03oool00`000000oooo
0?ooo`010000000000D000000?ooo`3oool0oooo000000220?ooo`040000003oool0oooo0?ooo`40
000000001@000000oooo0?ooo`3oool000000840oooo00<000000?ooo`3oool00P3oool100000000
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo00<0oooo
0@00000000030000003oool0oooo00<0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?oo
o`040?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo07T0oooo00<00000
0?ooo`3oool0103oool100000040oooo00000`3oool000000?ooo`040?ooo`030000003oool0oooo
07T0oooo00<000000?ooo`3oool0103oool100000040oooo00000`3oool000000?ooo`050?ooo`03
0000003oool0oooo07L0oooo00<000000?ooo`3oool01@3oool100000040oooo00000`3oool00000
0?ooo`060?ooogT00000203oool100000040oooo00000`3oool000000?ooo`060?ooo`030000003o
ool0oooo07D0oooo00<000000?ooo`3oool01P3oool100000040oooo00000`3oool000000?ooo`06
0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool01P3oool100000040oooo00000`3o
ool000000?ooo`060?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool01P3oool10000
0040oooo00000`3oool000000?ooo`060?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3o
ool01P3oool100000040oooo00000`3oool000000?ooo`060?ooo`030000003oool0oooo07D0oooo
00<000000?ooo`3oool01P3oool100000040oooo00000`3oool000000?ooo`060?ooo`030000003o
ool0oooo07D0oooo00<000000?ooo`3oool01P3oool100000040oooo00000`3oool000000?ooo`06
0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool01P3oool100000040oooo00000`3o
ool000000?ooo`060?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool01P3oool10000
0040oooo00000`3oool000000?ooo`060?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3o
ool01P3oool100000040oooo00000`3oool000000?ooo`060?ooo`030000003oool0oooo07D0oooo
00<000000?ooo`3oool01P3oool100000040oooo00000`3oool000000?ooo`070?ooo`030000003o
ool0oooo07<0oooo00<000000?ooo`3oool01`3oool100000040oooo00000`3oool000000?ooo`07
0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool01`3oool100000040oooo00000`3o
ool000000?ooo`070?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool01`3oool10000
0040oooo00000`3oool000000?ooo`070?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3o
ool01`3oool100000040oooo00000`3oool000000?ooo`070?ooo`030000003oool0oooo07<0oooo
00<000000?ooo`3oool01P3oool100000040oooo0@3oool000030?ooo`000000oooo00L0oooo00<0
00000?ooo`3oool0L`3oool00`000000oooo0?ooo`060?ooo`4000000@3oool10?ooo`000P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool01P3oool1
00000040oooo0@3oool00080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1c0?oo
o`030000003oool0oooo00H0oooo0@0000010?ooo`40oooo00020?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`060?ooo`4000000@3oool10?ooo`00
0P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0
1P3oool100000040oooo0@3oool00080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`1c0?ooo`030000003oool0oooo00H0oooo0@0000010?ooo`40oooo00020?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`060?ooo`4000000@3oool1
0?ooo`000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo07<0oooo00<000000?oo
o`3oool01P3oool100000040oooo0@3oool00080oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`1c0?ooo`030000003oool0oooo00H0oooo0@0000010?ooo`40oooo00020?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`060?ooo`400000
0@3oool10?ooo`000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo07<0oooo00<0
00000?ooo`3oool01P3oool100000040oooo0@3oool00080oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`1c0?ooo`030000003oool0oooo00H0oooo0@0000010?ooo`40oooo00020?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`060?oo
o`4000000@3oool10?ooo`000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo07<0
oooo00<000000?ooo`3oool01P3oool100000040oooo0@3oool00080oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo00H0oooo0@0000010?ooo`40oooo
00020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?oo
o`060?ooo`4000000@3oool10?ooo`000P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0740oooo00<000000?ooo`3oool01`3oool100000040oooo0@3oool00080oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool00@3oool00080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1a0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool00@3oool00080oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0@3oool000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1a0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`1a0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00@3oool0
00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`1a0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00@3oool000<0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`1a0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00@3oool000<0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1a0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00@3oool000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1a0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00@3o
ool000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`1a0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00@3oool000<0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`1a0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00@3oool000<0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00P3oool000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1a
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool000<0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool00P3oool000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1_0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0P3oool000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1_0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`1_0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool0
00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`1_0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool000@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`1_0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool000@0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1_0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00P3oool000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1_0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`1_0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool000@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00`3oool000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`1_0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool000@0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00`3oool000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1_
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool000@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool00`3oool000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1]0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0`3oool000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1]0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool0
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`1]0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool000D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`1]0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool000D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool00`3oool000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1]0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00`3oool000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1]0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3o
ool000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`1]0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool000D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`1]0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool000D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1]
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0103oool000H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1]0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
103oool000H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1[0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`1[0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool0
00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`1[0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool000H0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`1[0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool000H0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1[0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0103oool000H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1[0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0:0?ooo`d000003P3oool0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0[0?ooo`@000001@0=000:0000
02d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`001P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo02P0oooo300000070?ooo`L00000:@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00060?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool09P3oool700000140oooo100000000`15000000000?ooo`0V0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0T0?ooo`H00000603oool4000002D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo02<0oooo1@00000L0?ooo`@000008`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool08P3oool30000
0240oooo1000000Q0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool000L0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0Q0?ooo`8000009@3oool010000000
L`0000000000000O0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool000L0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0O0?ooo`<000009`3oool200000003
07<000000000oooo01d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`00
1`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01d0oooo0`00000Z0?ooo`<00000
703oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0703oool3000002d0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool06`3oool200000300oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool06P3oool200000340oooo0P00000J0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0I0?ooo`800000<`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0603oool2000003D0oooo0P00000H0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0G
0?ooo`800000=`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01P3oool000L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0F0?oo
o`800000>@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01P3oool000L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0F0?ooo`80
0000>@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01P3oool000L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0E0?ooo`800000
>`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1P3oool000L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0503oool2
000003`0oooo0P00000E0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool0
00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00H0oooo00070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`0l0?ooo`800000503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0
oooo00070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0m0?ooo`800000503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo
00080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`0n0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`060?ooo`00203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0?P3oool2000001<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`06
0?ooo`00203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0180oooo0P0000100?oo
o`8000004`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00080?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0o0?ooo`<0
00000P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01P3oool000P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo03l0oooo00<000000000700000000P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool000P0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo03l0oooo00<000000000700000000P3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool000P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0@0?ooo`800000@@3oool0
0`000000000L000000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`060?ooo`00203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0100oooo0P0000110?ooo`050000000001`000000?ooo`0000003`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo00080?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0403oool200000440oooo00D00000000070000000oooo0000000?0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0@0?ooo`800000@@3oool01@000000000L0000003oool0000000l0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0100oooo00<000000<ZO40000000@03oool01@000000000L0000003oool0
000000l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`00203oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0100oooo00<000000<ZO40000000@03oool01@00
0000000L0000003oool0000000l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`07
0?ooo`00203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0100oooo00<000000<ZO
40000000@03oool01@000000000L0000003oool0000000l0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0140oooo0P0000100?ooo`@00000403oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00L0oooo00080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool2000003l0
oooo1@00000@0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool000P0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`800000?`3oool500000100oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0140oooo00<000000<]d00000000?P3oool500000100oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`00203oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0140oooo00<000000<]d00000000?@3oool4000000030?ooo`000000
oooo00l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`00203oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo00@000000?ooo`3oool000000P3;M000
0`000000oooo0?ooo`0j0?ooo`@0000000<0oooo0000003oool03`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00L0oooo00090?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool03P3oool01`000000oooo0?ooo`3oool000000<]d00000000?03oool500000140oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`002@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00h0oooo00L000000?ooo`3oool0oooo0000003;M000000003/0oooo
100000000`3oool000000?ooo`0@0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1`3oool000T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?ooo`070000003o
ool0oooo0?ooo`000000bg@00000000j0?ooo`@0000000<0oooo0000003oool0403oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00090?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool03`3oool01`000000oooo0?ooo`3oool000000<]d00000000>@3oool50000
00030?ooo`000000oooo0100oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?oo
o`002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo00D000000?ooo`3o
ool0oooo000000020<]d00030000003oool0oooo03H0oooo1@0000000`3oool000000?ooo`0@0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool000T0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000<]d0000
0000=`3oool5000000030?ooo`000000oooo0140oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`070?ooo`002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool00P3oool010000000bg@000000000000e0?ooo`H0000000<0oooo0000003o
ool04@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00090?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`040000
002j@000^T00000003@0oooo1@0000020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`080?ooo`002@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool01@000000^T000;Y0002j@00000000380
oooo1@0000030?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`080?ooo`002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool00`3oool01@000000^T000;Y0002j@00000000340oooo1@0000020?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`00
2@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
103oool01@000000^T000;Y0002j@000000002l0oooo1@0000030?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`002@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01@3oool01@000000^T00
0;Y0002j@000000002d0oooo1@0000040?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`080?ooo`002@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool01@3oool00`000000^T000;Y000020;Y000030000
003oool0oooo02P0oooo1P0000050?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`080?ooo`002@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool01@3oool010000000^T000;Y0002j@002000002P0oooo
1`0000050?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`080?ooo`002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool01P3oool00`000000^T000000000209T9008000009@3oool7000000D0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo0009
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`07
0?ooo`800000102I2@000`000000oooo0?ooo`0P0?ooo`P000001P3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool000T0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00P0oooo00<0000009T9
002I2@000`2I2@000`000000oooo0?ooo`0M0?ooo`P00000203oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool000T0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00T0oooo0P00000409T90080
00006`3oool9000000T0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00P0oooo00090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0:0?ooo`030000002I2@00V@T000<0V@T00`00000E0?ooo`X00000
2`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
203oool000X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo00/0oooo0P00000309T900030000001/0000K00000D000003P3oool;000000/0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo000:
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0=
0?ooo`040000002I2@00V@T0000000L0K0005`00000=0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`002P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool03P3oool3000000T0K00000<00000
03L0000g00001`0g0009000000l0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00P0oooo000:0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`<000001`1/00000`000000=`0003L0000703L0
00L000004@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0203oool000X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo01<0oooo1@00000206`000030000000g0000=`0000L0=`001000000D0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`00
2P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
5`3oool>000001D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00P0oooo000:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0>@3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool000X0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03P0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo000:
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0h
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`09
0?ooo`002P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool0>03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool02@3oool000X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo03P0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`090?ooo`002P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`002`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0=P3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool000/0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo03H0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo
000;0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`0f0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`090?ooo`002`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool02@3oool000/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo03@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00T0oooo000;0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0:0?ooo`002`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool02P3oool000/0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo000;0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0c0?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`002`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0<P3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02P3oool000/0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0380
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0
oooo000;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`0b0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0:0?ooo`002`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool0<P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool02P3oool000/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00X0oooo000;0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`002`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool02P3oool000/0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo000;0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0`0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`002`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0<03oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02P3oool0
00`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
02l0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00X0oooo000<0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0^0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0:0?ooo`00303oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool02P3oool000`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00X0oooo000<0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`00303oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool02`3oool000`0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo000<0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0/0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`00303o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0;03o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02`3o
ool000`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00/0oooo000<0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`0/0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0;0?ooo`00303oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool02`3oool000`0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00/0oooo000<0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`00303oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02`3oool000`0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo000<0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`00
303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
2`3oool000`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00/0oooo000=0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0;0?ooo`003@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool02`3oool000d0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo000=0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0303oool000d0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo000=0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?oo
o`003@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0303oool000d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool0503ooolK000001@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool04`3oool00`000000IP0006H0000>06H000030000001V0000IP00
00H0IP0000<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00`0oooo000=0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`0C0?ooo`030000001V0000IP0000h0IP0000<0000006H0001V00001P1V00000`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0303oool000d0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01<0oooo
00<0000006H0001V00003P1V00000`000000IP0006H0000706H000030000003oool0oooo0140oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool04`3oool00`000000IP0006H0
000>06H000030000001V0000IP0000L0IP0000<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`0C0?ooo`030000001V0000IP0000d0IP0000<00000
06H0001V0000201V00000`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo0180oooo00<0000006H0001V00003@1V00000`000000IP0006H0000806H0
00030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0<0?oo
o`003@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool04P3oool00`000000IP0006H0000=06H000030000001V0000IP0000P0IP0000<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00`0oooo000=0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0B0?ooo`030000
001V0000IP0001P0IP0000<000000?ooo`3oool0403oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00`0oooo000>0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0B0?ooo`030000001V0000IP0001T0IP0000<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00`0oooo000>0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0B0?ooo`030000001V0000
IP0001T0IP0000<000000?ooo`3oool03`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00`0oooo000>0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`0B0?ooo`030000001V0000IP0001T0IP0000<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo000>0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool04@3ooolK000000<0oooo00<0000006H0001V00006@1V00000`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03@3oool000h0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0A0?ooo`030000001/0000K00000L0K000
00<0000006`0001/00003@1/00001@000000oooo0?ooo`3oool0000001/0IP0000<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo000>0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool04@3oool00`000000K00006`0000706`000030000
001/0000K00000d0K00000D000000?ooo`3oool0oooo0000000L06H000030000003oool0oooo00h0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0=0?ooo`003P3oool00`000000oooo
0?ooo`040?oooaD000002@1/00000`000000K00006`0000=06`000D00000701V000B000000H0oooo
00<000000?ooo`3oool03@3oool000h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0@0?ooo`030000001/0000K00000P0K00000<0000006`0001/00003@1/000010000000oooo0?oo
o`3ooolN00000100oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0=0?ooo`003P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0140oooo00<0000006`0001/0000201/
00000`000000K00006`0000=06`000050000003oool0oooo0?ooo`000000702_/m`00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool000h0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0A0?ooo`030000001/0000K00000T0K00000<0
000006`0001/0000301/00001@000000oooo0?ooo`3oool0000001`0[k?L00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo000>0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool04@3oool00`000000K00006`0000906`000030000001/
0000K00000`0K00000D000000?ooo`3oool0oooo0000000L0:ncg0030000003oool0oooo00l0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`003P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0140oooo00<0000006`0001/00002@1/00000`000000K00006`0
000<06`000050000003oool0oooo0?ooo`000000702_/m`00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool000h0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0B0?ooo`030000001/0000K00001P0K00000D000000?ooo`3oool0oooo
0000000L0:ncg0030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0=0?ooo`003P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0180oooo00<0
000006`0001/0000601/00001@000000oooo0?ooo`3oool0000001`0[k?L00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo000>0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool04P3oool00`000000K00006`0000H06`000050000003o
ool0oooo0?ooo`000000702_/m`00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool03@3oool000h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0A0?ooo`030000001/0000K00001T0K00000D000000?ooo`3oool0oooo0000000L0:ncg0030000
003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`003P3o
ool01@000000oooo0?ooo`3oool0000001@0oooo00<0000006`0001/00006@1/00001@000000oooo
0?ooo`3oool0000001/0[k?L00<000000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool00000
00l0oooo000>0?ooo`050000003oool0oooo0?ooo`000000503oool00`000000K00006`0000I06`0
00050000003oool0oooo0?ooo`0000006`2_/m`00`000000oooo0?ooo`0B0?ooo`050000003oool0
oooo0?ooo`0000003`3oool000h0oooo00D000000?ooo`3oool0oooo0000000D0?ooo`030000001/
0000K00001T0K00000D000000?ooo`3oool0oooo0000000K0:ncg0030000003oool0oooo0180oooo
00D000000?ooo`3oool0oooo0000000?0?ooo`003`3oool00`000000oooo0000000E0?oooad00000
0`3oool00`000000[k?L0:ncg00I0:ncg0030000003oool0oooo01<0oooo00@000000?ooo`3oool0
00003`3oool000l0oooo00<000000?ooo`0000005@3oool00`000000[k?L0:ncg00I0:ncg0050000
003oool0oooo0?ooo`0000006`2_/m`00`000000oooo0?ooo`0C0?ooo`030000003oool000000100
oooo000?0?ooo`030000003oool0000001D0oooo00<000000:ncg02_/m`06@2_/m`01@000000oooo
0?ooo`3oool0000001/0[k?L00<000000?ooo`3oool04`3oool00`000000oooo0000000@0?ooo`00
3`3oool00`000000oooo0000000E0?ooo`030000002_/m`0[k?L01T0[k?L00D000000?ooo`3oool0
oooo0000000K0:ncg0030000003oool0oooo01<0oooo00<000000?ooo`000000403oool000l0oooo
0P00000F0?ooo`030000002_/m`0[k?L01T0[k?L00D000000?ooo`3oool0oooo0000000K0:ncg003
0000003oool0oooo01@0oooo0P00000@0?ooo`003`3oool2000001H0oooo00<000000:ncg02_/m`0
6@2_/m`01@000000oooo0?ooo`3oool0000001/0[k?L00<000000?ooo`3oool0503oool200000100
oooo000?0?ooo`8000005P3ooolM000000<0oooo7@00000F0?ooo`800000403oool000l0oooo0P00
001Y0?ooo`800000403oool000l0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0>
0?ooo`003`3ooom]00000100oooo0000\
\>"],
  ImageRangeCache->{{{0, 139}, {286.938, 0}} -> {0.277322, -0.00159863, \
0.00320398, 0.00320398}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Export as a state-space to Matlab/Simulink", "Text"],

Cell["Calculate[Stage2]", "Input"],

Cell["domatlabexport = True;", "Input"],

Cell[TextData[{
  "If[domatlabexport,\n\tMatlabExport[\n\t\t\"",
  StyleBox["twowiresimpleblades_\"<>modelcase<>\"",
    FontFamily->"Lucida Grande",
    FontWeight->"Plain"],
  ".m\",\n\t\t\
{\"mbtwsbA\",ssAspoiler[potentialmatrices2,kineticmatrix,1.0,0]},\n\t\t\
{\"mbtwsbB\",ssB[coupling2,kineticmatrix,1.0]},\n\t\t{\"mbtwsbC\",ssC},\n\t\t\
{\"mbtwsbD\",ssD}\n\t]\n]"
}], "Input"]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1920}, {0, 1027}},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{935, 715},
WindowMargins->{{110, Automatic}, {Automatic, 31}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"]}, {None, Inherited, None}},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {36, 36}},
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False},
CellLabelAutoDelete->True,
DockedCells -> FEPrivate`FrontEndResource[ "FEExpressions", \
"CompatibilityToolbar"],
StyleDefinitions -> "Default.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 106, 3, 73, "Section"],

Cell[CellGroupData[{
Cell[1907, 60, 58, 0, 38, "Subsection"],
Cell[1968, 62, 118, 3, 33, "Text"],
Cell[2089, 67, 284, 8, 102, "Input"],

Cell[CellGroupData[{
Cell[2398, 79, 210, 4, 52, "Text"],
Cell[2611, 85, 106, 1, 30, "Input"],
Cell[2720, 88, 106, 3, 30, "Input"],
Cell[2829, 93, 1163, 22, 336, "Input"],
Cell[3995, 117, 45, 4, 66, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4077, 126, 193, 4, 52, "Text"],
Cell[4273, 132, 589, 10, 130, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[4899, 147, 174, 3, 49, "Text"],
Cell[5076, 152, 792, 13, 210, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[5905, 170, 43, 0, 30, "Text"],
Cell[5951, 172, 32, 0, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[6020, 177, 54, 0, 30, "Text"],
Cell[6077, 179, 40, 0, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[6154, 184, 61, 0, 30, "Text"],
Cell[6218, 186, 28, 0, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[6283, 191, 40, 0, 30, "Text"],
Cell[6326, 193, 220, 4, 70, "Input"],
Cell[6549, 199, 161, 3, 70, "Input"],
Cell[6713, 204, 109, 3, 70, "Input"],
Cell[6825, 209, 235, 4, 70, "Input"],
Cell[7063, 215, 151, 3, 70, "Input"],
Cell[7217, 220, 338, 6, 70, "Input"],
Cell[7558, 228, 299, 5, 70, "Input"],
Cell[7860, 235, 134, 3, 70, "Input"],
Cell[7997, 240, 155, 3, 70, "Input"],
Cell[8155, 245, 118, 3, 70, "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8322, 254, 37, 0, 38, "Subsection"],
Cell[8362, 256, 71, 0, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[8470, 261, 68, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[8563, 265, 45, 0, 70, "Subsubsection"],
Cell[8611, 267, 2240, 58, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10888, 330, 71, 0, 70, "Subsubsection"],
Cell[10962, 332, 1213, 25, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12212, 362, 86, 1, 70, "Subsubsection"],
Cell[12301, 365, 380, 7, 70, "Text"],
Cell[12684, 374, 2662, 68, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15383, 447, 52, 0, 70, "Subsubsection"],
Cell[15438, 449, 341, 6, 70, "Text"],
Cell[15782, 457, 1261, 30, 70, "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[17092, 493, 35, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[17152, 497, 136, 3, 33, "Text"],
Cell[17291, 502, 91, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17419, 508, 112, 3, 33, "Text"],
Cell[17534, 513, 939, 16, 210, "Input"],
Cell[18476, 531, 124, 2, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[18637, 538, 98, 2, 30, "Text"],
Cell[18738, 542, 86, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18861, 548, 171, 3, 33, "Text"],
Cell[19035, 553, 111, 3, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19183, 561, 59, 0, 33, "Text"],
Cell[19245, 563, 120, 6, 102, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[19402, 574, 114, 3, 30, "Text"],
Cell[19519, 579, 56, 0, 70, "Input"],
Cell[19578, 581, 58, 0, 70, "Input"],
Cell[19639, 583, 58, 0, 70, "Input"],
Cell[19700, 585, 58, 0, 70, "Input"],
Cell[19761, 587, 62, 0, 70, "Input"],
Cell[19826, 589, 56, 0, 70, "Input"],
Cell[19885, 591, 68, 0, 70, "Input"],
Cell[19956, 593, 60, 0, 70, "Input"],
Cell[20019, 595, 62, 0, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[20118, 600, 38, 0, 30, "Text"],
Cell[20159, 602, 57, 0, 30, "Input"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[20255, 607, 27, 0, 30, "Input"],

Cell[CellGroupData[{
Cell[20307, 611, 59, 0, 38, "Subsection"],
Cell[20369, 613, 35, 0, 30, "Input"],

Cell[CellGroupData[{
Cell[20429, 617, 74, 1, 33, "Text"],

Cell[CellGroupData[{
Cell[20528, 622, 136, 4, 30, "Input"],
Cell[20667, 628, 207, 3, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[20923, 637, 54, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[21002, 641, 196, 12, 210, "Input"],
Cell[21201, 655, 584, 15, 121, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[21834, 676, 47, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[21906, 680, 214, 12, 70, "Input"],
Cell[22123, 694, 293, 9, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[22465, 709, 34, 0, 30, "Text"],

Cell[CellGroupData[{
Cell[22524, 713, 108, 3, 70, "Input"],
Cell[22635, 718, 50, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22722, 724, 108, 3, 70, "Input"],
Cell[22833, 729, 50, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22920, 735, 94, 2, 70, "Input"],
Cell[23017, 739, 42, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23096, 745, 96, 2, 70, "Input"],
Cell[23195, 749, 42, 1, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[23286, 756, 51, 0, 30, "Text"],

Cell[CellGroupData[{
Cell[23362, 760, 58, 0, 30, "Input"],
Cell[23423, 762, 76, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23536, 768, 58, 0, 30, "Input"],
Cell[23597, 770, 76, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23710, 776, 46, 0, 30, "Input"],
Cell[23759, 778, 55, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23851, 784, 48, 0, 30, "Input"],
Cell[23902, 786, 54, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[24005, 793, 50, 0, 33, "Text"],
Cell[24058, 795, 168, 6, 70, "Input"],
Cell[24229, 803, 129, 3, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[24395, 811, 41, 0, 30, "Text"],

Cell[CellGroupData[{
Cell[24461, 815, 18, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[24504, 819, 27, 0, 30, "Input"],
Cell[24534, 821, 53, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24624, 827, 93, 1, 30, "Input"],
Cell[24720, 830, 464, 12, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25221, 847, 245, 4, 30, "Input"],
Cell[25469, 853, 33058, 733, 278, 6757, 404, "GraphicsData", "PostScript", \
"Graphics"],
Cell[58530, 1588, 243, 5, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[58822, 1599, 18, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[58865, 1603, 27, 0, 30, "Input"],
Cell[58895, 1605, 53, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[58985, 1611, 93, 1, 30, "Input"],
Cell[59081, 1614, 467, 12, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[59585, 1631, 363, 6, 70, "Input"],
Cell[59951, 1639, 41538, 834, 294, 6571, 398, "GraphicsData", "PostScript", \
"Graphics"],
Cell[101492, 2475, 243, 5, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[101784, 2486, 18, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[101827, 2490, 27, 0, 30, "Input"],
Cell[101857, 2492, 53, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[101947, 2498, 93, 1, 30, "Input"],
Cell[102043, 2501, 460, 12, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[102540, 2518, 184, 3, 50, "Input"],
Cell[102727, 2523, 39925, 851, 296, 7724, 449, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[142701, 3380, 18, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[142744, 3384, 27, 0, 30, "Input"],
Cell[142774, 3386, 53, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[142864, 3392, 93, 1, 30, "Input"],
Cell[142960, 3395, 413, 11, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[143410, 3411, 184, 3, 50, "Input"],
Cell[143597, 3416, 31209, 743, 296, 7661, 448, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[174855, 4165, 18, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[174898, 4169, 27, 0, 30, "Input"],
Cell[174928, 4171, 52, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[175017, 4177, 93, 1, 30, "Input"],
Cell[175113, 4180, 416, 11, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[175566, 4196, 196, 4, 50, "Input"],
Cell[175765, 4202, 30312, 471, 296, 1391, 109, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[206126, 4679, 18, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[206169, 4683, 27, 0, 30, "Input"],
Cell[206199, 4685, 53, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[206289, 4691, 93, 1, 30, "Input"],
Cell[206385, 4694, 466, 12, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[206888, 4711, 196, 4, 50, "Input"],
Cell[207087, 4717, 49765, 934, 296, 6556, 396, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[256925, 5659, 58, 0, 38, "Subsection"],
Cell[256986, 5661, 34, 0, 30, "Input"],

Cell[CellGroupData[{
Cell[257045, 5665, 74, 1, 33, "Text"],

Cell[CellGroupData[{
Cell[257144, 5670, 133, 3, 30, "Input"],
Cell[257280, 5675, 207, 3, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[257536, 5684, 54, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[257615, 5688, 194, 12, 210, "Input"],
Cell[257812, 5702, 584, 15, 121, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[258445, 5723, 47, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[258517, 5727, 212, 12, 210, "Input"],
Cell[258732, 5741, 293, 9, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[259074, 5756, 34, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[259133, 5760, 107, 3, 70, "Input"],
Cell[259243, 5765, 50, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[259330, 5771, 107, 3, 70, "Input"],
Cell[259440, 5776, 50, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[259527, 5782, 93, 2, 70, "Input"],
Cell[259623, 5786, 42, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[259702, 5792, 95, 2, 70, "Input"],
Cell[259800, 5796, 42, 1, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[259891, 5803, 51, 0, 30, "Text"],

Cell[CellGroupData[{
Cell[259967, 5807, 57, 0, 70, "Input"],
Cell[260027, 5809, 76, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[260140, 5815, 57, 0, 70, "Input"],
Cell[260200, 5817, 76, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[260313, 5823, 45, 0, 70, "Input"],
Cell[260361, 5825, 55, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[260453, 5831, 47, 0, 70, "Input"],
Cell[260503, 5833, 54, 1, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[260606, 5840, 41, 0, 30, "Text"],

Cell[CellGroupData[{
Cell[260672, 5844, 18, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[260715, 5848, 26, 0, 30, "Input"],
Cell[260744, 5850, 53, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[260834, 5856, 92, 1, 30, "Input"],
Cell[260929, 5859, 465, 12, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[261431, 5876, 171, 3, 50, "Input"],
Cell[261605, 5881, 31916, 695, 296, 6178, 373, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[293570, 6582, 18, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[293613, 6586, 26, 0, 30, "Input"],
Cell[293642, 6588, 53, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[293732, 6594, 92, 1, 30, "Input"],
Cell[293827, 6597, 467, 12, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[294331, 6614, 171, 3, 50, "Input"],
Cell[294505, 6619, 41515, 834, 296, 6568, 398, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[336069, 7459, 18, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[336112, 7463, 26, 0, 30, "Input"],
Cell[336141, 7465, 53, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[336231, 7471, 92, 1, 30, "Input"],
Cell[336326, 7474, 462, 12, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[336825, 7491, 179, 3, 50, "Input"],
Cell[337007, 7496, 40521, 845, 296, 7437, 432, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[377577, 8347, 18, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[377620, 8351, 26, 0, 30, "Input"],
Cell[377649, 8353, 53, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[377739, 8359, 92, 1, 30, "Input"],
Cell[377834, 8362, 413, 11, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[378284, 8378, 179, 3, 50, "Input"],
Cell[378466, 8383, 31209, 743, 296, 7661, 448, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[409724, 9132, 18, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[409767, 9136, 26, 0, 30, "Input"],
Cell[409796, 9138, 52, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[409885, 9144, 92, 1, 30, "Input"],
Cell[409980, 9147, 413, 11, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[410430, 9163, 191, 4, 50, "Input"],
Cell[410624, 9169, 34094, 607, 296, 3420, 224, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[444767, 9782, 18, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[444810, 9786, 26, 0, 30, "Input"],
Cell[444839, 9788, 53, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[444929, 9794, 92, 1, 30, "Input"],
Cell[445024, 9797, 466, 12, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[445527, 9814, 191, 4, 50, "Input"],
Cell[445721, 9820, 49765, 934, 296, 6556, 396, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[495559, 10762, 58, 0, 33, "Text"],
Cell[495620, 10764, 34, 0, 30, "Input"],
Cell[495657, 10766, 39, 0, 30, "Input"],
Cell[495699, 10768, 383, 9, 174, "Input"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

