(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    598097,      12038]*)
(*NotebookOutlinePosition[    599362,      12077]*)
(*  CellTagsIndexPosition[    599318,      12073]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
The recalculation of the two-wire simple model with blades - V3.0- LOS values\
\
\>", "Section"],

Cell[CellGroupData[{

Cell["Switches, version numbers, paths etc", "Subsection"],

Cell["\<\
Switches to enable loading of previously saved results instead of \
recalculating from scratch\
\>", "Text"],

Cell["\<\
useprecomputed = False; (* set to True to use saved results from precomputed \
subdirectory *)
If[useprecomputed,
\texceptdamping = False, (* False by default, True to recalculate just \
damping-dependent stuff *)
\texceptdamping = True (* DON\"T CHANGE *)
];\
\>", "Input"],

Cell[CellGroupData[{

Cell["\<\
Definition of the current case - label, descriptive comment, and \
specification in terms of overrides relative to the default parameters
**** EDIT THIS SECTION TO DEFINE A NEW CASE ****\
\>", "Text"],

Cell["modelcase = \"IBS\";", "Input",
  CellChangeTimes -> {{3.451735605084487*^9, 3.451735610137718*^9}}],

Cell["\<\
modelcasecomment = \"LIGO-I ETM, SOS with blades creating the \
Undulators....\";\
\>", "Input"],

Cell["\<\
overrides = {
\ttx -> 0.0127,              (* thickness of optic, 1inch *)
\ttr -> (68.2*10^-3)/2,     (* radius of optic, 3inch diameter *)
\tm0 -> 124*10^-3,          (* mass of the compound 2\" mirror and holder *)
\tl0 -> 0.094,               (* wire length *)
\tr0 -> (127*10^-6)/2,      (* radius of wire, not critical can be adjusted
\t\t\t\t\t available diameters: 101um, 113um, 127um, 143um, 160um, 
\t\t\t\t\t\t\t\t\t180um, 202um, 310um, 355um, 370um *)

\tdpitch -> 3*10^-3,        (* height of wire break-off above c.o.m. *)
\tdyaw1 -> 35*10^-3,        (* y-separation of wires at structure *)
\tdyaw2 -> 76.2*10^-3,  (* y-separation of wires at optic, 
\t\t\t\t\t\t\t\toptic diameter + 2*1mm standoffs *)
\tkbz -> 75,\t\t\t\t  (* per-blade elastic constant in N/m *)
\tI0y -> 48.6*10^-6,        (* moment of inertia (longitudinal, pitch) *)
\tI0z -> 50.9*10^-6,         (* moment of inertia (yaw) *)
\tI0x -> 91.5*10^-6\t\t\t(* moment of inertia (roll) *)
};\
\>", "Input",
  CellChangeTimes -> {{3.451735653241503*^9, 3.451735656671795*^9}, \
{3.451736835316125*^9, 3.451736838490003*^9}, {3.451736880785919*^9, \
3.45173688180026*^9}}],

Cell["\<\
nonoptvars = {
\t
};\
\>", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The path in which the core model definition and model-specific support files \
are installed. 
**** EDIT THE PATHS AND/OR ADD CLAUSES FOR NEW SYSTEMS AS APPROPRIATE ****\
\>", "Text"],

Cell[BoxData[
    \(\(modeldirectory\  = \ 
        Switch[\[IndentingNewLine]$System, \[IndentingNewLine]"\<Power \
Macintosh\>", \
"\<Boadicea:Users:mbarton:Work:LIGO:analysis:AdvLIGOModel:twowiresimpleblades:\
current\>", \[IndentingNewLine]"\<Mac OS X x86 (32-bit)\>", \
"\</Users/slagmolen/Documents/mathematica/pendmodels/TwoWireSimpleBlades/\
current\>", \[IndentingNewLine]"\<Microsoft Windows\>", \
"\<C:\winslagmolen\mathematica\pendmodels\TwoWireSimpleBlades\current\>"\
\[IndentingNewLine]];\)\)], "Input",
  CellChangeTimes -> {{3.4517175049427156`*^9, 3.451717517645606*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
The path in which custom packages are installed (if different from above). 
**** EDIT THE PATHS AND/OR ADD CLAUSES FOR NEW SYSTEMS AS APPROPRIATE ****\
\>", "Text"],

Cell[BoxData[
    \(\(modelsupportdirectory\  = \ 
        Switch[\[IndentingNewLine]$System, \[IndentingNewLine]"\<Power \
Macintosh\>", "\<Boadicea:Users:mbarton:Work:MathLib\>", \[IndentingNewLine]"\
\<Mac OS X\>", "\</Users/slagmolen/Documents/pendtoolkit/v60\>", \
\[IndentingNewLine]"\<Mac OS X x86 (32-bit)\>", \
"\</Users/slagmolen/Documents/mathematica/pendtoolkit/v60\>", \
\[IndentingNewLine]"\<Solaris\>", "\</home/mbarton/MathLib\>", \
\[IndentingNewLine]"\<Linux\>", "\</home/mbarton/MathLib\>", \
\[IndentingNewLine]"\<Linux x86 (64 bit)\>", "\</home/mbarton/MathLib\>", \
\[IndentingNewLine]"\<Microsoft Windows\>", \
"\<C:\winslagmolen\mathematica\pendtoolkit\v50\>"\[IndentingNewLine]];\)\)], \
"Input",
  CellChangeTimes -> {{3.4517370857194138`*^9, 3.451737105314629*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Enable the mode shape plots", "Text"],

Cell["doplots = True;", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Enable export of state space to Matlab", "Text"],

Cell["domatlabexport = False;", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["The number of interesting low frequency modes", "Text"],

Cell["noofLF = 6;", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Usage notes for switches", "Text"],

Cell["\<\
useprecomputed::usage = \"useprecomputed is a switch variable which, when set \
to True, causes results to be read in from files in the data subdirectory \
rather than being calculated afresh.\";\
\>", "Input"],

Cell["\<\
domatlabexport::usage = \"domatlabexport is a switch variable which enables \
the calculation of the state space matrices for Matlab.\";\
\>", "Input"],

Cell["\<\
doplots::usage = \"doplots is a switch variable which enables mode shape \
plots.\";\
\>", "Input"],

Cell["\<\
modelcase::usage = \"modelcase is a string that serves as a label for the \
case of the model currently being calculated, as well as as a name for the \
subdirectory where the files for that case are stored.\";\
\>", "Input"],

Cell["\<\
modelcasecomment::usage = \"modelcasecomment is a string that describes the \
case of the model currently being calculated.\";\
\>", "Input"],

Cell["\<\
modeldirectory::usage = \"modeldirectory is a string (in the format \
appropriate for the local filesystem) that specifies the directory where the \
model definition files (ASUS3ModelDefn.nb and ASUS3ModelDefn.m) is stored. \
The files for particular cases will be stored in subdirectories of this \
directory.\";\
\>", "Input"],

Cell["\<\
modelsupportdirectory::usage = \"modelsupportdirectory is a string (in the \
format appropriate for the local filesystem) that specifies the directory \
where additional support files (e.g., StatusWindow.nb/StatusWindow.m) are \
stored (if different from modeldirectory).\";\
\>", "Input"],

Cell["\<\
overrides::usage = \"overrides is a list of substitutions that modify or \
replace those in defaultvalues.\";\
\>", "Input"],

Cell["\<\
nonoptvars::usage = \"nonoptvars is a list of variables that should be held \
frozen for debugging purpose in the optimization.\";\
\>", "Input"],

Cell["\<\
noofLF::usage = \"noofLF should be set to the number of interesting low \
frequency modes.\";\
\>", "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Version history", "Subsection"],

Cell["See matching ASUS4ModelDefn.nb in directory above this.", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Instructions", "Subsection"]], "Subsection"],

Cell[CellGroupData[{

Cell["Initial installation", "Subsubsection"],

Cell[TextData[{
  "1. Check the assignment to ",
  StyleBox["modelcase",
    FontFamily->"Courier"],
  " in the Switches sextion above. It should correspond to the name of the \
directory in which this copy of ",
  StyleBox["ASUS4ModelCalcXXX.nb",
    FontFamily->"Courier"],
  " is installed.\n2. Check the assignment to ",
  StyleBox["modeldirectory",
    FontFamily->"Courier"],
  " in the Switches section above. Check that there is a case in the ",
  StyleBox["Switch[]", "Program"],
  " statement corresponding to the value of ",
  StyleBox["$System", "Program"],
  " for your version of ",
  StyleBox["Mathematica,",
    FontSlant->"Italic"],
  " and if not, create one. The value returned for that case should be a \
string giving an absolute path to the root directory for the quad pendulum \
model. The model root directory will be the parent of the one containing this \
copy of ASUS4ModelCalc.nb and contains the factory version of ",
  StyleBox["A",
    FontFamily->"Courier"],
  "SUS4",
  StyleBox["ModelDefn.nb",
    FontFamily->"Courier"],
  ", ",
  StyleBox["A",
    FontFamily->"Courier"],
  "SUS4",
  StyleBox["ModelDefn.m",
    FontFamily->"Courier"],
  ", and various other definition and support files. The path string should \
be in the particular standard syntax for your OS (e.g., slash-delimited for \
Unix, colon-delimited for Mac, etc).\n3. Check the assignment to ",
  StyleBox["modelsupportdirectory",
    FontFamily->"Courier"],
  " in the Switches section above. Check that there is a case in the Switch[] \
statement corresponding to the value of $System for your version of ",
  StyleBox["Mathematica,",
    FontSlant->"Italic"],
  " and if not, create one. The value returned for that case should be a \
string giving an absolute path to the directory where you have placed the \
custom packages  ",
  StyleBox["RotationsXYZ.nb",
    FontFamily->"Courier"],
  ", ",
  StyleBox["RotationsXYZ.m",
    FontFamily->"Courier"],
  ", ",
  StyleBox["MyShapes.nb",
    FontFamily->"Courier"],
  " and ",
  StyleBox["MyShapes.m",
    FontFamily->"Courier"],
  ".  The path string should be in the particular standard syntax for your OS \
(e.g., slash-delimited for Unix, colon-delimited for Mac, etc)."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["To do calculations with the precomputed values", "Subsubsection"],

Cell[TextData[{
  "1. Check sure that this directory contains a ",
  StyleBox["precomputed",
    FontFamily->"Courier"],
  " subdirectory with various saved results (",
  StyleBox["allparams.m",
    FontFamily->"Courier"],
  " etc). If the directory is empty, there are no precomputed results and you \
will need to do the full calculation.\n2. If there are precomputed results, \
look for an assignment statement to the variable ",
  StyleBox["precomputed",
    FontFamily->"Courier"],
  " at the very beginning of this file and make sure that it is set to ",
  StyleBox["True",
    FontFamily->"Courier"],
  ". (Otherwise set it to ",
  StyleBox["False",
    FontFamily->"Courier"],
  " to force the full calculation)\n3. Evaluate cells in this notebook in \
order from the top. If the wire bending elasticity is not of interest, you \
can stop after the sections \"Stage 0 of the computation\" and \"Listings and \
plots with Stage 0 data\". The final two sections, \"Stages 1 and 2\" and \
\"Listings and plots with Stage 2 data\" take much longer to run.\n4. View \
the output in the \"Listings and plots\" sections. Add commands for new \
listings and plots using the examples there as a guide."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["To try different values with the same basic model structure", \
"Subsubsection"],

Cell[TextData[{
  "Many interesting variations can be implemented by just defining overrides \
to some or all of the default values of constants in the substitution list ",
  StyleBox["defaultvalues",
    FontFamily->"Courier"],
  ".Use this method where possible so that differences are confined to one \
well-defined spot in the code.To do this, proceed as follows:"
}], "Text"],

Cell[TextData[{
  "1. If you want to preserve the results from the current variation, (i) \
duplicate the entire directory containing containing this file, (ii) give the \
new directory a name reflecting the variation you're going to try, e.g., ",
  StyleBox["heavieroptic",
    FontFamily->"Courier"],
  ",  (iii) rename the new copy of this file to include some or all of the \
case name (e.g., ",
  StyleBox["A",
    FontFamily->"Courier"],
  "SUS4",
  StyleBox["ModelCalcDefault.nb",
    FontFamily->"Courier"],
  " -> ",
  StyleBox["A",
    FontFamily->"Courier"],
  "SUS4",
  StyleBox["ModelCalcHeavierOptic.nb",
    FontFamily->"Courier"],
  "), (iv) close this file and continue from here new copy in the new \
directory, (iv) (you should be in the new copy now) edit the assignment to ",
  StyleBox["modelcase",
    FontFamily->"Courier"],
  " in the Switches section above to correspond to the new directory name, \
and (v) edit the assignment to ",
  StyleBox["modelcasecomment",
    FontFamily->"Courier"],
  " in the Switches section to describe the new case.\n2. Edit the assignment \
to ",
  StyleBox["overrides",
    FontFamily->"Courier"],
  " in the Switches section above, adding, removing or changing overrides to \
reflect whatever new configuration you want. For example, ",
  StyleBox["m3->80",
    FontFamily->"Courier"],
  " will set the optic mass to 80 kg, ",
  StyleBox["m3->scale[2",
    FontFamily->"Courier"],
  "] will double it from what ever it was, and ",
  StyleBox["m3->increment[5",
    FontFamily->"Courier"],
  "] will add 5 kg.\n3. Edit the assignment to ",
  StyleBox["useprecomputed",
    FontFamily->"Courier"],
  " in the Switches section above to make it set ",
  StyleBox["useprecomputed",
    FontFamily->"Courier"],
  " to ",
  StyleBox["False",
    FontFamily->"Courier"],
  ".\n4. Delete all the saved result files in the ",
  StyleBox["precomputed",
    FontFamily->"Courier"],
  " subdirectory (of the new copy!).\n5. Select all the cells in this \
notebook and evaluate them.WARNING: recomputing the whole notebook takes \
several hours. Stage 0 is about 3 minutes, Stage 1 is about an hour, Stage 2 \
is about two hours, and the full collection of listings and plots at the end \
are a few minutes. Depending on what precision you want, you might be able to \
get away with evaluating only Stages 0 and 1, or only Stage 0.\n6. Edit the \
assignment to ",
  StyleBox["useprecomputed",
    FontFamily->"Courier"],
  " in the Switches section above to make it set ",
  StyleBox["useprecomputed",
    FontFamily->"Courier"],
  " to ",
  StyleBox["True", "Program"],
  ". Evaluate it. Save the file."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["To hack the model structure", "Subsubsection"],

Cell["\<\
Some changes, such as adding asymmetries, are too radical to be implemented \
by overriding values. And sometimes, as in starting a design for a new optic, \
you want to make a new set of default values to avoid having to override \
ridiculous numbers of them. In such cases the model definition needs to be \
hacked.\
\>", "Text"],

Cell[TextData[{
  "1. Duplicate the entire directory containing this file and edit the \
assignments to ",
  StyleBox["modelcase",
    FontFamily->"Courier"],
  " and ",
  StyleBox["modelcasecomment", "Program"],
  " in the new copy of this file as explained in \"To try different values \
with the same basic model structure\", step 1, above.\n2. Make a local copy \
of ",
  StyleBox["A",
    FontFamily->"Courier"],
  "SUS4",
  StyleBox["ModelDefn.nb",
    FontFamily->"Courier"],
  " in the new directory (e.g., by copying it from the factory version in the \
model root directory one level above).\n3. Hack the local copy to change the \
structure of the model as desired (this is left as an exercise for the \
reader).\n4. PUT CONSPICUOUS COMMENTS AT THE TOP OF THE NEW MODEL SAYING HOW \
IT DIFFERS FROM THE FACTORY VERSION!\n5. Continue from Step 2 of \"To try \
different values with the same basic model structure\" above. ",
  StyleBox["ASUS4ModelCalc.nb",
    FontFamily->"Courier"],
  " will find the customized version of ",
  StyleBox["ASUS4ModelDefn.m",
    FontFamily->"Courier"],
  " because it looks in its own directory (specified by ",
  StyleBox["modelcase",
    FontFamily->"Courier"],
  ") before checking the root directory."
}], "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Preliminaries", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
The directory in which this copy of ASUSModelCalc.nb and the other files \
associated with this case are stored.\
\>", "Text"],

Cell[BoxData[
    \(\(SetDirectory[ToFileName[{modeldirectory, modelcase}]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The path in which the model definition and model-specific support files are \
installed.\
\>", "Text"],

Cell[BoxData[
    \( (*Clear[$Path]\[IndentingNewLine]$Path = \
{"\</Applications/Mathematica.app/SystemFiles/Links\>", \
"\</Users/slagmolen/Library/Mathematica/Kernel\>", \
"\</Users/slagmolen/Library/Mathematica/Autoload\>", \
"\</Users/slagmolen/Library/Mathematica/Applications\>", \
"\</Library/Mathematica/Kernel\>", "\</Library/Mathematica/Autoload\>", \
"\</Library/Mathematica/Applications\>", "\<.\>", "\</Users/slagmolen\>", \
"\</Applications/Mathematica.app/AddOns/Packages\>", \
"\</Applications/Mathematica.app/AddOns/LegacyPackages\>", \
"\</Applications/Mathematica.app/SystemFiles/Autoload\>", \
"\</Applications/Mathematica.app/AddOns/Autoload\>", \
"\</Applications/Mathematica.app/AddOns/Applications\>", \
"\</Applications/Mathematica.app/AddOns/ExtraPackages\>", \
"\</Applications/Mathematica.app/SystemFiles/Kernel/Packages\>", \
"\</Applications/Mathematica.app/Documentation/English/System\>"}*) \)], \
"Input"],

Cell[BoxData[
    \(\($Path\  = \ Append[$Path, modeldirectory];\)\)], "Input",
  CellChangeTimes -> {3.451736698892377*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
The path in which custom packages are installed (if different from above).\
\>", "Text"],

Cell[BoxData[
    \(\($Path\  = \ Append[$Path, modelsupportdirectory];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Read in the model definition. First look for a customized model in the \
current directory, then look for the factory model in the directory above.\
\>", "Text"],

Cell["\<\
Get[\"TwoWireSimpleBladesDefn.m\",Path->{Directory[],ParentDirectory[\
Directory[]]}];\
\>", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Check that core model is loaded and correct", "Text"],

Cell["\<\
If[
\tmodelcomment!=\"Two-wire simple pendulum with blades\"
\t||modelversion<3.0,
\tAbort[]
];\
\>", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Archive some stuff that doesn't get recomputed here, just in case it's useful \
to look at\
\>", "Text"],

Cell["saveprecomputed[\"allvars.m\",allvars];", "Input"],

Cell["saveprecomputed[\"startpos.m\",startpos];", "Input"],

Cell["saveprecomputed[\"gravlist.m\",gravlist];", "Input"],

Cell["saveprecomputed[\"wirelist.m\",wirelist];", "Input"],

Cell["saveprecomputed[\"springlist.m\",springlist];", "Input"],

Cell["saveprecomputed[\"kinetic.m\",kinetic];", "Input"],

Cell["saveprecomputed[\"defaultvalues.m\",defaultvalues];", "Input"],

Cell["saveprecomputed[\"overrides.m\",overrides];", "Input"],

Cell["saveprecomputed[\"nonoptvars.m\",nonoptvars];", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Open the status window", "Text"],

Cell["OpenStatusWindow[WindowSize->{500,300}];", "Input"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell["Reset[All]", "Input"],

Cell[CellGroupData[{

Cell["Listings and plots with Stage 0A Data", "Subsection"],

Cell["Calculate[Stage0A]", "Input"],

Cell[CellGroupData[{

Cell["View the eigenfrequencies", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
Table[{Length[allvars]-index+1, Hz0A[[index]]}, {index, 1, \
Length[allvars]}]\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \({{6, 7.882747495950438`}, {5, 5.525695086716362`}, {4, 
        2.097818589556624`}, {3, 1.7003578401639126`}, {2, 
        1.6183374474849537`}, {1, 1.3350640708308175`}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["View the important low-frequency modes", "Text"],

Cell[CellGroupData[{

Cell["\<\
Join[\t
\t{{\"N\",\"f\",\"type\"}},
\tTable[
\t\tJoin[
\t\t\t{i},
\t\t\t{Hz0A[[-i]]},
\t\t\timportant[e2ni.eigenvectors0A[[-i]],0.7]
\t\t],
\t\t{i,noofLF}
\t]
]//TableForm\
\>", "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"N\"\>", "\<\"f\"\>", "\<\"type\"\>"},
          {"1", "1.3350640708308175`", "pitch0"},
          {"2", "1.6183374474849537`", "roll0"},
          {"3", "1.7003578401639126`", "pitch0"},
          {"4", "2.097818589556624`", "yaw0"},
          {"5", "5.525695086716362`", "z0"},
          {"6", "7.882747495950438`", "roll0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["View the higher frequency modes", "Text"],

Cell[CellGroupData[{

Cell["\<\
Join[\t
\t{{\"N\",\"f\",\"type\"}},
\tTable[
\t\tJoin[
\t\t\t{i},
\t\t\t{Hz0A[[-i]]},
\t\t\timportant[e2ni.eigenvectors0A[[-i]],0.7]
\t\t],
\t\t{i,noofLF+1,Length[allvars]}
\t]
]//TableForm\
\>", "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"N\"\>", "\<\"f\"\>", "\<\"type\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Classify the modes", "Text"],

Cell[CellGroupData[{

Cell["\<\
longpitchmodes0 = \
Select[Range[-noofLF,-1],longpitchQ[e2ni.eigenvectors0A[[#]]]&]\
\>", "Input"],

Cell[BoxData[
    \({\(-3\), \(-1\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
transrollmodes0 = \
Select[Range[-noofLF,-1],transrollQ[e2ni.eigenvectors0A[[#]]]&]\
\>", "Input"],

Cell[BoxData[
    \({\(-6\), \(-2\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
yawmodes0 = Select[Range[-noofLF,-1],yawQ[e2ni.eigenvectors0A[[#]]]&]\
\>", "Input"],

Cell[BoxData[
    \({\(-4\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
vertmodes0 = Select[Range[-noofLF,-1],vertQ[e2ni.eigenvectors0A[[#]]]&]\
\>", "Input"],

Cell[BoxData[
    \({\(-5\)}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["View the mode frequencies by groups", "Text"],

Cell[CellGroupData[{

Cell["longpitchfreqs0 = Hz0A[[longpitchmodes0]]", "Input"],

Cell[BoxData[
    \({1.7003578401639126`, 1.3350640708308175`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["transrollfreqs0 = Hz0A[[transrollmodes0]]", "Input"],

Cell[BoxData[
    \({7.882747495950438`, 1.6183374474849537`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["yawfreqs0 = Hz0A[[yawmodes0]]", "Input"],

Cell[BoxData[
    \({2.097818589556624`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["vertfreqs0 = Hz0A[[vertmodes0]]", "Input"],

Cell[BoxData[
    \({5.525695086716362`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Export stuff for Matlab comparison", "Text"],

Cell["\<\
longpitchfreqs00 = longpitchfreqs0;
transrollfreqs00 = transrollfreqs0;
yawfreqs00 = yawfreqs0;
vertfreqs00 = vertfreqs0;
constval0 = constval;\
\>", "Input"],

Cell["\<\
saveprecomputed[\"matlabcomp0.m\",longpitchfreqs00,transrollfreqs00,\
yawfreqs00,vertfreqs00,constval0];\
\>", "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Mode shape listings/plots", "Text"],

Cell[CellGroupData[{

Cell["#1", "Text"],

Cell[CellGroupData[{

Cell["Hz0A[[-1]]", "Input"],

Cell[BoxData[
    \(1.3350640708308175`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pretty[Chop[e2ni . eigenvectors0A[\([\(-1\)]\)], 10^\(-4\)]]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
          {"\<\"optic\"\>", "0.008768073422728836`", "0", "0", 
            "0", \(-0.9999615597053987`\), "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DoWithStatus["\<Plotting stage 0A mode 1\>", \ 
      eigenplot[eigenvectors0A[\([\(-1\)]\)],  .1, {0, \(-1\), 0}, \ 
        floatmatrix0A]]\)], "Input",
  CellChangeTimes -> {{3.4517357002801437`*^9, 3.451735738493672*^9}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 6.00564 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.50282 6.00564 0 6.00564 [
[ 0 0 0 0 ]
[ 1 6.00564 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 6.00564 L
s
0 6.00564 m
.19985 4.80542 L
s
.19985 4.80542 m
.19985 1.20023 L
s
.19985 1.20023 m
0 0 L
s
1 0 m
.80015 1.20023 L
s
.80015 1.20023 m
.80015 4.80542 L
s
.80015 4.80542 m
1 6.00564 L
s
1 6.00564 m
1 0 L
s
0 0 m
0 6.00564 L
s
0 6.00564 m
1 6.00564 L
s
1 6.00564 m
1 0 L
s
1 0 m
0 0 L
s
.19985 1.20023 m
.80015 1.20023 L
s
.80015 1.20023 m
.80015 4.80542 L
s
.80015 4.80542 m
.19985 4.80542 L
s
.19985 4.80542 m
.19985 1.20023 L
s
0 0 m
1 0 L
1 6.00564 L
0 6.00564 L
closepath
clip
newpath
.5 Mabswid
.71 .502 .606 r
.38801 3.51235 m .60595 3.53422 L .6233 3.35116 L p F P
0 g
s
.5095 3.42912 m
.50975 3.38563 L
s
.71 .502 .606 r
.6233 3.35116 m .40675 3.32943 L .38801 3.51235 L p F P
0 g
s
.691 .643 .798 r
.40675 3.32943 m .6233 3.35116 L .64223 3.17256 L p F P
0 g
s
.691 .643 .798 r
.64223 3.17256 m .4243 3.15069 L .40675 3.32943 L p F P
0 g
s
.707 .577 .707 r
.5 4.97546 m .75863 4.97546 L p .24137 4.71682 L F P
0 g
s
.707 .577 .707 r
.75863 4.97546 m .75863 4.71682 L .24137 4.71682 L p F P
0 g
s
.707 .577 .707 r
.24137 4.71682 m .24137 4.97546 L .5 4.97546 L p F P
0 g
s
.752 .614 .046 r
.24137 4.97546 m .24137 4.71682 L .20782 4.93912 L p F P
0 g
s
0 0 .046 r
.75863 4.71682 m .75863 4.97546 L .77438 5.09559 L p F P
0 g
s
0 0 .046 r
.79218 4.93912 m .75863 4.71682 L p .77438 5.09559 L F P
0 g
s
.282 0 0 r
.75863 4.71682 m .79218 4.93912 L .20782 4.93912 L p F P
0 g
s
.282 0 0 r
.20782 4.93912 m .24137 4.71682 L .75863 4.71682 L p F P
0 g
s
.5 5.09559 m
.50089 4.93912 L
s
.5017 4.79667 m
.50279 4.60538 L
s
.752 .614 .046 r
.22562 5.09559 m .24137 4.97546 L p .20782 4.93912 L F P
0 g
s
.679 .331 .378 r
.36922 3.68818 m .59127 3.71046 L .60595 3.53422 L p F P
0 g
s
.50854 3.59757 m
.50895 3.52448 L
s
.679 .331 .378 r
.60595 3.53422 m .38801 3.51235 L .36922 3.68818 L p F P
0 g
s
.615 .739 .935 r
.4243 3.15069 m .64223 3.17256 L .6616 3.00955 L p F P
0 g
s
.615 .739 .935 r
.6616 3.00955 m .43954 2.98727 L .4243 3.15069 L p F P
0 g
s
.603 .141 .129 r
.35162 3.84486 m .58041 3.86782 L .59127 3.71046 L p F P
0 g
s
.50279 4.60538 m
.50704 3.86046 L
s
.50763 3.75737 m
.50794 3.7021 L
s
.603 .141 .129 r
.59127 3.71046 m .36922 3.68818 L .35162 3.84486 L p F P
0 g
s
.481 .775 .996 r
.43954 2.98727 m .6616 3.00955 L .68013 2.87385 L p F P
0 g
s
.481 .775 .996 r
.68013 2.87385 m .45134 2.8509 L .43954 2.98727 L p F P
0 g
s
.484 0 0 r
.33662 3.96903 m .5745 3.99289 L .58041 3.86782 L p F P
0 g
s
.484 0 0 r
.58041 3.86782 m .35162 3.84486 L .33662 3.96903 L p F P
0 g
s
.298 .738 .965 r
.45134 2.8509 m .68013 2.87385 L .69639 2.77801 L p F P
0 g
s
.298 .738 .965 r
.69639 2.77801 m .45851 2.75414 L .45134 2.8509 L p F P
0 g
s
.01 w
.38457 2.74092 Mdot
.5 Mabswid
.752 .614 .046 r
.20782 4.93912 m .20782 5.23129 L .22562 5.09559 L p F P
0 g
s
0 0 .046 r
.77438 5.09559 m .79218 5.23129 L .79218 4.93912 L p F P
0 g
s
.084 .63 .84 r
.45851 2.75414 m .69639 2.77801 L .70871 2.73496 L p F P
0 g
s
.084 .63 .84 r
.70871 2.73496 m .45988 2.70999 L .45851 2.75414 L p F P
0 g
s
.324 0 0 r
.32582 4.04622 m .57465 4.07119 L .5745 3.99289 L p F P
0 g
s
.324 0 0 r
.5745 3.99289 m .33662 3.96903 L .32582 4.04622 L p F P
0 g
s
.707 .577 .707 r
.5 5.23129 m .20782 5.23129 L .20782 4.93912 L p F P
0 g
s
.707 .577 .707 r
.79218 4.93912 m .79218 5.23129 L .5 5.23129 L p F P
0 g
s
.707 .577 .707 r
.20782 4.93912 m .79218 4.93912 L p .5 5.23129 L F P
0 g
s
.137 0 0 r
.45988 2.70999 m .70871 2.73496 L .71535 2.7563 L p F P
0 g
s
.137 0 0 r
.71535 2.7563 m .45451 2.73013 L .45988 2.70999 L p F P
0 g
s
.124 0 0 r
.32085 4.06232 m .58169 4.08849 L .57465 4.07119 L p F P
0 g
s
.124 0 0 r
.57465 4.07119 m .32582 4.04622 L .32085 4.06232 L p F P
0 g
s
.707 .577 .707 r
.5 5.28053 m .79863 5.28053 L p .20137 4.9819 L F P
0 g
s
.707 .577 .707 r
.79863 5.28053 m .79863 4.9819 L .20137 4.9819 L p F P
0 g
s
.707 .577 .707 r
.20137 4.9819 m .20137 5.28053 L .5 5.28053 L p F P
0 g
s
.752 .614 .046 r
.18017 5.44221 m .20137 5.28053 L p .15573 5.28433 L F P
0 g
s
.752 .614 .046 r
.20137 5.28053 m .20137 4.9819 L .15573 5.28433 L p F P
0 g
s
0 0 .046 r
.79863 4.9819 m .79863 5.28053 L .81983 5.44221 L p F P
0 g
s
0 0 .046 r
.84427 5.28433 m .79863 4.9819 L p .81983 5.44221 L F P
0 g
s
.282 0 0 r
.79863 4.9819 m .84427 5.28433 L .15573 5.28433 L p F P
0 g
s
.282 0 0 r
.15573 5.28433 m .20137 4.9819 L .79863 4.9819 L p F P
0 g
s
.344 0 0 r
.45451 2.73013 m .71535 2.7563 L .71472 2.84909 L p F P
0 g
s
.344 0 0 r
.71472 2.84909 m .442 2.82173 L .45451 2.73013 L p F P
0 g
s
.109 .645 .858 r
.32313 4.00655 m .59585 4.03391 L .58169 4.08849 L p F P
0 g
s
.109 .645 .858 r
.58169 4.08849 m .32085 4.06232 L .32313 4.00655 L p F P
0 g
s
.752 .614 .046 r
.15573 5.28433 m .15573 5.6286 L .18017 5.44221 L p F P
0 g
s
0 0 .046 r
.81983 5.44221 m .84427 5.6286 L .84427 5.28433 L p F P
0 g
s
.5 5.44221 m
.50113 5.28433 L
s
.01 w
.36361 2.69336 Mdot
.63639 2.69336 Mdot
.5 Mabswid
.519 0 0 r
.442 2.82173 m .71472 2.84909 L .70591 3.0114 L p F P
0 g
s
.519 0 0 r
.70591 3.0114 m .42296 2.98301 L .442 2.82173 L p F P
0 g
s
.35 .755 .983 r
.33336 3.87611 m .6163 3.90449 L .59585 4.03391 L p F P
0 g
s
.35 .755 .983 r
.59585 4.03391 m .32313 4.00655 L .33336 3.87611 L p F P
0 g
s
.647 .24 .259 r
.42296 2.98301 m .70591 3.0114 L .68921 3.22862 L p F P
0 g
s
.647 .24 .259 r
.68921 3.22862 m .39929 3.19953 L .42296 2.98301 L p F P
0 g
s
.556 .765 .975 r
.35102 3.68064 m .64094 3.70973 L .6163 3.90449 L p F P
0 g
s
.556 .765 .975 r
.6163 3.90449 m .33336 3.87611 L .35102 3.68064 L p F P
0 g
s
.50205 5.15672 m
.51226 3.73142 L
s
.708 .475 .569 r
.39929 3.19953 m .68921 3.22862 L .66649 3.47317 L p F P
0 g
s
.708 .475 .569 r
.66649 3.47317 m .37409 3.44383 L .39929 3.19953 L p F P
0 g
s
.682 .663 .826 r
.37409 3.44383 m .66649 3.47317 L .64094 3.70973 L p F P
0 g
s
.682 .663 .826 r
.64094 3.70973 m .35102 3.68064 L .37409 3.44383 L p F P
0 g
s
.51226 3.73142 m
.51364 3.53858 L
s
.707 .577 .707 r
.5 5.6286 m .15573 5.6286 L .15573 5.28433 L p F P
0 g
s
.707 .577 .707 r
.84427 5.28433 m .84427 5.6286 L .5 5.6286 L p F P
0 g
s
.707 .577 .707 r
.15573 5.28433 m .84427 5.28433 L p .5 5.6286 L F P
0 g
s
.25 Mabswid
0 0 m
0 6.00564 L
s
0 6.00564 m
1 6.00564 L
s
1 6.00564 m
1 0 L
s
1 0 m
0 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{37.4375, 224.813},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40000U0000h2000`400?l00000o`00003o9@3oool0
02D0oooo000U0000000000<000000?ooo`3oool08@3oool10000000000<000000?ooo`3oool08@3o
ool10000000000<000000?ooo`3oool08@3oool1000000000P00000Q0?ooo`800000000200000240
oooo0P000000008000008@3oool2000000000P00000Q0?ooo`800000000200000240oooo0P000000
008000008@3oool20000000000<000000?ooo`0000007`3oool100000040oooo0@00000000030000
003oool0000001l0oooo0@0000010?ooo`40000000000`000000oooo0000000O0?ooo`4000000@3o
ool10000000000<000000?ooo`0000007`3oool100000040oooo0@00000000030000003oool00000
01l0oooo0@0000010?ooo`40000000000`000000oooo0000000O0?ooo`4000000@3oool100000000
00@000000?ooo`3oool000007@3oool00`000000oooo0?ooo`010000000000@000000?ooo`3oool0
00007@3oool00`000000oooo0?ooo`010000000000@000000?ooo`3oool000007@3oool00`000000
oooo0?ooo`010000000000@000000?ooo`3oool000007@3oool00`000000oooo0?ooo`0100000000
00@000000?ooo`3oool000007@3oool00`000000oooo0?ooo`010000000000@000000?ooo`3oool0
00007@3oool00`000000oooo0?ooo`010000000000@000000?ooo`3oool00000703oool010000000
oooo0?ooo`3oool10000000000D000000?ooo`3oool0oooo0000000K0?ooo`040000003oool0oooo
0?ooo`40000000001@000000oooo0?ooo`3oool0000001/0oooo00@000000?ooo`3oool0oooo0@00
000000050000003oool0oooo0?ooo`0000006`3oool010000000oooo0?ooo`3oool10000000000D0
00000?ooo`3oool0oooo0000000K0?ooo`040000003oool0oooo0?ooo`40000000001@000000oooo
0?ooo`3oool0000001/0oooo00@000000?ooo`3oool0oooo0@00000000050000003oool0oooo0?oo
o`0000006`3oool010000000oooo0?ooo`3oool10000000000<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo0080oooo0@00000000030000003oool0oooo0080
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`020?ooo`40000000000`000000oooo
0?ooo`020?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool00P3oool10000000000<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0080oooo0@00
000000030000003oool0oooo0080oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`02
0?ooo`40000000000`000000oooo0?ooo`020?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool00P3oool10000000000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo00<0oooo0@00000000030000003oool0oooo00<0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool00`3oool10000000000<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00<0oooo0@00000000030000003oool0oooo
00<0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`030?ooo`40000000000`000000
oooo0?ooo`030?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00`3oool100000000
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo
0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`040?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0103oool10000000000<000000?ooo`3oool0103ooolG000000H0oooo0@0000000003
0000003oool0oooo00@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`40
000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
103oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo00@0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`040?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0103oool10000000000<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo0@00000000030000003oool0oooo00@0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`40000000000`000000oooo0?oo
o`040?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0103oool10000000000<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo0@000000
00030000003oool0oooo00@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?oo
o`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool0103oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo00@0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`040?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0103oool10000000000<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo0@00000000030000003oool0oooo00@0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`40000000000`000000oooo
0?ooo`040?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0103oool10000000000<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo0@00
000000030000003oool0oooo00@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`04
0?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0103oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo00@0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`040?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0103oool10000000000<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo0@00000000030000003oool0oooo
00@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`40000000000`000000
oooo0?ooo`040?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0103oool100000000
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo
0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`040?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0103oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo00@0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`040?ooo`40000000000`000000oooo0?ooo`040?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool0103oool10000000000<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo0@00000000030000003oool0
oooo00@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`40000000000`00
0000oooo0?ooo`040?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0103oool10000
000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0
oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`040?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0103oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo00@0oooo0@00000000030000003oool0oooo00@0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`040?ooo`40000000000`000000oooo0?ooo`040?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0103oool10000000000<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo0@00000000030000003o
ool0oooo00@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`4000000000
0`000000oooo0?ooo`040?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0103oool1
0000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
00@0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`040?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool0103oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo00@0oooo0@00000000030000003oool0oooo00@0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`40000000000`000000oooo0?ooo`040?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool0103oool10000000000<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo0@00000000030000
003oool0oooo00@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`400000
00000`000000oooo0?ooo`040?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0103o
ool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`40000000000`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo1@0000080?ooo`030000003oool0oooo
00@0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000
oooo00000009000000<0oooo00<000000?ooo`3oool0103oool10000000000<000000?ooo`3oool0
103oool00`000000oooo0?ooo`060?ooo`030000001H0000F0000080F0001P0000020?ooo`030000
003oool0oooo00@0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3o
ool00`000000F00005P0000705P000040000003oool0oooo000000H0oooo0@00000000030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01P3oool5000000D0F00000@000000?ooo`3oool00000
1P3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`0300000024
0000Q0000080Q0001P0000020?ooo`030000003oool0oooo00@0oooo0@00000000030000003oool0
oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000Q00008@0000708@000040000003oool0
oooo000000H0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool0
0`000000Q00008@0000808@000040000003oool0oooo000000H0oooo0@00000000030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000Q00008@0000708@000050000003oool0
oooo0?ooo`0000001P3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`03000000240000Q00000L0Q00000D000000?ooo`3oool0oooo000000060?ooo`4000000000
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo1@00000508@000050000003oool0
oooo0?ooo`0000001P3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`030000002U?D80YCe20080YCe21P0000030?ooo`030000003oool0oooo00@0oooo0@000000
00030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000YCe20:Dm@P070:Dm
@P050000003oool0oooo0?ooo`0000001P3oool10000000000<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`050?ooo`030000002U?D80YCe200L0YCe200D000000?ooo`3oool0oooo00000006
0?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000:Dm
@P2U?D80202U?D801@000000oooo0?ooo`3oool0000000H0oooo0@00000000030000003oool0oooo
00@0oooo00<000000?ooo`3oool0103oool00`000000YCe20:Dm@P080:Dm@P050000003oool0oooo
0?ooo`0000001P3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?oo
o`030000002U?D80YCe200P0YCe200D000000?ooo`3oool0oooo000000060?ooo`40000000000`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000:Dm@P2U?D80202U?D801@00
0000oooo0?ooo`3oool0000000H0oooo0@00000000030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool6000000D0YCe200D000000?ooo`3oool0oooo000000060?ooo`40000000000`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000;EiT@2eNI400`2eNI460000
00<0oooo00<000000?ooo`3oool0103oool10000000000<000000?ooo`3oool0103oool00`000000
oooo0?ooo`040?ooo`030000002eNI40]GVA00P0]GVA00D000000?ooo`3oool0oooo000000060?oo
o`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000;EiT@2e
NI40202eNI401@000000oooo0?ooo`3oool0000000H0oooo0@00000000030000003oool0oooo00@0
oooo00<000000?ooo`3oool0103oool00`000000]GVA0;EiT@080;EiT@050000003oool0oooo0?oo
o`0000001P3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`03
0000002eNI40]GVA00T0]GVA00D000000?ooo`3oool0oooo000000060?ooo`40000000000`000000
oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000;EiT@2eNI40202eNI400`000000
oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo0@00000000030000003oool0oooo00@0oooo
00<000000?ooo`3oool00`3oool00`000000]GVA0;EiT@080;EiT@030000003oool0oooo0080oooo
00<000000?ooo`3oool0103oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?oo
o`030?ooo`030000002eNI40]GVA00P0]GVA00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`040?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo1P000005
0;EiT@030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool10000000000<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`030000002^ZM<0[ZWC00<0[ZWC1P0000040?oo
o`030000003oool0oooo00@0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000[ZWC0:jYd`080:jYd`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0103oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000
002^ZM<0[ZWC0080[ZWC00<000000:jYd`2^ZM<00`2^ZM<00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00@0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3o
ool00`000000[ZWC0:jYd`030:jYd`030000002^ZM<0[ZWC00<0[ZWC00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`040?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0
oooo0080oooo00<000000:jYd`2^ZM<00`2^ZM<00`000000[ZWC0:jYd`020:jYd`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0103oool10000000000<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`020?ooo`030000002^ZM<0[ZWC00<0[ZWC00<000000:jYd`2^ZM<00P2^ZM<00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo0@00000000030000003oool0oooo00@0
oooo00<000000?ooo`3oool00P3oool00`000000[ZWC0:jYd`030:jYd`030000002^ZM<0[ZWC0080
[ZWC00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`40000000000`000000oooo
0?ooo`040?ooo`030000003oool0oooo0080oooo1`0000040:jYd`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?oo
o`020?ooo`030000002>`oT0S/?i00<0S/?i1P0000050?ooo`030000003oool0oooo00@0oooo0@00
000000030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000S/?i08k3n@03
08k3n@030000002>`oT0S/?i0080S/?i00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`04
0?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<0000008k3
n@2>`oT00`2>`oT00`000000S/?i08k3n@0208k3n@030000003oool0oooo00<0oooo00<000000?oo
o`3oool0103oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`03
0000002>`oT0S/?i00<0S/?i00<0000008k3n@2>`oT00P2>`oT00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00@0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0P3oool00`000000S/?i08k3n@0308k3n@050000002>`oT0S/?i08k3n@0000001P3oool00`000000
oooo0?ooo`040?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo
00<0000008k3n@2>`oT00`2>`oT01@000000S/?i08k3n@2>`oT0000000H0oooo00<000000?ooo`3o
ool0103oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`D00000
00<0S/?i0000002>`oT00P2>`oT00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000FL7k05W1
n`0205W1n`H000001P3oool00`000000oooo0?ooo`040?ooo`40000000000`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0080oooo00<0000005W1n`1I`O/00`1I`O/01@000000FL7k05W1n`1I
`O/0000000H0oooo00<000000?ooo`3oool0103oool10000000000<000000?ooo`3oool0103oool0
1@000000oooo0?ooo`3oool0000000H0FL7k00D0000005W1n`1I`O/0FL7k000000060?ooo`030000
003oool0oooo00@0oooo0@00000000030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo
0000000605W1n`040000001I`O/0FL7k000000L0oooo00<000000?ooo`3oool0103oool100000000
00<000000?ooo`3oool0103oool010000000oooo0?ooo`3oool500000080FL7k00@0000005W1n`1I
`O/000001`3oool00`000000oooo0?ooo`040?ooo`40000000000`000000oooo0?ooo`040?ooo`05
0000003oool0oooo0?ooo`000000100KYM/6000000L0oooo00<000000?ooo`3oool0103oool10000
000000<000000?ooo`3oool0103oool010000000oooo0?ooo`3oool5000000806jGK00@0000001^U
f`0KYM/000001`3oool00`000000oooo0?ooo`040?ooo`40000000000`000000oooo0?ooo`040?oo
o`030000003oool0oooo00H0oooo1P0000070?ooo`030000003oool0oooo00@0oooo0@0000000003
0000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00@0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo0@00000000030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00@0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo0@00000000030000003oool0oooo
00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00@0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo0@00000000030000003oool0oooo00@0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo
0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00@0oooo0@00000000030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo0@000000
00030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00@0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo0@00000000030000
003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00@0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo0@00000000030000003oool0
oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00@0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo0@00000000030000003oool0oooo00@0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0
oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00@0oooo0@00000000030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo0@00
000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00@0oooo0@00000000030000003oool0oooo00@0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo0@0000000003
0000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00@0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo0@00000000030000003o
ool0oooo00@0oooo5@0000000`3oool000000?ooo`050?ooo`40000000000`000000oooo0?ooo`04
0?ooo`8000002@1800000`000000B00004P0000604P000030000003oool0000000H0oooo0@000000
00030000003oool0oooo00@0oooo0P00000904P00003000000180000B00000H0B00000<000000?oo
o`0000001P3oool10000000000<000000?ooo`3oool0103oool2000000T0B00000<0000004P00018
00001P180003000000H0oooo0@00000000030000003oool0oooo00@0oooo00<0000004P000180000
201800000`000000B00004P0000604P000030000003oool0000000H0oooo0@00000000030000003o
ool0oooo00@0oooo00<0000004P000180000201800000`000000B00004P0000704P0008000001P3o
ool10000000000<000000?ooo`3oool0103oool00`000000B00004P0000804P00003000000180000
B00000L0B0000P0000060?ooo`40000000000`000000oooo0?ooo`030?ooo`8000002P1800000`00
0000B00004P0000704P000030000003oool0000000D0oooo0@00000000030000003oool0oooo00<0
oooo5`0000000`3oool000000?ooo`040?ooo`40000000000`000000oooo0?ooo`030?ooo`800000
2P2dTk@00`000000]9>d0;BC]0070;BC]0030000003oool0000000D0oooo0@00000000030000003o
ool0oooo00<0oooo6@0000050?ooo`40000000000`000000oooo0?ooo`030?ooo`8000002P180000
0`000000B00004P0000804P0008000001@3oool10000000000<000000?ooo`3oool00`3oool20000
00X0B00000<0000004P00018000020180002000000D0oooo0@00000000030000003oool0oooo0080
oooo0P00000;04P00003000000180000B00000P0B00000<000000?ooo`000000103oool100000000
00<000000?ooo`3oool00P3oool2000000/0B00000<0000004P000180000201800000`000000oooo
000000040?ooo`40000000000`000000oooo0?ooo`020?ooo`8000002`1800000`000000B00004P0
000804P000030000003oool0000000@0oooo0@00000000030000003oool0oooo0080oooo0P00000;
04P00003000000180000B00000T0B0000P0000040?ooo`40000000000`000000oooo0?ooo`020?oo
o`8000005`180002000000@0oooo0@00000000030000003oool0oooo0080oooo0P00000G04P00080
0000103oool10000000000@000000?ooo`3oool0oooo0P00000H04P000030000003oool0000000<0
oooo0@00000000040000003oool0oooo0?ooo`800000601800000`000000oooo000000030?ooo`40
0000000010000000oooo0?ooo`3ooolK000000030?ooo`000000oooo0080oooo0@00000000040000
003oool0oooo0?ooo`800000602dTk@00`000000oooo000000030?ooo`400000000010000000oooo
0?ooo`3oool2000001P0]9>d00<000000?ooo`0000000`3oool10000000000@000000?ooo`3oool0
oooo0P00000H0;BC]0030000003oool0000000<0oooo0@00000000060000003oool0oooo0000003o
ool00000602dTk@00`000000oooo000000030?ooo`40000000001P000000oooo0?ooo`000000oooo
000001P0]9>d00@000000?ooo`3oool000000P3oool10000000000H000000?ooo`3oool000000?oo
o`00000H0;BC]0040000003oool0oooo00000080oooo0@00000000060000003oool0oooo0000003o
ool00000602dTk@010000000oooo0?ooo`0000020?ooo`40000000001P000000oooo0?ooo`000000
oooo000001P0]9>d00@000000?ooo`3oool000000P3oool10000000000H000000?ooo`3oool00000
0?ooo`00000H0;BC]0040000003oool0oooo00000080oooo0@00000000060000003oool0oooo0000
003oool00000602dTk@010000000oooo0?ooo`0000020?ooo`40000000000`000000oooo00000002
0?ooo`030000002dTk@0]9>d01H0]9>d00H000000?ooo`3oool0oooo0000003oool10000000000<0
00000?ooo`0000000P3ooolJ000000<0oooo0@0000010?ooo`40000000000`000000oooo0000000O
0?ooo`4000000@3oool10000000000<000000?ooo`0000007`3oool100000040oooo0@0000000003
0000003oool0000001l0oooo0@0000010?ooo`40000000000`000000oooo0000000O0?ooo`400000
0@3oool1000000000P00000Q0?ooo`800000000200000240oooo0P000000008000008@3oool20000
00000P00000Q0?ooo`800000000200000240oooo0P000000008000008@3oool20000000000<00000
0?ooo`3oool08@3oool10000000000<000000?ooo`3oool08@3oool10000000000<000000?ooo`3o
ool08@3oool1000000009@00000002D0oooo000U0?ooo`00\
\>"],
  ImageRangeCache->{{{91.5625, 120.5}, {263.438, 84.625}} -> {-0.110124, \
0.472488, 0.00460335, 0.00460335}}],

Cell[BoxData[
    RowBox[{"DoWithStatus", "[", 
      RowBox[{"\<\"Plotting stage 0A mode 1\"\>", ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
          False,
          Editable->False]}], "]"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#2", "Text"],

Cell[CellGroupData[{

Cell["Hz0A[[-2]]", "Input"],

Cell[BoxData[
    \(1.6183374474849537`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pretty[Chop[e2ni . eigenvectors0A[\([\(-2\)]\)], 10^\(-4\)]]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
          {"\<\"optic\"\>", "0", \(-0.15348338318454874`\), "0", "0", 
            "0", \(-0.9881512288542807`\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(DoWithStatus["\<Plotting stage 0A mode 2\>", \ 
      eigenplot[eigenvectors0A[\([\(-2\)]\)],  .1, {\(-1\), 0, 0}, \ 
        floatmatrix0A]]\), "\[IndentingNewLine]", 
    \( (*Status["\<Plotting stage 0A mode 2\>"]\ ; 
      eigenplot[eigenvectors0A[\([\(-2\)]\)],  .1, {\(-1\), 0, 0}, \ 
        floatmatrix0A]\ \ ; Done[]*) \)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 2.00188 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.50094 2.00188 1.11131e-016 2.00188 [
[ 0 0 0 0 ]
[ 1 2.00188 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
1 0 m
1 2.00188 L
s
1 2.00188 m
0 2.00188 L
s
0 2.00188 m
0 0 L
s
0 0 m
1 0 L
s
.92314 .15386 m
.07686 .15386 L
s
.07686 .15386 m
.07686 1.84802 L
s
.07686 1.84802 m
.92314 1.84802 L
s
.92314 1.84802 m
.92314 .15386 L
s
1 0 m
1 2.00188 L
s
1 2.00188 m
.92314 1.84802 L
s
.92314 1.84802 m
.92314 .15386 L
s
.92314 .15386 m
1 0 L
s
0 0 m
.07686 .15386 L
s
.07686 .15386 m
.07686 1.84802 L
s
.07686 1.84802 m
0 2.00188 L
s
0 2.00188 m
0 0 L
s
0 0 m
1 0 L
1 2.00188 L
0 2.00188 L
closepath
clip
newpath
.5 Mabswid
.707 .577 .707 r
.36539 1.86209 m .48118 1.86209 L .48118 1.7463 L p F P
0 g
s
.707 .577 .707 r
.48118 1.7463 m .25537 1.7463 L p .36539 1.86209 L F P
0 g
s
.281 0 0 r
.25537 1.7463 m .48118 1.7463 L .47854 1.85088 L p F P
0 g
s
.8 .653 .099 r
.25537 1.86209 m .25537 1.7463 L .22105 1.85088 L p F P
0 g
s
.707 .577 .707 r
.25537 1.7463 m .25537 1.86209 L .36539 1.86209 L p F P
0 g
s
.281 0 0 r
.47854 1.85088 m .22105 1.85088 L .25537 1.7463 L p F P
0 g
s
.715 .584 .008 r
.48118 1.7463 m .48118 1.86209 L .47998 1.91701 L p F P
0 g
s
.715 .584 .008 r
.47854 1.85088 m .48118 1.7463 L p .47998 1.91701 L F P
0 g
s
.8 .653 .099 r
.23977 1.91701 m .25537 1.86209 L p .22105 1.85088 L F P
0 g
s
0 0 .099 r
.74463 1.75208 m .74463 1.86209 L .7611 1.92009 L p F P
0 g
s
0 0 .099 r
.77895 1.85747 m .74463 1.75208 L p .7611 1.92009 L F P
0 g
s
.707 .577 .707 r
.63461 1.86209 m .74463 1.86209 L .74463 1.75208 L p F P
0 g
s
.707 .577 .707 r
.74463 1.75208 m .51882 1.75208 L p .63461 1.86209 L F P
0 g
s
.283 0 0 r
.51882 1.75208 m .74463 1.75208 L .77895 1.85747 L p F P
0 g
s
.707 .577 .707 r
.51882 1.75208 m .51882 1.86209 L .63461 1.86209 L p F P
0 g
s
.283 0 0 r
.77895 1.85747 m .52146 1.85747 L .51882 1.75208 L p F P
0 g
s
0 0 .008 r
.52008 1.92009 m .51882 1.86209 L p .52146 1.85747 L F P
0 g
s
0 0 .008 r
.51882 1.86209 m .51882 1.75208 L .52146 1.85747 L p F P
0 g
s
.082 .642 .745 r
.5665 .88858 m .56291 .89465 L .64603 .8898 L p F P
0 g
s
.082 .642 .745 r
.64603 .8898 m .65437 .88346 L .5665 .88858 L p F P
0 g
s
0 .458 .739 r
.65437 .88346 m .64603 .8898 L .72658 .91088 L p F P
0 g
s
0 .458 .739 r
.72658 .91088 m .73951 .90574 L .65437 .88346 L p F P
0 g
s
0 .237 .67 r
.73951 .90574 m .72658 .91088 L .79667 .95581 L p F P
0 g
s
0 .237 .67 r
.79667 .95581 m .81361 .95323 L .73951 .90574 L p F P
0 g
s
0 .003 .545 r
.81361 .95323 m .79667 .95581 L .84945 1.0202 L p F P
0 g
s
.475 .834 .573 r
.41646 .9764 m .42097 .97773 L .48536 .92495 L p F P
0 g
s
.475 .834 .573 r
.48536 .92495 m .48453 .92061 L .41646 .9764 L p F P
0 g
s
.287 .772 .688 r
.48453 .92061 m .48536 .92495 L .56291 .89465 L p F P
0 g
s
.287 .772 .688 r
.56291 .89465 m .5665 .88858 L .48453 .92061 L p F P
0 g
s
0 .003 .545 r
.84945 1.0202 m .8694 1.0213 L .81361 .95323 L p F P
0 g
s
0 0 .377 r
.8694 1.0213 m .84945 1.0202 L .87975 1.09776 L p F P
0 g
s
0 0 .377 r
.87975 1.09776 m .90142 1.10328 L .8694 1.0213 L p F P
0 g
s
0 0 .185 r
.90142 1.10328 m .87975 1.09776 L .88459 1.18087 L p F P
0 g
s
.726 .738 .221 r
.34668 1.13564 m .35496 1.12837 L .37604 1.04782 L p F P
0 g
s
.726 .738 .221 r
.37604 1.04782 m .36896 1.05049 L .34668 1.13564 L p F P
0 g
s
.626 .822 .413 r
.36896 1.05049 m .37604 1.04782 L .42097 .97773 L p F P
0 g
s
.626 .822 .413 r
.42097 .97773 m .41646 .9764 L .36896 1.05049 L p F P
0 g
s
0 0 .185 r
.88459 1.18087 m .90655 1.19114 L .90142 1.10328 L p F P
0 g
s
0 0 0 r
.90655 1.19114 m .88459 1.18087 L .86352 1.26142 L p F P
0 g
s
.763 .59 .019 r
.35181 1.2235 m .35981 1.21148 L .35496 1.12837 L p F P
0 g
s
.763 .59 .019 r
.35496 1.12837 m .34668 1.13564 L .35181 1.2235 L p F P
0 g
s
.01 w
.35133 .88851 Mdot
.5 Mabswid
0 0 0 r
.86352 1.26142 m .88427 1.27629 L .90655 1.19114 L p F P
0 g
s
0 0 0 r
.88427 1.27629 m .86352 1.26142 L .81859 1.33151 L p F P
0 g
s
0 0 0 r
.81859 1.33151 m .83677 1.35039 L .88427 1.27629 L p F P
0 g
s
0 0 0 r
.83677 1.35039 m .81859 1.33151 L .75419 1.38429 L p F P
0 g
s
.646 .165 0 r
.43962 1.37355 m .44288 1.35343 L .39011 1.28904 L p F P
0 g
s
.646 .165 0 r
.39011 1.28904 m .38383 1.30548 L .43962 1.37355 L p F P
0 g
s
.736 .392 0 r
.38383 1.30548 m .39011 1.28904 L .35981 1.21148 L p F P
0 g
s
.736 .392 0 r
.35981 1.21148 m .35181 1.2235 L .38383 1.30548 L p F P
0 g
s
0 0 0 r
.75419 1.38429 m .7687 1.40618 L .83677 1.35039 L p F P
0 g
s
0 0 0 r
.7687 1.40618 m .75419 1.38429 L .67664 1.41459 L p F P
0 g
s
0 0 0 r
.67664 1.41459 m .68673 1.4382 L .7687 1.40618 L p F P
0 g
s
.123 0 0 r
.68673 1.4382 m .67664 1.41459 L .59352 1.41944 L p F P
0 g
s
.123 0 0 r
.59352 1.41944 m .59886 1.44333 L .68673 1.4382 L p F P
0 g
s
.323 0 0 r
.59886 1.44333 m .59352 1.41944 L .51298 1.39836 L p F P
0 g
s
.323 0 0 r
.51298 1.39836 m .51372 1.42105 L .59886 1.44333 L p F P
0 g
s
.503 0 0 r
.51372 1.42105 m .51298 1.39836 L .44288 1.35343 L p F P
0 g
s
.503 0 0 r
.44288 1.35343 m .43962 1.37355 L .51372 1.42105 L p F P
0 g
s
.715 .584 .008 r
.47998 1.91701 m .47854 1.98292 L .47854 1.85088 L p F P
0 g
s
.8 .653 .099 r
.22105 1.85088 m .22105 1.98292 L .23977 1.91701 L p F P
0 g
s
.31664 1.15268 m
.35286 1.79516 L
s
.356 1.85088 m
.35964 1.91547 L
s
.68865 1.80132 m
.76067 1.62191 L
s
.64159 1.91855 m
.66611 1.85747 L
s
.76067 1.62191 m
.81959 1.47513 L
s
.89617 1.28435 m
.92482 1.21298 L
s
.81959 1.47513 m
.89617 1.28435 L
s
0 0 .099 r
.7611 1.92009 m .77895 1.98292 L .77895 1.85747 L p F P
0 g
s
0 0 .008 r
.52146 1.85747 m .52146 1.98292 L .52008 1.92009 L p F P
0 g
s
.01 w
.65715 .88209 Mdot
.34285 .88209 Mdot
.5 Mabswid
.707 .577 .707 r
.3465 1.98292 m .22105 1.98292 L p .47854 1.85088 L F P
0 g
s
.707 .577 .707 r
.22105 1.98292 m .22105 1.85088 L .47854 1.85088 L p F P
0 g
s
.707 .577 .707 r
.47854 1.85088 m .47854 1.98292 L .3465 1.98292 L p F P
0 g
s
.707 .577 .707 r
.6535 1.98292 m .52146 1.98292 L p .77895 1.85747 L F P
0 g
s
.707 .577 .707 r
.52146 1.98292 m .52146 1.85747 L .77895 1.85747 L p F P
0 g
s
.707 .577 .707 r
.77895 1.85747 m .77895 1.98292 L .6535 1.98292 L p F P
0 g
s
.25 Mabswid
1 0 m
1 2.00188 L
s
1 2.00188 m
0 2.00188 L
s
0 2.00188 m
0 0 L
s
0 0 m
1 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{119, 238.188},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40001g0000kR000`400?l00000o`00003oM`3oool0
07L0000000000`000000oooo0?ooo`1b0?ooo`8000000002000007<0oooo0P00000000800000LP3o
ool100000040oooo0@00000000030000003oool000000740oooo0@0000010?ooo`40000000000`00
0000oooo0000001`0?ooo`030000003oool0oooo00400000000010000000oooo0?ooo`00001_0?oo
o`030000003oool0oooo00400000000010000000oooo0?ooo`00001^0?ooo`040000003oool0oooo
0?ooo`40000000001@000000oooo0?ooo`3oool0000006d0oooo00@000000?ooo`3oool0oooo0@00
000000050000003oool0oooo0?ooo`000000K03oool00`000000oooo0?ooo`020?ooo`4000000000
0`000000oooo0?ooo`020?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool00`3oool1
0000000000<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo
00<0oooo0@00000000030000003oool0oooo00<0oooo00<000000?ooo`3oool0IP3oool00`000000
oooo0?ooo`040?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo06H0oooo
00<000000?ooo`3oool0103oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?oo
o`1T0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0I03oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`050?oo
o`030000003oool0oooo0680oooo00<000000?ooo`3oool01P3oool10000000000<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo00H0oooo0@00000000030000
003oool0oooo00H0ooooI00000090?ooo`40000000000`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0600oooo00<000000?ooo`3oool01`3oool10000000000<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`1P0?ooo`030000003oool0oooo00L0oooo0@00000000030000003oool0oooo
00H0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`070?ooo`40000000000`000000
oooo0?ooo`060?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool01`3oool100000000
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo00L0oooo
0@00000000030000003oool0oooo00H0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?oo
o`070?ooo`40000000000`000000oooo0?ooo`060?ooo`030000003oool0oooo0600oooo00<00000
0?ooo`3oool01`3oool10000000000<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1P0?oo
o`030000003oool0oooo00L0oooo0@00000000030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0H03oool00`000000oooo0?ooo`070?ooo`40000000000`000000oooo0?ooo`060?ooo`030000
003oool0oooo0600oooo00<000000?ooo`3oool01`3oool10000000000<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo00L0oooo0@00000000030000003oool0
oooo00H0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`070?ooo`40000000000`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool01`3oool10000
000000<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo00L0
oooo0@00000000030000003oool0oooo00H0oooo00<000000?ooo`3oool0H03oool00`000000oooo
0?ooo`070?ooo`40000000000`000000oooo0?ooo`060?ooo`030000003oool0oooo0600oooo00<0
00000?ooo`3oool01`3oool10000000000<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1P
0?ooo`030000003oool0oooo00L0oooo0@00000000030000003oool0oooo00H0oooo00<000000?oo
o`3oool0H03oool00`000000oooo0?ooo`070?ooo`40000000000`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0600oooo00<000000?ooo`3oool01`3oool10000000000<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo00L0oooo0@00000000030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`070?ooo`4000000000
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool01`3oool1
0000000000<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo
00L0oooo0@00000000030000003oool0oooo00H0oooo00<000000?ooo`3oool0H03oool00`000000
oooo0?ooo`070?ooo`40000000000`000000oooo0?ooo`060?ooo`030000003oool0oooo0600oooo
00<000000?ooo`3oool01`3oool10000000000<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`1P0?ooo`030000003oool0oooo00L0oooo0@00000000030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0H03oool00`000000oooo0?ooo`070?ooo`40000000000`000000oooo0?ooo`060?oo
o`030000003oool0oooo0600oooo00<000000?ooo`3oool01`3oool10000000000<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo00L0oooo0@00000000030000
003oool0oooo00H0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`070?ooo`400000
00000`000000oooo0?ooo`060?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool01`3o
ool10000000000<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0
oooo00L0oooo0@00000000030000003oool0oooo00H0oooo00<000000?ooo`3oool0H03oool00`00
0000oooo0?ooo`070?ooo`40000000000`000000oooo0?ooo`060?ooo`030000003oool0oooo0600
oooo00<000000?ooo`3oool01`3oool10000000000<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`1P0?ooo`030000003oool0oooo00L0oooo0@00000000030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0H03oool00`000000oooo0?ooo`070?ooo`40000000000`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool01`3oool10000000000<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo00L0oooo0@0000000003
0000003oool0oooo00H0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`070?ooo`40
000000000`000000oooo0?ooo`060?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0
1`3oool10000000000<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1P0?ooo`030000003o
ool0oooo00L0oooo0@00000000030000003oool0oooo00H0oooo00<000000?ooo`3oool0H03oool0
0`000000oooo0?ooo`070?ooo`40000000000`000000oooo0?ooo`060?ooo`030000003oool0oooo
0600oooo00<000000?ooo`3oool01`3oool10000000000<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo00L0oooo0@00000000030000003oool0oooo00H0oooo
00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`070?ooo`40000000000`000000oooo0?oo
o`060?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool01`3oool10000000000<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo00L0oooo0@000000
00030000003oool0oooo00H0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`070?oo
o`40000000000`000000oooo0?ooo`060?ooo`030000003oool0oooo0600oooo00<000000?ooo`3o
ool01`3oool10000000000<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1P0?ooo`030000
003oool0oooo00L0oooo0@00000000030000003oool0oooo00H0oooo00<000000?ooo`3oool0H03o
ool00`000000oooo0?ooo`070?ooo`40000000000`000000oooo0?ooo`060?ooo`030000003oool0
oooo0600oooo00<000000?ooo`3oool01`3oool10000000000<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`1P0?ooo`030000003oool0oooo00L0oooo0@00000000030000003oool0oooo00H0
oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`070?ooo`40000000000`000000oooo
0?ooo`060?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool01`3oool10000000000<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo00L0oooo0@00
000000030000003oool0oooo00H0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`07
0?ooo`40000000000`000000oooo0?ooo`060?ooo`030000003oool0oooo0600oooo00<000000?oo
o`3oool01`3oool10000000000<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1P0?ooo`03
0000003oool0oooo00L0oooo0@00000000030000003oool0oooo00H0oooo00<000000?ooo`3oool0
H03oool00`000000oooo0?ooo`070?ooo`40000000000`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0600oooo00<000000?ooo`3oool01`3oool10000000000<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`1P0?ooo`030000003oool0oooo00L0oooo0@00000000030000003oool0oooo
00H0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`070?ooo`40000000000`000000
oooo0?ooo`060?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool01`3oool100000000
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo00L0oooo
0@00000000030000003oool0oooo00H0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?oo
o`070?ooo`40000000000`000000oooo0?ooo`060?ooo`030000003oool0oooo0600oooo00<00000
0?ooo`3oool01`3oool10000000000<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1P0?oo
o`030000003oool0oooo00L0oooo0@00000000030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0H03oool00`000000oooo0?ooo`070?ooo`40000000000`000000oooo0?ooo`060?ooo`030000
003oool0oooo0600oooo00<000000?ooo`3oool01`3oool10000000000<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo00L0oooo0@00000000030000003oool0
oooo00H0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`070?ooo`40000000000`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool01`3oool10000
000000<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo00L0
oooo0@00000000030000003oool0oooo00H0oooo00<000000?ooo`3oool0H03oool00`000000oooo
0?ooo`070?ooo`40000000000`000000oooo0?ooo`060?ooo`030000003oool0oooo0600oooo00<0
00000?ooo`3oool01`3oool10000000000<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1P
0?ooo`030000003oool0oooo00L0oooo0@00000000030000003oool0oooo00H0oooo00<000000?oo
o`3oool0H03oool00`000000oooo0?ooo`070?ooo`40000000000`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0600oooo00<000000?ooo`3oool01`3oool10000000000<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo00L0oooo0@00000000030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`070?ooo`4000000000
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool01`3oool1
0000000000<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo
00L0oooo0@00000000030000003oool0oooo00H0oooo00<000000?ooo`3oool0H03oool00`000000
oooo0?ooo`070?ooo`40000000000`000000oooo0?ooo`060?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00L0oooo
0@00000000030000003oool0oooo00H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`0L0?ooo`L000007@3oool00`000000oooo0?ooo`070?ooo`40000000000`000000oooo0?ooo`06
0?ooo`030000003oool0oooo03D0oooo1`00000401BT_PH000006P3oool00`000000oooo0?ooo`07
0?ooo`40000000000`000000oooo0?ooo`060?ooo`030000003oool0oooo0380oooo0`00000>0?oo
o`L000005P3oool00`000000oooo0?ooo`070?ooo`40000000000`000000oooo0?ooo`060?ooo`03
0000003oool0oooo02l0oooo1000000D0?ooo`D00000503oool00`000000oooo0?ooo`070?ooo`40
000000000`000000oooo0?ooo`060?ooo`030000003oool0oooo02d0oooo1000000I0?ooo`@00000
4P3oool00`000000oooo0?ooo`070?ooo`40000000000`000000oooo0?ooo`060?ooo`030000003o
ool0oooo02`0oooo0`00000M0?ooo`0400000000?:/0000000000100oooo00<000000?ooo`3oool0
1`3oool10000000000<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0[0?ooo`800000803o
ool200000003000lZ`000000000000h0oooo00<000000?ooo`3oool01`3oool10000000000<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0Z0?ooo`8000008`3oool00`00000003b[000lZ`02
000000`0oooo00<000000?ooo`3oool01`3oool10000000000<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0X0?ooo`8000009P3oool01@00000003b[000lZ`00?:/0000000/0oooo00<00000
0?ooo`3oool01`3oool10000000000<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0W0?oo
o`800000:@3oool2000000030000R`000000oooo00T0oooo00<000000?ooo`3oool01`3oool10000
000000<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0V0?ooo`800000:`3oool00`000000
002;0000000:0?ooo`030000003oool0oooo00L0oooo0@00000000030000003oool0oooo00H0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0/0?ooo`030000000008/0000000T0oooo
00<000000?ooo`3oool01`3oool10000000000<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0T0?ooo`030000003oool0oooo02h0oooo00<000000000R`000000203oool00`000000oooo0?oo
o`070?ooo`40000000000`000000oooo0?ooo`060?ooo`030000003oool0oooo02@0oooo00<00000
0?ooo`3oool0;P3oool010000000002;0000R`0000070?ooo`030000003oool0oooo00L0oooo0@00
000000030000003oool0oooo00H0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0`
0?ooo`030000000008/0000000L0oooo00<000000?ooo`3oool01`3oool10000000000<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0380oooo00<000000000
R`0000001P3oool00`000000oooo0?ooo`070?ooo`40000000000`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool0<`3oool3000000D0oooo00<000000?ooo`3o
ool01`3oool10000000000<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo03@0oooo00<000000000H00000001@3oool00`000000oooo0?ooo`070?ooo`400000
00000`000000oooo0?ooo`060?ooo`030000003oool0oooo0200oooo0P00000g0?ooo`0300000000
0600000000@0oooo00<000000?ooo`3oool01`3oool10000000000<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo03H0oooo00<000000000H0000000103oool0
0`000000oooo0?ooo`070?ooo`40000000000`000000oooo0?ooo`060?ooo`030000003oool0oooo
01l0oooo0P00000h0?ooo`04000000000600001P000000<0oooo00<000000?ooo`3oool01`3oool1
0000000000<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
03P0oooo00<000000000H00000000`3oool00`000000oooo0?ooo`070?ooo`40000000000`000000
oooo0?ooo`060?ooo`030000003oool0oooo01h0oooo0P00000j0?ooo`03000000000600000000<0
oooo00<000000?ooo`3oool01`3oool10000000000<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0N0?ooo`800000>P3oool010000000001P0000H00000020?ooo`030000003oool0oooo00L0
oooo0@00000000030000003oool0oooo00H0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`0j0?ooo`80001P00@000000?ooo`3oool000002@3oool10000000000<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0M0?ooo`800000?03oool2000000040000H0000000oooo000000T0
oooo0@00000000030000003oool0oooo00H0oooo00<000000?ooo`3oool07@3oool2000003`0oooo
00H000000000;`00000000000?ooo`0000090?ooo`40000000000`000000oooo0?ooo`060?ooo`03
0000003oool0oooo01d0oooo0P00000l0?ooo`060000000002l0000_0000003oool000002@3oool1
0000000000<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
03/0oooo00H000000000;`0002l000000?ooo`0000090?ooo`40000000000`000000oooo0?ooo`06
0?ooo`030000003oool0oooo01`0oooo0P00000m0?ooo`060000000002l0000_0000003oool00000
2@3oool10000000000<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0L0?ooo`800000?@3o
ool01P000000000_0000;`000000oooo000000T0oooo0@00000000030000003oool0oooo00H0oooo
00<000000?ooo`3oool0703oool2000003h0oooo00D000000000;`000000oooo000000090?ooo`40
000000000`000000oooo0?ooo`060?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
0P00000n0?ooo`050000000002l000000?ooo`0000002@3oool10000000000<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00800000?P3oool01@000000000_
0000003oool0000000T0oooo0@00000000030000003oool0oooo00H0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`02000003h0oooo00D000000000;`000000oooo000000090?ooo`40
000000000`000000oooo0?ooo`060?ooo`030000003oool0oooo01T0oooo00H000000?ooo`3oool0
00000<>G1000000m0?ooo`050000000002l000000?ooo`0000002@3oool10000000000<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0I0?ooo`040000003oool0oooo0?ooo`800000?@3oool3
000000030?ooo`000000oooo00P0oooo0@00000000030000003oool0oooo00H0oooo00<000000?oo
o`3oool06@3oool010000000oooo0?ooo`3oool2000003`0oooo100000000`3oool000000?ooo`08
0?ooo`40000000000`000000oooo0?ooo`060?ooo`030000003oool0oooo01T0oooo00@000000?oo
o`3oool0oooo0P00000l0?ooo`@0000000<0oooo0000003oool0203oool10000000000<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0I0?ooo`040000003oool0oooo0?ooo`800000?03oool3
00000080oooo0P0000080?ooo`40000000000`000000oooo0?ooo`060?ooo`030000003oool0oooo
01T0oooo00H000000?ooo`3oool0oooo0000002lI00k0?ooo`@000000P3oool00`000000oooo0?oo
o`070?ooo`40000000000`000000oooo0?ooo`060?ooo`030000003oool0oooo01T0oooo00L00000
0?ooo`3oool0oooo0000002lI000000003X0oooo100000020?ooo`030000003oool0oooo00L0oooo
0@00000000030000003oool0oooo00H0oooo00<000000?ooo`3oool06P3oool010000000oooo0?oo
o`3oool2000003X0oooo100000000`3oool00000000000090?ooo`40000000000`000000oooo0?oo
o`060?ooo`030000003oool0oooo01X0oooo00L000000?ooo`3oool0oooo0000002lI000000003T0
oooo100000000`3oool00000000000090?ooo`40000000000`000000oooo0?ooo`060?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool00P3oool2000003P0oooo10000000103oool00000
0?ooo`0000090?ooo`40000000000`000000oooo0?ooo`060?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool00P3oool00`000000_6@00000000g0?ooo`@0000000@0oooo0000003oool0
00002@3oool10000000000<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo0080oooo00<000000;aT00000000=P3oool600000080oooo00<000000?ooo`3oool0
1`3oool10000000000<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo00<0oooo00<000000;aT00000000=@3oool4000000050?ooo`000000oooo0?ooo`000000
2@3oool10000000000<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo00<0oooo00<000000;aT00000000=03oool5000000050?ooo`000000oooo0?ooo`000000
2@3oool10000000000<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo00@0oooo00<000000:DZ00000000<P3oool5000000030?ooo`000000oooo0080oooo00<0
00000?ooo`3oool01`3oool10000000000<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo00@0oooo00@000000:DZ002U:P000000<@3oool400000080oooo00D0
00000?ooo`3oool0oooo000000090?ooo`40000000000`000000oooo0?ooo`060?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool01@3oool010000000YBX00:DZ0000000_0?ooo`D00000
00<0oooo0000003oool00`3oool00`000000oooo0?ooo`070?ooo`40000000000`000000oooo0?oo
o`060?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool01@3oool010000000YBX00:DZ
0000000_0?ooo`@000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo
0@00000000030000003oool0oooo00H0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`060?ooo`040000002U:P00YBX0000002d0oooo100000030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01`3oool10000000000<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo00L0oooo00@000000:DZ002U:P000000:`3oool500000080oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`40000000000`000000oooo0?oo
o`060?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0203oool010000000YBX00:DZ
0000000X0?ooo`H000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo
0@00000000030000003oool0oooo00H0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`080?ooo`030000002U:P00YBX0008000009P3oool6000000<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`070?ooo`40000000000`000000oooo0?ooo`060?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool02@3oool200000080P0000P00000S0?ooo`H00000103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo0@00000000030000003oool0oooo
00H0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0:0?ooo`03000000200000P000
0080P00000<000000?ooo`3oool07P3oool7000000D0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`070?ooo`40000000000`000000oooo0?ooo`060?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool02`3oool2000000<0P00000<000000?ooo`3oool06`3oool8000000D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`40000000000`000000oooo
0?ooo`060?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool03@3oool200000080P000
0P00000I0?ooo`P000001`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo
0@00000000030000003oool0oooo00H0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`0>0?ooo`8000000P200003000001@0oooo2@0000080?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01`3oool10000000000<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo0100oooo0`000002058000D000003@3oool:000000P0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`40000000000`000000oooo0?ooo`060?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool04P3oool2000000H0DP005@00000:0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool10000000000<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01@0oooo0`00000505800003
0000000O00007`0000L07`001`00000;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01`3oool10000000000<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo01L0oooo100000000`1B0000000001l0000801l000D000003@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00L0oooo0@00000000030000003oool0oooo00H0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`h000003`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00L0oooo0@00000000030000003oool0oooo00H0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool01`3oool10000000000<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo03L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?oo
o`40000000000`000000oooo0?ooo`060?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool0=P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo0@00000000030000
003oool0oooo00H0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0f0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool10000000000<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`070?ooo`40000000000`000000oooo0?ooo`060?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00L0oooo0@00000000030000003oool0oooo00H0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`0e0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01`3oool10000
000000<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo03@0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`070?ooo`40000000000`000000oooo
0?ooo`060?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00L0oooo0@00000000030000003oool0oooo00H0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool01`3oool10000000000<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`07
0?ooo`40000000000`000000oooo0?ooo`060?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool0<`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00L0oooo0@0000000003
0000003oool0oooo00H0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0b0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool10000000000<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`070?ooo`40000000000`000000oooo0?ooo`060?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00L0oooo0@00000000030000003oool0oooo00H0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool1
0000000000<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
0300oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`40000000000`000000
oooo0?ooo`060?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0;`3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00L0oooo0@00000000030000003oool0oooo00H0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool01`3oool10000000000<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`070?ooo`40000000000`000000oooo0?ooo`060?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00L0oooo0@000000
00030000003oool0oooo00H0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0^0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool01`3oool10000000000<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`070?ooo`40000000000`000000oooo0?ooo`060?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo00L0oooo0@00000000030000003oool0oooo00H0oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool01`3o
ool10000000000<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`070?ooo`40000000000`00
0000oooo0?ooo`060?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00L0oooo0@00000000030000003oool0oooo00H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool01`3oool10000000000<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`070?ooo`40000000000`000000oooo0?ooo`060?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0:`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00L0oooo0@00
000000030000003oool0oooo00H0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01`3oool10000000000<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`070?ooo`40000000000`000000oooo0?ooo`060?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo00L0oooo0@00000000030000003oool0oooo00H0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
1`3oool10000000000<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`070?ooo`4000000000
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0180oooo6`00000J0?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool01`3oool10000000000<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0B0?ooo`03000000170000A`0000P0A`0000<0000004L000170000301700000`00
0000oooo0?ooo`020?oooa/00000503oool00`000000oooo0?ooo`070?ooo`40000000000`000000
oooo0?ooo`060?ooo`030000003oool0oooo0140oooo00<0000004L0001700002@1700000`000000
A`0004L0000<04L000030000003oool0oooo0080oooo00<0000004P0001800004`1800001@000000
B00004P000180000000001@0oooo00<000000?ooo`3oool01`3oool10000000000<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0A0?ooo`03000000170000A`0000T0A`0000<0000004L00017
0000301700000`000000oooo0?ooo`020?ooo`03000000180000B0000180B00000<0000004P00018
00000`1800000`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00L0oooo0@00000000030000
003oool0oooo00H0oooo00<000000?ooo`3oool04@3oool00`000000A`0004L0000904L000030000
00170000A`0000`0A`0000<000000?ooo`3oool00P3oool00`000000B00004P0000B04P000030000
00180000B00000<0B00000<000000?ooo`3oool04@3oool00`000000oooo0?ooo`070?ooo`400000
00000`000000oooo0?ooo`060?ooo`030000003oool0oooo0100oooo00<0000004L0001700002P17
00000`000000A`0004L0000<04L000030000003oool0oooo0080oooo00<0000004P0001800004@18
00000`000000B00004P0000404P000030000003oool0oooo0140oooo00<000000?ooo`3oool01`3o
ool10000000000<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0@0?ooo`03000000170000
A`0000X0A`0000<0000004L000170000301700000`000000oooo0?ooo`020?ooo`03000000180000
B0000140B00000<0000004P0001800001@1800000`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo00L0oooo0@00000000030000003oool0oooo00H0oooo00<000000?ooo`3oool0403oool00`00
0000A`0004L0000I04L000030000003oool0oooo0080oooo00<0000004P0001800006@1800000`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo00L0oooo0@00000000030000003oool0oooo00H0
oooo00<000000?ooo`3oool03`3oool00`000000A`0004L0000J04L000030000003oool0oooo0080
oooo00<0000004P0001800006@1800000`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00L0
oooo0@00000000030000003oool0oooo00H0oooo00<000000?ooo`3oool03`3oool00`000000A`00
04L0000J04L000030000003oool0oooo0080oooo00<0000004P0001800006P1800000`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00L0oooo0@00000000030000003oool0oooo00H0oooo00<0
00000?ooo`3oool03`3oool00`000000A`0004L0000J04L000030000003oool0oooo0080oooo00<0
000004P0001800006P1800000`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00L0oooo0@00
000000030000003oool0oooo00H0oooo00<000000?ooo`3oool03P3oool00`000000A`0004L0000K
04L000030000003oool0oooo0080oooo00<0000004P0001800006P1800000`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00L0oooo0@00000000030000003oool0oooo00H0oooo=@00000M04P0
018000002@3oool10000000000<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0?0?ooo`03
0000002dTk@0]9>d01/0]9>d00<000000?ooo`3oool00P3ooolO00000140oooo00<000000?ooo`3o
ool01P3oool10000000000<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0?0?ooo`030000
002dTk@0]9>d01/0]9>d00<000000?ooo`3oool00P3oool00`000000]9>d0;BC]00K0;BC]0030000
003oool0oooo00l0oooo00<000000?ooo`3oool01P3oool10000000000<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0@0?ooo`030000002dTk@0]9>d01/0]9>d00<000000?ooo`3oool00P3o
ool00`000000]9>d0;BC]00K0;BC]0030000003oool0oooo0100oooo00<000000?ooo`3oool01@3o
ool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0@0?ooo`030000002dTk@0
]9>d01/0]9>d00<000000?ooo`3oool00P3oool00`000000]9>d0;BC]00K0;BC]0030000003oool0
oooo0100oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0A0?ooo`030000002dTk@0]9>d01/0]9>d00<000000?ooo`3oool00P3oool00`00
0000]9>d0;BC]00K0;BC]0030000003oool0oooo0140oooo00<000000?ooo`3oool0103oool10000
000000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0A0?ooo`030000002dTk@0]9>d01/0
]9>d00<000000?ooo`3oool00P3oool00`000000]9>d0;BC]00K0;BC]0030000003oool0oooo0140
oooo00<000000?ooo`3oool0103oool10000000000<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0B0?ooo`030000002dTk@0]9>d01/0]9>d00<000000?ooo`3oool00P3oool00`000000]9>d
0;BC]00K0;BC]0030000003oool0oooo0180oooo00<000000?ooo`3oool00`3oool10000000000<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0B0?ooo`030000002dTk@0]9>d01/0]9>d00<0
00000?ooo`3oool00P3oool00`000000]9>d0;BC]00K0;BC]0030000003oool0oooo0180oooo00<0
00000?ooo`3oool00`3oool10000000000D000000?ooo`3oool0oooo0000000E0?ooo`030000002d
Tk@0]9>d01/0]9>d00<000000?ooo`3oool00P3oool00`000000]9>d0;BC]00K0;BC]0030000003o
ool0oooo01<0oooo00<000000?ooo`3oool00P3oool10000000000D000000?ooo`3oool0oooo0000
000E0?ooo`030000002dTk@0]9>d01/0]9>d00<000000?ooo`3oool00P3oool00`000000]9>d0;BC
]00K0;BC]0030000003oool0oooo01@0oooo00@000000?ooo`3oool0oooo0@00000000040000003o
ool0oooo000001H0oooo00<000000;BC]02dTk@06`2dTk@00`000000oooo0?ooo`020?ooo`030000
002dTk@0]9>d01/0]9>d00<000000?ooo`3oool0503oool010000000oooo0?ooo`3oool100000000
00@000000?ooo`3oool000005P3oool00`000000]9>d0;BC]00K0;BC]0030000003oool0oooo0080
oooo00<000000;BC]02dTk@06`2dTk@00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0040
000000000`000000oooo0000000G0?ooo`030000002dTk@0]9>d01/0]9>d00<000000?ooo`3oool0
0P3oool00`000000]9>d0;BC]00K0;BC]0030000003oool0oooo01D0oooo00<000000?ooo`3oool0
0@00000000030000003oool0000001L0oooo00<000000;BC]02dTk@06`2dTk@00`000000oooo0?oo
o`020?ooo`030000002dTk@0]9>d01/0]9>d00<000000?ooo`3oool05P3oool100000040oooo0@00
000000800000603oool00`000000]9>d0;BC]00K0;BC]0030000003oool0oooo0080oooo00<00000
0;BC]02dTk@06`2dTk@00`000000oooo0?ooo`0F0?ooo`4000000@3oool1000000000P00000H0?oo
oal00000103ooolO000001T0oooo0P00000000030000003oool0oooo0780oooo0P00000007L00000
0000\
\>"],
  ImageRangeCache->{{{91.5625, 185.75}, {299.5, 110}} -> {-0.235381, 0.58088, \
0.0042429, 0.0042429}}],

Cell[BoxData[
    RowBox[{"DoWithStatus", "[", 
      RowBox[{"\<\"Plotting stage 0A mode 2\"\>", ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
          False,
          Editable->False]}], "]"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#3", "Text"],

Cell[CellGroupData[{

Cell["Hz0A[[-3]]", "Input"],

Cell[BoxData[
    \(1.7003578401639126`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pretty[Chop[e2ni . eigenvectors0A[\([\(-3\)]\)], 10^\(-4\)]]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
          {"\<\"optic\"\>", "0.04465399220071174`", "0", "0", "0", 
            "0.999002513000112`", "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Status["\<Plotting stage 0A mode 3\>"]\ ; 
    eigenplot[eigenvectors0A[\([\(-3\)]\)],  .1, {0, \(-1\), \(- .25\)}, \ 
      floatmatrix0A]\ \ ; Done[]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 4.95269 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.04936 5.09872 2.49583e-016 5.09872 [
[ 0 0 0 0 ]
[ 1 4.95269 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
.1333 4.95269 L
s
.1333 4.95269 m
.26075 3.76924 L
s
.26075 3.76924 m
.21037 .65115 L
s
.21037 .65115 m
0 0 L
s
1 0 m
.78963 .65115 L
s
.78963 .65115 m
.73925 3.76924 L
s
.73925 3.76924 m
.8667 4.95269 L
s
.8667 4.95269 m
1 0 L
s
0 0 m
.1333 4.95269 L
s
.1333 4.95269 m
.8667 4.95269 L
s
.8667 4.95269 m
1 0 L
s
1 0 m
0 0 L
s
.21037 .65115 m
.78963 .65115 L
s
.78963 .65115 m
.73925 3.76924 L
s
.73925 3.76924 m
.26075 3.76924 L
s
.26075 3.76924 m
.21037 .65115 L
s
0 0 m
1 0 L
1 4.95269 L
0 4.95269 L
closepath
clip
newpath
.5 Mabswid
.692 .685 .839 r
.5 3.94925 m .70365 3.94925 L p .29381 3.76668 L F P
0 g
s
.692 .685 .839 r
.70365 3.94925 m .70619 3.76668 L .29381 3.76668 L p F P
0 g
s
.692 .685 .839 r
.29381 3.76668 m .29635 3.94925 L .5 3.94925 L p F P
0 g
s
.752 .614 .046 r
.28579 4.07381 m .29635 3.94925 L p .27094 4.01282 L F P
0 g
s
.752 .614 .046 r
.29635 3.94925 m .29381 3.76668 L .27094 4.01282 L p F P
0 g
s
0 0 .046 r
.70619 3.76668 m .70365 3.94925 L .71421 4.07381 L p F P
0 g
s
0 0 .046 r
.72906 4.01282 m .70619 3.76668 L p .71421 4.07381 L F P
0 g
s
.408 0 0 r
.70619 3.76668 m .72906 4.01282 L .27094 4.01282 L p F P
0 g
s
.408 0 0 r
.27094 4.01282 m .29381 3.76668 L .70619 3.76668 L p F P
0 g
s
.752 .614 .046 r
.27094 4.01282 m .27407 4.21199 L .28579 4.07381 L p F P
0 g
s
0 0 .046 r
.71421 4.07381 m .72593 4.21199 L .72906 4.01282 L p F P
0 g
s
.51114 3.85605 m
.5686 2.73306 L
s
.5 4.07381 m
.50312 4.01282 L
s
.668 .44 .565 r
.67276 2.85295 m .48831 2.87053 L .50215 3.02563 L p F P
0 g
s
.696 .611 .758 r
.48831 2.87053 m .67276 2.85295 L .65795 2.69905 L p F P
0 g
s
.696 .611 .758 r
.65795 2.69905 m .47289 2.71686 L .48831 2.87053 L p F P
0 g
s
.668 .44 .565 r
.50215 3.02563 m .68825 3.00807 L .67276 2.85295 L p F P
0 g
s
.675 .747 .905 r
.47289 2.71686 m .65795 2.69905 L .64476 2.55609 L p F P
0 g
s
.675 .747 .905 r
.64476 2.55609 m .45686 2.57434 L .47289 2.71686 L p F P
0 g
s
.598 .244 .34 r
.68825 3.00807 m .50215 3.02563 L .51349 3.17225 L p F P
0 g
s
.598 .244 .34 r
.51349 3.17225 m .70345 3.15449 L .68825 3.00807 L p F P
0 g
s
.597 .83 .988 r
.45686 2.57434 m .64476 2.55609 L .63414 2.43409 L p F P
0 g
s
.597 .83 .988 r
.63414 2.43409 m .44125 2.45297 L .45686 2.57434 L p F P
0 g
s
.488 .03 .091 r
.70345 3.15449 m .51349 3.17225 L .52139 3.2997 L p F P
0 g
s
.488 .03 .091 r
.52139 3.2997 m .71727 3.28154 L .70345 3.15449 L p F P
0 g
s
.688 .696 .853 r
.5 4.21199 m .27407 4.21199 L .27094 4.01282 L p F P
0 g
s
.688 .696 .853 r
.72906 4.01282 m .72593 4.21199 L .5 4.21199 L p F P
0 g
s
.688 .696 .853 r
.27094 4.01282 m .72906 4.01282 L p .5 4.21199 L F P
0 g
s
.46 .843 .985 r
.44125 2.45297 m .63414 2.43409 L .62708 2.34366 L p F P
0 g
s
.46 .843 .985 r
.62708 2.34366 m .42724 2.36333 L .44125 2.45297 L p F P
0 g
s
.687 .698 .855 r
.5 4.26148 m .73013 4.26148 L p .26662 4.05925 L F P
0 g
s
.687 .698 .855 r
.73013 4.26148 m .73338 4.05925 L .26662 4.05925 L p F P
0 g
s
.687 .698 .855 r
.26662 4.05925 m .26987 4.26148 L .5 4.26148 L p F P
0 g
s
.752 .614 .046 r
.25629 4.42161 m .26987 4.26148 L p .23689 4.37925 L F P
0 g
s
.752 .614 .046 r
.26987 4.26148 m .26662 4.05925 L .23689 4.37925 L p F P
0 g
s
0 0 .046 r
.73338 4.05925 m .73013 4.26148 L .74371 4.42161 L p F P
0 g
s
.34 0 0 r
.71727 3.28154 m .52139 3.2997 L .52491 3.39634 L p F P
0 g
s
.34 0 0 r
.52491 3.39634 m .72853 3.37758 L .71727 3.28154 L p F P
0 g
s
0 0 .046 r
.76311 4.37925 m .73338 4.05925 L p .74371 4.42161 L F P
0 g
s
.408 0 0 r
.73338 4.05925 m .76311 4.37925 L .23689 4.37925 L p F P
0 g
s
.408 0 0 r
.23689 4.37925 m .26662 4.05925 L .73338 4.05925 L p F P
0 g
s
.271 .77 .882 r
.42724 2.36333 m .62708 2.34366 L .62455 2.29576 L p F P
0 g
s
.271 .77 .882 r
.62455 2.29576 m .41617 2.31633 L .42724 2.36333 L p F P
0 g
s
.01 w
.39857 2.25228 Mdot
.60143 2.25228 Mdot
.5 Mabswid
.152 0 0 r
.72853 3.37758 m .52491 3.39634 L .52322 3.44997 L p F P
0 g
s
.152 0 0 r
.52322 3.44997 m .73593 3.43045 L .72853 3.37758 L p F P
0 g
s
.752 .614 .046 r
.23689 4.37925 m .24101 4.60182 L .25629 4.42161 L p F P
0 g
s
0 0 .046 r
.74371 4.42161 m .75899 4.60182 L .76311 4.37925 L p F P
0 g
s
.51302 4.24596 m
.56294 3.57278 L
s
.5 4.42161 m
.50314 4.37925 L
s
0 0 0 r
.41617 2.31633 m .62455 2.29576 L .62737 2.30046 L p F P
0 g
s
0 0 0 r
.62737 2.30046 m .40948 2.32196 L .41617 2.31633 L p F P
0 g
s
.07 .632 .709 r
.73593 3.43045 m .52322 3.44997 L .51579 3.44936 L p F P
0 g
s
.07 .632 .709 r
.51579 3.44936 m .73819 3.42895 L .73593 3.43045 L p F P
0 g
s
.175 0 0 r
.40948 2.32196 m .62737 2.30046 L .636 2.36453 L p F P
0 g
s
.175 0 0 r
.636 2.36453 m .40848 2.38689 L .40948 2.32196 L p F P
0 g
s
.68 .713 .873 r
.5 4.60182 m .24101 4.60182 L .23689 4.37925 L p F P
0 g
s
.68 .713 .873 r
.76311 4.37925 m .75899 4.60182 L .5 4.60182 L p F P
0 g
s
.68 .713 .873 r
.23689 4.37925 m .76311 4.37925 L p .5 4.60182 L F P
0 g
s
.303 .786 .908 r
.73819 3.42895 m .51579 3.44936 L .50267 3.38711 L p F P
0 g
s
.56294 3.57278 m
.57263 3.442 L
s
.303 .786 .908 r
.50267 3.38711 m .73436 3.36576 L .73819 3.42895 L p F P
0 g
s
.378 0 0 r
.40848 2.38689 m .636 2.36453 L .65013 2.48807 L p F P
0 g
s
.378 0 0 r
.65013 2.48807 m .41406 2.5111 L .40848 2.38689 L p F P
0 g
s
.51 .844 .997 r
.73436 3.36576 m .50267 3.38711 L .48483 3.26344 L p F P
0 g
s
.51 .844 .997 r
.48483 3.26344 m .72415 3.2412 L .73436 3.36576 L p F P
0 g
s
.57263 3.442 m
.58312 3.30057 L
s
.541 .131 .213 r
.41406 2.5111 m .65013 2.48807 L .66852 2.66126 L p F P
0 g
s
.541 .131 .213 r
.66852 2.66126 m .42622 2.68463 L .41406 2.5111 L p F P
0 g
s
.01 w
.38104 2.37406 Mdot
.61896 2.37406 Mdot
.5 Mabswid
.646 .784 .947 r
.72415 3.2412 m .48483 3.26344 L .46425 3.08932 L p F P
0 g
s
.646 .784 .947 r
.46425 3.08932 m .70834 3.06638 L .72415 3.2412 L p F P
0 g
s
.58312 3.30057 m
.59341 3.16181 L
s
.651 .393 .516 r
.42622 2.68463 m .66852 2.66126 L .68888 2.86344 L p F P
0 g
s
.651 .393 .516 r
.68888 2.86344 m .44373 2.88678 L .42622 2.68463 L p F P
0 g
s
.691 .621 .773 r
.70834 3.06638 m .46425 3.08932 L .44373 2.88678 L p F P
0 g
s
.691 .621 .773 r
.44373 2.88678 m .68888 2.86344 L .70834 3.06638 L p F P
0 g
s
.25 Mabswid
0 0 m
.1333 4.95269 L
s
.1333 4.95269 m
.8667 4.95269 L
s
.8667 4.95269 m
1 0 L
s
1 0 m
0 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{11.8125, 58.5},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40000;0000>R000`400?l00000o`00003o2`3oool0
00/0oooo000;0000000000<000000?ooo`3oool01`3oool1000000000P0000070?ooo`8000000002
000000L0oooo0P000000008000001`3oool2000000000P0000070?ooo`80000000000`000000oooo
000000050?ooo`4000000@3oool10000000000<000000?ooo`0000001P0000010?ooo`4000000000
0`000000oooo000000050?ooo`4000000@3oool10000000000<000000?ooo`0000001@3oool10000
0040oooo0@00000000030000003oool0000000D0oooo0@0000010?ooo`40000000000`000000oooo
000000050?ooo`4000000@3oool10000000000<000000?ooo`0000001@3oool100000040oooo0@00
000000030000003oool0000000D0oooo0@0000010?ooo`40000000000`000000oooo000000050?oo
o`4000000@3oool10000000000<000000?ooo`0000001@3oool100000040oooo0@00000000030000
003oool0000000D0oooo0@0000010?ooo`40000000000`000000oooo000000050?ooo`4000000@3o
ool10000000000<000000?ooo`0000001@3oool100000040oooo0@00000000030000003oool00000
00D0oooo0@0000010?ooo`40000000000`000000oooo000000050?ooo`4000000@3oool100000000
00<000000?ooo`0000001@3oool100000040oooo0@00000000030000003oool0000000D0oooo0@00
00010?ooo`40000000000`000000oooo000000050?ooo`4000000@3oool10000000000H000000?oo
o`000000oooo0000003oool200000080oooo0@00000000040000003oool000000?ooo`@000000P3o
ool10000000000@000000?ooo`000000oooo100000020?ooo`400000000010000000oooo0000003o
ool400000040oooo0@0000010?ooo`0000D0oooo000000000000oooo0000000208XQ=P030000003o
ool000000040oooo0000103oool000000000003oool400000040oooo0@0000010?ooo`0000D0oooo
000000000000oooo000000020:ITQ0030000003oool000000040oooo0000103oool000000000003o
ool400000040oooo0@0000010?ooo`0000D0oooo000000000000oooo000000020;2Na@030000003o
ool000000040oooo00000`3oool00000000000020?ooo`<000000@3oool100000040oooo00000`3o
ool00000000000020?ooo`<000000@3oool100000040oooo00000`3oool00000000000020?ooo`<0
00000@3oool100000040oooo00000`3oool00000000000020?ooo`<000000@3oool100000040oooo
00000`3oool00000000000020?ooo`<000000@3oool100000040oooo00000`3oool0000000000002
0?ooo`<000000@3oool100000040oooo00000`3oool00000000000020?ooo`<000000@3oool10000
0040oooo00000`3oool00000000000020?ooo`<000000@3oool100000040oooo00000`3oool00000
0000000500000040oooo0@0000010?ooo`0000<0oooo0000000000000P1X000300000040oooo0@00
00010?ooo`0000<0oooo0000000000001@0000010?ooo`4000000@3oool000030?ooo`0000000000
00D000000@3oool100000040oooo00000`3oool000000000000206P000030000001X000000000080
00000@3oool000030?ooo`00000000000080J00000<0000006P0001X00000P0000010?ooo`0000<0
oooo0000000000001`0000010?ooo`0000<0oooo0000000000001@2^]]l200000040oooo00000`3o
ool00000000000050:jfg`8000000@3oool000030?ooo`000000000000L000000@3oool000030?oo
o`000000oooo00H0oooo0@0000010?ooo`0000<0oooo0000003oool01P3oool100000040oooo0000
0`3oool000000?ooo`060?ooo`4000000@3oool000030?ooo`000000000000L000000@3oool000/0
oooo0000\
\>"],
  ImageRangeCache->{{{91.5625, 100}, {597.125, 551.375}} -> {-1.72643, \
12.7707, 0.018596, 0.018596}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#4", "Text"],

Cell[CellGroupData[{

Cell["Hz0A[[-4]]", "Input"],

Cell[BoxData[
    \(2.097818589556624`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pretty[Chop[e2ni . eigenvectors0A[\([\(-4\)]\)], 10^\(-4\)]]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
          {"\<\"optic\"\>", "0", "0", "0", "1.`", "0", "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Status["\<Plotting stage 0A mode 4\>"]\ ; 
    eigenplot[eigenvectors0A[\([\(-4\)]\)],  .5, {0, \(-3\), \(- .25\)}, \ 
      floatmatrix0A]\ \ ; Done[]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 5.89255 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.52467 6.04934 -0.156788 6.04934 [
[ 0 0 0 0 ]
[ 1 5.89255 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
.01481 5.89255 L
s
.01481 5.89255 m
.08799 5.2311 L
s
.08799 5.2311 m
.07735 .23308 L
s
.07735 .23308 m
0 0 L
s
1 0 m
.92265 .23308 L
s
.92265 .23308 m
.91201 5.2311 L
s
.91201 5.2311 m
.98519 5.89255 L
s
.98519 5.89255 m
1 0 L
s
0 0 m
.01481 5.89255 L
s
.01481 5.89255 m
.98519 5.89255 L
s
.98519 5.89255 m
1 0 L
s
1 0 m
0 0 L
s
.07735 .23308 m
.92265 .23308 L
s
.92265 .23308 m
.91201 5.2311 L
s
.91201 5.2311 m
.08799 5.2311 L
s
.08799 5.2311 m
.07735 .23308 L
s
0 0 m
1 0 L
1 5.89255 L
0 5.89255 L
closepath
clip
newpath
.5 Mabswid
.707 .592 .726 r
.5 5.35631 m .83533 5.35631 L p .1641 5.02582 L F P
0 g
s
.707 .592 .726 r
.83533 5.35631 m .8359 5.02582 L .1641 5.02582 L p F P
0 g
s
.707 .592 .726 r
.1641 5.02582 m .16467 5.35631 L .5 5.35631 L p F P
0 g
s
.752 .614 .046 r
.15767 5.4367 m .16467 5.35631 L p .14975 5.17621 L F P
0 g
s
.752 .614 .046 r
.16467 5.35631 m .1641 5.02582 L .14975 5.17621 L p F P
0 g
s
0 0 .046 r
.8359 5.02582 m .83533 5.35631 L .84233 5.4367 L p F P
0 g
s
0 0 .046 r
.85025 5.17621 m .8359 5.02582 L p .84233 5.4367 L F P
0 g
s
.4 0 0 r
.8359 5.02582 m .85025 5.17621 L .14975 5.17621 L p F P
0 g
s
.4 0 0 r
.14975 5.17621 m .1641 5.02582 L .8359 5.02582 L p F P
0 g
s
.44939 5.17621 m
.5 5.4367 L
s
.815 .648 .676 r
.06659 3.45457 m .06647 3.50329 L p .25664 3.24924 L F P
0 g
s
.08789 3.31544 m
.10653 3.41141 L
s
.815 .648 .676 r
.06647 3.50329 m .27453 3.48964 L .25664 3.24924 L p F P
0 g
s
.815 .648 .676 r
.25664 3.24924 m .06708 3.26016 L .06659 3.45457 L p F P
0 g
s
.816 .714 .753 r
.06708 3.26016 m .25664 3.24924 L .27398 3.01531 L p F P
0 g
s
.802 .573 .59 r
.06944 3.73457 m .32619 3.71578 L .27453 3.48964 L p F P
0 g
s
.12366 3.49954 m
.15051 3.63776 L
s
.802 .573 .59 r
.27453 3.48964 m .06647 3.50329 L .06392 3.70979 L p F P
0 g
s
.802 .573 .59 r
.06392 3.70979 m .06944 3.73457 L p .27453 3.48964 L F P
0 g
s
.816 .714 .753 r
.06668 3.20398 m .06708 3.26016 L p .27398 3.01531 L F P
0 g
s
.816 .714 .753 r
.27398 3.01531 m .06541 3.02572 L .06668 3.20398 L p F P
0 g
s
.804 .779 .83 r
.06541 3.02572 m .27398 3.01531 L .32538 2.80826 L p F P
0 g
s
.773 .472 .477 r
.14934 3.92823 m .40756 3.90763 L .32619 3.71578 L p F P
0 g
s
.16792 3.72736 m
.19604 3.87213 L
s
.773 .472 .477 r
.32619 3.71578 m .06944 3.73457 L .14934 3.92823 L p F P
0 g
s
.20606 3.92371 m
.43195 5.08643 L
s
.804 .779 .83 r
.06482 2.99427 m .06541 3.02572 L p .32538 2.80826 L F P
0 g
s
.804 .779 .83 r
.32538 2.80826 m .06742 2.81939 L p .06482 2.99427 L F P
0 g
s
.763 .846 .914 r
.06742 2.81939 m .32538 2.80826 L .40696 2.64705 L p F P
0 g
s
.752 .614 .046 r
.14975 5.17621 m .15037 5.52053 L .15767 5.4367 L p F P
0 g
s
0 0 .046 r
.84233 5.4367 m .84963 5.52053 L .85025 5.17621 L p F P
0 g
s
.804 .779 .83 r
.06742 2.81939 m .06198 2.84211 L .06482 2.99427 L p F P
0 g
s
.705 .311 .299 r
.25183 4.06915 m .51206 4.04711 L .40756 3.90763 L p F P
0 g
s
.705 .311 .299 r
.40756 3.90763 m .14934 3.92823 L .25183 4.06915 L p F P
0 g
s
.763 .846 .914 r
.40696 2.64705 m .14706 2.65689 L .06742 2.81939 L p F P
0 g
s
.633 .894 .986 r
.14706 2.65689 m .40696 2.64705 L .51215 2.54783 L p F P
0 g
s
.01 w
.3532 2.49939 Mdot
.6468 2.49939 Mdot
.5 Mabswid
.517 0 0 r
.36812 4.14248 m .63073 4.11952 L .51206 4.04711 L p F P
0 g
s
.517 0 0 r
.51206 4.04711 m .25183 4.06915 L .36812 4.14248 L p F P
0 g
s
.633 .894 .986 r
.51215 2.54783 m .2499 2.55693 L .14706 2.65689 L p F P
0 g
s
.707 .593 .726 r
.5 5.52053 m .15037 5.52053 L .14975 5.17621 L p F P
0 g
s
.707 .593 .726 r
.85025 5.17621 m .84963 5.52053 L .5 5.52053 L p F P
0 g
s
.707 .593 .726 r
.14975 5.17621 m .85025 5.17621 L p .5 5.52053 L F P
0 g
s
.209 .732 .844 r
.2499 2.55693 m .51215 2.54783 L .6318 2.52232 L p F P
0 g
s
0 0 0 r
.48751 4.13852 m .75264 4.11527 L .63073 4.11952 L p F P
0 g
s
0 0 0 r
.63073 4.11952 m .36812 4.14248 L .48751 4.13852 L p F P
0 g
s
.707 .593 .726 r
.5 5.54927 m .85214 5.54927 L p .14723 5.20253 L F P
0 g
s
.707 .593 .726 r
.85214 5.54927 m .85277 5.20253 L .14723 5.20253 L p F P
0 g
s
.707 .593 .726 r
.14723 5.20253 m .14786 5.54927 L .5 5.54927 L p F P
0 g
s
.752 .614 .046 r
.14013 5.63803 m .14786 5.54927 L p .13137 5.36877 L F P
0 g
s
.752 .614 .046 r
.14786 5.54927 m .14723 5.20253 L .13137 5.36877 L p F P
0 g
s
0 0 .046 r
.85277 5.20253 m .85214 5.54927 L .85987 5.63803 L p F P
0 g
s
0 0 .046 r
.86863 5.36877 m .85277 5.20253 L p .85987 5.63803 L F P
0 g
s
.4 0 0 r
.85277 5.20253 m .86863 5.36877 L .13137 5.36877 L p F P
0 g
s
.4 0 0 r
.13137 5.36877 m .14723 5.20253 L .85277 5.20253 L p F P
0 g
s
.209 .732 .844 r
.6318 2.52232 m .36703 2.53132 L .2499 2.55693 L p F P
0 g
s
.415 0 0 r
.36703 2.53132 m .6318 2.52232 L .75463 2.57598 L p F P
0 g
s
.566 .903 .978 r
.5981 4.05453 m .86565 4.03174 L .75264 4.11527 L p F P
0 g
s
.566 .903 .978 r
.75264 4.11527 m .48751 4.13852 L .5981 4.05453 L p F P
0 g
s
.415 0 0 r
.75463 2.57598 m .48741 2.58559 L .36703 2.53132 L p F P
0 g
s
.687 .255 .216 r
.48741 2.58559 m .75463 2.57598 L .86813 2.7064 L p F P
0 g
s
.752 .614 .046 r
.13137 5.36877 m .13206 5.73076 L .14013 5.63803 L p F P
0 g
s
0 0 .046 r
.85987 5.63803 m .86794 5.73076 L .86863 5.36877 L p F P
0 g
s
.5 5.63803 m
.55713 5.36877 L
s
.758 .877 .932 r
.68801 3.89625 m .95763 3.87464 L .86565 4.03174 L p F P
0 g
s
.758 .877 .932 r
.86565 4.03174 m .5981 4.05453 L .68801 3.89625 L p F P
0 g
s
.57208 5.29831 m
.86423 3.92139 L
s
.687 .255 .216 r
.86813 2.7064 m .59877 2.7173 L .48741 2.58559 L p F P
0 g
s
.777 .453 .44 r
.59877 2.7173 m .86813 2.7064 L .95991 2.90233 L p F P
0 g
s
.812 .802 .842 r
.96412 3.85142 m .95763 3.87464 L p .74692 3.67833 L F P
0 g
s
.812 .802 .842 r
.95763 3.87464 m .68801 3.89625 L .74692 3.67833 L p F P
0 g
s
.86423 3.92139 m
.87036 3.89247 L
s
.812 .802 .842 r
.74692 3.67833 m .96803 3.66219 L .96412 3.85142 L p F P
0 g
s
.87036 3.89247 m
.90952 3.7079 L
s
.01 w
.34487 2.55577 Mdot
.65513 2.55577 Mdot
.5 Mabswid
.777 .453 .44 r
.95991 2.90233 m .68896 2.91513 L .59877 2.7173 L p F P
0 g
s
.812 .57 .574 r
.95991 2.90233 m .96631 2.92837 L .96876 3.10905 L p F P
0 g
s
.812 .57 .574 r
.68896 2.91513 m .95991 2.90233 L p .96876 3.10905 L F P
0 g
s
.707 .594 .727 r
.5 5.73076 m .13206 5.73076 L .13137 5.36877 L p F P
0 g
s
.707 .594 .727 r
.86863 5.36877 m .86794 5.73076 L .5 5.73076 L p F P
0 g
s
.707 .594 .727 r
.13137 5.36877 m .86863 5.36877 L p .5 5.73076 L F P
0 g
s
.827 .729 .756 r
.96842 3.61194 m .96803 3.66219 L p .76768 3.42338 L F P
0 g
s
.827 .729 .756 r
.96803 3.66219 m .74692 3.67833 L .76768 3.42338 L p F P
0 g
s
.827 .729 .756 r
.76768 3.42338 m .96999 3.41033 L .96842 3.61194 L p F P
0 g
s
.90952 3.7079 m
.95389 3.49881 L
s
.812 .57 .574 r
.96876 3.10905 m .96927 3.14693 L p .68896 2.91513 L F P
0 g
s
.812 .57 .574 r
.96927 3.14693 m .74758 3.15924 L .68896 2.91513 L p F P
0 g
s
.826 .655 .671 r
.74758 3.15924 m .96927 3.14693 L .96982 3.34695 L p F P
0 g
s
.826 .655 .671 r
.96982 3.34695 m .96999 3.41033 L p .74758 3.15924 L F P
0 g
s
.826 .655 .671 r
.96999 3.41033 m .76768 3.42338 L .74758 3.15924 L p F P
0 g
s
.25 Mabswid
0 0 m
.01481 5.89255 L
s
.01481 5.89255 m
.98519 5.89255 L
s
.98519 5.89255 m
1 0 L
s
1 0 m
0 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{10.375, 61.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40000:0000?B000`400?l00000o`00003o2P3oool0
00X0oooo000:0?ooo`002P00000000030000003oool0oooo00D0oooo0P00000000X0000000000`00
0000oooo0?ooo`050?ooo`80000000000`000000oooo0?ooo`050?ooo`80000000000`000000oooo
0?ooo`050?ooo`80000000000`000000oooo0?ooo`050?ooo`80000000000`000000oooo0?ooo`05
0?ooo`80000000000`000000oooo0?ooo`050?ooo`80000000000`000000oooo0?ooo`050?ooo`80
000000000`000000oooo0?ooo`050?ooo`80000000000`000000oooo0?ooo`050?ooo`8000000000
0`000000oooo0?ooo`050?ooo`80000000000`000000oooo0?ooo`050?ooo`80000000000`000000
oooo0?ooo`050?ooo`80000000000`000000oooo0?ooo`050?ooo`80000000000`000000oooo0?oo
o`050?ooo`80000000000`000000oooo0?ooo`050?ooo`80000000000`000000oooo0?ooo`050?oo
o`80000000000`000000oooo0?ooo`050?ooo`80000000000`000000oooo0?ooo`050?ooo`800000
00000`000000oooo0?ooo`050?ooo`80000000000`000000oooo0?ooo`050?ooo`80000000001@00
0000oooo0?ooo`000000oooo008000000@3oool100000040000000000`000000oooo000000070000
0000100000000`3oool00000000000030000000010000000103oool000000<IcL036Lg0200000000
00<000000<g7e00000000`3oool4000000000`0000030?ooo`030000003?TI80ci6B004000000000
0`000000d;K0000000040?ooo`<000000003000000@0oooo0@0000010=>WZ`40000000000`000000
d:F]000000040?ooo`4000000@3CYj/10000000000<000000=2U[@000000103oool3000000000`00
00040?ooo`<000000003000000@0oooo0`00000000@000000P3oool00`000000clgG000000010000
000000@000000<EhNP35N7X000000P3oool40000000010000000103oool000000<;PkP32h>h20000
00002P00000000030000003oool0000000<0000000<0oooo0000000000000@00000000030000003o
ool0000000@0oooo0`00000000030000003oool0000000@0oooo0`00000000030000003oool00000
00@0oooo0`00000000040000003oool0oooo00000080oooo00<000000?ooo`0000000@0000000004
0000003oool0oooo00000080oooo00<000000?ooo`0000000@00000000040000003oool0oooo0000
0080oooo00<000000?ooo`0000000@00000000080000003oool0oooo0?ooo`000000oooo0000003o
ool2000000002P00000000X00000000:000000002P000000008000001P2dV;X2000000000P000006
0;BH^P8000000002000000H0]9Rj0P00000000X00000000:000000002P3oool000X0oooo0000\
\>"],
  ImageRangeCache->{{{91.5625, 98.8125}, {207.625, 159.75}} -> {-1.67039, \
3.60965, 0.018241, 0.018241}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#5", "Text"],

Cell[CellGroupData[{

Cell["Hz0A[[-5]]", "Input"],

Cell[BoxData[
    \(5.525695086716362`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pretty[Chop[e2ni . eigenvectors0A[\([\(-5\)]\)], 10^\(-4\)]]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
          {"\<\"optic\"\>", "0", "0", "1.`", "0", "0", "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Status["\<Plotting stage 0A mode 5\>"]\ ; 
    eigenplot[
      eigenvectors0A[\([\(-5\)]\)], \(- .2\), {0, \(-1\), \(- .25\)}, \ 
      floatmatrix0A]\ \ ; Done[]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 4.95269 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.04936 5.09872 2.49583e-016 5.09872 [
[ 0 0 0 0 ]
[ 1 4.95269 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
.1333 4.95269 L
s
.1333 4.95269 m
.26075 3.76924 L
s
.26075 3.76924 m
.21037 .65115 L
s
.21037 .65115 m
0 0 L
s
1 0 m
.78963 .65115 L
s
.78963 .65115 m
.73925 3.76924 L
s
.73925 3.76924 m
.8667 4.95269 L
s
.8667 4.95269 m
1 0 L
s
0 0 m
.1333 4.95269 L
s
.1333 4.95269 m
.8667 4.95269 L
s
.8667 4.95269 m
1 0 L
s
1 0 m
0 0 L
s
.21037 .65115 m
.78963 .65115 L
s
.78963 .65115 m
.73925 3.76924 L
s
.73925 3.76924 m
.26075 3.76924 L
s
.26075 3.76924 m
.21037 .65115 L
s
0 0 m
1 0 L
1 4.95269 L
0 4.95269 L
closepath
clip
newpath
.01 w
.4098 4.06034 Mdot
.5902 4.06034 Mdot
.39857 2.25228 Mdot
.60143 2.25228 Mdot
.5 Mabswid
.692 .685 .839 r
.25282 .82262 m .26 1.33845 L .74 1.33845 L p F P
0 g
s
.752 .614 .046 r
.26 1.33845 m .25282 .82262 L .21921 .72404 L p F P
0 g
s
.752 .614 .046 r
.21921 .72404 m .22844 1.31095 L .26 1.33845 L p F P
0 g
s
.04 .609 .746 r
.74 1.33845 m .26 1.33845 L .22844 1.31095 L p F P
0 g
s
.692 .685 .839 r
.74 1.33845 m .74718 .82262 L .25282 .82262 L p F P
0 g
s
0 0 .046 r
.74 1.33845 m .77156 1.31095 L .78079 .72404 L p F P
0 g
s
0 0 .046 r
.78079 .72404 m .74718 .82262 L .74 1.33845 L p F P
0 g
s
.04 .609 .746 r
.22844 1.31095 m .77156 1.31095 L .74 1.33845 L p F P
0 g
s
.01 w
.3962 4.43924 Mdot
.6038 4.43924 Mdot
.5 Mabswid
.134 .676 .828 r
.74718 .82262 m .78079 .72404 L .21921 .72404 L p F P
0 g
s
.134 .676 .828 r
.21921 .72404 m .25282 .82262 L .74718 .82262 L p F P
0 g
s
.5 .78726 m
.5 1.05531 L
s
.5 .52689 m
.5 .72404 L
s
.688 .696 .853 r
.77156 1.31095 m .22844 1.31095 L .21921 .72404 L p F P
0 g
s
.688 .696 .853 r
.21921 .72404 m .78079 .72404 L .77156 1.31095 L p F P
0 g
s
.687 .698 .855 r
.2127 .70495 m .22236 1.30564 L .77764 1.30564 L p F P
0 g
s
.752 .614 .046 r
.22236 1.30564 m .2127 .70495 L .16627 .56877 L p F P
0 g
s
.752 .614 .046 r
.16627 .56877 m .17923 1.26806 L .22236 1.30564 L p F P
0 g
s
.04 .609 .746 r
.77764 1.30564 m .22236 1.30564 L .17923 1.26806 L p F P
0 g
s
.687 .698 .855 r
.77764 1.30564 m .7873 .70495 L .2127 .70495 L p F P
0 g
s
0 0 .046 r
.77764 1.30564 m .82077 1.26806 L .83373 .56877 L p F P
0 g
s
0 0 .046 r
.83373 .56877 m .7873 .70495 L .77764 1.30564 L p F P
0 g
s
.04 .609 .746 r
.17923 1.26806 m .82077 1.26806 L .77764 1.30564 L p F P
0 g
s
.01 w
.38104 2.37406 Mdot
.61896 2.37406 Mdot
.5 Mabswid
.134 .676 .828 r
.7873 .70495 m .83373 .56877 L .16627 .56877 L p F P
0 g
s
.134 .676 .828 r
.16627 .56877 m .2127 .70495 L .7873 .70495 L p F P
0 g
s
.5 .6266 m
.5 .97101 L
s
.68 .713 .873 r
.82077 1.26806 m .17923 1.26806 L .16627 .56877 L p F P
0 g
s
.68 .713 .873 r
.16627 .56877 m .83373 .56877 L .82077 1.26806 L p F P
0 g
s
.5 .26875 m
.5 .56877 L
s
.25 Mabswid
0 0 m
.1333 4.95269 L
s
.1333 4.95269 m
.8667 4.95269 L
s
.8667 4.95269 m
1 0 L
s
1 0 m
0 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{11.8125, 58.5},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40000;0000>R000`400?l00000o`00003o2`3oool0
00/0oooo000;0000000000<000000?ooo`3oool01`3oool1000000000P0000070?ooo`8000000002
000000<0oooo00@000000?ooo`3oool0oooo0P000000008000000`3oool010000000oooo0?ooo`3o
ool2000000000P0000030?ooo`040000003oool0oooo0?ooo`800000000;000000000P0000070:jf
g`8000000002000000L0[[KO0P000000008000001`2^]]l2000000000P0000060:jfg`4000000@3o
ool1000000000P0000060:jfg`4000000@3oool1000000000P0000060:jfg`4000000@3oool10000
00000P0000060:jfg`4000000@3oool1000000002@0000010?ooo`40000000000`000000oooo0000
00050?ooo`4000000@3oool10000000000<000000?ooo`0000001@3oool100000040oooo0@000000
00030000003oool0000000D0oooo0@0000010?ooo`40000000000`000000oooo000000050?ooo`40
00000@3oool10000000000<000000?ooo`0000001@3oool100000040oooo0@00000000030000003o
ool0000000D0oooo0@0000010?ooo`40000000000`000000oooo000000050?ooo`4000000@3oool1
0000000000<000000?ooo`0000001@3oool100000040oooo0@00000000030000003oool0000000D0
oooo0@0000010?ooo`40000000001P000000oooo0000003oool000000?ooo`8000000P3oool10000
000000<000000?ooo`000000103oool00`000000oooo0?ooo`010000000000H000000?ooo`000000
oooo0000003oool200000080oooo0@00000000030000003oool0000000@0oooo00<000000?ooo`00
00000@3oool000030?ooo`000000000000@0oooo00<000000?ooo`0000000@3oool000030?ooo`00
0000000000@0oooo00<000000?ooo`0000000@3oool000030?ooo`000000000000@0oooo00<00000
0?ooo`0000000@3oool000030?ooo`000000000000@0oooo00<000000?ooo`0000000@3oool00003
0?ooo`000000000000@0oooo00<000000?ooo`0000000@3oool000030?ooo`000000000000@0oooo
00<000000?ooo`0000000@3oool000030?ooo`000000000000@0oooo00<000000?ooo`0000000@3o
ool000030?ooo`000000000000@0oooo00<000000?ooo`0000000@3oool000030?ooo`0000000000
00@0oooo00<000000?ooo`0000000@3oool000030?ooo`000000000000@0oooo00<000000?ooo`00
00000@3oool000030?ooo`000000000000@0oooo00<000000?ooo`0000000@3oool000030?ooo`00
0000000000@0oooo00<000000?ooo`0000000@3oool000030?ooo`000000000000@0oooo00<00000
0?ooo`0000000@3oool000030?ooo`000000000000D000000@3oool100000040oooo00000`3oool0
0000000000040?ooo`030000003oool000000040oooo00000`3oool00000000000040?ooo`030000
003oool000000040oooo00001P3oool000000000003oool000000?ooo`8000000@3oool100000040
oooo00000`3oool00000000000050?ooo`8000000@3oool000030?ooo`000000000000D0oooo0P00
00010?ooo`0000<0oooo0000000000001@3oool200000040oooo0000203oool000000?ooo`3oool0
00000?ooo`000000oooo0P0000010?ooo`0000<0oooo0000003oool01@3oool200000040oooo0000
0`3oool000000?ooo`050?ooo`8000000@3oool000030?ooo`000000oooo00H0oooo0@0000010?oo
o`0000<0oooo0000003oool01P3oool100000040oooo00000`3oool000000?ooo`060?ooo`400000
0@3oool000030?ooo`000000000000L000000@3oool000/0oooo0000\
\>"],
  ImageRangeCache->{{{91.5625, 100}, {472.688, 426.938}} -> {-1.72643, \
9.87811, 0.018596, 0.018596}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#6", "Text"],

Cell[CellGroupData[{

Cell["Hz0A[[-6]]", "Input"],

Cell[BoxData[
    \(7.882747495950438`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pretty[Chop[e2ni . eigenvectors0A[\([\(-6\)]\)], 10^\(-4\)]]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
          {"\<\"optic\"\>", "0", "0.004750688549861024`", "0", "0", 
            "0", \(-0.9999887154154802`\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Status["\<Plotting stage 0A mode 6\>"]\ ; 
    eigenplot[
      eigenvectors0A[\([\(-6\)]\)], \(- .2\), {\(-1\), 0, \(- .25\)}, \ 
      floatmatrix0A]\ \ ; Done[]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.71311 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.430632 1.86126 4.66207e-018 1.86126 [
[ 0 0 0 0 ]
[ 1 1.71311 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
1 0 m
.8868 1.71311 L
s
.8868 1.71311 m
.1132 1.71311 L
s
.1132 1.71311 m
0 0 L
s
0 0 m
1 0 L
s
.91844 .08415 m
.08156 .08415 L
s
.08156 .08415 m
.16388 1.55624 L
s
.16388 1.55624 m
.83612 1.55624 L
s
.83612 1.55624 m
.91844 .08415 L
s
1 0 m
.8868 1.71311 L
s
.8868 1.71311 m
.83612 1.55624 L
s
.83612 1.55624 m
.91844 .08415 L
s
.91844 .08415 m
1 0 L
s
0 0 m
.08156 .08415 L
s
.08156 .08415 m
.16388 1.55624 L
s
.16388 1.55624 m
.1132 1.71311 L
s
.1132 1.71311 m
0 0 L
s
0 0 m
1 0 L
1 1.71311 L
0 1.71311 L
closepath
clip
newpath
.5 Mabswid
.689 .691 .846 r
.44298 1.57093 m .48509 1.57093 L .485 1.53379 L p F P
0 g
s
.715 .584 .008 r
.485 1.53379 m .48509 1.57093 L .48379 1.66269 L p F P
0 g
s
.8 .653 .099 r
.2893 1.66269 m .30616 1.57093 L p .28201 1.65357 L F P
0 g
s
.8 .653 .099 r
.30616 1.57093 m .30496 1.53379 L .28201 1.65357 L p F P
0 g
s
.689 .691 .846 r
.30496 1.53379 m .30616 1.57093 L .44298 1.57093 L p F P
0 g
s
.689 .691 .846 r
.485 1.53379 m .30496 1.53379 L p .44298 1.57093 L F P
0 g
s
0 0 .099 r
.6978 1.44855 m .69384 1.57093 L .69874 1.59757 L p F P
0 g
s
.689 .691 .846 r
.51522 1.44855 m .51491 1.57093 L .55702 1.57093 L p F P
0 g
s
0 0 .008 r
.51529 1.59757 m .51491 1.57093 L p .51703 1.56004 L F P
0 g
s
0 0 .008 r
.51491 1.57093 m .51522 1.44855 L .51703 1.56004 L p F P
0 g
s
.689 .691 .846 r
.55702 1.57093 m .69384 1.57093 L .6978 1.44855 L p F P
0 g
s
.689 .691 .846 r
.6978 1.44855 m .51522 1.44855 L p .55702 1.57093 L F P
0 g
s
.421 0 0 r
.30496 1.53379 m .485 1.53379 L .48323 1.65357 L p F P
0 g
s
.421 0 0 r
.48323 1.65357 m .28201 1.65357 L .30496 1.53379 L p F P
0 g
s
.715 .584 .008 r
.48323 1.65357 m .485 1.53379 L p .48379 1.66269 L F P
0 g
s
0 0 .099 r
.72144 1.56004 m .6978 1.44855 L p .69874 1.59757 L F P
0 g
s
.393 0 0 r
.51522 1.44855 m .6978 1.44855 L .72144 1.56004 L p F P
0 g
s
.393 0 0 r
.72144 1.56004 m .51703 1.56004 L .51522 1.44855 L p F P
0 g
s
0 0 .099 r
.69874 1.59757 m .7165 1.69422 L .72144 1.56004 L p F P
0 g
s
0 0 .008 r
.51703 1.56004 m .51665 1.69422 L .51529 1.59757 L p F P
0 g
s
.61095 1.58548 m
.61823 1.56004 L
s
.715 .584 .008 r
.48379 1.66269 m .48335 1.69422 L .48323 1.65357 L p F P
0 g
s
.8 .653 .099 r
.28201 1.65357 m .2835 1.69422 L .2893 1.66269 L p F P
0 g
s
.287 0 0 r
.55283 1.29357 m .55028 1.25598 L .48091 1.25872 L p F P
0 g
s
.287 0 0 r
.48091 1.25872 m .47994 1.29644 L .55283 1.29357 L p F P
0 g
s
.483 0 0 r
.47994 1.29644 m .48091 1.25872 L .4138 1.24153 L p F P
0 g
s
.075 0 0 r
.62165 1.27009 m .61575 1.2335 L .55028 1.25598 L p F P
0 g
s
.075 0 0 r
.55028 1.25598 m .55283 1.29357 L .62165 1.27009 L p F P
0 g
s
.483 0 0 r
.4138 1.24153 m .40942 1.27847 L .47994 1.29644 L p F P
0 g
s
.647 .091 0 r
.40942 1.27847 m .4138 1.24153 L .35498 1.20577 L p F P
0 g
s
0 0 0 r
.6802 1.22788 m .6714 1.19312 L .61575 1.2335 L p F P
0 g
s
0 0 0 r
.61575 1.2335 m .62165 1.27009 L .6802 1.22788 L p F P
0 g
s
.647 .091 0 r
.35498 1.20577 m .34755 1.2411 L .40942 1.27847 L p F P
0 g
s
.765 .293 0 r
.34755 1.2411 m .35498 1.20577 L .30993 1.15439 L p F P
0 g
s
0 0 0 r
.72294 1.17041 m .71196 1.13819 L .6714 1.19312 L p F P
0 g
s
0 0 0 r
.6714 1.19312 m .6802 1.22788 L .72294 1.17041 L p F P
0 g
s
.63508 1.50115 m
.71907 1.20763 L
s
.765 .293 0 r
.30993 1.15439 m .30011 1.18737 L .34755 1.2411 L p F P
0 g
s
.28189 1.2353 m
.37028 1.59035 L
s
.822 .481 0 r
.30011 1.18737 m .30993 1.15439 L .28317 1.09182 L p F P
0 g
s
0 0 0 r
.74544 1.10268 m .73324 1.07349 L .71196 1.13819 L p F P
0 g
s
0 0 0 r
.71196 1.13819 m .72294 1.17041 L .74544 1.10268 L p F P
0 g
s
.71907 1.20763 m
.74522 1.11623 L
s
.684 .704 .862 r
.43632 1.69422 m .2835 1.69422 L p .48323 1.65357 L F P
0 g
s
.684 .704 .862 r
.2835 1.69422 m .28201 1.65357 L .48323 1.65357 L p F P
0 g
s
.684 .704 .862 r
.48323 1.65357 m .48335 1.69422 L .43632 1.69422 L p F P
0 g
s
.684 .704 .862 r
.56368 1.69422 m .51665 1.69422 L p .72144 1.56004 L F P
0 g
s
.684 .704 .862 r
.51665 1.69422 m .51703 1.56004 L .72144 1.56004 L p F P
0 g
s
.684 .704 .862 r
.72144 1.56004 m .7165 1.69422 L .56368 1.69422 L p F P
0 g
s
.822 .481 0 r
.28317 1.09182 m .27185 1.12187 L .30011 1.18737 L p F P
0 g
s
.2558 1.13052 m
.28189 1.2353 L
s
.808 .636 .081 r
.27185 1.12187 m .28317 1.09182 L .2778 1.02373 L p F P
0 g
s
0 0 .125 r
.74491 1.03091 m .7326 1.00502 L .73324 1.07349 L p F P
0 g
s
0 0 .125 r
.73324 1.07349 m .74544 1.10268 L .74491 1.03091 L p F P
0 g
s
.74522 1.11623 m
.76936 1.03186 L
s
.808 .636 .081 r
.2778 1.02373 m .26608 1.05052 L .27185 1.12187 L p F P
0 g
s
.719 .738 .222 r
.26608 1.05052 m .2778 1.02373 L .29501 .9567 L p F P
0 g
s
0 0 .264 r
.72063 .96213 m .70943 .93948 L .7326 1.00502 L p F P
0 g
s
0 0 .264 r
.7326 1.00502 m .74491 1.03091 L .72063 .96213 L p F P
0 g
s
.719 .738 .222 r
.29501 .9567 m .28408 .98021 L .26608 1.05052 L p F P
0 g
s
0 0 0 r
.28408 .98021 m .29501 .9567 L .33372 .8976 L p F P
0 g
s
.601 .139 0 r
.67439 .90354 m .66546 .88369 L .70943 .93948 L p F P
0 g
s
.601 .139 0 r
.70943 .93948 m .72063 .96213 L .67439 .90354 L p F P
0 g
s
0 0 0 r
.33372 .8976 m .32477 .91815 L .28408 .98021 L p F P
0 g
s
0 0 0 r
.32477 .91815 m .33372 .8976 L .39045 .8528 L p F P
0 g
s
.489 0 0 r
.61048 .86156 m .60479 .84376 L .66546 .88369 L p F P
0 g
s
.489 0 0 r
.66546 .88369 m .67439 .90354 L .61048 .86156 L p F P
0 g
s
0 0 0 r
.38452 .87107 m .39045 .8528 L .45952 .82736 L p F P
0 g
s
0 0 0 r
.39045 .8528 m .38452 .87107 L .32477 .91815 L p F P
0 g
s
.317 0 0 r
.53545 .84101 m .53362 .82422 L .60479 .84376 L p F P
0 g
s
.317 0 0 r
.60479 .84376 m .61048 .86156 L .53545 .84101 L p F P
0 g
s
0 0 0 r
.45952 .82736 m .45731 .84431 L .38452 .87107 L p F P
0 g
s
.104 0 0 r
.45731 .84431 m .45952 .82736 L .53362 .82422 L p F P
0 g
s
.104 0 0 r
.53362 .82422 m .53545 .84101 L .45731 .84431 L p F P
0 g
s
.01 w
.6325 .8227 Mdot
.3675 .8227 Mdot
.63972 .83941 Mdot
.36028 .83941 Mdot
.25 Mabswid
1 0 m
.8868 1.71311 L
s
.8868 1.71311 m
.1132 1.71311 L
s
.1132 1.71311 m
0 0 L
s
0 0 m
1 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{35.375, 60.5625},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40000S0000?2000`400?l00000o`00003o8`000000
008000007`3oool2000000000P00000N0?ooo`4000000@3oool10000000000<000000?ooo`000000
7@0000020?ooo`40000000000`000000oooo0000000L0?ooo`030000003oool0oooo004000000000
0`000000oooo0000000L0?ooo`030000003oool0oooo0040000000000`000000oooo0000000L0?oo
o`030000003oool0oooo0040000000000`000000oooo0000000L0?ooo`030000003oool0oooo0040
000000000`000000oooo0000000L0?ooo`030000003oool000000040oooo00000`000000oooo0000
000L0?ooo`030000003oool000000040oooo00000`3oool000000000000L0?ooo`030000003oool0
00000040oooo00000`3oool000000000000L0?ooo`030000003oool000000040oooo0000103oool0
00000?ooo`00000J0?ooo`040000003oool0oooo00000040oooo0000103oool000000?ooo`00000J
0?ooo`040000003oool0oooo00000040oooo0000103oool000000?ooo`00000J0?ooo`040000003o
ool0oooo00000040oooo0000103oool000000?ooo`00000J0?ooo`040000003oool0oooo00000040
oooo0000103oool000000?ooo`00000J0?ooo`040000003oool0oooo00000040oooo0000103oool0
00000?ooo`00000J0?ooo`040000003oool0oooo00000040oooo0000103oool000000?ooo`00000J
0?ooo`040000003oool0oooo00000040oooo0000103oool000000?ooo`00000J0?ooo`040000003o
ool0oooo00000040oooo0000103oool000000?ooo`00000J0?ooo`040000003oool0oooo00000040
oooo0000103oool000000?ooo`00000J0?ooo`040000003oool0oooo00000040oooo0000103oool0
00000?ooo`00000J0?ooo`040000003oool0oooo00000040oooo0000103oool000000?ooo`00000J
0?ooo`030000003oool000000080oooo0000103oool000000?ooo`00000J0?ooo`030000003oool0
00000080oooo0000103oool000000?ooo`00000J0?ooo`030000003oool000000080oooo0000103o
ool000000?ooo`00000J0?ooo`030000003oool000000080oooo0000103oool000000?ooo`00000J
0?ooo`030000003oool000000080oooo0000103oool000000?ooo`0000090?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo000000020?ooo`0000D0oooo0000
003oool0oooo000000070?ooo`030000003oool0oooo00H0000000<0oooo0000003oool01@3oool0
10000000oooo0?ooo`0000020?ooo`000P3oool00`000000oooo000000080?ooo`800000103oool3
000000L0oooo00@000000?ooo`3oool000000P3oool00080oooo00<000000?ooo`0000001P3oool2
000000T0oooo0P0000050?ooo`040000003oool0oooo00000080oooo00020?ooo`030000003oool0
000000D0oooo0P00000;0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3o
ool00080oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool000000P3oool00080oooo00<000000?ooo`000000103oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3o
ool00080oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`0=0?ooo`050000003oool0
oooo0?ooo`0000000P3oool100000040oooo0@3oool00080oooo00<000000?ooo`000000103oool0
0`000000oooo0?ooo`0=0?ooo`8000000P3oool010000000oooo0?ooo`0000020?ooo`000P3oool0
0`000000oooo000000040?ooo`030000003oool0oooo00d0oooo0P0000020?ooo`030000003oool0
000000<0oooo00020?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool0303oool20000
00<0oooo00<000000?ooo`0000000`3oool00080oooo00<000000?ooo`0000000`3oool2000000h0
oooo0P0000030?ooo`030000003oool0000000<0oooo00020?ooo`030000003oool0000000<0oooo
0`00000<0?ooo`<000000`3oool00`000000oooo000000030?ooo`000P3oool00`000000oooo0000
00030?ooo`040000003oool00000000000/0oooo0P0000040?ooo`030000003oool0000000<0oooo
00020?ooo`030000003oool0000000@0oooo0P0000000`33B`0000000?ooo`080?ooo`<00000103o
ool00`000000oooo000000030?ooo`000P3oool00`000000oooo000000040?ooo`030000003oool0
000000<000000`3oool5000000030?ooo`000000oooo00<0oooo00<000000?ooo`0000000`3oool0
0080oooo00<000000?ooo`000000103oool010000000oooo0?ooo`3oool6000000804`0000<00000
0?ooo`0000001@3oool00`000000oooo000000030?ooo`000P3oool00`000000oooo000000040?oo
o`030000003oool0oooo00<0oooo1P0000020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`0000000`3oool00080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool00080oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00@00000
0?ooo`3oool000000`3oool00080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000`3oool00080oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool000000`3oool000<0oooo00<000000?ooo`0000001@3oool00`000000oooo
0?ooo`030?ooo`L00000103oool010000000oooo0?ooo`0000030?ooo`000`3oool00`000000oooo
000000050?ooo`030000003oool0oooo00<0oooo00L0000006@0001T0000I0000000001T00000000
00@0oooo00@000000?ooo`3oool000000`3oool000<0oooo00<000000?ooo`0000001@3oool00`00
0000oooo0?ooo`030?ooo`070000001T0000I00006@000000000I000000000040?ooo`030000003o
ool0000000@0oooo00030?ooo`030000003oool0000000@0oooo2000000606@000070000003oool0
oooo0?ooo`000000oooo000000040?ooo`000`3oool00`000000oooo000000050000000306/00000
0000J`000080J`003@0000000`3oool000000?ooo`030?ooo`000`3oool00`000000oooo00000003
0?ooo`040000001[0000J`00000000<0J`000P0000060:ndg0070000003oool0oooo0?ooo`000000
oooo000000040?ooo`000`3oool2000000@0oooo00<0000006/0001[0000101[0002000000H0[kCL
00<000000?ooo`3oool00P3oool2000000@0oooo00030?ooo`800000103oool9000000H0[kCL00<0
00000?ooo`3oool00P3oool2000000@0oooo00030?ooo`030000003oool0oooo00<0oooo00<00000
0:ndg02_]=`0102_]=`2000000H0[kCL00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`000`3ooolL000000@0oooo0000\
\>"],
  ImageRangeCache->{{{91.5625, 118.813}, {739.438, 692}} -> {-1.57393, \
13.6364, 0.0157732, 0.0157732}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Listings and plots with Stage 2 Data", "Subsection"],

Cell["Calculate[Stage2]", "Input"],

Cell[CellGroupData[{

Cell["View the eigenfrequencies", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
Table[{Length[allvars]-index+1, Hz2[[index]]}, {index, 1, Length[allvars]}]\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \({{6, 7.929884455271951`}, {5, 5.525695092690836`}, {4, 
        2.1531127671514056`}, {3, 1.9291258770160107`}, {2, 
        1.6374043059813146`}, {1, 1.5174893099521674`}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["View the important low-frequency modes", "Text"],

Cell[CellGroupData[{

Cell["\<\
Join[\t
\t{{\"N\",\"f\",\"type\"}},
\tTable[
\t\tJoin[
\t\t\t{i},
\t\t\t{Hz2[[-i]]},
\t\t\timportant[e2ni.eigenvectors2[[-i]],0.7]
\t\t],
\t\t{i,noofLF}
\t]
]//TableForm\
\>", "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"N\"\>", "\<\"f\"\>", "\<\"type\"\>"},
          {"1", "1.5174893099521674`", "pitch0"},
          {"2", "1.6374043059813146`", "roll0"},
          {"3", "1.9291258770160107`", "pitch0"},
          {"4", "2.1531127671514056`", "yaw0"},
          {"5", "5.525695092690836`", "z0"},
          {"6", "7.929884455271951`", "roll0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["View the higher frequency modes", "Text"],

Cell[CellGroupData[{

Cell["\<\
Join[\t
\t{{\"N\",\"f\",\"type\"}},
\tTable[
\t\tJoin[
\t\t\t{i},
\t\t\t{Hz2[[-i]]},
\t\t\timportant[e2ni.eigenvectors2[[-i]],0.7]
\t\t],
\t\t{i,noofLF+1,Length[allvars]}
\t]
]//TableForm\
\>", "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"N\"\>", "\<\"f\"\>", "\<\"type\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Classify the modes", "Text"],

Cell[CellGroupData[{

Cell["\<\
longpitchmodes2 = \
Select[Range[-noofLF,-1],longpitchQ[e2ni.eigenvectors2[[#]]]&]\
\>", "Input"],

Cell[BoxData[
    \({\(-3\), \(-1\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
transrollmodes2 = \
Select[Range[-noofLF,-1],transrollQ[e2ni.eigenvectors2[[#]]]&]\
\>", "Input"],

Cell[BoxData[
    \({\(-6\), \(-2\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
yawmodes2 = Select[Range[-noofLF,-1],yawQ[e2ni.eigenvectors2[[#]]]&]\
\>", "Input"],

Cell[BoxData[
    \({\(-4\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
vertmodes2 = Select[Range[-noofLF,-1],vertQ[e2ni.eigenvectors2[[#]]]&]\
\>", "Input"],

Cell[BoxData[
    \({\(-5\)}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["View the mode frequencies by groups", "Text"],

Cell[CellGroupData[{

Cell["longpitchfreqs2 = Hz2[[longpitchmodes2]]", "Input"],

Cell[BoxData[
    \({1.9291258770160107`, 1.5174893099521674`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["transrollfreqs2 = Hz2[[transrollmodes2]]", "Input"],

Cell[BoxData[
    \({7.929884455271951`, 1.6374043059813146`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["yawfreqs2 = Hz2[[yawmodes2]]", "Input"],

Cell[BoxData[
    \({2.1531127671514056`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["vertfreqs2 = Hz2[[vertmodes2]]", "Input"],

Cell[BoxData[
    \({5.525695092690836`}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Mode shape listings/plots", "Text"],

Cell[CellGroupData[{

Cell["#1", "Text"],

Cell[CellGroupData[{

Cell["Hz2[[-1]]", "Input"],

Cell[BoxData[
    \(1.5174893099521674`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pretty[Chop[e2ni . eigenvectors2[\([\(-1\)]\)], 10^\(-4\)]]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
          {"\<\"optic\"\>", \(-0.02614122254290197`\), "0", "0", "0", 
            "0.9996582598488157`", "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Status["\<Plotting stage 2 mode 1\>"]\ ; 
    eigenplot[eigenvectors2[\([\(-1\)]\)],  .5, {0, \(-1\), 0}, \ 
      floatmatrix2]\ ; Done[]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 6.00564 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.50282 6.00564 0 6.00564 [
[ 0 0 0 0 ]
[ 1 6.00564 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 6.00564 L
s
0 6.00564 m
.19985 4.80542 L
s
.19985 4.80542 m
.19985 1.20023 L
s
.19985 1.20023 m
0 0 L
s
1 0 m
.80015 1.20023 L
s
.80015 1.20023 m
.80015 4.80542 L
s
.80015 4.80542 m
1 6.00564 L
s
1 6.00564 m
1 0 L
s
0 0 m
0 6.00564 L
s
0 6.00564 m
1 6.00564 L
s
1 6.00564 m
1 0 L
s
1 0 m
0 0 L
s
.19985 1.20023 m
.80015 1.20023 L
s
.80015 1.20023 m
.80015 4.80542 L
s
.80015 4.80542 m
.19985 4.80542 L
s
.19985 4.80542 m
.19985 1.20023 L
s
0 0 m
1 0 L
1 6.00564 L
0 6.00564 L
closepath
clip
newpath
.5 Mabswid
.655 .466 .616 r
.26556 3.55445 m .4578 3.44947 L .37151 3.28814 L p F P
0 g
s
.30363 3.37969 m
.31066 3.44109 L
s
.655 .466 .616 r
.37151 3.28814 m .1805 3.39245 L .26556 3.55445 L p F P
0 g
s
.747 .68 .786 r
.1805 3.39245 m .37151 3.28814 L .28359 3.13046 L p F P
0 g
s
.747 .68 .786 r
.17337 3.3799 m .1805 3.39245 L p .28359 3.13046 L F P
0 g
s
.747 .68 .786 r
.28359 3.13046 m .17145 3.1917 L .17337 3.3799 L p F P
0 g
s
.707 .577 .707 r
.5 4.97546 m .75863 4.97546 L p .24137 4.71682 L F P
0 g
s
.707 .577 .707 r
.75863 4.97546 m .75863 4.71682 L .24137 4.71682 L p F P
0 g
s
.707 .577 .707 r
.24137 4.71682 m .24137 4.97546 L .5 4.97546 L p F P
0 g
s
.752 .614 .046 r
.24137 4.97546 m .24137 4.71682 L .20782 4.93912 L p F P
0 g
s
0 0 .046 r
.75863 4.71682 m .75863 4.97546 L .77438 5.09559 L p F P
0 g
s
0 0 .046 r
.79218 4.93912 m .75863 4.71682 L p .77438 5.09559 L F P
0 g
s
.282 0 0 r
.75863 4.71682 m .79218 4.93912 L .20782 4.93912 L p F P
0 g
s
.282 0 0 r
.20782 4.93912 m .24137 4.71682 L .75863 4.71682 L p F P
0 g
s
.48209 4.93912 m
.5 5.09559 L
s
.42704 4.45804 m
.4658 4.79676 L
s
.752 .614 .046 r
.22562 5.09559 m .24137 4.97546 L p .20782 4.93912 L F P
0 g
s
.517 .222 .406 r
.34119 3.71148 m .53706 3.60451 L .4578 3.44947 L p F P
0 g
s
.32022 3.5246 m
.34152 3.71074 L
s
.517 .222 .406 r
.4578 3.44947 m .26556 3.55445 L .34119 3.71148 L p F P
0 g
s
.784 .847 .899 r
.1671 3.06082 m .17145 3.1917 L p .19944 2.98626 L F P
0 g
s
.784 .847 .899 r
.17145 3.1917 m .28359 3.13046 L .19944 2.98626 L p F P
0 g
s
.784 .847 .899 r
.19944 2.98626 m .16524 3.00494 L .1671 3.06082 L p F P
0 g
s
.342 0 .167 r
.40184 3.85283 m .60364 3.74263 L .53706 3.60451 L p F P
0 g
s
.342 0 .167 r
.53706 3.60451 m .34119 3.71148 L .40184 3.85283 L p F P
0 g
s
.34175 3.71279 m
.42704 4.45804 L
s
.757 .949 .941 r
.16524 3.00494 m .19944 2.98626 L .15986 2.92236 L closepath p F P
0 g
s
.14 0 0 r
.44164 3.96662 m .65146 3.85204 L .60364 3.74263 L p F P
0 g
s
.14 0 0 r
.60364 3.74263 m .40184 3.85283 L .44164 3.96662 L p F P
0 g
s
.01 w
.38457 2.74092 Mdot
.61543 2.74092 Mdot
.5 Mabswid
.752 .614 .046 r
.20782 4.93912 m .20782 5.23129 L .22562 5.09559 L p F P
0 g
s
0 0 .046 r
.77438 5.09559 m .79218 5.23129 L .79218 4.93912 L p F P
0 g
s
0 0 0 r
.4547 4.03984 m .67419 3.91999 L .65146 3.85204 L p F P
0 g
s
0 0 0 r
.65146 3.85204 m .44164 3.96662 L .4547 4.03984 L p F P
0 g
s
.707 .577 .707 r
.5 5.23129 m .20782 5.23129 L .20782 4.93912 L p F P
0 g
s
.707 .577 .707 r
.79218 4.93912 m .79218 5.23129 L .5 5.23129 L p F P
0 g
s
.707 .577 .707 r
.20782 4.93912 m .79218 4.93912 L p .5 5.23129 L F P
0 g
s
0 0 0 r
.436 4.05967 m .66608 3.93403 L .67419 3.91999 L p F P
0 g
s
0 0 0 r
.67419 3.91999 m .4547 4.03984 L .436 4.05967 L p F P
0 g
s
.707 .577 .707 r
.5 5.28053 m .79863 5.28053 L p .20137 4.9819 L F P
0 g
s
.707 .577 .707 r
.79863 5.28053 m .79863 4.9819 L .20137 4.9819 L p F P
0 g
s
.707 .577 .707 r
.20137 4.9819 m .20137 5.28053 L .5 5.28053 L p F P
0 g
s
.752 .614 .046 r
.18017 5.44221 m .20137 5.28053 L p .15573 5.28433 L F P
0 g
s
.752 .614 .046 r
.20137 5.28053 m .20137 4.9819 L .15573 5.28433 L p F P
0 g
s
0 0 .046 r
.79863 4.9819 m .79863 5.28053 L .81983 5.44221 L p F P
0 g
s
0 0 .046 r
.84427 5.28433 m .79863 4.9819 L p .81983 5.44221 L F P
0 g
s
.282 0 0 r
.79863 4.9819 m .84427 5.28433 L .15573 5.28433 L p F P
0 g
s
.282 0 0 r
.15573 5.28433 m .20137 4.9819 L .79863 4.9819 L p F P
0 g
s
.526 .915 .796 r
.38299 4.01605 m .62355 3.88469 L .66608 3.93403 L p F P
0 g
s
.526 .915 .796 r
.66608 3.93403 m .436 4.05967 L .38299 4.01605 L p F P
0 g
s
.752 .614 .046 r
.15573 5.28433 m .15573 5.6286 L .18017 5.44221 L p F P
0 g
s
0 0 .046 r
.81983 5.44221 m .84427 5.6286 L .84427 5.28433 L p F P
0 g
s
.47731 5.28433 m
.5 5.44221 L
s
.01 w
.36361 2.69336 Mdot
.63639 2.69336 Mdot
.5 Mabswid
.694 .973 .92 r
.29764 3.90578 m .54722 3.76949 L .62355 3.88469 L p F P
0 g
s
.694 .973 .92 r
.62355 3.88469 m .38299 4.01605 L .29764 3.90578 L p F P
0 g
s
.195 0 0 r
.07555 2.98026 m .08189 2.90392 L .11703 2.98172 L p F P
0 g
s
.195 0 0 r
.11703 2.98172 m .07346 3.00552 L .07555 2.98026 L p F P
0 g
s
.435 .097 .292 r
.06735 3.14968 m .07346 3.00552 L p .21212 3.17262 L F P
0 g
s
.435 .097 .292 r
.07346 3.00552 m .11703 2.98172 L .21212 3.17262 L p F P
0 g
s
.779 .906 .929 r
.18813 3.73664 m .44386 3.59699 L .54722 3.76949 L p F P
0 g
s
.779 .906 .929 r
.54722 3.76949 m .29764 3.90578 L .18813 3.73664 L p F P
0 g
s
.25508 3.73832 m
.45894 5.15658 L
s
.435 .097 .292 r
.21212 3.17262 m .06294 3.25408 L .06735 3.14968 L p F P
0 g
s
.634 .426 .583 r
.06187 3.33387 m .06294 3.25408 L p .32651 3.38808 L F P
0 g
s
.634 .426 .583 r
.06294 3.25408 m .21212 3.17262 L .32651 3.38808 L p F P
0 g
s
.758 .712 .81 r
.06859 3.52892 m .32651 3.38808 L .44386 3.59699 L p F P
0 g
s
.758 .712 .81 r
.44386 3.59699 m .18813 3.73664 L .06859 3.52892 L p F P
0 g
s
.22518 3.53026 m
.25508 3.73832 L
s
.707 .577 .707 r
.5 5.6286 m .15573 5.6286 L .15573 5.28433 L p F P
0 g
s
.707 .577 .707 r
.84427 5.28433 m .84427 5.6286 L .5 5.6286 L p F P
0 g
s
.707 .577 .707 r
.15573 5.28433 m .84427 5.28433 L p .5 5.6286 L F P
0 g
s
.634 .426 .583 r
.06859 3.52892 m .05949 3.51136 L .06187 3.33387 L p F P
0 g
s
.634 .426 .583 r
.32651 3.38808 m .06859 3.52892 L p .06187 3.33387 L F P
0 g
s
.25 Mabswid
0 0 m
0 6.00564 L
s
0 6.00564 m
1 6.00564 L
s
1 6.00564 m
1 0 L
s
1 0 m
0 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{108.813, 653.438},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40001/0002SB000`400?l00000o`00003oK03oool0
06`0oooo001/0?ooo`00K000000000030000003oool0oooo06P0oooo0@00000000030000003oool0
oooo06P0oooo0@00000000030000003oool0oooo06P0oooo0@00000000800000J03oool200000000
0P00001X0?ooo`8000000002000006P0oooo0P00000000800000J03oool2000000000P00001X0?oo
o`8000000002000006P0oooo0P00000000030000003oool0000006H0oooo0@0000010?ooo`400000
00000`000000oooo0000001V0?ooo`4000000@3oool10000000000<000000?ooo`000000IP3oool1
00000040oooo0@00000000030000003oool0000006H0oooo0@0000010?ooo`40000000000`000000
oooo0000001V0?ooo`4000000@3oool10000000000<000000?ooo`000000IP3oool100000040oooo
0@00000000040000003oool0oooo000006@0oooo00<000000?ooo`3oool00@00000000040000003o
ool0oooo000006@0oooo00<000000?ooo`3oool00@00000000040000003oool0oooo000006@0oooo
00<000000?ooo`3oool00@00000000040000003oool0oooo000006@0oooo00<000000?ooo`3oool0
0@00000000040000003oool0oooo000006@0oooo00<000000?ooo`3oool00@00000000040000003o
ool0oooo000006@0oooo00<000000?ooo`3oool00@00000000050000003oool0oooo0?ooo`000000
HP3oool010000000oooo0?ooo`3oool10000000000D000000?ooo`3oool0oooo0000001R0?ooo`04
0000003oool0oooo0?ooo`40000000001@000000oooo0?ooo`3oool000000680oooo00@000000?oo
o`3oool0oooo0@00000000050000003oool0oooo0?ooo`000000HP3oool010000000oooo0?ooo`3o
ool10000000000D000000?ooo`3oool0oooo0000001R0?ooo`040000003oool0oooo0?ooo`400000
00001@000000oooo0?ooo`3oool000000680oooo00@000000?ooo`3oool0oooo0@00000000030000
003oool0oooo0080oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`020?ooo`400000
00000`000000oooo0?ooo`020?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool00P3o
ool10000000000<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0
oooo0080oooo0@00000000030000003oool0oooo0080oooo00<000000?ooo`3oool0GP3oool00`00
0000oooo0?ooo`020?ooo`40000000000`000000oooo0?ooo`020?ooo`030000003oool0oooo05h0
oooo00<000000?ooo`3oool00P3oool10000000000<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1N0?ooo`030000003oool0oooo0080oooo0@00000000030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0G03oool00`000000oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`03
0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool00`3oool10000000000<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo00<0oooo0@0000000003
0000003oool0oooo00<0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`030?ooo`40
000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0
0`3oool10000000000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1L0?ooo`030000003o
ool0oooo00<0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0FP3oool0
0`000000oooo0?ooo`040?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo
05X0oooo00<000000?ooo`3oool0103oool10000000000<000000?ooo`3oool0103oool00`000000
oooo0?ooo`1J0?ooo`030000003oool0oooo00@0oooo0@00000000030000003oool0oooo00@0oooo
00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`040?ooo`40000000000`000000oooo0?oo
o`040?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0103oool10000000000<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00@0oooo0@000000
00030000003oool0oooo00@0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`040?oo
o`40000000000`000000oooo0?ooo`050?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool01@3oool10000000000<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo00D0oooo0@00000000030000003oool0oooo00D0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`050?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00D0
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo
0?ooo`060?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool01P3oool10000000000<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo00H0oooo0@00
000000030000003oool0oooo00H0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`06
0?ooo`40000000000`000000oooo0?ooo`060?ooo`030000003oool0oooo05H0oooo00<000000?oo
o`3oool01P3oool10000000000<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1F0?ooo`03
0000003oool0oooo00H0oooo0@00000000030000003oool0oooo00H0oooo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`060?ooo`40000000000`000000oooo0?ooo`070?ooo`030000003o
ool0oooo05@0oooo00<000000?ooo`3oool01`3oool10000000000<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`1D0?ooo`030000003oool0oooo00L0oooo0@00000000030000003oool0oooo
00L0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`070?ooo`40000000000`000000
oooo0?ooo`070?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool01`3oool100000000
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo00L0oooo
0@00000000030000003oool0oooo00L0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?oo
o`070?ooo`40000000000`000000oooo0?ooo`080?ooo`030000003oool0oooo0580oooo00<00000
0?ooo`3oool0203oool10000000000<000000?ooo`3oool0203oool00`000000oooo0?ooo`1B0?oo
o`030000003oool0oooo00P0oooo0@00000000030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0DP3oool00`000000oooo0?ooo`080?ooo`40000000000`000000oooo0?ooo`080?ooo`030000
003oool0oooo0580oooo00<000000?ooo`3oool0203oool10000000000<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo00P0oooo0@00000000030000003oool0
oooo00P0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`080?ooo`40000000000`00
0000oooo0?ooo`090?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool02@3oool10000
000000<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo00T0
oooo0@00000000030000003oool0oooo00T0oooo00<000000?ooo`3oool0D03oool00`000000oooo
0?ooo`090?ooo`40000000000`000000oooo0?ooo`090?ooo`030000003oool0oooo0500oooo00<0
00000?ooo`3oool02@3oool10000000000<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1@
0?ooo`030000003oool0oooo00T0oooo0@00000000030000003oool0oooo00T0oooo00<000000?oo
o`3oool0D03oool00`000000oooo0?ooo`090?ooo`40000000000`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo04h0oooo00<000000?ooo`3oool02P3oool10000000000<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo00X0oooo0@00000000030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0:0?ooo`4000000000
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool02P3oool1
0000000000<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo
00X0oooo0@00000000030000003oool0oooo00X0oooo00<000000?ooo`3oool0CP3oool00`000000
oooo0?ooo`0:0?ooo`40000000000`000000oooo0?ooo`0;0?ooo`030000003oool0oooo04`0oooo
00<000000?ooo`3oool02`3oool10000000000<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`1<0?ooo`030000003oool0oooo00/0oooo0@00000000030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`0;0?ooo`40000000000`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo04`0oooo00<000000?ooo`3oool02`3oool10000000000<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo00/0oooo0@00000000030000
003oool0oooo00/0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0;0?ooo`400000
00000`000000oooo0?ooo`0;0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool02`3o
ool10000000000<000000?ooo`3oool0303oool00`000000oooo0?ooo`1:0?ooo`030000003oool0
oooo00`0oooo0@00000000030000003oool0oooo00`0oooo00<000000?ooo`3oool0BP3oool00`00
0000oooo0?ooo`0<0?ooo`40000000000`000000oooo0?ooo`0<0?ooo`030000003oool0oooo04X0
oooo00<000000?ooo`3oool0303oool10000000000<000000?ooo`3oool0303oool00`000000oooo
0?ooo`1:0?ooo`030000003oool0oooo00`0oooo0@00000000030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0BP3oool00`000000oooo0?ooo`0<0?ooo`40000000000`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0303oool10000000000<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00d0oooo0@0000000003
0000003oool0oooo00d0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0=0?ooo`40
000000000`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0
3@3oool10000000000<000000?ooo`3oool03@3oool00`000000oooo0?ooo`180?ooo`030000003o
ool0oooo00d0oooo0@00000000030000003oool0oooo00d0oooo00<000000?ooo`3oool0B03oool0
0`000000oooo0?ooo`0=0?ooo`40000000000`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
04P0oooo00<000000?ooo`3oool03@3oool10000000000<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`160?ooo`030000003oool0oooo00h0oooo0@00000000030000003oool0oooo00h0oooo
00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0>0?ooo`40000000000`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool03P3oool10000000000<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00h0oooo0@000000
00030000003oool0oooo00h0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0>0?oo
o`40000000000`000000oooo0?ooo`0>0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3o
ool03P3oool10000000000<000000?ooo`3oool03`3oool00`000000oooo0?ooo`140?ooo`030000
003oool0oooo00l0oooo0@00000000030000003oool0oooo00l0oooo00<000000?ooo`3oool0A03o
ool00`000000oooo0?ooo`0?0?ooo`40000000000`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo04@0oooo00<000000?ooo`3oool03`3oool10000000000<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`140?ooo`030000003oool0oooo00l0oooo0@00000000030000003oool0oooo00l0
oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0?0?ooo`40000000000`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool03`3oool10000000000<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0100oooo0@00
000000030000003oool0oooo0100oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0@
0?ooo`40000000000`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0480oooo00<000000?oo
o`3oool0403oool10000000000<000000?ooo`3oool0403oool00`000000oooo0?ooo`120?ooo`03
0000003oool0oooo0100oooo0@00000000030000003oool0oooo0100oooo00<000000?ooo`3oool0
@P3oool00`000000oooo0?ooo`0@0?ooo`40000000000`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo0480oooo00<000000?ooo`3oool0403oool10000000000<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`100?ooo`030000003oool0oooo0140oooo0@00000000030000003oool0oooo
0140oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0A0?ooo`40000000000`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool04@3oool100000000
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0140oooo
0@00000000030000003oool0oooo0140oooo00<000000?ooo`3oool0@03oool00`000000oooo0?oo
o`0A0?ooo`40000000000`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0400oooo00<00000
0?ooo`3oool04@3oool10000000000<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0n0?oo
o`030000003oool0oooo0180oooo0@00000000030000003oool0oooo0180oooo00<000000?ooo`3o
ool0?P3oool00`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo03h0oooo00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3oool04P3o
oom2000001@0oooo0@00000000030000003oool0oooo0180oooo00<000000?ooo`3oool0?P3oool0
0`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
03h0oooo00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`0n0?ooo`030000003oool0oooo0180oooo0@00000000030000003oool0oooo0180oooo
00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool04P3oool10000000000<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0180oooo0@000000
00030000003oool0oooo0180oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0B0?oo
o`40000000000`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3o
ool04P3oool10000000000<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0n0?ooo`030000
003oool0oooo0180oooo0@00000000030000003oool0oooo0180oooo00<000000?ooo`3oool0?P3o
ool00`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo03h0oooo00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`0n0?ooo`030000003oool0oooo0180oooo0@00000000030000003oool0oooo0180
oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool04P3oool10000000000<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0180oooo0@00
000000030000003oool0oooo0180oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0B
0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03h0oooo00<000000?oo
o`3oool04P3oool10000000000<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0n0?ooo`03
0000003oool0oooo0180oooo0@00000000030000003oool0oooo0180oooo00<000000?ooo`3oool0
?P3oool00`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo03h0oooo00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0180oooo0@00000000030000003oool0oooo
0180oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0B0?ooo`40000000000`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool04P3oool100000000
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0180oooo
0@00000000030000003oool0oooo0180oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?oo
o`0B0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03h0oooo00<00000
0?ooo`3oool04P3oool10000000000<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0n0?oo
o`030000003oool0oooo0180oooo0@00000000030000003oool0oooo0180oooo00<000000?ooo`3o
ool0?P3oool00`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo03h0oooo00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0180oooo0@00000000030000003oool0
oooo0180oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0B0?ooo`40000000000`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool04P3oool10000
000000<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0180
oooo0@00000000030000003oool0oooo0180oooo00<000000?ooo`3oool0?P3oool00`000000oooo
0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03h0oooo00<0
00000?ooo`3oool04P3oool10000000000<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0n
0?ooo`030000003oool0oooo0180oooo0@00000000030000003oool0oooo0180oooo00<000000?oo
o`3oool0?P3oool00`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo03h0oooo00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0180oooo0@00000000030000003o
ool0oooo0180oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0B0?ooo`4000000000
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool04P3oool1
0000000000<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo
0180oooo0@00000000030000003oool0oooo0180oooo00<000000?ooo`3oool0?P3oool00`000000
oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03h0oooo
00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0n0?ooo`030000003oool0oooo0180oooo0@00000000030000003oool0oooo0180oooo00<00000
0?ooo`3oool0?P3oool00`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0180oooo0@00000000030000
003oool0oooo0180oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0B0?ooo`400000
00000`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool04P3o
ool10000000000<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0
oooo0180oooo0@00000000030000003oool0oooo0180oooo00<000000?ooo`3oool0?P3oool00`00
0000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03h0
oooo00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`0n0?ooo`030000003oool0oooo0180oooo0@00000000030000003oool0oooo0180oooo00<0
00000?ooo`3oool0?P3oool00`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool04P3oool10000000000<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0180oooo0@0000000003
0000003oool0oooo0180oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0B0?ooo`40
000000000`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0
4P3oool10000000000<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0n0?ooo`030000003o
ool0oooo0180oooo0@00000000030000003oool0oooo0180oooo00<000000?ooo`3oool0?P3oool0
0`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
03h0oooo00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`0n0?ooo`030000003oool0oooo0180oooo0@00000000030000003oool0oooo0180oooo
00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool04P3oool10000000000<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0180oooo0@000000
00030000003oool0oooo0180oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0B0?oo
o`40000000000`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3o
ool04P3oool10000000000<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0n0?ooo`030000
003oool0oooo0180oooo0@00000000030000003oool0oooo0180oooo00<000000?ooo`3oool0?P3o
ool00`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo03h0oooo00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`0n0?ooo`030000003oool0oooo0180oooo0@00000000030000003oool0oooo0180
oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool04P3oool10000000000<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0180oooo0@00
000000030000003oool0oooo0180oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0B
0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03h0oooo00<000000?oo
o`3oool04P3oool10000000000<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0n0?ooo`03
0000003oool0oooo0180oooo0@00000000030000003oool0oooo0180oooo00<000000?ooo`3oool0
?P3oool00`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo03h0oooo00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0180oooo0@00000000030000003oool0oooo
0180oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0B0?ooo`40000000000`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool04P3oool100000000
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0180oooo
0@00000000030000003oool0oooo0180oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?oo
o`0B0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03h0oooo00<00000
0?ooo`3oool04P3oool10000000000<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0n0?oo
o`030000003oool0oooo0180oooo0@00000000030000003oool0oooo0180oooo00<000000?ooo`3o
ool0?P3oool00`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo03h0oooo00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0180oooo0@00000000030000003oool0
oooo0180oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0B0?ooo`40000000000`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool04P3oool10000
000000<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0180
oooo0@00000000030000003oool0oooo0180oooo00<000000?ooo`3oool0?P3oool00`000000oooo
0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03h0oooo00<0
00000?ooo`3oool04P3oool10000000000<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0n
0?ooo`030000003oool0oooo0180oooo0@00000000030000003oool0oooo0180oooo00<000000?oo
o`3oool0?P3oool00`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo03h0oooo00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0180oooo0@00000000030000003o
ool0oooo0180oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0B0?ooo`4000000000
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool04P3oool1
0000000000<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo
0180oooo0@00000000030000003oool0oooo0180oooo00<000000?ooo`3oool0?P3oool00`000000
oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03h0oooo
00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0n0?ooo`030000003oool0oooo0180oooo0@00000000030000003oool0oooo0180oooo00<00000
0?ooo`3oool0?P3oool00`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0180oooo0@00000000030000
003oool0oooo0180oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0B0?ooo`400000
00000`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool04P3o
ool10000000000<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0
oooo0180oooo0@00000000030000003oool0oooo0180oooo00<000000?ooo`3oool0?P3oool00`00
0000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03h0
oooo00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`0n0?ooo`030000003oool0oooo0180oooo0@00000000030000003oool0oooo0180oooo00<0
00000?ooo`3oool0?P3oool00`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool04P3oool10000000000<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0180oooo0@0000000003
0000003oool0oooo0180oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0B0?ooo`40
000000000`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0
4P3oool10000000000<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0n0?ooo`030000003o
ool0oooo0180oooo0@00000000030000003oool0oooo0180oooo00<000000?ooo`3oool0?P3oool0
0`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
03h0oooo00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`0n0?ooo`030000003oool0oooo0180oooo0@00000000030000003oool0oooo0180oooo
00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool04P3oool10000000000<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0180oooo0@000000
00030000003oool0oooo0180oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0B0?oo
o`40000000000`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3o
ool04P3oool10000000000<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0n0?ooo`030000
003oool0oooo0180oooo0@00000000030000003oool0oooo0180oooo00<000000?ooo`3oool0?P3o
ool00`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo03h0oooo00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`0n0?ooo`030000003oool0oooo0180oooo0@00000000030000003oool0oooo0180
oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool04P3oool10000000000<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0180oooo0@00
000000030000003oool0oooo0180oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0B
0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03h0oooo00<000000?oo
o`3oool04P3oool10000000000<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0n0?ooo`03
0000003oool0oooo0180oooo0@00000000030000003oool0oooo0180oooo00<000000?ooo`3oool0
?P3oool00`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo03h0oooo00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0180oooo0@00000000030000003oool0oooo
0180oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0B0?ooo`40000000000`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool04P3oool100000000
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0180oooo
0@00000000030000003oool0oooo0180oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?oo
o`0B0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03h0oooo00<00000
0?ooo`3oool04P3oool10000000000<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0n0?oo
o`030000003oool0oooo0180oooo0@00000000030000003oool0oooo0180oooo00<000000?ooo`3o
ool0?P3oool00`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo03h0oooo00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0180oooo0@00000000030000003oool0
oooo0180oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0B0?ooo`40000000000`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool04P3oool10000
000000<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0180
oooo0@00000000030000003oool0oooo0180oooo00<000000?ooo`3oool0?P3oool00`000000oooo
0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03h0oooo00<0
00000?ooo`3oool04P3oool10000000000<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0n
0?ooo`030000003oool0oooo0180oooo0@00000000030000003oool0oooo0180oooo00<000000?oo
o`3oool0?P3oool00`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo03h0oooo00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0180oooo0@00000000030000003o
ool0oooo0180oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0180oooo0@00000000030000003oool0oooo
0180oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0B0?ooo`40000000000`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool04P3oool100000000
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0180oooo
0@00000000030000003oool0oooo0180oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04P3oool10000000000<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0180oooo0@000000
00030000003oool0oooo0180oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0B0?oo
o`40000000000`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3o
ool04P3oool10000000000<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0n0?ooo`030000
003oool0oooo0180oooo0@00000000030000003oool0oooo0180oooo00<000000?ooo`3oool0?P3o
ool00`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo03h0oooo00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`0n0?ooo`030000003oool0oooo0180oooo0@00000000030000003oool0oooo0180
oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool04P3oool10000000000<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0180oooo0@00
000000030000003oool0oooo0180oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0B
0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03h0oooo00<000000?oo
o`3oool04P3oool10000000000<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0n0?ooo`03
0000003oool0oooo0180oooo0@00000000030000003oool0oooo0180oooo00<000000?ooo`3oool0
?P3oool00`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo03h0oooo00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0180oooo0@00000000030000003oool0oooo
0180oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0B0?ooo`40000000000`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool04P3oool100000000
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo03h0oooo
00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool04P3oool10000000000<00000
0?ooo`3oool01@3oool2000000L0oooo00D000000?ooo`3oool0oooo000000100?ooo`030000003o
ool0oooo0180oooo0@00000000030000003oool0oooo00D0oooo0P0000070?ooo`8000000P3oool0
0`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0180oooo0@00000000030000003oool0oooo
00D0oooo00<000000340000000001P3oool200000080oooo00<000000?ooo`3oool0?P3oool00`00
0000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`050?ooo`030000000a0000000000H0
oooo00D000000<7bl0000000oooo000000100?ooo`030000003oool0oooo0180oooo0@0000000003
0000003oool0oooo00D0oooo00@000000340000a000000001@3oool00`000000`O;`0<7bl0020000
0400oooo00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3oool01@3oool010000000
<@000340000000050?ooo`0300000031l_00`O;`00800000@03oool00`000000oooo0?ooo`0B0?oo
o`40000000000`000000oooo0?ooo`050?ooo`050000000a0000<@00034000000000103oool01@00
0000`O;`0<7bl031l_0000000400oooo00<000000?ooo`3oool04P3oool10000000000<000000?oo
o`3oool01@3oool00`000000<@0000000002000000@0oooo00H000000<7bl031l_0000000<SHiP00
000o0?ooo`030000003oool0oooo0180oooo0@00000000030000003oool0oooo00@0oooo0`000003
06lHBP040000003oool0oooo0?ooo`<000000P38f>H00`000000oooo0?ooo`0m0?ooo`030000003o
ool0oooo0180oooo0@00000000030000003oool0oooo00@0oooo00<0000006lHBP1_64X00`1_64X0
1@000000oooo0?ooo`3oool0000000D0b=SV00<000000?ooo`3oool0?03oool00`000000oooo0?oo
o`0B0?ooo`40000000000`000000oooo0?ooo`040?ooo`030000001_64X0KaQ:00@0KaQ:00@00000
0?ooo`3oool000001@38f>H00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0180oooo0@00
000000030000003oool0oooo00@0oooo00<0000006lHBP1_64X0101_64X010000000oooo0?ooo`00
00060<SHiP030000003oool0oooo03/0oooo00<000000?ooo`3oool04P3oool10000000000<00000
0?ooo`3oool0103oool00`000000KaQ:06lHBP0506lHBP030000003oool0000000H0b=SV00<00000
0?ooo`3oool0>`3oool00`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`040?oo
o`030000001_64X0KaQ:00D0KaQ:00@000000?ooo`3oool000001P38f>H00`000000oooo0?ooo`0j
0?ooo`030000003oool0oooo0180oooo0@00000000030000003oool0oooo00@0oooo00<0000006lH
BP1_64X01P1_64X00`000000oooo000000060<SHiP030000003oool0oooo03X0oooo00<000000?oo
o`3oool04P3oool10000000000<000000?ooo`3oool0103oool00`000000KaQ:06lHBP0606lHBP03
0000003oool0000000L0b=SV00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0B0?ooo`40
000000000`000000oooo0?ooo`040?ooo`030000001_64X0KaQ:00L0KaQ:0P0000080<SHiP030000
003oool0oooo03P0oooo00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3oool0103o
ool00`000000KaQ:06lHBP0706lHBP8000002038f>H00`000000oooo0?ooo`0h0?ooo`030000003o
ool0oooo0180oooo0@00000000030000003oool0oooo00@0oooo00<0000006lHBP1_64X0201_64X0
0`000000b=SV0<SHiP070<SHiP030000003oool0oooo03L0oooo00<000000?ooo`3oool04P3oool1
0000000000<000000?ooo`3oool0103oool00`000000KaQ:06lHBP0806lHBP0300000038f>H0b=SV
00L0b=SV00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0B0?ooo`40000000000`000000
oooo0?ooo`040?ooo`030000001_64X0KaQ:00T0KaQ:00<000000<SHiP38f>H01`38f>H00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo0180oooo0@00000000030000003oool0oooo00@0oooo
00<0000006lHBP1_64X02@1_64X00`000000b=SV0<SHiP070<SHiP030000003oool0oooo03H0oooo
00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3oool0103oool00`000000KaQ:06lH
BP0:06lHBP0300000038f>H0b=SV00L0b=SV00<000000?ooo`3oool0=@3oool00`000000oooo0?oo
o`0B0?ooo`40000000000`000000oooo0?ooo`040?ooo`030000001_64X0KaQ:00X0KaQ:00<00000
0<SHiP38f>H01@38f>H2000000030;n^b@000000oooo03D0oooo00<000000?ooo`3oool04P3oool1
0000000000<000000?ooo`3oool0103oool00`000000KaQ:06lHBP0;06lHBP0300000038f>H0b=SV
0080b=SV0P0000030;n^b@030000003oool0oooo03@0oooo00<000000?ooo`3oool04P3oool10000
000000<000000?ooo`3oool0103oool00`000000KaQ:06lHBP0;06lHBP0500000038f>H0b=SV0<SH
iP0000001P2o[/T00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0180oooo0@0000000003
0000003oool0oooo00@0oooo00<0000006lHBP1_64X0301_64X3000000L0_jk900<000000?ooo`3o
ool0<`3oool00`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`040?ooo`030000
001_64X0KaQ:00`0KaQ:00<000000;n^b@2o[/T0202o[/T00`000000oooo0?ooo`0b0?ooo`030000
003oool0oooo0180oooo0@00000000030000003oool0oooo00@0oooo00<0000006lHBP1_64X02P1_
64X2000000030:9]U@000000_jk900T0_jk900<000000?ooo`3oool0<@3oool00`000000oooo0?oo
o`0B0?ooo`40000000000`000000oooo0?ooo`040?ooo`030000001_64X0KaQ:00P0KaQ:0P000003
0:9]U@030000002o[/T0_jk900P0_jk900<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0B
0?ooo`40000000000`000000oooo0?ooo`030?ooo`030000001_64X0KaQ:00L0KaQ:0P0000060:9]
U@030000002o[/T0_jk900P0_jk900<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0B0?oo
o`40000000000`000000oooo0?ooo`030?ooo`030000001_64X0KaQ:00D0KaQ:0P0000080:9]U@03
0000002o[/T0_jk900P0_jk900<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0B0?ooo`40
000000000`000000oooo0?ooo`030?ooo`030000001_64X0KaQ:00<0KaQ:0P00000;0:9]U@030000
002o[/T0_jk900P0_jk900<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0B0?ooo`400000
00000`000000oooo0?ooo`030?ooo`040000001_64X0KaQ:06lHBP8000003@2RKID00`000000_jk9
0;n^b@080;n^b@030000003oool0oooo02l0oooo00<000000?ooo`3oool04P3oool10000000000<0
00000?ooo`3oool00`3oool010000000KaQ:00000000000@0:9]U@030000002o[/T0_jk900P0_jk9
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?oo
o`030?ooo`8000004`2RKID00`000000_jk90;n^b@080;n^b@030000003oool0oooo02d0oooo00<0
00000?ooo`3oool04P3oool10000000000<000000?ooo`3oool00`3oool00`000000XVfE0:9]U@0B
0:9]U@030000002o[/T0_jk900P0_jk900<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0B
0?ooo`40000000000`000000oooo0?ooo`030?ooo`030000002RKID0XVfE01<0XVfE00<000000;n^
b@2o[/T0202o[/T00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0180oooo0@0000000003
0000003oool0oooo00<0oooo00<000000:9]U@2RKID04`2RKID00`000000_jk90;n^b@080;n^b@03
0000003oool0oooo02`0oooo00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3oool0
0`3oool00`000000XVfE0:9]U@0D0:9]U@030000002o[/T0_jk900P0_jk900<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`030?ooo`030000002R
KID0XVfE01@0XVfE00<000000;n^b@2o[/T01P2o[/T2000000030:MgW@000000oooo02/0oooo00<0
00000?ooo`3oool04P3oool10000000000<000000?ooo`3oool00`3oool00`000000XVfE0:9]U@0E
0:9]U@030000002o[/T0_jk900<0_jk90P0000030:MgW@030000003oool0oooo02X0oooo00<00000
0?ooo`3oool04P3oool10000000000<000000?ooo`3oool00`3oool00`000000XVfE0:9]U@0E0:9]
U@040000002o[/T0_jk90;n^b@8000001P2WMid00`000000oooo0?ooo`0Y0?ooo`030000003oool0
oooo0180oooo0@00000000030000003oool0oooo00<0oooo00<000000:9]U@2RKID05P2RKID30000
00P0YgNM00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0B0?ooo`40000000000`000000
oooo0?ooo`030?ooo`030000002RKID0XVfE01L0XVfE00<000000:MgW@2WMid0202WMid00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo0180oooo0@00000000030000003oool0oooo00<0oooo
00<000000:9]U@2RKID05`2RKID00`000000YgNM0:MgW@080:MgW@030000003oool0oooo02P0oooo
00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3oool00`3oool00`000000XVfE0:9]
U@0H0:9]U@030000002WMid0YgNM00P0YgNM00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`0B0?ooo`40000000000`000000oooo0?ooo`030?ooo`030000002RKID0XVfE01P0XVfE00<00000
0:MgW@2WMid0202WMid00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0180oooo0@000000
00030000003oool0oooo00<0oooo00<000000:9]U@2RKID06@2RKID00`000000YgNM0:MgW@080:Mg
W@030000003oool0oooo02H0oooo00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3o
ool00`3oool00`000000XVfE0:9]U@0I0:9]U@030000002WMid0YgNM00P0YgNM00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`030?ooo`030000
002RKID0XVfE01X0XVfE00<000000:MgW@2WMid0202WMid00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo0180oooo0@00000000030000003oool0oooo00<0oooo00<000000:9]U@2RKID0602R
KID2000000030<:fc`000000YgNM00P0YgNM00<000000?ooo`3oool09@3oool00`000000oooo0?oo
o`0B0?ooo`40000000000`000000oooo0?ooo`030?ooo`030000002RKID0XVfE01H0XVfE0P000003
0<:fc`030000002WMid0YgNM00P0YgNM00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0B
0?ooo`40000000000`000000oooo0?ooo`030?ooo`030000002RKID0XVfE01@0XVfE0P0000060<:f
c`030000002WMid0YgNM00L0YgNM00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0B0?oo
o`40000000000`000000oooo0?ooo`030?ooo`030000002RKID0XVfE0180XVfE0P0000080<:fc`03
0000002WMid0YgNM00P0YgNM00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0B0?ooo`40
000000000`000000oooo0?ooo`030?ooo`030000002RKID0XVfE0100XVfE0P00000;0<:fc`030000
002WMid0YgNM00L0YgNM00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0B0?ooo`400000
00000`000000oooo0?ooo`030?ooo`030000002RKID0XVfE00h0XVfE0P00000=0<:fc`030000002W
Mid0YgNM00P0YgNM00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0B0?ooo`4000000000
0`000000oooo0?ooo`030?ooo`030000002RKID0XVfE00d0XVfE00<000000<:fc`32]/l03P32]/l0
0`000000YgNM0:MgW@050:MgW@<00000903oool00`000000oooo0?ooo`0B0?ooo`40000000000`00
0000oooo0?ooo`030?ooo`030000002RKID0XVfE00/0XVfE0P00000A0<:fc`030000002WMid0YgNM
00<0YgNM0P00000308@hI`030000003oool0oooo0240oooo00<000000?ooo`3oool04P3oool10000
000000<000000?ooo`3oool00`3oool00`000000XVfE0:9]U@090:9]U@8000005032]/l00`000000
YgNM0:MgW@02000000D0Q3QW00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0B0?ooo`40
000000000`000000oooo0?ooo`030?ooo`030000002RKID0XVfE00L0XVfE0P00000F0<:fc`030000
002WMid0000000P0Q3QW00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0B0?ooo`400000
00000`000000oooo0?ooo`030?ooo`030000002RKID0XVfE00D0XVfE0P00000I0<:fc`0300000024
>6L0Q3QW00L0Q3QW00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0B0?ooo`4000000000
0`000000oooo0?ooo`030?ooo`030000002RKID0XVfE00<0XVfE0P00000L0<:fc`0300000024>6L0
Q3QW00L0Q3QW00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0B0?ooo`40000000000`00
0000oooo0?ooo`030?ooo`040000002RKID0XVfE0:9]U@8000007P32]/l00`000000Q3QW08@hI`07
08@hI`030000003oool0oooo01l0oooo00<000000?ooo`3oool04P3oool10000000000<000000?oo
o`3oool00`3oool010000000XVfE00000000000Q0<:fc`0300000024>6L0Q3QW00L0Q3QW00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`040?oo
o`0300000032]/l0`[K?00h0`[K?00<000000<:fc`32]/l04032]/l00`000000Q3QW08@hI`0708@h
I`030000003oool0oooo01h0oooo00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3o
ool01@3oool00`000000`[K?0<:fc`0=0<:fc`0300000032]/l0`[K?0140`[K?00<0000008@hI`24
>6L01`24>6L00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0180oooo0@00000000030000
003oool0oooo00D0oooo00<000000<:fc`32]/l03@32]/l00`000000`[K?0<:fc`0A0<:fc`030000
0024>6L0Q3QW00L0Q3QW00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0B0?ooo`400000
00000`000000oooo0?ooo`060?ooo`0300000032]/l0`[K?00`0`[K?00<000000<:fc`32]/l04P32
]/l00`000000Q3QW08@hI`0708@hI`030000003oool0oooo01`0oooo00<000000?ooo`3oool04P3o
ool10000000000<000000?ooo`3oool01P3oool00`000000`[K?0<:fc`0=0<:fc`0300000032]/l0
`[K?0140`[K?00<0000008@hI`24>6L01`24>6L00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo0180oooo0@00000000030000003oool0oooo00L0oooo00<000000<:fc`32]/l03032]/l00`00
0000`[K?0<:fc`0B0<:fc`0300000024>6L0Q3QW00L0Q3QW00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`080?ooo`0300000032]/l0`[K?00/0
`[K?00<000000<:fc`32]/l04P32]/l00`000000Q3QW08@hI`0708@hI`030000003oool0oooo01/0
oooo00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3oool0203oool00`000000`[K?
0<:fc`0;0<:fc`0300000032]/l0`[K?01<0`[K?00<0000008@hI`24>6L01`24>6L00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo0180oooo0@00000000030000003oool0oooo00T0oooo00<0
00000<:fc`32]/l02P32]/l00`000000`[K?0<:fc`0A0<:fc`80000000<0anO]00000024>6L01`24
>6L00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0180oooo0@00000000030000003oool0
oooo00T0oooo00<000000<:fc`32]/l02P32]/l00`000000`[K?0<:fc`0?0<:fc`8000000`37ind0
0`000000Q3QW08@hI`0408@hI`80000000<0E`0Z0000003oool06P3oool00`000000oooo0?ooo`0B
0?ooo`40000000000`000000oooo0?ooo`0:0?ooo`0300000032]/l0`[K?00T0`[K?00<000000<:f
c`32]/l03@32]/l2000000H0anO]00@0000008@hI`24>6L0Q3QW0P00000305L0:P030000003oool0
oooo01T0oooo00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3oool02P3oool00`00
0000`[K?0<:fc`090<:fc`0300000032]/l0`[K?00/0`[K?0P0000080<OWk@0400000024>6L00000
000000H0E`0Z00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0B0?ooo`40000000000`00
0000oooo0?ooo`0;0?ooo`0300000032]/l0`[K?00T0`[K?00<000000<:fc`32]/l02@32]/l00`00
0000anO]0<OWk@090<OWk@030000001G02X0E`0Z00H0E`0Z00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0<0?ooo`0300000032]/l0`[K?00P0
`[K?00<000000<:fc`32]/l01`32]/l2000000`0anO]00<0000005L0:P1G02X01`1G02X00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo0180oooo0@00000000030000003oool0oooo00`0oooo
00<000000<:fc`32]/l02032]/l00`000000`[K?0<:fc`050<:fc`8000003`37ind00`000000E`0Z
05L0:P0605L0:P030000003oool0oooo01L0oooo00<000000?ooo`3oool04P3oool10000000000<0
00000?ooo`3oool03@3oool00`000000`[K?0<:fc`070<:fc`0300000032]/l0`[K?00<0`[K?0P00
000B0<OWk@030000001G02X0E`0Z00H0E`0Z00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`0B0?ooo`40000000000`000000oooo0?ooo`0=0?ooo`0300000032]/l0`[K?00L0`[K?00@00000
0<:fc`32]/l0`[K?0P00000D0<OWk@030000001G02X0E`0Z00H0E`0Z00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0>0?ooo`0300000032]/l0
`[K?00H0`[K?00@000000<:fc`32]/l000005`37ind00`000000E`0Z05L0:P0605L0:P030000003o
ool0oooo01D0oooo00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3oool03`3oool0
0`000000`[K?0<:fc`050<:fc`<000006037ind00`000000E`0Z05L0:P0605L0:P030000003oool0
oooo01D0oooo00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3oool03`3oool00`00
0000`[K?0<:fc`040<:fc`8000006`37ind00`000000E`0Z05L0:P0605L0:P030000003oool0oooo
01@0oooo00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3oool0403oool010000000
`[K?0<:fc`32]/l200000080anO]00<000000<OWk@37ind06@37ind00`000000E`0Z05L0:P0505L0
:P030000003oool0oooo01@0oooo00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3o
ool0403oool010000000`[K?0000000000040<OWk@0300000037ind0anO]01T0anO]00<0000005L0
:P1G02X01P1G02X00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo0@0000000003
0000003oool0oooo0140oooo00<000000<OWk@37ind01037ind00`000000anO]0<OWk@0J0<OWk@03
0000001G02X0E`0Z00D0E`0Z00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0B0?ooo`40
000000000`000000oooo0?ooo`0B0?ooo`0300000037ind0anO]00<0anO]00<000000<OWk@37ind0
6P37ind00`000000E`0Z05L0:P0605L0:P030000003oool0oooo0180oooo00<000000?ooo`3oool0
4P3oool10000000000<000000?ooo`3oool04P3oool00`000000anO]0<OWk@030<OWk@0300000037
ind0anO]01/0anO]00<0000005L0:P1G02X00`1G02X3000001@0oooo00<000000?ooo`3oool04P3o
ool10000000000<000000?ooo`3oool04P3oool2000000@0anO]00<000000<OWk@37ind06`37ind0
10000000E`0Z05L0:P1G02X2000000<08`0000<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0B0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`030000003oool0000000<0anO]00<00000
0<OWk@37ind07037ind3000000D08`0000<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0B
0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`030000003oool0000000@0anO]00<000000<OW
k@37ind06@37ind2000000030;7ij`0000008`0000H08`0000<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`040000003oool0oooo0000
00<0anO]00<000000<OWk@37ind05`37ind2000000<0/OW[00<0000002<0000S00001@0S00000`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0180oooo0@00000000030000003oool0oooo0180
oooo00@000000?ooo`3oool000000`37ind00`000000anO]0<OWk@0E0<OWk@8000001P2anN/00`00
00008`0002<0000402<000030000003oool0oooo0100oooo00<000000?ooo`3oool04P3oool10000
000000<000000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool000000080anO]00<000000<OW
k@37ind05037ind00`000000/OW[0;7ij`070;7ij`030000000S00008`0000@08`0000<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo0080oooo00<000000<OWk@0000005037ind2000000/0/OW[00<0000002<0000S
00000`0S00000`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0180oooo0@00000000030000
003oool0oooo0180oooo00<000000?ooo`3oool00P3oool00`000000anO]0000000B0<OWk@800000
3@2anN/00`0000008`0002<0000402<000030000003oool0oooo00h0oooo00<000000?ooo`3oool0
4P3oool10000000000<000000?ooo`3oool04P3oool00`000000oooo0?ooo`030?ooo`8000004@37
ind00`000000/OW[0;7ij`0>0;7ij`030000000S00008`0000<08`0000<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo00@0oooo0P00000>0<OWk@8000004P2anN/00`0000008`0002<0000302<000030000003oool0
oooo00d0oooo00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`040?ooo`8000003037ind2000001D0/OW[00<0000002<0000S00000P0S00000`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0180oooo0@00000000030000003oool0oooo0180
oooo00<000000?ooo`3oool01@3oool00`000000anO]0<OWk@080<OWk@8000005`2anN/00`000000
8`0002<00003000000l0oooo00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`050?ooo`0300000037ind0anO]00L0anO]00<000000;7ij`2anN/0
602anN/6000000h0oooo00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`050?ooo`8000001P37ind2000001`0/OW[1@00000>0?ooo`030000003o
ool0oooo0180oooo0@00000000030000003oool0oooo0180oooo00<000000?ooo`3oool01@3oool0
0`000000oooo000000030<OWk@800000702anN/20000000308KZb`0000000000008000003P3oool0
0`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00D0oooo00@000000?ooo`000000anO]0P00000L0;7ij`8000000`26j//4000000h0oooo00<00000
0?ooo`3oool04P3oool10000000000<000000?ooo`3oool04P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0000001`0/OW[0P00000608KZb`@000003@3oool00`000000oooo0?ooo`0B0?oo
o`40000000000`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3o
ool000006P2anN/00`000000Q^[;08KZb`0708KZb`<000003@3oool00`000000oooo0?ooo`0B0?oo
o`40000000000`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3o
ool00000602anN/2000000X0Q^[;0P00000>0?ooo`030000003oool0oooo0180oooo0@0000000003
0000003oool0oooo0180oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool00000
01D0/OW[0P00000=08KZb`030000003oool0oooo00`0oooo00<000000?ooo`3oool04P3oool10000
000000<000000?ooo`3oool04P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00<000000;7ij`2anN/04@2anN/00`000000Q^[;08KZb`0;08KZb`8000003`3oool00`000000
oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00`3oool00`000000/OW[0;7ij`0>0;7ij`8000003026j//200000140oooo
00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00<0oooo00<000000;7ij`2anN/0302anN/2000000`0Q^[;0P00
000C0?ooo`030000003oool0oooo0180oooo0@00000000030000003oool0oooo0180oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000002anN/0/OW[00T0/OW[0P00000<
08KZb`8000005@3oool00`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000/OW[0;7ij`070;7i
j`0300000026j//0Q^[;00X0Q^[;0P00000G0?ooo`030000003oool0oooo0180oooo0@0000000003
0000003oool0oooo0180oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`03
0000002anN/0/OW[00@0/OW[0P00000<08KZb`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool04P3oool10000000000<000000?ooo`3oool04P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00D0oooo00<000000;7ij`2anN/00P2anN/2000000`0Q^[;0P00000J0?ooo`030000
003oool0oooo0180oooo0@00000000030000003oool0oooo0180oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`060?ooo`040000002anN/00000000000`0Q^[;0P00000L0?ooo`030000
003oool0oooo0180oooo0@00000000030000003oool0oooo0180oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`060?ooo`8000003026j//2000001h0oooo00<000000?ooo`3oool04P3o
ool10000000000<000000?ooo`3oool04P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00H0oooo00@000000?ooo`00000000002026j//200000200oooo00<000000?ooo`3oool04P3o
ool10000000000<000000?ooo`3oool04P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00D0oooo00D000000?ooo`3oool0oooo0000000508KZb`8000008P3oool00`000000oooo0?oo
o`0B0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`80000000<0Q^[;000000000000903oool0
0`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0:P3oool00`000000
oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0180oooo
0@00000000030000003oool0oooo0180oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool04P3oool10000000000<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo0180oooo0@00000000030000003oool0oooo0180oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool04P3oool10000000000<000000?ooo`3oool04P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0B0?ooo`400000
00000`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0180oooo0@00000000030000003oool0
oooo0180oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0180
oooo0@00000000030000003oool0oooo0180oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool04P3oool10000000000<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0:@3oool00`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo0180oooo0@00000000030000003oool0oooo0180oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool04P3oool10000000000<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0B0?ooo`40
000000000`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0180oooo0@00000000030000003o
ool0oooo0180oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
0180oooo0@00000000030000003oool0oooo0180oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool04P3oool100000000
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0X0?ooo`030000003oool0oooo0180oooo0@00000000030000003oool0oooo0180oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool04P3oool10000000000<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0B0?oo
o`40000000000`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0180oooo0@00000000030000
003oool0oooo0180oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool09`3o
ool00`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0
oooo0180oooo0@00000000030000003oool0oooo0180oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool04P3oool10000
000000<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo0180oooo0@00000000030000003oool0oooo0180oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool04P3oool10000000000<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0B
0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0180oooo0@0000000003
0000003oool0oooo0180oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo0180oooo0@00000000030000003oool0oooo0180oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool04P3oool1
0000000000<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0B0?ooo`40000000000`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo0180oooo0@00000000030000003oool0oooo0180oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?oo
o`0B0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0180oooo0@000000
00030000003oool0oooo0180oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo02D0oooo00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo0180oooo0@00000000030000003oool0oooo0180oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool04P3o
ool10000000000<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0B0?ooo`40000000000`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo0180oooo0@00000000030000003oool0oooo0180
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02@0
oooo00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0903oool00`000000oooo
0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0180oooo0@00
000000030000003oool0oooo0180oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool04P3oool10000000000<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0903oool00`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo0180oooo0@00000000030000003oool0oooo0180oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
4P3oool10000000000<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0B0?ooo`4000000000
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0180oooo0@00000000030000003oool0oooo
0180oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0180oooo
0@00000000030000003oool0oooo0180oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool04P3oool10000000000<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0180oooo0@00000000030000003oool0oooo0180oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool04P3oool10000000000<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0B0?ooo`400000
00000`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0180oooo0@00000000030000003oool0
oooo0180oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool04P3oool10000000000<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`0B0?ooo`40000000000`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0080
oooo>00000040?ooo`030000003oool0oooo0180oooo0@00000000030000003oool0oooo0180oooo
00<000000?ooo`3oool00P3oool00`000000B00004P0000=04P00003000000180000B00000@0B000
00<0000004P0001800007@1800000`000000oooo0?ooo`020?ooo`030000003oool0oooo0180oooo
0@00000000030000003oool0oooo0180oooo00<000000?ooo`3oool00P3oool00`000000B00004P0
000=04P00003000000180000B00000@0B00000<0000004P0001800007@1800000`000000oooo0?oo
o`020?ooo`030000003oool0oooo0180oooo0@00000000030000003oool0oooo0180oooo00D00000
0?ooo`3oool0oooo0000000A04P00003000000180000B00000<0B00000<0000004P0001800007@18
00000`000000oooo0?ooo`020?ooo`030000003oool0oooo0180oooo0@00000000030000003oool0
oooo0180oooo00D000000?ooo`3oool0oooo0000000A04P00003000000180000B00000<0B00000<0
000004P0001800007P1800001@000000oooo0?ooo`3oool0000001@0oooo0@00000000030000003o
ool0oooo0180oooo00D000000?ooo`3oool0oooo0000000A04P00003000000180000B00000@0B000
00<0000004P0001800007@1800001@000000oooo0?ooo`3oool0000001@0oooo0@00000000030000
003oool0oooo0180oooo00D000000?ooo`3oool0oooo0000000A04P00003000000180000B00000@0
B00000<0000004P0001800007@1800001@000000oooo0?ooo`3oool0000001@0oooo0@0000000003
0000003oool0oooo0180oooo00D000000?ooo`3oool0oooo0000000A04P00003000000180000B000
00@0B00000<0000004P0001800007@1800001@000000oooo0?ooo`3oool0000001@0oooo0@000000
00030000003oool0oooo0180oooo00D000000?ooo`3oool0oooo0000000A04P00003000000180000
B00000@0B00000<0000004P0001800007@1800001@000000oooo0?ooo`3oool0000001@0oooo0@00
000000030000003oool0oooo0180oooo00@000000?ooo`3oool000004P1800000`000000B00004P0
000404P00003000000180000B00001d0B00000D000000?ooo`3oool0oooo0000000D0?ooo`400000
00000`000000oooo0?ooo`0B0?ooo`@000004`1800000`000000B00004P0000T04P000@00000503o
ool10000000000<000000?ooo`3oool04P3oool010000000oooo0?ooo`00000C04P0000300000018
0000B00002@0B00000@000000?ooo`3oool00000503oool10000000000<000000?ooo`3oool04P3o
ool010000000oooo0?ooo`00000C04P00003000000180000B00002@0B00000@000000?ooo`3oool0
0000503oool10000000000<000000?ooo`3oool04P3oool010000000oooo0?ooo`00000C04P00003
000000180000B00002@0B00000@000000?ooo`3oool00000503oool10000000000<000000?ooo`3o
ool04@3oool01@000000oooo0?ooo`3oool0000001<0B00000<0000004P000180000901800001@00
0000oooo0?ooo`3oool0000001<0oooo0@00000000030000003oool0oooo0140oooo00@000000?oo
o`3oool00000501800000`000000B00004P0000T04P000050000003oool0oooo0?ooo`0000004`3o
ool10000000000<000000?ooo`3oool04@3oool010000000oooo0?ooo`00000E04P0000300000018
0000B00002@0B00000@000000?ooo`3oool000004`3oool10000000000<000000?ooo`3oool04@3o
ool010000000oooo0?ooo`00000E04P00003000000180000B00002@0B00000@000000?ooo`3oool0
00004`3oool10000000000<000000?ooo`3oool04@3oool010000000oooo0?ooo`00000E04P00003
000000180000B00002@0B00000@000000?ooo`3oool000004`3oool10000000000<000000?ooo`3o
ool04@3oool010000000oooo0?ooo`00000E04P00003000000180000B00002@0B00000@000000?oo
o`3oool000004`3oool10000000000<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool0
000001D0B00000<0000004P000180000901800001@000000oooo0?ooo`3oool000000180oooo0@00
000000030000003oool0oooo0100oooo00@000000?ooo`3oool000005P1800000`000000B00004P0
000T04P000050000003oool0oooo0?ooo`0000004P3oool10000000000<000000?ooo`3oool0403o
ool010000000oooo0?ooo`00000F04P00003000000180000B00002D0B00000@000000?ooo`3oool0
00004P3oool10000000000<000000?ooo`3oool0403oool010000000oooo0?ooo`00000G04P00003
000000180000B00002@0B00000@000000?ooo`3oool000004P3oool10000000000<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`1000000080oooo00<000000?ooo`3oool0403oool100000000
00<000000?ooo`3oool0403oool010000000oooo0?ooo`00000G0;BC]0030000002dTk@0]9>d02@0
]9>d00@000000?ooo`3oool000004P3oool10000000000<000000?ooo`3oool03`3oool01@000000
oooo0?ooo`3oool0000001L0]9>d00<000000;BC]02dTk@0902dTk@01@000000oooo0?ooo`3oool0
00000140oooo0@00000000030000003oool0oooo00l0oooo00D000000?ooo`3oool0oooo0000000G
0;BC]0030000002dTk@0]9>d02@0]9>d00D000000?ooo`3oool0oooo0000000A0?ooo`4000000000
0`000000oooo0?ooo`0?0?ooo`050000003oool0oooo0?ooo`0000005`2dTk@00`000000]9>d0;BC
]00T0;BC]0050000003oool0oooo0?ooo`0000004@3oool10000000000<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`1200000080oooo00<000000?ooo`3oool03`3oool10000000000<00000
0?ooo`3oool03`3oool010000000oooo0?ooo`00000I04P00003000000180000B00002@0B00000@0
00000?ooo`3oool000004@3oool10000000000<000000?ooo`3oool03`3oool010000000oooo0?oo
o`00000I04P00003000000180000B00002@0B00000@000000?ooo`3oool000004@3oool100000000
00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool0000001T0B00000<0000004P00018
0000901800001@000000oooo0?ooo`3oool000000100oooo0@00000000030000003oool0oooo00h0
oooo00@000000?ooo`3oool000006P1800000`000000B00004P0000U04P000040000003oool0oooo
00000100oooo0@00000000030000003oool0oooo00h0oooo00@000000?ooo`3oool000006P180000
0`000000B00004P0000U04P000040000003oool0oooo00000100oooo0@00000000030000003oool0
oooo00h0oooo00@000000?ooo`3oool000006P1800000`000000B00004P0000U04P000040000003o
ool0oooo00000100oooo0@00000000030000003oool0oooo00h0oooo00@000000?ooo`3oool00000
6P1800000`000000B00004P0000U04P000040000003oool0oooo00000100oooo0@00000000030000
003oool0oooo00h0oooo00@000000?ooo`3oool000006`1800000`000000B00004P0000T04P00004
0000003oool0oooo00000100oooo0@00000000030000003oool0oooo00d0oooo00D000000?ooo`3o
ool0oooo0000000K04P00003000000180000B00002@0B00000D000000?ooo`3oool0oooo0000000?
0?ooo`40000000000`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000001`0B00000<00000
04P0001800009@18000010000000oooo0?ooo`00000?0?ooo`40000000000`000000oooo0?ooo`0=
0?ooo`040000003oool0oooo000001`0B00000<0000004P0001800009@18000010000000oooo0?oo
o`00000?0?ooo`40000000000`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000001`0B000
00<0000004P0001800009@18000010000000oooo0?ooo`00000?0?ooo`40000000000`000000oooo
0?ooo`0=0?ooo`040000003oool0oooo000001`0B00000<0000004P0001800009@18000010000000
oooo0?ooo`00000?0?ooo`40000000000`000000oooo0?ooo`0=0?ooo`040000003oool0oooo0000
01`0B00000<0000004P0001800009@18000010000000oooo0?ooo`00000?0?ooo`40000000000`00
0000oooo0?ooo`0<0?ooo`050000003oool0oooo0?ooo`0000007@1800000`000000B00004P0000T
04P000050000003oool0oooo0?ooo`0000003P3oool10000000000<000000?ooo`3oool0303oool0
10000000oooo0?ooo`00000N04P00003000000180000B00002@0B00000D000000?ooo`3oool0oooo
0000000>0?ooo`40000000000`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000001h0B000
00<0000004P0001800009@18000010000000oooo0?ooo`00000>0?ooo`40000000000`000000oooo
0?ooo`0<0?ooo`040000003oool0oooo000001h0B00000<0000004P0001800009@18000010000000
oooo0?ooo`00000>0?ooo`40000000000`000000oooo0?ooo`0<0?ooo`040000003oool0oooo0000
04H0B00000@000000?ooo`3oool000003P3oool10000000000<000000?ooo`3oool0303oool01000
0000oooo0?ooo`00001604P000040000003oool0oooo000000h0oooo0@00000000030000003oool0
oooo00/0oooo00D000000?ooo`3oool0oooo0000001604P000050000003oool0oooo0?ooo`000000
3@3oool10000000000<000000?ooo`3oool02`3oool01@000000oooo0?ooo`3oool0000004H0B000
00D000000?ooo`3oool0oooo0000000=0?ooo`40000000000`000000oooo0?ooo`0;0?ooo`040000
003oool0oooo000004P0B00000@000000?ooo`3oool000003@3oool10000000000<000000?ooo`3o
ool02`3oool010000000oooo0?ooo`00001804P000040000003oool0oooo000000d0oooo0@000000
00030000003oool0oooo00/0oooo00@000000?ooo`3oool00000B018000010000000oooo0?ooo`00
000=0?ooo`40000000000`000000oooo0?ooo`0;0?ooo`040000003oool0oooo000004P0B00000@0
00000?ooo`3oool000003@3oool10000000000<000000?ooo`3oool02`3oool010000000oooo0?oo
o`00001804P000040000003oool0oooo000000d0oooo0@00000000030000003oool0oooo00X0oooo
00D000000?ooo`3oool0oooo0000001804P000050000003oool0oooo0?ooo`000000303oool10000
000000<000000?ooo`3oool02P3oool010000000oooo0?ooo`00001:04P000040000003oool0oooo
000000`0oooo0@00000000030000003oool0oooo00X0oooo00@000000?ooo`3oool00000BP180000
10000000oooo0?ooo`00000<0?ooo`40000000000`000000oooo0?ooo`0:0?ooo`040000003oool0
oooo000004X0B00000@000000?ooo`3oool00000303oool10000000000<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`1<00000080oooo00<000000?ooo`3oool02P3oool10000000000<00000
0?ooo`3oool02P3oool010000000oooo0?ooo`00001:0;BC]0040000003oool0oooo000000`0oooo
0@00000000030000003oool0oooo00T0oooo00D000000?ooo`3oool0oooo0000001:0;BC]0050000
003oool0oooo0?ooo`0000002`3oool10000000000<000000?ooo`3oool02@3oool01@000000oooo
0?ooo`3oool0000004X0]9>d00D000000?ooo`3oool0oooo0000000;0?ooo`40000000000`000000
oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`000000BP2dTk@01@000000oooo0?ooo`3oool0
000000/0oooo0@00000000030000003oool0oooo00T0oooo00D000000?ooo`3oool0oooo0000001:
0;BC]0050000003oool0oooo0?ooo`0000002`3oool10000000000<000000?ooo`3oool02@3oool0
1@000000oooo0?ooo`3oool0000004X0]9>d00D000000?ooo`3oool0oooo0000000;0?ooo`400000
00000`000000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`000000BP2dTk@01@000000oooo
0?ooo`3oool0000000/0oooo0@00000000030000003oool0oooo00P0oooo00<000000?ooo`3oool0
0P3oool00`000000]9>d0;BC]0180;BC]0030000003oool0oooo0080oooo00<000000?ooo`3oool0
203oool10000000000<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000002d
Tk@0]9>d04P0]9>d00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`4000000000
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000;BC]02dTk@0B02dTk@0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo0@00000000030000003oool0oooo
00P0oooo00<000000?ooo`3oool00P3oool00`000000]9>d0;BC]0180;BC]0030000003oool0oooo
0080oooo00<000000?ooo`3oool0203oool10000000000<000000?ooo`3oool0203oool00`000000
oooo0?ooo`020?ooo`030000002dTk@0]9>d04P0]9>d00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`080?ooo`40000000000`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo
00<000000;BC]02dTk@0B02dTk@00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo
0@00000000030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000]9>d0;BC
]0180;BC]0030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool10000000000<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000002dTk@0]9>d04P0]9>d00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`40000000000`000000oooo0?ooo`070?oo
o`030000003oool0oooo00<0oooo00<000000;BC]02dTk@0B02dTk@00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00L0oooo0@00000000030000003oool0oooo00L0oooo00<000000?ooo`3o
ool00`3oool00`000000]9>d0;BC]0180;BC]0030000003oool0oooo00<0oooo00<000000?ooo`3o
ool01`3oool10000000000<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000
002dTk@0]9>d04P0]9>d00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`400000
00000`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000;BC]02dTk@0B02d
Tk@00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo0@00000000030000003oool0
oooo00H0oooo00<000000?ooo`3oool0103oool00`000000]9>d0;BC]0180;BC]0030000003oool0
oooo00@0oooo00<000000?ooo`3oool01P3oool10000000000<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`040?ooo`030000002dTk@0]9>d04P0]9>d00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`060?ooo`40000000000`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0
oooo00<000000;BC]02dTk@0B02dTk@00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0
oooo0@00000000030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000]9>d
0;BC]0180;BC]0030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool10000000000<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000002dTk@0]9>d04P0]9>d00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`40000000000`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00@0oooo00<000000;BC]02dTk@0B02dTk@00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00H0oooo0@00000000030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool00`000000]9>d0;BC]0180;BC]0030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool10000000000<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`03
0000002dTk@0]9>d04P0]9>d00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`40
000000000`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000;BC]02dTk@0
B02dTk@00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo0@00000000030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000]9>d0;BC]0180;BC]0030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`030000002dTk@0]9>d04P0]9>d00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo00<000000;BC]02dTk@0B02dTk@00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000
]9>d0;BC]0180;BC]0030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool100000000
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000002dTk@0]9>d04P0]9>d
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`40000000000`000000oooo0?oo
o`040?ooo`030000003oool0oooo00H0oooo00<000000;BC]02dTk@0B02dTk@00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00@0oooo0@00000000030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01P3oool00`000000]9>d0;BC]0180;BC]0030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0103oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?oo
o`030000002dTk@0]9>d04P0]9>d00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?oo
o`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0ooooC00000080?ooo`03
0000003oool0oooo00@0oooo0@00000000030000003oool0oooo00@0oooo00<000000?ooo`3oool0
FP3oool00`000000oooo0?ooo`040?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003o
ool0oooo05`0oooo00<000000?ooo`3oool00`3oool10000000000<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`1L0?ooo`030000003oool0oooo00<0oooo0@00000000030000003oool0oooo
00<0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`030?ooo`40000000000`000000
oooo0?ooo`030?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool00`3oool100000000
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo00<0oooo
0@00000000030000003oool0oooo00<0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?oo
o`030?ooo`40000000000`000000oooo0?ooo`020?ooo`030000003oool0oooo05h0oooo00<00000
0?ooo`3oool00P3oool10000000000<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1N0?oo
o`030000003oool0oooo0080oooo0@00000000030000003oool0oooo0080oooo00<000000?ooo`3o
ool0GP3oool00`000000oooo0?ooo`020?ooo`40000000000`000000oooo0?ooo`020?ooo`030000
003oool0oooo05h0oooo00<000000?ooo`3oool00P3oool10000000000<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0080oooo0@00000000030000003oool0
oooo0080oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`020?ooo`40000000001@00
0000oooo0?ooo`3oool000000680oooo00@000000?ooo`3oool0oooo0@00000000050000003oool0
oooo0?ooo`000000HP3oool010000000oooo0?ooo`3oool10000000000D000000?ooo`3oool0oooo
0000001R0?ooo`040000003oool0oooo0?ooo`40000000001@000000oooo0?ooo`3oool000000680
oooo00@000000?ooo`3oool0oooo0@00000000050000003oool0oooo0?ooo`000000HP3oool01000
0000oooo0?ooo`3oool10000000000D000000?ooo`3oool0oooo0000001R0?ooo`040000003oool0
oooo0?ooo`400000000010000000oooo0?ooo`00001T0?ooo`030000003oool0oooo004000000000
10000000oooo0?ooo`00001T0?ooo`030000003oool0oooo00400000000010000000oooo0?ooo`00
001T0?ooo`030000003oool0oooo00400000000010000000oooo0?ooo`00001T0?ooo`030000003o
ool0oooo00400000000010000000oooo0?ooo`00001T0?ooo`030000003oool0oooo004000000000
10000000oooo0?ooo`00001T0?ooo`030000003oool0oooo0040000000000`000000oooo0000001V
0?ooo`4000000@3oool10000000000<000000?ooo`000000IP3oool100000040oooo0@0000000003
0000003oool0000006H0oooo0@0000010?ooo`40000000000`000000oooo0000001V0?ooo`400000
0@3oool10000000000<000000?ooo`000000IP3oool100000040oooo0@00000000030000003oool0
000006H0oooo0@0000010?ooo`4000000002000006P0oooo0P00000000800000J03oool200000000
0P00001X0?ooo`8000000002000006P0oooo0P00000000800000J03oool2000000000P00001X0?oo
o`80000000000`000000oooo0?ooo`1X0?ooo`40000000000`000000oooo0?ooo`1X0?ooo`400000
00000`000000oooo0?ooo`1X0?ooo`400000001/00000000K03oool006`0oooo0000\
\>"],
  ImageRangeCache->{{{91.5625, 177.563}, {606.375, 84.625}} -> {0.239462, \
0.158748, 0.00154895, 0.00154895}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#2", "Text"],

Cell[CellGroupData[{

Cell["Hz2[[-2]]", "Input"],

Cell[BoxData[
    \(1.6374043059813146`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pretty[Chop[e2ni . eigenvectors2[\([\(-2\)]\)], 10^\(-4\)]]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
          {"\<\"optic\"\>", "0", \(-0.15205637188702067`\), "0", "0", 
            "0", \(-0.9883718226298016`\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Status["\<Plotting stage 2 mode 2\>"]\ ; 
    eigenplot[eigenvectors2[\([\(-2\)]\)],  .1, {\(-1\), 0, 0}, \ 
      floatmatrix2]\ ; Done[]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 2.00188 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.50094 2.00188 1.11131e-016 2.00188 [
[ 0 0 0 0 ]
[ 1 2.00188 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
1 0 m
1 2.00188 L
s
1 2.00188 m
0 2.00188 L
s
0 2.00188 m
0 0 L
s
0 0 m
1 0 L
s
.92314 .15386 m
.07686 .15386 L
s
.07686 .15386 m
.07686 1.84802 L
s
.07686 1.84802 m
.92314 1.84802 L
s
.92314 1.84802 m
.92314 .15386 L
s
1 0 m
1 2.00188 L
s
1 2.00188 m
.92314 1.84802 L
s
.92314 1.84802 m
.92314 .15386 L
s
.92314 .15386 m
1 0 L
s
0 0 m
.07686 .15386 L
s
.07686 .15386 m
.07686 1.84802 L
s
.07686 1.84802 m
0 2.00188 L
s
0 2.00188 m
0 0 L
s
0 0 m
1 0 L
1 2.00188 L
0 2.00188 L
closepath
clip
newpath
.5 Mabswid
.707 .577 .707 r
.36514 1.86209 m .48118 1.86209 L .48118 1.74605 L p F P
0 g
s
.707 .577 .707 r
.48118 1.74605 m .25537 1.74605 L p .36514 1.86209 L F P
0 g
s
.281 0 0 r
.25537 1.74605 m .48118 1.74605 L .47854 1.8506 L p F P
0 g
s
.8 .653 .099 r
.25537 1.86209 m .25537 1.74605 L .22105 1.8506 L p F P
0 g
s
.707 .577 .707 r
.25537 1.74605 m .25537 1.86209 L .36514 1.86209 L p F P
0 g
s
.281 0 0 r
.47854 1.8506 m .22105 1.8506 L .25537 1.74605 L p F P
0 g
s
.715 .584 .008 r
.48118 1.74605 m .48118 1.86209 L .47999 1.91688 L p F P
0 g
s
.715 .584 .008 r
.47854 1.8506 m .48118 1.74605 L p .47999 1.91688 L F P
0 g
s
.8 .653 .099 r
.23981 1.91688 m .25537 1.86209 L p .22105 1.8506 L F P
0 g
s
0 0 .099 r
.74463 1.75232 m .74463 1.86209 L .76114 1.92022 L p F P
0 g
s
0 0 .099 r
.77895 1.85775 m .74463 1.75232 L p .76114 1.92022 L F P
0 g
s
.707 .577 .707 r
.63486 1.86209 m .74463 1.86209 L .74463 1.75232 L p F P
0 g
s
.707 .577 .707 r
.74463 1.75232 m .51882 1.75232 L p .63486 1.86209 L F P
0 g
s
.283 0 0 r
.51882 1.75232 m .74463 1.75232 L .77895 1.85775 L p F P
0 g
s
.707 .577 .707 r
.51882 1.75232 m .51882 1.86209 L .63486 1.86209 L p F P
0 g
s
.283 0 0 r
.77895 1.85775 m .52146 1.85775 L .51882 1.75232 L p F P
0 g
s
0 0 .008 r
.52009 1.92022 m .51882 1.86209 L p .52146 1.85775 L F P
0 g
s
0 0 .008 r
.51882 1.86209 m .51882 1.75232 L .52146 1.85775 L p F P
0 g
s
.082 .642 .745 r
.56533 .88858 m .56181 .89465 L .64492 .8898 L p F P
0 g
s
.082 .642 .745 r
.64492 .8898 m .6532 .88346 L .56533 .88858 L p F P
0 g
s
0 .458 .739 r
.6532 .88346 m .64492 .8898 L .72547 .91088 L p F P
0 g
s
0 .458 .739 r
.72547 .91088 m .73834 .90574 L .6532 .88346 L p F P
0 g
s
0 .237 .669 r
.73834 .90574 m .72547 .91088 L .79556 .95581 L p F P
0 g
s
0 .237 .669 r
.79556 .95581 m .81244 .95324 L .73834 .90574 L p F P
0 g
s
0 .003 .544 r
.81244 .95324 m .79556 .95581 L .84834 1.02021 L p F P
0 g
s
.475 .834 .574 r
.41528 .9764 m .41986 .97772 L .48425 .92494 L p F P
0 g
s
.475 .834 .574 r
.48425 .92494 m .48335 .92061 L .41528 .9764 L p F P
0 g
s
.287 .772 .688 r
.48335 .92061 m .48425 .92494 L .56181 .89465 L p F P
0 g
s
.287 .772 .688 r
.56181 .89465 m .56533 .88858 L .48335 .92061 L p F P
0 g
s
0 .003 .544 r
.84834 1.02021 m .86822 1.02131 L .81244 .95324 L p F P
0 g
s
0 0 .377 r
.86822 1.02131 m .84834 1.02021 L .87863 1.09776 L p F P
0 g
s
0 0 .377 r
.87863 1.09776 m .90025 1.10329 L .86822 1.02131 L p F P
0 g
s
0 0 .185 r
.90025 1.10329 m .87863 1.09776 L .88348 1.18088 L p F P
0 g
s
.726 .739 .222 r
.3455 1.13563 m .35385 1.12836 L .37492 1.04781 L p F P
0 g
s
.726 .739 .222 r
.37492 1.04781 m .36778 1.05049 L .3455 1.13563 L p F P
0 g
s
.626 .823 .413 r
.36778 1.05049 m .37492 1.04781 L .41986 .97772 L p F P
0 g
s
.626 .823 .413 r
.41986 .97772 m .41528 .9764 L .36778 1.05049 L p F P
0 g
s
0 0 .185 r
.88348 1.18088 m .90537 1.19115 L .90025 1.10329 L p F P
0 g
s
0 0 0 r
.90537 1.19115 m .88348 1.18088 L .8624 1.26143 L p F P
0 g
s
.764 .59 .019 r
.35063 1.2235 m .35869 1.21148 L .35385 1.12836 L p F P
0 g
s
.764 .59 .019 r
.35385 1.12836 m .3455 1.13563 L .35063 1.2235 L p F P
0 g
s
.01 w
.35133 .88851 Mdot
.5 Mabswid
0 0 0 r
.8624 1.26143 m .88309 1.2763 L .90537 1.19115 L p F P
0 g
s
0 0 0 r
.88309 1.2763 m .8624 1.26143 L .81747 1.33152 L p F P
0 g
s
0 0 0 r
.81747 1.33152 m .83559 1.35039 L .88309 1.2763 L p F P
0 g
s
0 0 0 r
.83559 1.35039 m .81747 1.33152 L .75307 1.38429 L p F P
0 g
s
.646 .166 0 r
.43844 1.37355 m .44177 1.35343 L .38899 1.28903 L p F P
0 g
s
.646 .166 0 r
.38899 1.28903 m .38265 1.30548 L .43844 1.37355 L p F P
0 g
s
.736 .392 0 r
.38265 1.30548 m .38899 1.28903 L .35869 1.21148 L p F P
0 g
s
.736 .392 0 r
.35869 1.21148 m .35063 1.2235 L .38265 1.30548 L p F P
0 g
s
0 0 0 r
.75307 1.38429 m .76752 1.40618 L .83559 1.35039 L p F P
0 g
s
0 0 0 r
.76752 1.40618 m .75307 1.38429 L .67552 1.41459 L p F P
0 g
s
0 0 0 r
.67552 1.41459 m .68554 1.4382 L .76752 1.40618 L p F P
0 g
s
.123 0 0 r
.68554 1.4382 m .67552 1.41459 L .5924 1.41944 L p F P
0 g
s
.123 0 0 r
.5924 1.41944 m .59768 1.44333 L .68554 1.4382 L p F P
0 g
s
.323 0 0 r
.59768 1.44333 m .5924 1.41944 L .51186 1.39836 L p F P
0 g
s
.323 0 0 r
.51186 1.39836 m .51253 1.42105 L .59768 1.44333 L p F P
0 g
s
.503 0 0 r
.51253 1.42105 m .51186 1.39836 L .44177 1.35343 L p F P
0 g
s
.503 0 0 r
.44177 1.35343 m .43844 1.37355 L .51253 1.42105 L p F P
0 g
s
.715 .584 .008 r
.47999 1.91688 m .47854 1.98292 L .47854 1.8506 L p F P
0 g
s
.8 .653 .099 r
.22105 1.8506 m .22105 1.98292 L .23981 1.91688 L p F P
0 g
s
.31549 1.15267 m
.35268 1.7949 L
s
.3559 1.8506 m
.35964 1.91521 L
s
.68844 1.80158 m
.76067 1.62086 L
s
.64169 1.91855 m
.66599 1.85775 L
s
.76067 1.62086 m
.81755 1.47853 L
s
.89521 1.2842 m
.92367 1.21298 L
s
.81755 1.47853 m
.89521 1.2842 L
s
0 0 .099 r
.76114 1.92022 m .77895 1.98292 L .77895 1.85775 L p F P
0 g
s
0 0 .008 r
.52146 1.85775 m .52146 1.98292 L .52009 1.92022 L p F P
0 g
s
.01 w
.65715 .88209 Mdot
.34285 .88209 Mdot
.5 Mabswid
.707 .577 .707 r
.34622 1.98292 m .22105 1.98292 L p .47854 1.8506 L F P
0 g
s
.707 .577 .707 r
.22105 1.98292 m .22105 1.8506 L .47854 1.8506 L p F P
0 g
s
.707 .577 .707 r
.47854 1.8506 m .47854 1.98292 L .34622 1.98292 L p F P
0 g
s
.707 .577 .707 r
.65378 1.98292 m .52146 1.98292 L p .77895 1.85775 L F P
0 g
s
.707 .577 .707 r
.52146 1.98292 m .52146 1.85775 L .77895 1.85775 L p F P
0 g
s
.707 .577 .707 r
.77895 1.85775 m .77895 1.98292 L .65378 1.98292 L p F P
0 g
s
.25 Mabswid
1 0 m
1 2.00188 L
s
1 2.00188 m
0 2.00188 L
s
0 2.00188 m
0 0 L
s
0 0 m
1 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{170.25, 340.813},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002Z0001E2000`400?l00000o`00003oZP000000
00030000003oool0oooo0:D0oooo0P00000000800000YP3oool2000000000P00002U0?ooo`400000
0@3oool10000000000<000000?ooo`000000Y03oool100000040oooo0@00000000030000003oool0
00000:<0oooo00<000000?ooo`3oool00@00000000040000003oool0oooo00000:80oooo00<00000
0?ooo`3oool00@00000000040000003oool0oooo00000:40oooo00@000000?ooo`3oool0oooo0@00
000000050000003oool0oooo0?ooo`000000X03oool010000000oooo0?ooo`3oool10000000000D0
00000?ooo`3oool0oooo0000002O0?ooo`030000003oool0oooo0080oooo0@00000000030000003o
ool0oooo0080oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`020?ooo`4000000000
0`000000oooo0?ooo`020?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool00`3oool1
0000000000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo
00<0oooo0@00000000030000003oool0oooo00<0oooo00<000000?ooo`3oool0V@3oool00`000000
oooo0?ooo`040?ooo`40000000000`000000oooo0?ooo`040?ooo`030000003oool0oooo09P0oooo
00<000000?ooo`3oool0103oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?oo
o`2G0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0UP3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`050?oo
o`030000003oool0oooo09D0oooo00<000000?ooo`3oool01P3oool10000000000<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo00H0oooo0@00000000030000
003oool0oooo00H0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`070?ooo`400000
00000`000000oooo0?ooo`070?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool01`3o
ool10000000000<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0
oooo00P0oooo0@00000000030000003oool0oooo00P0oooo00<000000?ooo`3oool0T03oool00`00
0000oooo0?ooo`080?ooo`40000000000`000000oooo0?ooo`080?ooo`030000003oool0oooo08l0
oooo00<000000?ooo`3oool02@3oool10000000000<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`2>0?ooo`030000003oool0oooo00T0oooo0@00000000030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0S@3oool00`000000oooo0?ooo`0:0?ooo`40000000000`000000oooo0?ooo`0:
0?oooi000000303oool10000000000<000000?ooo`3oool02P3oool00`000000oooo0?ooo`2<0?oo
o`030000003oool0oooo00X0oooo0@00000000030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0S03oool00`000000oooo0?ooo`0:0?ooo`40000000000`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool10000000000<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo00X0oooo0@00000000030000003oool0
oooo00X0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0:0?ooo`40000000000`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool10000
000000<000000?ooo`3oool02P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo00X0
oooo0@00000000030000003oool0oooo00X0oooo00<000000?ooo`3oool0S03oool00`000000oooo
0?ooo`0:0?ooo`40000000000`000000oooo0?ooo`0:0?ooo`030000003oool0oooo08`0oooo00<0
00000?ooo`3oool02P3oool10000000000<000000?ooo`3oool02P3oool00`000000oooo0?ooo`2<
0?ooo`030000003oool0oooo00X0oooo0@00000000030000003oool0oooo00X0oooo00<000000?oo
o`3oool0S03oool00`000000oooo0?ooo`0:0?ooo`40000000000`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool10000000000<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo00X0oooo0@00000000030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0:0?ooo`4000000000
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool1
0000000000<000000?ooo`3oool02P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo
00X0oooo0@00000000030000003oool0oooo00X0oooo00<000000?ooo`3oool0S03oool00`000000
oooo0?ooo`0:0?ooo`40000000000`000000oooo0?ooo`0:0?ooo`030000003oool0oooo08`0oooo
00<000000?ooo`3oool02P3oool10000000000<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`2<0?ooo`030000003oool0oooo00X0oooo0@00000000030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0S03oool00`000000oooo0?ooo`0:0?ooo`40000000000`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool10000000000<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo00X0oooo0@00000000030000
003oool0oooo00X0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0:0?ooo`400000
00000`000000oooo0?ooo`0:0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3o
ool10000000000<000000?ooo`3oool02P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0
oooo00X0oooo0@00000000030000003oool0oooo00X0oooo00<000000?ooo`3oool0S03oool00`00
0000oooo0?ooo`0:0?ooo`40000000000`000000oooo0?ooo`0:0?ooo`030000003oool0oooo08`0
oooo00<000000?ooo`3oool02P3oool10000000000<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`2<0?ooo`030000003oool0oooo00X0oooo0@00000000030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0S03oool00`000000oooo0?ooo`0:0?ooo`40000000000`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool10000000000<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo00X0oooo0@0000000003
0000003oool0oooo00X0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0:0?ooo`40
000000000`000000oooo0?ooo`0:0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0
2P3oool10000000000<000000?ooo`3oool02P3oool00`000000oooo0?ooo`2<0?ooo`030000003o
ool0oooo00X0oooo0@00000000030000003oool0oooo00X0oooo00<000000?ooo`3oool0S03oool0
0`000000oooo0?ooo`0:0?ooo`40000000000`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
08`0oooo00<000000?ooo`3oool02P3oool10000000000<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`2<0?ooo`030000003oool0oooo00X0oooo0@00000000030000003oool0oooo00X0oooo
00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0:0?ooo`40000000000`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool10000000000<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo00X0oooo0@000000
00030000003oool0oooo00X0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0:0?oo
o`40000000000`000000oooo0?ooo`0:0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3o
ool02P3oool10000000000<000000?ooo`3oool02P3oool00`000000oooo0?ooo`2<0?ooo`030000
003oool0oooo00X0oooo0@00000000030000003oool0oooo00X0oooo00<000000?ooo`3oool0S03o
ool00`000000oooo0?ooo`0:0?ooo`40000000000`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo08`0oooo00<000000?ooo`3oool02P3oool10000000000<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`2<0?ooo`030000003oool0oooo00X0oooo0@00000000030000003oool0oooo00X0
oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0:0?ooo`40000000000`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool10000000000<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo00X0oooo0@00
000000030000003oool0oooo00X0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0:
0?ooo`40000000000`000000oooo0?ooo`0:0?ooo`030000003oool0oooo08`0oooo00<000000?oo
o`3oool02P3oool10000000000<000000?ooo`3oool02P3oool00`000000oooo0?ooo`2<0?ooo`03
0000003oool0oooo00X0oooo0@00000000030000003oool0oooo00X0oooo00<000000?ooo`3oool0
S03oool00`000000oooo0?ooo`0:0?ooo`40000000000`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo08`0oooo00<000000?ooo`3oool02P3oool10000000000<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`2<0?ooo`030000003oool0oooo00X0oooo0@00000000030000003oool0oooo
00X0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0:0?ooo`40000000000`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool100000000
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo00X0oooo
0@00000000030000003oool0oooo00X0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?oo
o`0:0?ooo`40000000000`000000oooo0?ooo`0:0?ooo`030000003oool0oooo08`0oooo00<00000
0?ooo`3oool02P3oool10000000000<000000?ooo`3oool02P3oool00`000000oooo0?ooo`2<0?oo
o`030000003oool0oooo00X0oooo0@00000000030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0S03oool00`000000oooo0?ooo`0:0?ooo`40000000000`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool10000000000<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo00X0oooo0@00000000030000003oool0
oooo00X0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0:0?ooo`40000000000`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool10000
000000<000000?ooo`3oool02P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo00X0
oooo0@00000000030000003oool0oooo00X0oooo00<000000?ooo`3oool0S03oool00`000000oooo
0?ooo`0:0?ooo`40000000000`000000oooo0?ooo`0:0?ooo`030000003oool0oooo08`0oooo00<0
00000?ooo`3oool02P3oool10000000000<000000?ooo`3oool02P3oool00`000000oooo0?ooo`2<
0?ooo`030000003oool0oooo00X0oooo0@00000000030000003oool0oooo00X0oooo00<000000?oo
o`3oool0S03oool00`000000oooo0?ooo`0:0?ooo`40000000000`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool10000000000<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo00X0oooo0@00000000030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0:0?ooo`4000000000
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool1
0000000000<000000?ooo`3oool02P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo
00X0oooo0@00000000030000003oool0oooo00X0oooo00<000000?ooo`3oool0S03oool00`000000
oooo0?ooo`0:0?ooo`40000000000`000000oooo0?ooo`0:0?ooo`030000003oool0oooo08`0oooo
00<000000?ooo`3oool02P3oool10000000000<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`2<0?ooo`030000003oool0oooo00X0oooo0@00000000030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0S03oool00`000000oooo0?ooo`0:0?ooo`40000000000`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool10000000000<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo00X0oooo0@00000000030000
003oool0oooo00X0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0:0?ooo`400000
00000`000000oooo0?ooo`0:0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3o
ool10000000000<000000?ooo`3oool02P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0
oooo00X0oooo0@00000000030000003oool0oooo00X0oooo00<000000?ooo`3oool0S03oool00`00
0000oooo0?ooo`0:0?ooo`40000000000`000000oooo0?ooo`0:0?ooo`030000003oool0oooo08`0
oooo00<000000?ooo`3oool02P3oool10000000000<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`2<0?ooo`030000003oool0oooo00X0oooo0@00000000030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0S03oool00`000000oooo0?ooo`0:0?ooo`40000000000`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool10000000000<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo00X0oooo0@0000000003
0000003oool0oooo00X0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0:0?ooo`40
000000000`000000oooo0?ooo`0:0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0
2P3oool10000000000<000000?ooo`3oool02P3oool00`000000oooo0?ooo`2<0?ooo`030000003o
ool0oooo00X0oooo0@00000000030000003oool0oooo00X0oooo00<000000?ooo`3oool0S03oool0
0`000000oooo0?ooo`0:0?ooo`40000000000`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
08`0oooo00<000000?ooo`3oool02P3oool10000000000<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`2<0?ooo`030000003oool0oooo00X0oooo0@00000000030000003oool0oooo00X0oooo
00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0:0?ooo`40000000000`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool10000000000<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo00X0oooo0@000000
00030000003oool0oooo00X0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0:0?oo
o`40000000000`000000oooo0?ooo`0:0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3o
ool02P3oool10000000000<000000?ooo`3oool02P3oool00`000000oooo0?ooo`2<0?ooo`030000
003oool0oooo00X0oooo0@00000000030000003oool0oooo00X0oooo00<000000?ooo`3oool0S03o
ool00`000000oooo0?ooo`0:0?ooo`40000000000`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo08`0oooo00<000000?ooo`3oool02P3oool10000000000<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`2<0?ooo`030000003oool0oooo00X0oooo0@00000000030000003oool0oooo00X0
oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0:0?ooo`40000000000`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool10000000000<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo00X0oooo0@00
000000030000003oool0oooo00X0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0:
0?ooo`40000000000`000000oooo0?ooo`0:0?ooo`030000003oool0oooo08`0oooo00<000000?oo
o`3oool02P3oool10000000000<000000?ooo`3oool02P3oool00`000000oooo0?ooo`2<0?ooo`03
0000003oool0oooo00X0oooo0@00000000030000003oool0oooo00X0oooo00<000000?ooo`3oool0
S03oool00`000000oooo0?ooo`0:0?ooo`40000000000`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo08`0oooo00<000000?ooo`3oool02P3oool10000000000<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`2<0?ooo`030000003oool0oooo00X0oooo0@00000000030000003oool0oooo
00X0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0:0?ooo`40000000000`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool100000000
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo00X0oooo
0@00000000030000003oool0oooo00X0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?oo
o`0:0?ooo`40000000000`000000oooo0?ooo`0:0?ooo`030000003oool0oooo08`0oooo00<00000
0?ooo`3oool02P3oool10000000000<000000?ooo`3oool02P3oool00`000000oooo0?ooo`2<0?oo
o`030000003oool0oooo00X0oooo0@00000000030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0S03oool00`000000oooo0?ooo`0:0?ooo`40000000000`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0[0?ooo`030000
003oool0oooo00X0oooo0@00000000030000003oool0oooo00X0oooo00<000000?ooo`3oool0:`3o
ool00`000000oooo0?ooo`0Y0?ooo`X00000:`3oool00`000000oooo0?ooo`0:0?ooo`4000000000
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo04h0oooo2@00000601BT_P<0000000<007Fm
0000000000000P00000W0?ooo`030000003oool0oooo00X0oooo0@00000000030000003oool0oooo
00X0oooo00<000000?ooo`3oool0B`3oool30000000304W5/0000000000000H000002@3oool40000
0003001e_@000000000000<000008P3oool00`000000oooo0?ooo`0:0?ooo`40000000000`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo04T0oooo0P0000000`19aK0000000000000F0?ooo`<0
00000`00MKd3000001l0oooo00<000000?ooo`3oool02P3oool10000000000<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`160?ooo`D000007@3oool400000003000lZ`000000000001d0oooo
00<000000?ooo`3oool02P3oool10000000000<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`130?ooo`H000008P3oool20000008003b[00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`0:0?ooo`40000000000`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0440oooo1@00000W
0?ooo`0300000000?:/003b[008000006P3oool00`000000oooo0?ooo`0:0?ooo`40000000000`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0400oooo0`00000[0?ooo`8000000P00?:/00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo00X0oooo0@00000000030000003oool0oooo00X0
oooo00<000000?ooo`3oool0?P3oool3000002l0oooo00@00000000lZ`00?:/00000603oool00`00
0000oooo0?ooo`0:0?ooo`40000000000`000000oooo0?ooo`0:0?ooo`030000003oool0oooo03d0
oooo00<0000007WETP000000<@3oool200000003000lZ`000000000001H0oooo00<000000?ooo`3o
ool02P3oool10000000000<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0l0?ooo`030000
001ieI80000003@0oooo00@00000000lZ`00?:/000005@3oool00`000000oooo0?ooo`0:0?ooo`40
000000000`000000oooo0?ooo`0:0?ooo`030000003oool0oooo03/0oooo00<0000007WETP000000
=P3oool00`00000003b[000lZ`02000001<0oooo00<000000?ooo`3oool02P3oool10000000000<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0j0?ooo`<00000>@3oool400000180oooo00<0
00000?ooo`3oool02P3oool10000000000<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0h
0?ooo`<00000?03oool010000000002;0000R`00000A0?ooo`030000003oool0oooo00X0oooo0@00
000000030000003oool0oooo00X0oooo00<000000?ooo`3oool0=`3oool00`000000NMFB0000000n
0?ooo`040000000008/0002;00000100oooo00<000000?ooo`3oool02P3oool10000000000<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0f0?ooo`030000001ieI80000003l0oooo00@00000
0000R`0008/00000403oool00`000000oooo0?ooo`0:0?ooo`40000000000`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo03D0oooo00<000000:3BJ@000000@@3oool010000000002;0000R`00
000?0?ooo`030000003oool0oooo00X0oooo0@00000000030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0=@3oool00`000000X=9Y0?ooo`120?ooo`040000000008/0002;000000h0oooo00<0
00000?ooo`3oool02P3oool10000000000<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0d
0?ooo`030000002PdVT0000004@0oooo00@000000000R`0008/000003@3oool00`000000oooo0?oo
o`0:0?ooo`40000000000`000000oooo0?ooo`0:0?ooo`030000003oool0oooo03@0oooo0P000016
0?ooo`040000000008/0002;000000`0oooo00<000000?ooo`3oool02P3oool10000000000<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0c0?ooo`800000B03oool010000000002;0000R`00
000;0?ooo`030000003oool0oooo00X0oooo0@00000000030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0<P3oool00`000000X=9Y000000180?ooo`040000000008/0002;000000/0oooo00<0
00000?ooo`3oool02P3oool10000000000<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0b
0?ooo`800000BP3oool010000000002;0000R`00000:0?ooo`030000003oool0oooo00X0oooo0@00
000000030000003oool0oooo00X0oooo00<000000?ooo`3oool0<@3oool2000004`0oooo10000009
0?ooo`030000003oool0oooo00X0oooo0@00000000030000003oool0oooo00X0oooo00<000000?oo
o`3oool0<03oool00`000000X=9Y0000001<0?ooo`04000000000600001P000000T0oooo00<00000
0?ooo`3oool02P3oool10000000000<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0`0?oo
o`800000CP3oool010000000001P0000H00000080?ooo`030000003oool0oooo00X0oooo0@000000
00030000003oool0oooo00X0oooo00<000000?ooo`3oool0;`3oool2000004l0oooo00@000000000
H00006000000203oool00`000000oooo0?ooo`0:0?ooo`40000000000`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo02l0oooo0P00001@0?ooo`04000000000600001P000000L0oooo00<00000
0?ooo`3oool02P3oool10000000000<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0^0?oo
o`800000D@3oool010000000001P0000H00000070?ooo`030000003oool0oooo00X0oooo0@000000
00030000003oool0oooo00X0oooo00<000000?ooo`3oool0;P3oool200000540oooo00D000000000
H0000600001P000000060?ooo`030000003oool0oooo00X0oooo0@00000000030000003oool0oooo
00X0oooo00<000000?ooo`3oool0;@3oool00`000000^Kdh0?ooo`1B0?ooo`04000000000600001P
000000H0oooo00<000000?ooo`3oool02P3oool10000000000<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0]0?ooo`800000D`3oool010000000001P0000H00000060?ooo`030000003oool0
oooo00X0oooo0@00000000030000003oool0oooo00X0oooo00<000000?ooo`3oool0;@3oool20000
05<0oooo00D000000000H0000600001P000000050?ooo`030000003oool0oooo00X0oooo0@000000
00030000003oool0oooo00X0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`1C0?oo
o`04000000000600001P000000D0oooo00<000000?ooo`3oool02P3oool10000000000<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0/0?ooo`800000E@3oool01@000000001P0000H0000600
000000@0oooo00<000000?ooo`3oool02P3oool10000000000<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0/0?ooo`800000EP3oool30000H0030000003oool0oooo0080oooo00<000000?oo
o`3oool02P3oool10000000000<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0/0?ooo`80
0000EP3oool200000080001P00D000000?ooo`3oool0oooo0000000<0?ooo`40000000000`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo02/0oooo0P00001G0?ooo`030000000002l000000080
00000`3oool00`000000oooo0?ooo`0:0?ooo`40000000000`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo02/0oooo0P00001G0?ooo`050000000002l0000_0000;`0000000`3oool00`000000
oooo0?ooo`0:0?ooo`40000000000`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02/0oooo
0P00001G0?ooo`050000000002l0000_0000;`0000000`3oool00`000000oooo0?ooo`0:0?ooo`40
000000000`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0
EP3oool01@000000000_0000;`0002l0000000<0oooo00<000000?ooo`3oool02P3oool100000000
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0Z0?ooo`800000F03oool01@000000000_
0000;`0002l0000000<0oooo00<000000?ooo`3oool02P3oool10000000000<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0Z0?ooo`800000F03oool01@000000000_0000;`0002l0000000<0
oooo00<000000?ooo`3oool02P3oool10000000000<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0Z0?ooo`800000F03oool01@000000000_0000;`0002l0000000<0oooo00<000000?ooo`3o
ool02P3oool10000000000<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0Z0?ooo`800000
F@3oool010000000000_0000;`0000030?ooo`030000003oool0oooo00X0oooo0@00000000030000
003oool0oooo00X0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`020?ooo`800000
F@3oool01@000000000_0000;`0002l000000080oooo00<000000?ooo`3oool02P3oool100000000
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0080oooo
0P00001I0?ooo`050000000002l0000_0000;`0000000P3oool00`000000oooo0?ooo`0:0?ooo`40
000000000`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
0P3oool2000005T0oooo00D000000000;`0002l0000_000000020?ooo`030000003oool0oooo00X0
oooo0@00000000030000003oool0oooo00X0oooo00<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`020?ooo`800000F@3oool01@000000000_0000;`0002l000000080oooo00<000000?ooo`3o
ool02P3oool10000000000<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo0080oooo00<000000<>G10000000F03oool01@000000000_0000;`0002l000000080
oooo00<000000?ooo`3oool02P3oool10000000000<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0U0?ooo`030000003oool0oooo00<0oooo0P00001H0?ooo`050000000002l0000_0000;`00
00000P3oool00`000000oooo0?ooo`0:0?ooo`40000000000`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo02D0oooo00<000000?ooo`3oool00`3oool2000005P0oooo0`0000001@0002l00000
0?ooo`3oool0000000`0oooo0@00000000030000003oool0oooo00X0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`030?ooo`800000E`3oool600000080oooo00<000000?ooo`3oool0
2P3oool10000000000<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo00<0oooo0P00001G0?ooo`H000000P3oool00`000000oooo0?ooo`0:0?ooo`4000000000
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool00`3oool2
000005L0oooo1@0000030?ooo`030000003oool0oooo00X0oooo0@00000000030000003oool0oooo
00X0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`020?ooo`800000E`3oool50000
00<0oooo00<000000?ooo`3oool02P3oool10000000000<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo0080oooo00<000000;aT003oool0E@3oool6000000<0
oooo00<000000?ooo`3oool02P3oool10000000000<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo0080oooo00<000000;aT00000000E@3oool600000080oooo
0P00000<0?ooo`40000000000`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool00P3oool00`000000_6@00000001E0?ooo`D000000`3oool2000000`0oooo0@00
000000030000003oool0oooo00X0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`03
0?ooo`030000002lI000000005<0oooo1P0000020?ooo`030000003oool0000000`0oooo0@000000
00030000003oool0oooo00X0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`030?oo
o`030000002lI000000005<0oooo1P0000020?ooo`030000003oool0000000`0oooo0@0000000003
0000003oool0oooo00X0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`030?ooo`03
0000002lI000000005<0oooo1@0000030?ooo`030000003oool0000000`0oooo0@00000000030000
003oool0oooo00X0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`040?ooo`030000
002lI00000000580oooo1@0000020?ooo`040000003oool0oooo000000`0oooo0@00000000030000
003oool0oooo00X0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`040?ooo`030000
002lI00000000540oooo1P0000020?ooo`040000003oool0oooo000000`0oooo0@00000000030000
003oool0oooo00X0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`040?ooo`030000
002lI00000000540oooo1P0000020?ooo`040000003oool0oooo000000`0oooo0@00000000030000
003oool0oooo00X0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`050?ooo`030000
002lI000000004l0oooo1P0000020?ooo`050000003oool0oooo0?ooo`000000303oool100000000
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00D0oooo
00<000000;aT00000000C`3oool600000080oooo00D000000?ooo`3oool0oooo0000000<0?ooo`40
000000000`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
1P3oool00`000000_6@00000001=0?ooo`H000000P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00X0oooo0@00000000030000003oool0oooo00X0oooo00<000000?ooo`3oool09P3o
ool00`000000oooo0?ooo`060?ooo`030000002lI000000004d0oooo1P0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool02P3oool10000000000<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00H0oooo00@000000;aT000000000000B`3o
ool6000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`4000000000
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool01`3oool0
10000000YBX00:DZ000000190?ooo`L000000P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00X0oooo0@00000000030000003oool0oooo00X0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`070?ooo`040000002U:P00YBX0000004T0oooo1P0000030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool02P3oool10000000000<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo00@000000:DZ002U:P000000A`3o
ool6000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`4000000000
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0203oool0
10000000YBX00:DZ000000160?ooo`H000000`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00X0oooo0@00000000030000003oool0oooo00X0oooo00<000000?ooo`3oool09`3oool0
0`000000oooo0?ooo`080?ooo`050000002U:P00YBX00:DZ00000000A03oool6000000@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`40000000000`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool02@3oool01@000000YBX00:DZ002U
:P00000004<0oooo1@0000040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02P3o
ool10000000000<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0
oooo00X0oooo00D000000:DZ002U:P00YBX0000000110?ooo`H00000103oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00X0oooo0@00000000030000003oool0oooo00X0oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`0;0?ooo`040000002U:P00YBX0000003l0oooo1`00
00040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02P3oool10000000000<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00`0oooo00@00000
0:DZ002U:P000000?@3oool8000000@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0:0?ooo`40000000000`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool03@3oool010000000YBX00:DZ0000000k0?ooo`P000001@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00X0oooo0@00000000030000003oool0oooo00X0oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`0=0?ooo`030000002U:P00YBX000<00000=`3oool9
000000D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0:0?ooo`40000000000`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool03P3oool00`00
0000YBX000000002080000030000003oool0oooo03<0oooo2@0000060?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool02P3oool10000000000<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0W0?ooo`030000003oool0oooo00l0oooo0P000003080000800000<P3oool8000000L0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`40000000000`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0403oool00`000000P000
08000003080000030000003oool0oooo02d0oooo2@0000080?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool02P3oool10000000000<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0W0?ooo`030000003oool0oooo0140oooo0P000004080000800000:`3oool:000000P0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`40000000000`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool04`3oool00`000000P00008000003
080000030000003oool0oooo02H0oooo2P00000:0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02P3oool10000000000<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo01@0oooo0P000004080000800000903oool;000000/0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`40000000000`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo02L0oooo00<000000?ooo`3oool05P3oool00`000000P00008000003080000<0
00007`3oool<000000/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`40
000000000`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0
5`3oool2000000<0P00000<000000580001B00001000000I0?ooo``000003@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00X0oooo0@00000000030000003oool0oooo00X0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`0I0?ooo`04000000200000P000000000H0DP00
1@00000B0?ooo``000003P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo
0@00000000030000003oool0oooo00X0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`0J0?ooo`<000002`1B000L00000100oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0:0?ooo`40000000000`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool06`3oool3000000/0DP0000<0000001l0000O00002`0O000:00000180oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`40000000000`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool07P3oool5000000H0DP0000<0000001l0
000O0000300O0007000001<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0:0?oo
o`40000000000`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool08`3oool500000080DP0000<0000001l0000O00002`0O0005000001D0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0:0?ooo`40000000000`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo02P0oooo00<000000?ooo`3oool0:03ooolC000001H0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0:0?ooo`40000000000`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00X0oooo0@00000000030000003oool0oooo00X0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`1A0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02P3oool1
0000000000<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
0500oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0:0?ooo`40000000000`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0D03oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00X0oooo0@00000000030000003oool0oooo00X0oooo
00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool02P3oool10000000000<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0X0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0:0?ooo`40000000000`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool0C`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00X0oooo0@000000
00030000003oool0oooo00X0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`1>0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool02P3oool10000000000<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`0:0?ooo`40000000000`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo02P0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo00X0oooo0@00000000030000003oool0oooo00X0oooo00<000000?ooo`3oool0:03o
ool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool02P3o
ool10000000000<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0
oooo04d0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`40000000000`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0C03oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00X0oooo0@00000000030000003oool0oooo00X0
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool02P3oool10000000000<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0:0?ooo`40000000000`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool0BP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00X0oooo0@00
000000030000003oool0oooo00X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1:
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool02P3oool10000000000<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo04T0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0:0?ooo`40000000000`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo00X0oooo0@00000000030000003oool0oooo00X0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
2P3oool10000000000<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo04P0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0:0?ooo`4000000000
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0B03oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00X0oooo0@00000000030000003oool0oooo
00X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool02P3oool10000000000<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0:0?ooo`40000000000`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00X0oooo
0@00000000030000003oool0oooo00X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`160?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool02P3oool10000000000<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`0:0?ooo`40000000000`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo00X0oooo0@00000000030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool02P3oool10000000000<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo04@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0:0?ooo`400000
00000`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0A03o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00X0oooo0@00000000030000003oool0
oooo00X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`140?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool02P3oool10000000000<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`0:0?ooo`40000000000`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02X0
oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00X0
oooo0@00000000030000003oool0oooo00X0oooo00<000000?ooo`3oool0:P3oool00`000000oooo
0?ooo`110?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool02P3oool10000000000<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`0:0?ooo`40000000000`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo00X0oooo0@00000000030000003oool0oooo00X0oooo00<000000?oo
o`3oool0:P3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool02P3oool10000000000<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo0400oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0:0?ooo`40
000000000`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00X0oooo0@00000000030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0o0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool02P3oool10000000000<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0:0?ooo`40000000000`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
00X0oooo0@00000000030000003oool0oooo00X0oooo00<000000?ooo`3oool0:P3oool00`000000
oooo0?ooo`0n0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool02P3oool100000000
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo03d0oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0:0?ooo`40000000000`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo00X0oooo0@00000000030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool02P3oool10000000000<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo03`0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0:0?oo
o`40000000000`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool0?03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00X0oooo0@00000000030000
003oool0oooo00X0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool02P3oool10000000000<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`0:0?ooo`40000000000`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo01/0oooo9`00000V0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool02P3oool1
0000000000<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0K0?ooo`03000000170000A`00
00d0A`0000<0000004L0001700004`1700000`000000oooo0?ooo`030?ooobP000007@3oool00`00
0000oooo0?ooo`0:0?ooo`40000000000`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01X0
oooo00<0000004L0001700003P1700000`000000A`0004L0000C04L000030000003oool0oooo00<0
oooo00<0000004P0001800007@1800000`000000B00004P0000404P000030000003oool0oooo01/0
oooo00<000000?ooo`3oool02P3oool10000000000<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0J0?ooo`03000000170000A`0000h0A`0000<0000004L0001700004`1700000`000000oooo
0?ooo`030?ooo`03000000180000B00001`0B00000<0000004P0001800001P1800000`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo00X0oooo0@00000000030000003oool0oooo00X0oooo00<0
00000?ooo`3oool06P3oool00`000000A`0004L0000>04L00003000000170000A`0001<0A`0000<0
00000?ooo`3oool00`3oool00`000000B00004P0000L04P00003000000180000B00000H0B00000<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`0:0?ooo`40000000000`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo01T0oooo00<0000004L0001700003`1700000`000000A`0004L0000C
04L000030000003oool0oooo00<0oooo00<0000004P000180000701800000`000000B00004P00006
04P000030000003oool0oooo01X0oooo00<000000?ooo`3oool02P3oool10000000000<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0I0?ooo`03000000170000A`0000l0A`0000<0000004L0
001700004`1700000`000000oooo0?ooo`030?ooo`03000000180000B00001/0B00000<0000004P0
001800001`1800000`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00X0oooo0@0000000003
0000003oool0oooo00X0oooo00<000000?ooo`3oool06@3oool00`000000A`0004L0000?04L00003
000000170000A`0001<0A`0000<000000?ooo`3oool00`3oool00`000000B00004P0000K04P00003
000000180000B00000P0B00000<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0:0?ooo`40
000000000`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01P0oooo00<0000004L000170000
401700000`000000A`0004L0000C04L000030000003oool0oooo00<0oooo00<0000004P000180000
6P1800000`000000B00004P0000904P000030000003oool0oooo01T0oooo00<000000?ooo`3oool0
2P3oool10000000000<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0H0?ooo`0300000017
0000A`0002D0A`000P0000050?ooo`03000000180000B00001X0B00000<0000004P0001800002@18
00000`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00X0oooo0@00000000030000003oool0
oooo00X0oooo00<000000?ooo`3oool05`3oool00`000000A`0004L0000V04L0008000001@3oool0
0`000000B00004P0000V04P000030000003oool0oooo01T0oooo00<000000?ooo`3oool02P3oool1
0000000000<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0G0?ooo`03000000170000A`00
02H0A`000P0000050?ooo`800000:01800000`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
00X0oooo0@00000000030000003oool0oooo00X0oooo00<000000?ooo`3oool05`3oool00`000000
A`0004L0000V04L0008000001@3oool2000002P0B00000<000000?ooo`3oool0603oool00`000000
oooo0?ooo`0:0?ooo`40000000000`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01H0oooo
00<0000004L0001700009`170002000000D0oooo0P00000X04P000030000003oool0oooo01P0oooo
00<000000?ooo`3oool02P3oool10000000000<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0F0?ooo`03000000170000A`0002L0A`000P0000050?ooo`800000:@1800000`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo00X0oooo0@00000000030000003oool0oooo00X0oooo00<00000
0?ooo`3oool05P3oool00`000000A`0004L0000W04L0008000001@3oool2000002T0B00000<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`0:0?ooo`40000000000`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo01D0oooo00<0000004L000170000:0170002000000D0oooo0P00000Y04P0
00030000003oool0oooo01L0oooo00<000000?ooo`3oool02P3oool10000000000<000000?ooo`3o
ool02P3ooom<000002T0B0006`00000<0?ooo`40000000000`000000oooo0?ooo`090?ooo`030000
003oool0oooo01H0oooo00<000000;BC]02dTk@0:02dTk@2000000D0oooo0P00000Z04P000030000
003oool0oooo01H0oooo00<000000?ooo`3oool02P3oool10000000000<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0F0?ooo`030000002dTk@0]9>d02P0]9>d0P0000050?ooobd000006@3o
ool00`000000oooo0?ooo`090?ooo`40000000000`000000oooo0?ooo`080?ooo`030000003oool0
oooo01L0oooo00<000000;BC]02dTk@0:02dTk@2000000D0oooo0P00000Z0;BC]0030000003oool0
oooo01L0oooo00<000000?ooo`3oool02@3oool10000000000<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0G0?ooo`030000002dTk@0]9>d02P0]9>d0P0000050?ooo`800000:P2dTk@00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo00P0oooo0@00000000030000003oool0oooo00L0
oooo00<000000?ooo`3oool0603oool00`000000]9>d0;BC]00X0;BC]08000001@3oool2000002X0
]9>d00<000000?ooo`3oool0603oool00`000000oooo0?ooo`080?ooo`40000000000`000000oooo
0?ooo`070?ooo`030000003oool0oooo01P0oooo00<000000;BC]02dTk@0:02dTk@2000000D0oooo
0P00000Z0;BC]0030000003oool0oooo01T0oooo00<000000?ooo`3oool01`3oool10000000000<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0I0?ooo`030000002dTk@0]9>d02P0]9>d0P00
00050?ooo`800000:P2dTk@00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00L0oooo0@00
000000030000003oool0oooo00H0oooo00<000000?ooo`3oool06@3oool00`000000]9>d0;BC]00X
0;BC]08000001P3oool00`000000]9>d0;BC]00X0;BC]0030000003oool0oooo01X0oooo00<00000
0?ooo`3oool01P3oool10000000000<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0J0?oo
o`030000002dTk@0]9>d02P0]9>d0P0000060?ooo`030000002dTk@0]9>d02P0]9>d00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`060?ooo`40000000000`000000oooo0?ooo`050?ooo`03
0000003oool0oooo01X0oooo00<000000;BC]02dTk@0:02dTk@2000000H0oooo00<000000;BC]02d
Tk@0:02dTk@00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@00000000030000
003oool0oooo00@0oooo00<000000?ooo`3oool06`3oool00`000000]9>d0;BC]00X0;BC]0800000
1P3oool00`000000]9>d0;BC]00X0;BC]0030000003oool0oooo01/0oooo00<000000?ooo`3oool0
1@3oool10000000000<000000?ooo`3oool0103oool00`000000oooo0?ooo`0K0?ooo`030000002d
Tk@0]9>d02P0]9>d0P0000060?ooo`030000002dTk@0]9>d02P0]9>d00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`040?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0
oooo01`0oooo00<000000;BC]02dTk@0:02dTk@2000000H0oooo00<000000;BC]02dTk@0:02dTk@0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00@0oooo0@00000000030000003oool0oooo
00<0oooo00<000000?ooo`3oool0703oool00`000000]9>d0;BC]00X0;BC]08000001P3oool00`00
0000]9>d0;BC]00X0;BC]0030000003oool0oooo01d0oooo00<000000?ooo`3oool00`3oool10000
000000<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0M0?ooo`030000002dTk@0]9>d02P0
]9>d0P0000060?ooo`030000002dTk@0]9>d02P0]9>d00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`020?ooo`030000003oool0oooo01d0oooo
00<000000;BC]02dTk@0:02dTk@2000000H0oooo00<000000;BC]02dTk@0:02dTk@00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo0080oooo0@00000000050000003oool0oooo0?ooo`000000
803oool00`000000]9>d0;BC]00X0;BC]08000001P3oool00`000000]9>d0;BC]00X0;BC]0030000
003oool0oooo01h0oooo00<000000?ooo`3oool00P3oool10000000000D000000?ooo`3oool0oooo
0000000P0?ooo`030000002dTk@0]9>d02P0]9>d00<000000?ooo`3oool01@3oool00`000000]9>d
0;BC]00X0;BC]0030000003oool0oooo01l0oooo00@000000?ooo`3oool0oooo0@00000000040000
003oool0oooo00000240oooo00<000000;BC]02dTk@0:02dTk@00`000000oooo0?ooo`050?ooo`03
0000002dTk@0]9>d02P0]9>d00<000000?ooo`3oool07`3oool010000000oooo0?ooo`3oool10000
000000@000000?ooo`3oool000008@3oool00`000000]9>d0;BC]00X0;BC]0030000003oool0oooo
00D0oooo00<000000;BC]02dTk@0:02dTk@00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
0040000000000`000000oooo0000000R0?ooo`030000002dTk@0]9>d02P0]9>d00<000000?ooo`3o
ool01@3oool00`000000]9>d0;BC]00X0;BC]0030000003oool0oooo0200oooo00<000000?ooo`3o
ool00@00000000030000003oool000000280oooo00<000000;BC]02dTk@0:02dTk@00`000000oooo
0?ooo`050?ooo`030000002dTk@0]9>d02P0]9>d00<000000?ooo`3oool08@3oool100000040oooo
0@000000008000008`3oool/000000L0oooo;000000S0?ooo`4000000@3oool1000000000P00002V
0?ooo`80000000000`000000oooo0?ooo`2U0?ooo`800000002Z00000000\
\>"],
  ImageRangeCache->{{{91.5625, 226.75}, {431.375, 159.75}} -> {-0.0881031, \
0.588452, 0.0029561, 0.0029561}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#3", "Text"],

Cell[CellGroupData[{

Cell["Hz2[[-3]]", "Input"],

Cell[BoxData[
    \(1.9291258770160107`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pretty[Chop[e2ni . eigenvectors2[\([\(-3\)]\)], 10^\(-4\)]]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
          {"\<\"optic\"\>", "0.014986198295352481`", "0", "0", "0", 
            "0.9998877006247513`", "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Status["\<Plotting stage 2 mode 2\>"]\ ; 
    eigenplot[eigenvectors2[\([\(-3\)]\)],  .5, {0, \(-1\), \(- .25\)}, \ 
      floatmatrix2]\ ; Done[]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 4.95269 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.04936 5.09872 2.49583e-016 5.09872 [
[ 0 0 0 0 ]
[ 1 4.95269 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
.1333 4.95269 L
s
.1333 4.95269 m
.26075 3.76924 L
s
.26075 3.76924 m
.21037 .65115 L
s
.21037 .65115 m
0 0 L
s
1 0 m
.78963 .65115 L
s
.78963 .65115 m
.73925 3.76924 L
s
.73925 3.76924 m
.8667 4.95269 L
s
.8667 4.95269 m
1 0 L
s
0 0 m
.1333 4.95269 L
s
.1333 4.95269 m
.8667 4.95269 L
s
.8667 4.95269 m
1 0 L
s
1 0 m
0 0 L
s
.21037 .65115 m
.78963 .65115 L
s
.78963 .65115 m
.73925 3.76924 L
s
.73925 3.76924 m
.26075 3.76924 L
s
.26075 3.76924 m
.21037 .65115 L
s
0 0 m
1 0 L
1 4.95269 L
0 4.95269 L
closepath
clip
newpath
.5 Mabswid
.692 .685 .839 r
.5 3.94925 m .70365 3.94925 L p .29381 3.76668 L F P
0 g
s
.692 .685 .839 r
.70365 3.94925 m .70619 3.76668 L .29381 3.76668 L p F P
0 g
s
.692 .685 .839 r
.29381 3.76668 m .29635 3.94925 L .5 3.94925 L p F P
0 g
s
.752 .614 .046 r
.28579 4.07381 m .29635 3.94925 L p .27094 4.01282 L F P
0 g
s
.752 .614 .046 r
.29635 3.94925 m .29381 3.76668 L .27094 4.01282 L p F P
0 g
s
0 0 .046 r
.70619 3.76668 m .70365 3.94925 L .71421 4.07381 L p F P
0 g
s
0 0 .046 r
.72906 4.01282 m .70619 3.76668 L p .71421 4.07381 L F P
0 g
s
.408 0 0 r
.70619 3.76668 m .72906 4.01282 L .27094 4.01282 L p F P
0 g
s
.408 0 0 r
.27094 4.01282 m .29381 3.76668 L .70619 3.76668 L p F P
0 g
s
.752 .614 .046 r
.27094 4.01282 m .27407 4.21199 L .28579 4.07381 L p F P
0 g
s
0 0 .046 r
.71421 4.07381 m .72593 4.21199 L .72906 4.01282 L p F P
0 g
s
.52081 3.85615 m
.62862 2.7282 L
s
.5 4.07381 m
.50583 4.01282 L
s
.561 .377 .589 r
.76533 2.8021 m .60155 2.88678 L .66958 3.02643 L p F P
0 g
s
.658 .589 .766 r
.60155 2.88678 m .76533 2.8021 L .69179 2.66504 L p F P
0 g
s
.658 .589 .766 r
.69179 2.66504 m .52804 2.75065 L .60155 2.88678 L p F P
0 g
s
.713 .77 .896 r
.52804 2.75065 m .69179 2.66504 L .61933 2.53915 L p F P
0 g
s
.713 .77 .896 r
.61933 2.53915 m .45363 2.62666 L .52804 2.75065 L p F P
0 g
s
.561 .377 .589 r
.77955 2.83044 m .76533 2.8021 L p .66958 3.02643 L F P
0 g
s
.561 .377 .589 r
.66958 3.02643 m .78125 2.96933 L .77955 2.83044 L p F P
0 g
s
.431 .146 .377 r
.78125 2.96933 m .66958 3.02643 L .72755 3.16064 L p F P
0 g
s
.431 .146 .377 r
.78389 3.04622 m .78125 2.96933 L p .72755 3.16064 L F P
0 g
s
.715 .899 .962 r
.45363 2.62666 m .61933 2.53915 L .5528 2.43323 L p F P
0 g
s
.715 .899 .962 r
.5528 2.43323 m .38325 2.52357 L .45363 2.62666 L p F P
0 g
s
.431 .146 .377 r
.72755 3.16064 m .78678 3.13068 L .78389 3.04622 L p F P
0 g
s
.272 0 .138 r
.78678 3.13068 m .72755 3.16064 L .77076 3.27968 L p F P
0 g
s
.272 0 .138 r
.79392 3.24214 m .78678 3.13068 L p .77076 3.27968 L F P
0 g
s
.688 .696 .853 r
.5 4.21199 m .27407 4.21199 L .27094 4.01282 L p F P
0 g
s
.688 .696 .853 r
.72906 4.01282 m .72593 4.21199 L .5 4.21199 L p F P
0 g
s
.688 .696 .853 r
.27094 4.01282 m .72906 4.01282 L p .5 4.21199 L F P
0 g
s
.652 .955 .943 r
.38325 2.52357 m .5528 2.43323 L .49749 2.35653 L p F P
0 g
s
.652 .955 .943 r
.49749 2.35653 m .32233 2.45047 L .38325 2.52357 L p F P
0 g
s
.687 .698 .855 r
.5 4.26148 m .73013 4.26148 L p .26662 4.05925 L F P
0 g
s
.687 .698 .855 r
.73013 4.26148 m .73338 4.05925 L .26662 4.05925 L p F P
0 g
s
.687 .698 .855 r
.26662 4.05925 m .26987 4.26148 L .5 4.26148 L p F P
0 g
s
.752 .614 .046 r
.25629 4.42161 m .26987 4.26148 L p .23689 4.37925 L F P
0 g
s
.752 .614 .046 r
.26987 4.26148 m .26662 4.05925 L .23689 4.37925 L p F P
0 g
s
0 0 .046 r
.73338 4.05925 m .73013 4.26148 L .74371 4.42161 L p F P
0 g
s
.272 0 .138 r
.77076 3.27968 m .79553 3.26725 L .79392 3.24214 L p F P
0 g
s
.087 0 0 r
.79553 3.26725 m .77076 3.27968 L .7944 3.37275 L p F P
0 g
s
.087 0 0 r
.80623 3.35863 m .79553 3.26725 L p .7944 3.37275 L F P
0 g
s
0 0 .046 r
.76311 4.37925 m .73338 4.05925 L p .74371 4.42161 L F P
0 g
s
.408 0 0 r
.73338 4.05925 m .76311 4.37925 L .23689 4.37925 L p F P
0 g
s
.408 0 0 r
.23689 4.37925 m .26662 4.05925 L .73338 4.05925 L p F P
0 g
s
.521 .916 .826 r
.32233 2.45047 m .49749 2.35653 L .45913 2.31844 L p F P
0 g
s
.521 .916 .826 r
.45913 2.31844 m .27686 2.41655 L .32233 2.45047 L p F P
0 g
s
.01 w
.39857 2.25228 Mdot
.60143 2.25228 Mdot
.5 Mabswid
.087 0 0 r
.7944 3.37275 m .80714 3.3664 L .80623 3.35863 L p F P
0 g
s
0 0 0 r
.80714 3.3664 m .7944 3.37275 L .79401 3.42844 L p F P
0 g
s
0 0 0 r
.81904 3.40838 m .80714 3.3664 L p .79401 3.42844 L F P
0 g
s
.752 .614 .046 r
.23689 4.37925 m .24101 4.60182 L .25629 4.42161 L p F P
0 g
s
0 0 .046 r
.74371 4.42161 m .75899 4.60182 L .76311 4.37925 L p F P
0 g
s
.5 4.42161 m
.50586 4.37925 L
s
0 0 0 r
.27686 2.41655 m .45913 2.31844 L .44349 2.32749 L p F P
0 g
s
0 0 0 r
.44349 2.32749 m .25308 2.42998 L .27686 2.41655 L p F P
0 g
s
0 0 0 r
.79401 3.42844 m .82094 3.41508 L .81904 3.40838 L p F P
0 g
s
.334 .79 .656 r
.82094 3.41508 m .79401 3.42844 L .7664 3.43602 L p F P
0 g
s
.334 .79 .656 r
.83139 3.40561 m .82094 3.41508 L p .7664 3.43602 L F P
0 g
s
0 0 0 r
.25308 2.42998 m .44349 2.32749 L .45538 2.38919 L p F P
0 g
s
0 0 0 r
.45538 2.38919 m .25651 2.49578 L .25308 2.42998 L p F P
0 g
s
.68 .713 .873 r
.5 4.60182 m .24101 4.60182 L .23689 4.37925 L p F P
0 g
s
.68 .713 .873 r
.76311 4.37925 m .75899 4.60182 L .5 4.60182 L p F P
0 g
s
.68 .713 .873 r
.23689 4.37925 m .76311 4.37925 L p .5 4.60182 L F P
0 g
s
.334 .79 .656 r
.7664 3.43602 m .83585 3.40156 L .83139 3.40561 L p F P
0 g
s
.527 .921 .865 r
.83585 3.40156 m .7664 3.43602 L .71106 3.38808 L p F P
0 g
s
.527 .921 .865 r
.84281 3.36175 m .83585 3.40156 L p .71106 3.38808 L F P
0 g
s
.114 0 0 r
.25651 2.49578 m .45538 2.38919 L .49703 2.50313 L p F P
0 g
s
.114 0 0 r
.49703 2.50313 m .29035 2.61299 L .25651 2.49578 L p F P
0 g
s
.527 .921 .865 r
.71106 3.38808 m .85035 3.31862 L .84281 3.36175 L p F P
0 g
s
.659 .934 .969 r
.85035 3.31862 m .71106 3.38808 L .63168 3.28398 L p F P
0 g
s
.659 .934 .969 r
.85309 3.28471 m .85035 3.31862 L p .63168 3.28398 L F P
0 g
s
.659 .934 .969 r
.84459 3.1768 m .85997 3.19948 L .85309 3.28471 L p F P
0 g
s
.659 .934 .969 r
.63168 3.28398 m .84459 3.1768 L p .85309 3.28471 L F P
0 g
s
.327 .006 .259 r
.29035 2.61299 m .49703 2.50313 L .56633 2.66019 L p F P
0 g
s
.327 .006 .259 r
.56633 2.66019 m .35354 2.77193 L .29035 2.61299 L p F P
0 g
s
.01 w
.38104 2.37406 Mdot
.61896 2.37406 Mdot
.5 Mabswid
.698 .815 .937 r
.84459 3.1768 m .63168 3.28398 L .53694 3.1328 L p F P
0 g
s
.52432 4.24582 m
.57456 3.88262 L
s
.698 .815 .937 r
.53694 3.1328 m .75315 3.02253 L .84459 3.1768 L p F P
0 g
s
.57456 3.88262 m
.67516 3.15537 L
s
.509 .309 .545 r
.35354 2.77193 m .56633 2.66019 L .65575 2.84175 L p F P
0 g
s
.509 .309 .545 r
.65575 2.84175 m .43958 2.95363 L .35354 2.77193 L p F P
0 g
s
.641 .591 .783 r
.75315 3.02253 m .53694 3.1328 L .43958 2.95363 L p F P
0 g
s
.641 .591 .783 r
.43958 2.95363 m .65575 2.84175 L .75315 3.02253 L p F P
0 g
s
.25 Mabswid
0 0 m
.1333 4.95269 L
s
.1333 4.95269 m
.8667 4.95269 L
s
.8667 4.95269 m
1 0 L
s
1 0 m
0 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{133.688, 662.063},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000250002UR000`400?l00000o`00003oQ@3oool0
08D0oooo00250000000000<000000?ooo`3oool0P@3oool1000000000P0000210?ooo`8000000002
00000840oooo0P00000000800000P@3oool20000000000<000000?ooo`000000O`3oool100000040
oooo0@00000000030000003oool0000007l0oooo0@0000010?ooo`40000000000`000000oooo0000
001o0?ooo`4000000@3oool10000000000<000000?ooo`000000OP3oool00`000000oooo0?ooo`01
0000000000@000000?ooo`3oool00000O@3oool00`000000oooo0?ooo`010000000000@000000?oo
o`3oool00000O@3oool00`000000oooo0?ooo`010000000000@000000?ooo`3oool00000O03oool0
10000000oooo0?ooo`3oool10000000000D000000?ooo`3oool0oooo0000001k0?ooo`040000003o
ool0oooo0?ooo`40000000001@000000oooo0?ooo`3oool0000007/0oooo00@000000?ooo`3oool0
oooo0@00000000050000003oool0oooo0?ooo`000000NP3oool00`000000oooo0?ooo`020?ooo`40
000000000`000000oooo0?ooo`020?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0
0P3oool10000000000<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1g0?ooo`030000003o
ool0oooo0080oooo0@00000000030000003oool0oooo0080oooo00<000000?ooo`3oool0M`3oool0
0`000000oooo0?ooo`020?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo
07D0oooo00<000000?ooo`3oool00`3oool10000000000<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`1e0?ooo`030000003oool0oooo00<0oooo0@00000000030?ooo`000000oooo00<0oooo
00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`020?ooo`4000000@3oool000030?ooo`00
0000oooo00@0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`030?ooo`4000000@3o
ool000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`03
0?ooo`4000000@3oool000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool0L`3oool00`00
0000oooo0?ooo`030?ooo`4000000@3oool000030?ooo`000000oooo00@0oooo00<000000?ooo`3o
ool0LP3oool00`000000oooo0?ooo`040?ooo`4000000@3oool000030?ooo`000000oooo00D0oooo
00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`040?ooo`4000000@3oool000030?ooo`00
0000oooo00D0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`040?ooo`4000000@3o
ool000030?ooo`000000oooo00D0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`05
0?ooo`4000000@3oool000030?ooo`000000oooo00H0oooo00<000000?ooo`3oool0K`3oool00`00
0000oooo0?ooo`050?ooo`4000000@3oool000030?ooo`000000oooo00H0oooo00<000000?ooo`3o
ool0K`3oool00`000000oooo0?ooo`050?ooo`4000000@3oool000030?ooo`000000oooo00H0oooo
00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`060?ooo`4000000@3oool000030?ooo`00
0000oooo00L0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`060?ooo`4000000@3o
ool000030?ooo`000000oooo00L0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`06
0?ooo`4000000@3oool000030?ooo`000000oooo00L0oooo00<000000?ooo`3oool0K03oool00`00
0000oooo0?ooo`070?ooo`4000000@3oool000030?ooo`000000oooo00P0oooo00<000000?ooo`3o
ool0J`3oool00`000000oooo0?ooo`070?ooo`4000000@3oool000030?ooo`000000oooo00P0oooo
00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`070?ooo`4000000@3oool000030?ooo`00
0000oooo00P0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`080?ooo`4000000@3o
ool000030?ooo`000000oooo00P0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`08
0?ooo`4000000@3oool000030?ooo`000000oooo00T0oooo00<000000?ooo`3oool0J@3oool00`00
0000oooo0?ooo`080?ooo`4000000@3oool000030?ooo`000000oooo00T0oooo00<000000?ooo`3o
ool0J03oool00`000000oooo0?ooo`090?ooo`4000000@3oool000030?ooo`000000oooo00T0oooo
00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`090?ooo`4000000@3oool000030?ooo`00
0000oooo00X0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`090?ooo`4000000@3o
ool000030?ooo`000000oooo00X0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0:
0?ooo`4000000@3oool000030?ooo`000000oooo00X0oooo00<000000?ooo`3oool0IP3oool00`00
0000oooo0?ooo`0:0?ooo`4000000@3oool000030?ooo`000000oooo00/0oooo00<000000?ooo`3o
ool0I@3oool00`000000oooo0?ooo`0:0?ooo`4000000@3oool000030?ooo`000000oooo00/0oooo
00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0:0?ooo`4000000@3oool000030?ooo`00
0000oooo00/0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0;0?ooo`4000000@3o
ool000030?ooo`000000oooo00`0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0;
0?ooo`4000000@3oool000030?ooo`000000oooo00`0oooo00<000000?ooo`3oool0H`3oool00`00
0000oooo0?ooo`0;0?ooo`4000000@3oool000030?ooo`000000oooo00`0oooo00<000000?ooo`3o
ool0HP3oool00`000000oooo0?ooo`0<0?ooo`4000000@3oool000030?ooo`000000oooo00d0oooo
00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0<0?ooo`4000000@3oool000030?ooo`00
0000oooo00d0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0<0?ooo`4000000@3o
ool000030?ooo`000000oooo00d0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0=
0?ooo`4000000@3oool000030?ooo`000000oooo00d0oooo00<000000?ooo`3oool0H03oool00`00
0000oooo0?ooo`0=0?ooo`4000000@3oool000030?ooo`000000oooo00h0oooo00<000000?ooo`3o
ool0G`3oool00`000000oooo0?ooo`0=0?ooo`4000000@3oool000030?ooo`000000oooo00h0oooo
00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0>0?ooo`4000000@3oool000030?ooo`00
0000oooo00h0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0>0?ooo`4000000@3o
ool000030?ooo`000000oooo00l0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`0>
0?ooo`4000000@3oool000030?ooo`000000oooo00l0oooo00<000000?ooo`3oool0G03oool00`00
0000oooo0?ooo`0?0?ooo`4000000@3oool00080oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`1L0?ooo`030000003oool0oooo00h0oooo0@0000010?ooo`40oooo00020?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0>0?ooo`400000
0@3oool10?ooo`000P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo05X0oooo00<0
00000?ooo`3oool03`3oool100000040oooo0@3oool00080oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00l0oooo0@0000010?ooo`40oooo00020?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0?0?oo
o`4000000@3oool10?ooo`000P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool0403oool100000040oooo0@3oool00080oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0100oooo0@0000010?ooo`40oooo
00020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`0@0?ooo`4000000@3oool10?ooo`000P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo05H0oooo00<000000?ooo`3oool04@3oool100000040oooo0@3oool00080oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0140oooo0@0000010?oo
o`40oooo00020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`0A0?ooo`4000000@3oool10?ooo`000P3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo05@0oooo00<000000?ooo`3oool04P3oool100000040oooo0@3oool00080oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo0@00
00010?ooo`40oooo00020?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0E03oool0
0`000000oooo0?ooo`0B0?ooo`4000000@3oool10?ooo`000P3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo05<0oooo00<000000?ooo`3oool04P3oool100000040oooo0@3oool00080
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo01<0
oooo0@0000010?ooo`40oooo00020?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
DP3oool00`000000oooo0?ooo`0C0?ooo`4000000@3oool10?ooo`000P3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool04`3oool100000040oooo0@3o
ool00080oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0
oooo01@0oooo0@0000010?ooo`40oooo00020?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0D03oool00`000000oooo0?ooo`0D0?ooo`4000000@3oool10?ooo`000P3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0503oool100000040
oooo0@3oool00080oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1>0?ooo`030000
003oool0oooo01D0oooo0@0000010?ooo`40oooo00020?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool0CP3oool00`000000oooo0?ooo`0E0?ooo`4000000@3oool10?ooo`000P3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool05@3oool1
00000040oooo0@3oool00080oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1<0?oo
o`030000003oool0oooo01H0oooo0@0000010?ooo`40oooo00020?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0F0?ooo`4000000@3oool10?ooo`00
0P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0
5P3oool100000040oooo0@3oool00080oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`1:0?ooo`030000003oool0oooo01L0oooo0@0000010?ooo`40oooo00020?ooo`030000003oool0
oooo01H0ooooCP00000I0?ooo`4000000@3oool10?ooo`000P3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo04X0oooo00<000000?ooo`3oool05`3oool100000040oooo0@3oool00080
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo01L0
oooo0@0000010?ooo`40oooo00020?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
BP3oool00`000000oooo0?ooo`0G0?ooo`4000000@3oool10?ooo`000P3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool05`3oool100000040oooo0@3o
ool00080oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0
oooo01L0oooo0@0000010?ooo`40oooo00020?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool0BP3oool00`000000oooo0?ooo`0G0?ooo`4000000@3oool10?ooo`000P3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool05`3oool100000040
oooo0@3oool00080oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1:0?ooo`030000
003oool0oooo01L0oooo0@0000010?ooo`40oooo00020?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool0BP3oool00`000000oooo0?ooo`0G0?ooo`4000000@3oool10?ooo`000`3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
04X0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`010?ooo`000`3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`010?ooo`000`3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`010?ooo`000`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04X0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo04X0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`010?oo
o`000`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo04X0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`010?ooo`000`3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo04X0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`010?ooo`000`3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04X0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`010?ooo`000`3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04X0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`01
0?ooo`000`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04X0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo04X0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`010?ooo`00
0`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo04X0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`010?ooo`000`3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
04T0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`010?ooo`000`3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04T0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`010?ooo`000`3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`010?ooo`000`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04P0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo04P0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`010?oo
o`000`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo04P0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`010?ooo`000`3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo04P0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`010?ooo`000`3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04P0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`010?ooo`000`3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04P0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`01
0?ooo`000`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04P0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo04P0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`010?ooo`00
0`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`010?ooo`00103oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo04P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`00103oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
04P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04P0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`020?ooo`00103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04P0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo04P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`020?oo
o`00103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo04P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`00103o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo04P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`00103oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04P0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04P0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`02
0?ooo`00103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04P0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo04P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`00
103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo04P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`00103oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
04P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04P0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`020?ooo`00103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04P0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo04P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`020?oo
o`00103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo04P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`00103o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo04P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`00103oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04P0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04P0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`02
0?ooo`00103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04P0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo04P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`00
1@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo04L0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`030?ooo`001@3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
04L0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`030?ooo`001@3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04L0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`030?ooo`001@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04L0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo04L0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`030?oo
o`001@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo04L0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`030?ooo`001@3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo04L0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`030?ooo`001@3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04L0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04H0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`03
0?ooo`001@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04H0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo04H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`030?ooo`00
1@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo04H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`030?ooo`001@3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
04H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`030?ooo`001@3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04H0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`030?ooo`001@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo04H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`030?oo
o`001@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo04H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`030?ooo`001@3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo04H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`030?ooo`001@3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04H0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04H0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`03
0?ooo`001P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04H0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo04H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`00
1P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo04H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`001P3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
04H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`040?ooo`001P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo04H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?oo
o`001P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo04H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`001P3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo04H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`001P3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04H0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04H0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`04
0?ooo`001P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04H0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo04H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`00
1P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo04D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`001P3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
04D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04D0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`040?ooo`001P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04D0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo04D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?oo
o`001P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo04D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`001P3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo04D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`001P3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04D0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04D0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`001`3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`05
0?ooo`001`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04D0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo04D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00
1`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo04D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`001`3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
04D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04@0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`050?ooo`001`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo04@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?oo
o`001`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo04@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`001`3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo04@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04@0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04@0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`05
0?ooo`001`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04@0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo04@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`00
1`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo04@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`001`3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
04@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04@0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`050?ooo`001`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo04@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?oo
o`001`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo04@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`001`3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo04@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04@0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`050?ooo`00203oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo04@0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`060?ooo`00203oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`06
0?ooo`00203oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo04@0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`060?ooo`00203oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo04@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`060?ooo`00
203oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`060?ooo`00203oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo04<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`060?ooo`00203oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`060?ooo`00203oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool01P3oool000P0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`130?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01P3oool000P0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool01P3oool000P0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`130?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01P3oool000P0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool01P3oool000P0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`130?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool01P3oool000P0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool01P3oool000P0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`130?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool01P3oool000P0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`130?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01P3o
ool000P0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`130?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool01P3oool000P0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`060?ooo`00203oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01P0
oooo0P0000000`25j]<000000?ooo`0V0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool01P3oool000P0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0F0?ooo`<00000
0`25j]<00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
1P3oool000P0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`D000001025
j]<2000002@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`060?ooo`00203oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0180oooo2000000508GZd`030000003oool0
oooo0240oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`060?ooo`00203oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo0100oooo2P00000608GZd`030000003oool0oooo
0200oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`060?ooo`00203oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo00l0oooo2`00000408GZd`80000000<0Y_Ca0000003o
ool0803oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00H0oooo00080?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool03@3oool=00000080QN[C0P0000030:Kdl@030000
003oool0oooo00`0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo00H0oooo00080?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool02`3o
oolA000000H0Y_Ca00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00H0oooo00080?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool02@3ooolB
000000P0Y_Ca00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo00H0oooo00080?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01`3ooolD0000
00P0Y_Ca00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
00H0oooo00080?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3ooolC000000<0
7@0000<000000:Kdl@2Vm?401P2Vm?400`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool01P3oool000P0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`030?oooa<000001@0M00000`000000Y_Ca0:Kdl@070:Kdl@030000003oool0oooo01/0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`060?ooo`00203oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo0080oooo4P00000701d000030000002Vm?40Y_Ca00P0Y_Ca00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00H0oooo0008
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04`00000901d000030000002Vm?40
Y_Ca00L0Y_Ca00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo00H0oooo00080?ooo`030000003oool0oooo01@0oooo00<000000?ooo`0000004@00000;01d0
00030000002Vm?40Y_Ca00P0Y_Ca00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo00H0oooo00080?ooo`030000003oool0oooo01@0oooo00<000000?ooo`00
00003`00000=01d000030000002Vm?40Y_Ca00H0Y_Ca0P0000000`2gi_H000000?ooo`0I0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool01P3oool000P0oooo00<000000?ooo`3oool0
503oool00`000000oooo0000000>000000h07@0000<000000:Kdl@2Vm?40102Vm?42000000<0]nKf
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00H0oooo
00080?ooo`030000003oool0oooo01@0oooo00<000000?ooo`0000003000000A01d000040000002V
m?40Y_Ca0:Kdl@8000001P2gi_H00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool01P3oool000P0oooo00<000000?ooo`3oool0503oool00`000000oooo0000
000:000001<07@0000@000000:Kdl@00000000002@2gi_H00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool01P3oool000P0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`08000001D07@000P00000;0;OVmP030000003oool0oooo01H0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`060?ooo`00203oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo00L000005`0M00000`000000]nKf0;OVmP0:0;OVmP030000003oool0
oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`070?ooo`002@3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo00D000006@0M00000`000000]nKf0;OVmP0:0;OV
mP030000003oool0oooo01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`070?oo
o`002@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00<000006`0M00000`000000
]nKf0;OVmP0;0;OVmP030000003oool0oooo01<0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`070?ooo`002@3oool00`000000oooo0?ooo`0C0?ooo`040000003oool0oooo000001h0
7@0000<000000;OVmP2gi_H02`2gi_H00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool01`3oool000T0oooo00<000000?ooo`3oool04`3oool010000000oooo
0?ooo`00000N01d000030000002gi_H0]nKf00/0]nKf00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo00L0oooo00090?ooo`030000003oool0oooo01<0oooo
00D000000?ooo`3oool0oooo0000000K01d000<000003P2gi_H00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool01`3oool000T0oooo00<000000?ooo`3oool0
4`3oool01@000000oooo0?ooo`3oool0000001T07@000P00000305<1@P030000002gi_H0]nKf00`0
]nKf00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00L0
oooo00090?ooo`030000003oool0oooo01<0oooo00D000000?ooo`3oool0oooo0000000G01d00080
00001@1C0D800`000000]nKf0;OVmP0<0;OVmP030000003oool0oooo0100oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`070?ooo`002@3oool00`000000oooo0?ooo`0C0?ooo`050000
003oool0oooo0?ooo`0000005@0M0002000000P0D`5200<000000;OVmP2gi_H0302gi_H00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01`3oool000T0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`030000000M00007@0001007@00
0P00000:05<1@P030000002gi_H0]nKf00X0]nKf0P0000000`2faND000000?ooo`0?0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool01`3oool000T0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`020?ooo`030000000M00007@0000h07@000P00000=05<1@P030000002g
i_H0]nKf00L0]nKf0P0000030;K5i@030000003oool0oooo00h0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`070?ooo`002@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo0080oooo00<0000001d0000M0000300M0002000000l0D`5200<000000;OVmP2gi_H01@2gi_H2
000000H0]/GU00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo00L0oooo00090?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool00P3oool00`00
00007@0001d0000:01d0008000004P1C0D800`000000]nKf0;OVmP020;OVmP800000202faND00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01`3oool000T0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`030?ooo`030000000M00007@0000L0
7@000P00000D05<1@P030000002gi_H0]nKf008000002`2faND00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool01`3oool000T0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`030?ooo`030000000M00007@0000D07@000P00000G05<1@P800000
3@2faND00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
1`3oool000T0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`030?ooo`030000000M
00007@0000<07@000P00000I05<1@P030000002faND0]/GU00d0]/GU00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00L0oooo00090?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool00`3oool0100000007@0001d0000M0002000001`0D`5200<0
00000;K5i@2faND0302faND00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool01`3oool000T0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`04
0?ooo`<000007P1C0D800`000000]/GU0;K5i@0=0;K5i@030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`070?ooo`002@3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo00@0oooo00<0000005<1@P1C0D807`1C0D800`000000]/GU0;K5i@0<0;K5
i@030000003oool0oooo00X0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`070?oo
o`002@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo00<0000005<1@P1C
0D807`1C0D800`000000]/GU0;K5i@0=0;K5i@030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`070?ooo`002@3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo00D0oooo00<0000005<1@P1C0D807`1C0D800`000000]/GU0;K5i@0<0;K5i@030000
003oool0oooo00T0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`070?ooo`002@3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00D0oooo00<0000005<1@P1C0D807`1C
0D800`000000]/GU0;K5i@0=0;K5i@030000003oool0oooo00P0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`070?ooo`002@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo00H0oooo00<0000005<1@P1C0D807`1C0D800`000000]/GU0;K5i@0<0;K5i@030000003oool0
oooo00P0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`070?ooo`002@3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo00H0oooo00<0000005<1@P1C0D807`1C0D800`00
0000]/GU0;K5i@0=0;K5i@030000003oool0oooo00L0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`070?ooo`002@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00H0
oooo00<0000005<1@P1C0D80801C0D800`000000]/GU0;K5i@0<0;K5i@030000003oool0oooo00L0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`070?ooo`002@3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo00H0oooo00<0000005<1@P1C0D807@1C0D83000000l0]/GU
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00L0oooo
00090?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01P3oool00`000000D`5205<1
@P0K05<1@P8000000`22Ch/00`000000]/GU0;K5i@0:0;K5i@80000000<0Z9K40000003oool01P3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00L0oooo00090?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool01P3oool00`000000D`5205<1@P0I05<1@P8000001@22Ch/0
0`000000]/GU0;K5i@080;K5i@8000000`2XU/@00`000000oooo0?ooo`050?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool01`3oool000T0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`070?ooo`030000001C0D80D`5201H0D`520P000008089?R`030000002faND0]/GU
00D0]/GU0P0000060:RFa0030000003oool0oooo00@0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`070?ooo`002@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00L0
oooo00<0000005<1@P1C0D80501C0D82000000X0PTn;00<000000;K5i@2faND00`2faND2000000P0
Z9K400<000000?ooo`3oool0103oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00L0
oooo00090?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0203oool00`000000D`52
05<1@P0A05<1@P8000003@22Ch/00`000000]/GU0;K5i@02000000/0Z9K400<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00L0oooo00090?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0203oool00`000000D`5205<1@P0?05<1@P8000003`22
Ch/3000000d0Z9K400<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00L0oooo00090?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0203oool0
0`000000D`5205<1@P0=05<1@P8000004P22Ch/00`000000Z9K40:RFa00=0:RFa0030000003oool0
oooo0080oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`070?ooo`002@3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo00T0oooo00<0000005<1@P1C0D802P1C0D820000
01@0PTn;00<000000:RFa02XU/@03@2XU/@00`000000oooo0?ooo`020?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool01`3oool000T0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`090?ooo`030000001C0D80D`5200P0D`520P00000G089?R`030000002XU/@0Z9K400d0
Z9K400D000000?ooo`3oool0oooo0000000F0?ooo`030000003oool0oooo00L0oooo00090?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool02@3oool00`000000D`5205<1@P0605<1@P80
00006@22Ch/00`000000Z9K40:RFa00>0:RFa0040000003oool0oooo000001H0oooo00<000000?oo
o`3oool01`3oool000T0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0:0?ooo`03
0000001C0D80D`5200<0D`520P00000L089?R`030000002XU/@0Z9K400d0Z9K400@000000?ooo`3o
ool000005P3oool00`000000oooo0?ooo`070?ooo`002@3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo00X0oooo00@0000005<1@P1C0D80D`520P00000N089?R`030000002XU/@0Z9K4
00h0Z9K400<000000?ooo`0000005P3oool00`000000oooo0?ooo`070?ooo`002@3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo00/0oooo0`00000Q089?R`030000002XU/@0Z9K400d0
Z9K400<000000?ooo`0000005P3oool00`000000oooo0?ooo`070?ooo`002P3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo00/0oooo00<00000089?R`22Ch/08@22Ch/00`000000Z9K4
0:RFa00>0:RFa08000005@3oool00`000000oooo0?ooo`080?ooo`002P3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo00/0oooo00<00000089?R`22Ch/08P22Ch/00`000000Z9K40:RF
a00=0:RFa08000005@3oool00`000000oooo0?ooo`080?ooo`002P3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo00`0oooo00<00000089?R`22Ch/08@22Ch/00`000000Z9K40:RFa00>
0:RFa0030000003oool0oooo01<0oooo00<000000?ooo`3oool0203oool000X0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0<0?ooo`0300000022Ch/0PTn;0280PTn;00<000000:RF
a02XU/@03@2XU/@00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo000:0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool03@3oool00`000000PTn;089?R`0Q089?R`03
0000002XU/@0Z9K400h0Z9K400<000000?ooo`3oool04P3oool00`000000oooo0?ooo`080?ooo`00
2P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00d0oooo00<00000089?R`22Ch/0
8P22Ch/00`000000Z9K40:RFa00;0:RFa0<00000503oool00`000000oooo0?ooo`080?ooo`002P3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00h0oooo00<00000089?R`22Ch/08@22
Ch/00`000000Z9K40:RFa0090:RFa08000000`2?H9H00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo00P0oooo000:0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool03P3oool0
0`000000PTn;089?R`0R089?R`030000002XU/@0Z9K400H0Z9K40P00000508mPUP030000003oool0
oooo0140oooo00<000000?ooo`3oool0203oool000X0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0?0?ooo`0300000022Ch/0PTn;0240PTn;00<000000:RFa02XU/@0102XU/@20000
00P0Sf2F00<000000?ooo`3oool0403oool00`000000oooo0?ooo`080?ooo`002P3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo00l0oooo00<00000089?R`22Ch/08P22Ch/010000000
Z9K40:RFa02XU/@2000000X0Sf2F00<000000?ooo`3oool0403oool00`000000oooo0?ooo`080?oo
o`002P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0100oooo00<00000089?R`22
Ch/07`22Ch/3000000030:RFa0000000000000`0Sf2F00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`080?ooo`002P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0100oooo
00<00000089?R`22Ch/07@22Ch/2000000<0Y9O800<0000008mPUP2?H9H0302?H9H00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo00P0oooo000:0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool04@3oool00`000000PTn;089?R`0J089?R`8000001@2TUlP00`000000Sf2F08mP
UP0<08mPUP030000003oool0oooo0100oooo00<000000?ooo`3oool0203oool000X0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0A0?ooo`0300000022Ch/0PTn;01P0PTn;0P000008
0:BGb0030000002?H9H0Sf2F00/0Sf2F00<000000?ooo`3oool0403oool00`000000oooo0?ooo`08
0?ooo`002P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<00000089?
R`22Ch/05@22Ch/2000000X0Y9O800<0000008mPUP2?H9H02`2?H9H00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo00P0oooo000:0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool04P3oool00`000000PTn;089?R`0C089?R`8000003@2TUlP00`000000Sf2F08mPUP0:08mPUP03
0000003oool0oooo0100oooo00<000000?ooo`3oool0203oool000X0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0C0?ooo`0300000022Ch/0PTn;0100PTn;0P00000?0:BGb0030000
002?H9H0Sf2F00X0Sf2F00<000000?ooo`3oool0403oool00`000000oooo0?ooo`080?ooo`002P3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<00000089?R`22Ch/03P22
Ch/200000180Y9O800<0000008mPUP2?H9H02@2?H9H00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00P0oooo000:0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0503oool0
0`000000PTn;089?R`0;089?R`800000502TUlP00`000000Sf2F08mPUP0908mPUP030000003oool0
oooo0100oooo00<000000?ooo`3oool0203oool000X0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0D0?ooo`0300000022Ch/0PTn;00T0PTn;0P00000G0:BGb0030000002?H9H0Sf2F
00P0Sf2F00<000000?ooo`3oool0403oool00`000000oooo0?ooo`080?ooo`002P3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo01D0oooo00<00000089?R`22Ch/01P22Ch/2000001T0
Y9O800<0000008mPUP2?H9H0202?H9H00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00P0
oooo000:0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool05@3oool00`000000PTn;
089?R`04089?R`800000702TUlP00`000000Sf2F08mPUP0708mPUP030000003oool0oooo0100oooo
00<000000?ooo`3oool0203oool000X0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`0F0?ooo`0400000022Ch/0PTn;089?R`8000007P2TUlP00`000000Sf2F08mPUP0708mPUP030000
003oool0oooo0100oooo00<000000?ooo`3oool0203oool000X0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`0F0?ooo`0400000022Ch/0000000000240Y9O800<0000008mPUP2?H9H0
1P2?H9H00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00P0oooo000:0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool05`3oool00`000000Y9O80:BGb00Q0:BGb0030000002?
H9H0Sf2F00H0Sf2F00<000000?ooo`3oool0403oool00`000000oooo0?ooo`080?ooo`002P3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01P0oooo00<000000:BGb02TUlP08@2TUlP0
0`000000Sf2F08mPUP0508mPUP030000003oool0oooo0100oooo00<000000?ooo`3oool0203oool0
00X0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0H0?ooo`030000002TUlP0Y9O8
0240Y9O800<0000008mPUP2?H9H01@2?H9H00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
00P0oooo000:0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool06@3oool00`000000
Y9O80:BGb00Q0:BGb0030000002?H9H0Sf2F0080Sf2F0`00000B0?ooo`030000003oool0oooo00P0
oooo000:0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool06@3oool00`000000Y9O8
0:BGb00Q0:BGb0030000002?H9H0Sf2F008000000P1^9F000`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo00P0oooo000:0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool06P3o
ool00`000000Y9O80:BGb00Q0:BGb0800000101^9F000`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00P0oooo000:0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool06P3oool0
0`000000Y9O80:BGb00Q0:BGb0030000001^9F00KREP00<0KREP00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`080?ooo`002P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
01/0oooo00<000000:BGb02TUlP08@2TUlP00`000000KREP06hUH00206hUH0030000003oool0oooo
0100oooo00<000000?ooo`3oool0203oool000X0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0K0?ooo`030000002TUlP0Y9O80240Y9O800<0000006hUH01^9F000`1^9F000`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00P0oooo000:0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool0703oool00`000000Y9O80:BGb00Q0:BGb0030000001^9F00KREP0080KREP
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`080?ooo`002P3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo01`0oooo00<000000:BGb02TUlP07`2TUlP2000000030;;@k`00
0000KREP0080KREP00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`080?ooo`002P3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01d0oooo00<000000:BGb02TUlP0702TUlP2
000000<0/]3_00D0000006hUH01^9F00KREP0000000A0?ooo`030000003oool0oooo00P0oooo000:
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool07@3oool00`000000Y9O80:BGb00J
0:BGb08000001P2bd>l010000000KREP06hUH000000A0?ooo`030000003oool0oooo00P0oooo000:
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool07P3oool00`000000Y9O80:BGb00G
0:BGb0800000202bd>l010000000KREP06hUH000000A0?ooo`030000003oool0oooo00P0oooo000:
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool07`3oool00`000000Y9O80:BGb00D
0:BGb08000002`2bd>l00`000000KREP0000000A0?ooo`030000003oool0oooo00P0oooo000;0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool07`3oool00`000000Y9O80:BGb00B0:BG
b08000003P2bd>l200000100oooo00<000000?ooo`3oool02@3oool000/0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0P0?ooo`030000002TUlP0Y9O80100Y9O800<000000;;@k`2b
d>l03P2bd>l200000100oooo00<000000?ooo`3oool02@3oool000/0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0P0?ooo`030000002TUlP0Y9O800h0Y9O80P00000B0;;@k`030000
003oool0oooo00h0oooo00<000000?ooo`3oool02@3oool000/0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0Q0?ooo`030000002TUlP0Y9O800/0Y9O80P00000E0;;@k`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool02@3oool000/0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`0Q0?ooo`030000002TUlP0Y9O800T0Y9O80P00000G0;;@k`030000003oool0
oooo00d0oooo00<000000?ooo`3oool02@3oool000/0oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`0R0?ooo`030000002TUlP0Y9O800H0Y9O80P00000J0;;@k`030000003oool0oooo
00`0oooo00<000000?ooo`3oool02@3oool000/0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0Q0?ooo`030000002TUlP0Y9O800@0Y9O80P00000L0;;@k`030000003oool0oooo00`0
oooo00<000000?ooo`3oool02@3oool000/0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0R0?ooo`040000002TUlP0Y9O80:BGb08000007`2bd>l00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00T0oooo000;0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
8P3oool010000000Y9O800000000000R0;;@k`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool02@3oool000/0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0S0?ooo`030000
002bd>l0/]3_0280/]3_00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`002`3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02@0oooo00<000000;;@k`2bd>l08P2b
d>l00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo000;0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0903oool00`000000/]3_0;;@k`0S0;;@k`030000003oool0
oooo00P0oooo00<000000?ooo`3oool02@3oool000/0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0U0?ooo`030000002bd>l0/]3_00d0/]3_00<000000;;@k`2bd>l04P2bd>l00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo000;0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool09@3oool00`000000/]3_0;;@k`0=0;;@k`030000002bd>l0/]3_01<0
/]3_00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`002`3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo02H0oooo00<000000;;@k`2bd>l0302bd>l00`000000/]3_
0;;@k`0C0;;@k`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool000/0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0W0?ooo`030000002bd>l0/]3_00/0/]3_00<0
00000;;@k`2bd>l04`2bd>l2000000P0oooo00<000000?ooo`3oool02@3oool000/0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0W0?ooo`030000002bd>l0/]3_00X0/]3_00<00000
0;;@k`2bd>l04P2bd>l200000080Z>oh00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`09
0?ooo`002`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02P0oooo00<000000;;@
k`2bd>l02@2bd>l00`000000/]3_0;;@k`0@0;;@k`800000102XkoP00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00T0oooo000;0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool0:03oool00`000000/]3_0;;@k`090;;@k`030000002bd>l0/]3_00h0/]3_0P0000070:S_n003
0000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool000/0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0Y0?ooo`030000002bd>l0/]3_00P0/]3_00<000000;;@k`2bd>l0
302bd>l2000000T0Z>oh00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`002`3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02T0oooo0P0000090;;@k`030000002b
d>l0/]3_00X0/]3_0P00000;0:S_n0030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3o
ool000/0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0Y0?ooo`8000002@2bd>l0
0`000000/]3_0;;@k`080;;@k`8000003@2XkoP00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00T0oooo000;0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo000000080;;@k`030000002bd>l0/]3_00H0/]3_0P00000?0:S_n0030000003oool0oooo
00@0oooo00<000000?ooo`3oool02@3oool000/0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0000000P0/]3_00<000000;;@k`2bd>l0102bd>l200000140
Z>oh00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`002`3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo02T0oooo00@000000?ooo`3oool000001P2bd>l00`000000
/]3_0;;@k`030;;@k`8000004P2XkoP00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0
oooo000;0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`020?ooo`030000002bd>l0/]3_00<0/]3_00@000000;;@k`2bd>l0/]3_0P00000D0:S_n003
0000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool000/0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0080oooo00<000000;;@k`2bd>l0
0`2bd>l010000000/]3_00000000000F0:S_n0030000003oool0oooo00D0oooo00<000000?ooo`3o
ool02@3oool000/0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo00<0oooo00<000000;;@k`2bd>l00P2bd>l2000001P0Z>oh00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`090?ooo`002`3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool00`3oool00`000000/]3_0;;@k`03000001T0Z>oh00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`002`3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0103oool200000080Z>oh00<00000
0:S_n02XkoP05`2XkoP00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo000;0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`050?oo
o`040000002XkoP0Z>oh000001T0Z>oh00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`09
0?ooo`002`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02P0oooo00<000000?oo
o`3oool01P3oool2000001X0Z>oh00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?oo
o`002`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool01P3oool2000001T0Z>oh00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`00
2`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
1`3oool00`000000Z>oh0:S_n00G0:S_n0030000003oool0oooo00H0oooo00<000000?ooo`3oool0
2@3oool000/0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo00L0oooo0P00000H0:S_n0030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3o
ool000/0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`0000005@2XkoP3000000P0oooo00<000000?ooo`3oool02@3oool0
00/0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`0000004`2XkoP200000080Q^_M00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`090?ooo`002`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02L0
oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`00000@0:S_n08000000`26jmd00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo000;0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?oo
o`0000003@2XkoP2000000D0Q^_M00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?oo
o`00303oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`030?ooo`030000002XkoP0Z>oh00P0Z>oh0P00000708K[g@03
0000003oool0oooo00H0oooo00<000000?ooo`3oool02P3oool000`0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
103oool00`000000Z>oh0:S_n0050:S_n08000002@26jmd00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00X0oooo000<0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool09`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000:S_n02XkoP00`2X
koP2000000/0Q^_M00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`00303oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`050?ooo`030000002XkoP0Z>oh008000003026jmd00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00X0oooo000<0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo0P00000>08K[
g@030000003oool0oooo00L0oooo00<000000?ooo`3oool02P3oool000`0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01`3oool00`000000Q^_M08K[g@0<08K[g@030000003oool0oooo00L0oooo00<000000?ooo`3o
ool02P3oool000`0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0W0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000Q^_M08K[g@0:08K[g@800000
2@3oool00`000000oooo0?ooo`0:0?ooo`00303oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`8000002026
jmd3000000X0oooo00<000000?ooo`3oool02P3oool000`0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0303oool0
0`000000Q^_M08K[g@0308K[g@80000000<0ELZW0000003oool02P3oool00`000000oooo0?ooo`0:
0?ooo`00303oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo02H0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0<0?ooo`8000000P26jmd4000000d0oooo00<000000?oo
o`3oool02P3oool000`0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0V0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0303oool00`000000oooo0000000200000100
oooo00<000000?ooo`3oool02P3oool000`0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo00X0oooo000<0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0:0?ooo`00303oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool02P3oool000`0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00X0oooo000<0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0:0?ooo`00
303oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
2P3oool000`0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo00X0oooo000<0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`0:0?ooo`00303oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool02P3oool000`0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo00X0oooo000<0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0:0?ooo`00303oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool02P3oool000`0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00X0oooo000<0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0:0?oo
o`00303oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool02P3oool000`0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo00X0oooo000<0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`0:0?ooo`00303oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo02@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool02P3oool000`0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo00X0oooo000<0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0:0?ooo`00303oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool02P3oool000`0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00X0oooo000<
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0:
0?ooo`00303oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool02P3oool000`0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo00X0oooo000<0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0:0?ooo`00303oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool02P3oool000d0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00/0oooo000=0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0;0?ooo`003@3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool02`3oool000d0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00/0oooo
000=0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool08P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0;0?ooo`003@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool02`3oool000d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo00/0oooo000=0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0;0?ooo`003@3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool02`3oool000d0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00/0oooo000=0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0;0?ooo`003@3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool02`3oool000d0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00/0
oooo000=0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`0;0?ooo`003@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool02`3oool000d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo00/0oooo000=0?ooo`030000003oool0oooo0180oooo00@000000?oo
o`3oool0oooo>00000040?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool02`3oool0
00d0oooo00<000000?ooo`3oool04P3oool5000001l0J00000<0000006P0001X00001@1X00000`00
0000J00006P0000<06P000H00000503oool00`000000oooo0?ooo`0;0?ooo`003@3oool00`000000
oooo0?ooo`0B0?ooo`050000003oool0oooo0?ooo`0000007`1X00000`000000J00006P0000506P0
00030000001X0000J00000`0J00000<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo00/0oooo000=0?ooo`030000003oool0oooo0180oooo00D000000?ooo`3o
ool0oooo0000000O06P000030000001X0000J00000D0J00000<0000006P0001X0000301X00000`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool02`3oool000d0
oooo00<000000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool0000001l0J00000<0000006P0
001X00001@1X00000`000000J00006P0000<06P000030000003oool0oooo0080oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0;0?ooo`003@3oool00`000000oooo0?ooo`0B0?ooo`05
0000003oool0oooo0?ooo`0000007`1X00000`000000J00006P0000406P000030000001X0000J000
00d0J00000<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00/0oooo000=0?ooo`030000003oool0oooo0140oooo00D000000?ooo`3oool0oooo0000000P06P0
00030000001X0000J00000@0J00000<0000006P0001X00003P1X00000`000000oooo0?ooo`020?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool02`3oool000d0oooo00<000000?ooo`3o
ool04@3oool01@000000oooo0?ooo`3oool0000001l0J00000<0000006P0001X00001@1X00000`00
0000J00006P0000>06P000030000003oool0oooo0080oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0;0?ooo`003@3oool00`000000oooo0?ooo`0A0?ooo`050000003oool0oooo0?oo
o`0000007`1X00000`000000J00006P0000506P000030000001X0000J00000h0J00000<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00/0oooo000=0?ooo`03
0000003oool0oooo0140oooo00D000000?ooo`3oool0oooo0000000O06P000030000001X0000J000
00D0J00000<0000006P0001X00003P1X00000`000000oooo0?ooo`020?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool02`3oool000d0oooo00<000000?ooo`3oool04@3oool01@000000
oooo0?ooo`3oool0000001l0J00000<0000006P0001X00001@1X00000`000000J00006P0000>06P0
00030000003oool0oooo0080oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0;0?oo
o`003@3oool00`000000oooo0?ooo`0A0?ooo`050000003oool0oooo0?ooo`0000007`1X00000`00
0000J00006P0000506P000030000001X0000J00000h0J00000<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo00/0oooo000=0?ooo`030000003oool0oooo0140
oooo00D000000?ooo`3oool0oooo0000000O06P000030000001X0000J00000D0J00000<0000006P0
001X00003P1X00000`000000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool02`3oool000d0oooo00<000000?ooo`3oool04@3oool01@000000oooo0?ooo`3oool00000
02H0J00000<0000006P0001X00003`1X00000`000000oooo0?ooo`020?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool02`3oool000d0oooo00<000000?ooo`3oool04@3oool01@000000
oooo0?ooo`3oool0000002H0J00000<0000006P0001X00003`1X00000`000000oooo0?ooo`020?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool02`3oool000d0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`020?ooo`030000001X0000J00002@0J00000<0000006P0001X
00003`1X00000`000000oooo0?ooo`030?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool02`3oool000d0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000
001X0000J00002@0J00000<0000006P0001X00003`1X00000`000000oooo0?ooo`030?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool02`3oool000d0oooo00<000000?ooo`3oool0403o
ool01@000000oooo0?ooo`3oool0000002L0J00000<0000006P0001X0000401X00000`000000oooo
0?ooo`020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool02`3oool000d0oooo00<0
00000?ooo`3oool0403oool01@000000oooo0?ooo`3oool0000002L0J00000<0000006P0001X0000
401X00000`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
2`3oool000d0oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool0000002L0J000
00<0000006P0001X0000401X00000`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool02`3oool000d0oooo00<000000?ooo`3oool0403oool01@000000oooo0?oo
o`3oool0000002H0J00000<0000006P0001X00004@1X00000`000000oooo0?ooo`020?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool02`3oool000d0oooo00<000000?ooo`3oool0403o
ool01@000000oooo0?ooo`3oool0000002H0J00000<0000006P0001X00004@1X00000`000000oooo
0?ooo`020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool02`3oool000d0oooo00<0
00000?ooo`3oool0403oool01@000000oooo0?ooo`3oool0000002H0J00000<0000006P0001X0000
4@1X00000`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
2`3oool000h0oooo00<000000?ooo`3oool03`3oool01@000000oooo0?ooo`3oool0000002H0J000
00<0000006P0001X00004@1X00000`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0303oool000h0oooo00<000000?ooo`3oool03`3oool01@000000oooo0?oo
o`3oool0000002H0J00000<0000006P0001X00004@1X00000`000000oooo0?ooo`020?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0303oool000h0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`020?ooo`030000001X0000J00002@0J00000<0000006P0001X00004@1X
00000`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0303o
ool000h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`030000001X0000
J00002@0J00000<0000006P0001X00004@1X00000`000000oooo0?ooo`030?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0303oool000h0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`020?ooo`030000001X0000J00002<0J00000<0000006P0001X00004P1X00000`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0303oool000h0
oooo00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool0000002H0J00000<0000006P0
001X00004`1X00000`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0303oool000h0oooo00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool00000
02H0J00000<0000006P0001X00004`1X00000`000000oooo0?ooo`020?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0303oool000h0oooo00<000000?ooo`3oool03P3oool01@000000
oooo0?ooo`3oool0000002H0J00000<0000006P0001X00004`1X00000`000000oooo0?ooo`020?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0303oool000h0oooo00<000000?ooo`3o
ool03P3oool01@000000oooo0?ooo`3oool0000002H0J00000<0000006P0001X00004`1X00000`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0303oool000h0
oooo00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool0000002H0J00000<0000006P0
001X00004`1X00000`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0303oool000h0oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`3oooln0000
00@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0<0?ooo`003P3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo00<000000;2bfP2`/]X08`2`/]X00`000000
/;;J0;2bfP0D0;2bfP030000003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0<0?ooo`003P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo
00<000000;2bfP2`/]X08`2`/]X00`000000/;;J0;2bfP0D0;2bfP030000003oool0oooo00<0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`003P3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo0080oooo00<000000;2bfP2`/]X08`2`/]X00`000000/;;J0;2b
fP0D0;2bfP030000003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0<0?ooo`003P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo00<00000
0;2bfP2`/]X08`2`/]X00`000000/;;J0;2bfP0D0;2bfP030000003oool0oooo00<0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`003P3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo0080oooo00<000000;2bfP2`/]X08`2`/]X00`000000/;;J0;2bfP0D0;2b
fP030000003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?oo
o`003P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo?`0000040?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool000h0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`020?ooo`030000001X0000J0000280J00000<0000006P0001X0000
5P1X00000`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
303oool000h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`030000001X
0000J0000280J00000<0000006P0001X00005P1X00000`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0303oool000h0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`020?ooo`030000001X0000J0000280J00000<0000006P0001X00005P1X0000
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool0
00h0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`030?ooo`030000001X0000J000
0280J00000<0000006P0001X00005P1X00000`000000oooo0?ooo`030?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0303oool000h0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`030?ooo`030000001X0000J0000280J00000<0000006P0001X00005P1X00000`000000
oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool000h0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`030000001X0000J00002<0J000
00<0000006P0001X00005`1X00000`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0303oool000h0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`020?ooo`030000001X0000J00002<0J00000<0000006P0001X00005`1X00000`000000oooo0?oo
o`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool000h0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`030000001X0000J0000280J00000<00000
06P0001X0000601X00000`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0303oool000h0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?oo
o`030000001X0000J0000280J00000<0000006P0001X0000601X00000`000000oooo0?ooo`020?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool000h0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`020?ooo`030000001X0000J0000280J00000<0000006P0001X
0000601X00000`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0303oool000h0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`030000
001X0000J0000280J00000<0000006P0001X0000601X00000`000000oooo0?ooo`020?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0303oool000h0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`020?ooo`030000001X0000J0000280J00000<0000006P0001X0000601X
00000`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303o
ool000h0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`030000001X0000
J0000280J00000<0000006P0001X0000601X00000`000000oooo0?ooo`030?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0303oool000h0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`030?ooo`030000001X0000J0000280J00000<0000006P0001X0000601X00000`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool000h0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`030000001X0000J0000240
J00000<0000006P0001X00006@1X00000`000000oooo0?ooo`030?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0303oool000h0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`020?ooo`030000001X0000J0000280J00000<0000006P0001X00006P1X00000`000000oooo
0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool000h0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000001X0000J0000280J00000<0
000006P0001X00006P1X00000`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0303oool000h0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`02
0?ooo`030000001X0000J0000280J00000<0000006P0001X00006P1X00000`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool000h0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000001X0000J0000280J00000<0000006P0
001X00006P1X00000`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0303oool000h0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`03
0000001X0000J0000280J00000<0000006P0001X00006P1X00000`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool000h0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`020?ooo`030000001X0000J0000280J00000<0000006P0001X0000
6P1X00000`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
303oool000h0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000001X
0000J0000240J00000<0000006P0001X00006`1X00000`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0303oool000l0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`030?ooo`030000001X0000J0000240J00000<0000006P0001X00006`1X0000
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03@3oool0
00l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000001X0000J000
0240J00000<0000006P0001X00006`1X00000`000000oooo0?ooo`030?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool03@3oool000l0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`030?ooo`030000001X0000J0000240J00000<0000006P0001X00006`1X00000`000000
oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03@3oool000l0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000001X0000J00003l0J000
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00d0oooo
000?0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool00`000000J00006P0
001106P000030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0=0?ooo`003`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo00<00000
06P0001X0000@@1X00000`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool03@3oool000l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?oo
o`030000001X0000J0000440J00000<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00d0oooo000?0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool00P3oool00`000000J00006P0001106P000030000003oool0oooo0080oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0=0?ooo`003`3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0080oooo00<0000006P0001X0000@@1X00000`000000oooo0?ooo`020?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool03@3oool000l0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`030?ooo`030000001X0000J0000440J00000<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo000?0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000J00006P0001106P000030000003oool0
oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`003`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00<0000006P0001X0000@@1X00000`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03@3oool000l0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000001X0000J0000440
J00000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0
oooo000?0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000J000
06P0001106P000030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0=0?ooo`003`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<0
000006P0001X0000@`1X00000`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool03@3oool000l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`02
0?ooo`030000001X0000J00004<0J00000<000000?ooo`3oool00P3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00d0oooo000?0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool00P3oool00`000000J00006P0001306P000030000003oool0oooo0080oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0=0?ooo`003`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0080oooo00<0000006P0001X0000@`1X00000`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool03@3oool000l0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`030?ooo`030000001X0000J00004<0J00000<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo000?0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool00`3ooom7000000D0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0=0?ooo`003`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00<0oooo00<000000:jfg`2^]]l0@`2^]]l00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool03@3oool000l0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`030?ooo`030000002^]]l0[[KO04<0[[KO00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo000?0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool00`3oool00`000000[[KO0:jfg`130:jfg`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`003`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000:jfg`2^]]l0@`2^]]l00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool000l0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000002^]]l0[[KO04<0[[KO00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo000?
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000[[KO0:jfg`13
0:jfg`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=
0?ooo`003`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000:jf
g`2^]]l0@`2^]]l00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool03@3oool000l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`03
0000002^]]l0[[KO04<0[[KO00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00d0oooo000?0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
103oool00`000000[[KO0:jfg`130:jfg`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0=0?ooo`003`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00@0oooo00<000000:jfg`2^]]l0@`2^]]l00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool03@3oool000l0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`040?ooo`030000002^]]l0[[KO04<0[[KO00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo000?0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0103oool00`000000[[KO0:jfg`130:jfg`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`003`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000:jfg`2^]]l0@`2^]]l00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool000l0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000002^]]l0[[KO04<0[[KO
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo
000?0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000[[KO0:jf
g`120:jfg`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0=0?ooo`003`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<00000
0:jfg`2^]]l0@P2^]]l00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool03@3oool000l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?oo
o`030000002^]]l0[[KO0480[[KO00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00d0oooo000?0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000[[KO0:jfg`120:jfg`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0=0?ooo`00403oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00D0oooo00<000000:jfg`2^]]l0@P2^]]l00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool03P3oool00100oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`050?ooo`030000002^]]l0[[KO0480[[KO00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00h0oooo000@0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000[[KO0:jfg`120:jfg`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`00403oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000:jfg`2^]]l0@P2^]]l00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03P3oool00100
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000002^]]l0[[KO0480
[[KO00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00h0
oooo000@0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000[[KO
0:jfg`120:jfg`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0>0?ooo`00403oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<0
00000:jfg`2^]]l0@P2^]]l00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool03P3oool00100oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`030000002^]]l0[[KO0480[[KO00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00h0oooo000@0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool01P3oool00`000000[[KO0:jfg`120:jfg`030000003oool0oooo00L0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`00403oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00H0oooo00<000000:jfg`2^]]l0@P2^]]l00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool03P3oool00100oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`060?ooo`030000002^]]l0[[KO0480[[KO00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo000@0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01P3ooom6000000T0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0>0?ooo`00403oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo05D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`00403oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0>0?ooo`00403oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo05D0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`00403oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0>0?ooo`00403oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo05D0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`00403oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0>
0?ooo`00403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`00403oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo05L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`00
403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0>0?ooo`00403oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`00403oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0>0?ooo`00403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
05L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`00403oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0>0?ooo`00403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`00403oool01@000000oooo0?oo
o`3oool0000005/0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`00403oool01@000000oooo
0?ooo`3oool0000005/0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`00403oool01@000000
oooo0?ooo`3oool0000005/0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`00403oool01@00
0000oooo0?ooo`3oool0000005/0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`00403oool0
1@000000oooo0?ooo`3oool0000005/0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`00403o
ool01@000000oooo0?ooo`3oool0000005/0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`00
403oool01@000000oooo0?ooo`3oool0000005/0oooo00D000000?ooo`3oool0oooo0000000@0?oo
o`00403oool01@000000oooo0?ooo`3oool0000005/0oooo00D000000?ooo`3oool0oooo0000000@
0?ooo`00403oool01@000000oooo0?ooo`3oool0000005/0oooo00D000000?ooo`3oool0oooo0000
000@0?ooo`00403oool010000000oooo0?ooo`00001M0?ooo`040000003oool0oooo00000100oooo
000@0?ooo`040000003oool0oooo000005d0oooo00@000000?ooo`3oool00000403oool00100oooo
00@000000?ooo`3oool00000G@3oool010000000oooo0?ooo`00000@0?ooo`00403oool010000000
oooo0?ooo`00001M0?ooo`040000003oool0oooo00000100oooo000A0?ooo`030000003oool00000
05d0oooo00<000000?ooo`0000004@3oool00140oooo00<000000?ooo`000000G@3oool00`000000
oooo0000000A0?ooo`004@3oool00`000000oooo0000001M0?ooo`030000003oool000000140oooo
000A0?ooo`030000003oool0000005d0oooo00<000000?ooo`0000004@3oool00140oooo00<00000
0?ooo`000000G@3oool00`000000oooo0000000A0?ooo`004@3oool00`000000oooo0000001M0?oo
o`030000003oool000000140oooo000A0?ooo`800000G`3oool200000140oooo000A0?ooo`800000
G`3oool200000140oooo000A0?ooo`800000G`3oool200000140oooo000A0?ooo`800000G`3oool2
00000140oooo000A0?ooo`800000G`3oool200000140oooo000A0?ooo`800000G`3oool200000140
oooo000A0?ooo`800000G`3oool200000140oooo000A0?ooo`800000G`3oool200000140oooo000A
0?ooo`800000G`3oool200000140oooo000A0?ooo`030000003oool0oooo05l0oooo00<000000?oo
o`3oool03`3oool00140oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`0?0?ooo`00
4@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo00l0oooo000A0?ooo`030000003o
ool0oooo05l0oooo00<000000?ooo`3oool03`3oool00140ooooH`00000A0?ooo`00Q@3oool00001
\
\>"],
  ImageRangeCache->{{{91.5625, 197.5}, {613.25, 84.625}} -> {0.232419, \
0.153012, 0.0014811, 0.0014811}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#4", "Text"],

Cell[CellGroupData[{

Cell["Hz2[[-4]]", "Input"],

Cell[BoxData[
    \(2.1531127671514056`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pretty[Chop[e2ni . eigenvectors2[\([\(-4\)]\)], 10^\(-4\)]]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
          {"\<\"optic\"\>", "0", "0", "0", "1.`", "0", "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Status["\<Plotting stage 2 mode 4\>"]\ ; 
    eigenplot[eigenvectors2[\([\(-4\)]\)],  .5, {0, \(-3\), \(- .25\)}, \ 
      floatmatrix2]\ ; Done[]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 5.89255 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.52467 6.04934 -0.156788 6.04934 [
[ 0 0 0 0 ]
[ 1 5.89255 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
.01481 5.89255 L
s
.01481 5.89255 m
.08799 5.2311 L
s
.08799 5.2311 m
.07735 .23308 L
s
.07735 .23308 m
0 0 L
s
1 0 m
.92265 .23308 L
s
.92265 .23308 m
.91201 5.2311 L
s
.91201 5.2311 m
.98519 5.89255 L
s
.98519 5.89255 m
1 0 L
s
0 0 m
.01481 5.89255 L
s
.01481 5.89255 m
.98519 5.89255 L
s
.98519 5.89255 m
1 0 L
s
1 0 m
0 0 L
s
.07735 .23308 m
.92265 .23308 L
s
.92265 .23308 m
.91201 5.2311 L
s
.91201 5.2311 m
.08799 5.2311 L
s
.08799 5.2311 m
.07735 .23308 L
s
0 0 m
1 0 L
1 5.89255 L
0 5.89255 L
closepath
clip
newpath
.5 Mabswid
.707 .592 .726 r
.5 5.35631 m .83533 5.35631 L p .1641 5.02582 L F P
0 g
s
.707 .592 .726 r
.83533 5.35631 m .8359 5.02582 L .1641 5.02582 L p F P
0 g
s
.707 .592 .726 r
.1641 5.02582 m .16467 5.35631 L .5 5.35631 L p F P
0 g
s
.752 .614 .046 r
.15767 5.4367 m .16467 5.35631 L p .14975 5.17621 L F P
0 g
s
.752 .614 .046 r
.16467 5.35631 m .1641 5.02582 L .14975 5.17621 L p F P
0 g
s
0 0 .046 r
.8359 5.02582 m .83533 5.35631 L .84233 5.4367 L p F P
0 g
s
0 0 .046 r
.85025 5.17621 m .8359 5.02582 L p .84233 5.4367 L F P
0 g
s
.4 0 0 r
.8359 5.02582 m .85025 5.17621 L .14975 5.17621 L p F P
0 g
s
.4 0 0 r
.14975 5.17621 m .1641 5.02582 L .8359 5.02582 L p F P
0 g
s
.44939 5.17621 m
.5 5.4367 L
s
.815 .648 .676 r
.06659 3.45457 m .06647 3.50329 L p .25664 3.24924 L F P
0 g
s
.08789 3.31544 m
.10653 3.41141 L
s
.815 .648 .676 r
.06647 3.50329 m .27453 3.48964 L .25664 3.24924 L p F P
0 g
s
.815 .648 .676 r
.25664 3.24924 m .06708 3.26016 L .06659 3.45457 L p F P
0 g
s
.816 .714 .753 r
.06708 3.26016 m .25664 3.24924 L .27398 3.01531 L p F P
0 g
s
.802 .573 .59 r
.06944 3.73457 m .32619 3.71578 L .27453 3.48964 L p F P
0 g
s
.12366 3.49954 m
.15051 3.63776 L
s
.802 .573 .59 r
.27453 3.48964 m .06647 3.50329 L .06392 3.70979 L p F P
0 g
s
.802 .573 .59 r
.06392 3.70979 m .06944 3.73457 L p .27453 3.48964 L F P
0 g
s
.816 .714 .753 r
.06668 3.20398 m .06708 3.26016 L p .27398 3.01531 L F P
0 g
s
.816 .714 .753 r
.27398 3.01531 m .06541 3.02572 L .06668 3.20398 L p F P
0 g
s
.804 .779 .83 r
.06541 3.02572 m .27398 3.01531 L .32538 2.80826 L p F P
0 g
s
.773 .472 .477 r
.14934 3.92823 m .40756 3.90763 L .32619 3.71578 L p F P
0 g
s
.16792 3.72736 m
.19604 3.87213 L
s
.773 .472 .477 r
.32619 3.71578 m .06944 3.73457 L .14934 3.92823 L p F P
0 g
s
.20606 3.92371 m
.43195 5.08643 L
s
.804 .779 .83 r
.06482 2.99427 m .06541 3.02572 L p .32538 2.80826 L F P
0 g
s
.804 .779 .83 r
.32538 2.80826 m .06742 2.81939 L p .06482 2.99427 L F P
0 g
s
.763 .846 .914 r
.06742 2.81939 m .32538 2.80826 L .40696 2.64705 L p F P
0 g
s
.752 .614 .046 r
.14975 5.17621 m .15037 5.52053 L .15767 5.4367 L p F P
0 g
s
0 0 .046 r
.84233 5.4367 m .84963 5.52053 L .85025 5.17621 L p F P
0 g
s
.804 .779 .83 r
.06742 2.81939 m .06198 2.84211 L .06482 2.99427 L p F P
0 g
s
.705 .311 .299 r
.25183 4.06915 m .51206 4.04711 L .40756 3.90763 L p F P
0 g
s
.705 .311 .299 r
.40756 3.90763 m .14934 3.92823 L .25183 4.06915 L p F P
0 g
s
.763 .846 .914 r
.40696 2.64705 m .14706 2.65689 L .06742 2.81939 L p F P
0 g
s
.633 .894 .986 r
.14706 2.65689 m .40696 2.64705 L .51215 2.54783 L p F P
0 g
s
.01 w
.3532 2.49939 Mdot
.6468 2.49939 Mdot
.5 Mabswid
.517 0 0 r
.36812 4.14248 m .63073 4.11952 L .51206 4.04711 L p F P
0 g
s
.517 0 0 r
.51206 4.04711 m .25183 4.06915 L .36812 4.14248 L p F P
0 g
s
.633 .894 .986 r
.51215 2.54783 m .2499 2.55693 L .14706 2.65689 L p F P
0 g
s
.707 .593 .726 r
.5 5.52053 m .15037 5.52053 L .14975 5.17621 L p F P
0 g
s
.707 .593 .726 r
.85025 5.17621 m .84963 5.52053 L .5 5.52053 L p F P
0 g
s
.707 .593 .726 r
.14975 5.17621 m .85025 5.17621 L p .5 5.52053 L F P
0 g
s
.209 .732 .844 r
.2499 2.55693 m .51215 2.54783 L .6318 2.52232 L p F P
0 g
s
0 0 0 r
.48751 4.13852 m .75264 4.11527 L .63073 4.11952 L p F P
0 g
s
0 0 0 r
.63073 4.11952 m .36812 4.14248 L .48751 4.13852 L p F P
0 g
s
.707 .593 .726 r
.5 5.54927 m .85214 5.54927 L p .14723 5.20253 L F P
0 g
s
.707 .593 .726 r
.85214 5.54927 m .85277 5.20253 L .14723 5.20253 L p F P
0 g
s
.707 .593 .726 r
.14723 5.20253 m .14786 5.54927 L .5 5.54927 L p F P
0 g
s
.752 .614 .046 r
.14013 5.63803 m .14786 5.54927 L p .13137 5.36877 L F P
0 g
s
.752 .614 .046 r
.14786 5.54927 m .14723 5.20253 L .13137 5.36877 L p F P
0 g
s
0 0 .046 r
.85277 5.20253 m .85214 5.54927 L .85987 5.63803 L p F P
0 g
s
0 0 .046 r
.86863 5.36877 m .85277 5.20253 L p .85987 5.63803 L F P
0 g
s
.4 0 0 r
.85277 5.20253 m .86863 5.36877 L .13137 5.36877 L p F P
0 g
s
.4 0 0 r
.13137 5.36877 m .14723 5.20253 L .85277 5.20253 L p F P
0 g
s
.209 .732 .844 r
.6318 2.52232 m .36703 2.53132 L .2499 2.55693 L p F P
0 g
s
.415 0 0 r
.36703 2.53132 m .6318 2.52232 L .75463 2.57598 L p F P
0 g
s
.566 .903 .978 r
.5981 4.05453 m .86565 4.03174 L .75264 4.11527 L p F P
0 g
s
.566 .903 .978 r
.75264 4.11527 m .48751 4.13852 L .5981 4.05453 L p F P
0 g
s
.415 0 0 r
.75463 2.57598 m .48741 2.58559 L .36703 2.53132 L p F P
0 g
s
.687 .255 .216 r
.48741 2.58559 m .75463 2.57598 L .86813 2.7064 L p F P
0 g
s
.752 .614 .046 r
.13137 5.36877 m .13206 5.73076 L .14013 5.63803 L p F P
0 g
s
0 0 .046 r
.85987 5.63803 m .86794 5.73076 L .86863 5.36877 L p F P
0 g
s
.5 5.63803 m
.55713 5.36877 L
s
.758 .877 .932 r
.68801 3.89625 m .95763 3.87464 L .86565 4.03174 L p F P
0 g
s
.758 .877 .932 r
.86565 4.03174 m .5981 4.05453 L .68801 3.89625 L p F P
0 g
s
.57208 5.29831 m
.86423 3.92139 L
s
.687 .255 .216 r
.86813 2.7064 m .59877 2.7173 L .48741 2.58559 L p F P
0 g
s
.777 .453 .44 r
.59877 2.7173 m .86813 2.7064 L .95991 2.90233 L p F P
0 g
s
.812 .802 .842 r
.96412 3.85142 m .95763 3.87464 L p .74692 3.67833 L F P
0 g
s
.812 .802 .842 r
.95763 3.87464 m .68801 3.89625 L .74692 3.67833 L p F P
0 g
s
.86423 3.92139 m
.87036 3.89247 L
s
.812 .802 .842 r
.74692 3.67833 m .96803 3.66219 L .96412 3.85142 L p F P
0 g
s
.87036 3.89247 m
.90952 3.7079 L
s
.01 w
.34487 2.55577 Mdot
.65513 2.55577 Mdot
.5 Mabswid
.777 .453 .44 r
.95991 2.90233 m .68896 2.91513 L .59877 2.7173 L p F P
0 g
s
.812 .57 .574 r
.95991 2.90233 m .96631 2.92837 L .96876 3.10905 L p F P
0 g
s
.812 .57 .574 r
.68896 2.91513 m .95991 2.90233 L p .96876 3.10905 L F P
0 g
s
.707 .594 .727 r
.5 5.73076 m .13206 5.73076 L .13137 5.36877 L p F P
0 g
s
.707 .594 .727 r
.86863 5.36877 m .86794 5.73076 L .5 5.73076 L p F P
0 g
s
.707 .594 .727 r
.13137 5.36877 m .86863 5.36877 L p .5 5.73076 L F P
0 g
s
.827 .729 .756 r
.96842 3.61194 m .96803 3.66219 L p .76768 3.42338 L F P
0 g
s
.827 .729 .756 r
.96803 3.66219 m .74692 3.67833 L .76768 3.42338 L p F P
0 g
s
.827 .729 .756 r
.76768 3.42338 m .96999 3.41033 L .96842 3.61194 L p F P
0 g
s
.90952 3.7079 m
.95389 3.49881 L
s
.812 .57 .574 r
.96876 3.10905 m .96927 3.14693 L p .68896 2.91513 L F P
0 g
s
.812 .57 .574 r
.96927 3.14693 m .74758 3.15924 L .68896 2.91513 L p F P
0 g
s
.826 .655 .671 r
.74758 3.15924 m .96927 3.14693 L .96982 3.34695 L p F P
0 g
s
.826 .655 .671 r
.96982 3.34695 m .96999 3.41033 L p .74758 3.15924 L F P
0 g
s
.826 .655 .671 r
.96999 3.41033 m .76768 3.42338 L .74758 3.15924 L p F P
0 g
s
.25 Mabswid
0 0 m
.01481 5.89255 L
s
.01481 5.89255 m
.98519 5.89255 L
s
.98519 5.89255 m
1 0 L
s
1 0 m
0 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{110.938, 653.688},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40001^0002SB000`400?l00000o`00003oKP3oool0
06h0oooo001^0000000000<000000?ooo`3oool0JP3oool1000000000P00001Z0?ooo`8000000002
000006X0oooo0P00000000800000JP3oool20000000000<000000?ooo`000000J03oool100000040
oooo0@00000000030000003oool0000006P0oooo0@0000010?ooo`40000000000`000000oooo0000
001X0?ooo`4000000@3oool10000000000<000000?ooo`000000J03oool100000040oooo0@000000
00040000003oool0oooo000006H0oooo00<000000?ooo`3oool00@00000000040000003oool0oooo
000006H0oooo00<000000?ooo`3oool00@00000000040000003oool0oooo000006H0oooo00<00000
0?ooo`3oool00@00000000050000003oool0oooo0?ooo`000000I03oool010000000oooo0?ooo`3o
ool10000000000D000000?ooo`3oool0oooo0000001T0?ooo`040000003oool0oooo0?ooo`400000
00001@000000oooo0?ooo`3oool0000006@0oooo00@000000?ooo`3oool0oooo0@00000000030000
003oool0oooo0080oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`020?ooo`400000
00000`000000oooo0?ooo`020?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool00P3o
ool10000000000<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0
oooo0080oooo0@00000000030000003oool0oooo00<0oooo00<000000?ooo`3oool0GP3oool00`00
0000oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo05h0
oooo00<000000?ooo`3oool00`3oool10000000000<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`1N0?ooo`030000003oool0oooo00<0oooo0@00000000030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0GP3oool00`000000oooo0?ooo`030?ooo`40000000000`000000oooo0?ooo`04
0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0103oool10000000000<000000?oo
o`3oool0103oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo00@0oooo0@0000000003
0000003oool0oooo00@0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`040?ooo`40
000000000`000000oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0
1@3oool10000000000<000000?ooo`3oool01@3ooomN000000L0oooo0@00000000030000003oool0
oooo00D0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`40000000000`00
0000oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool01@3oool10000
000000<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0
oooo0@00000000030000003oool0oooo00D0oooo00<000000?ooo`3oool0FP3oool00`000000oooo
0?ooo`050?ooo`40000000000`000000oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo00<0
00000?ooo`3oool01@3oool10000000000<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1J
0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00D0oooo00<000000?oo
o`3oool0FP3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`050?ooo`03
0000003oool0oooo05X0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo0@00000000030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`4000000000
0`000000oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool01@3oool1
0000000000<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo
00D0oooo0@00000000030000003oool0oooo00D0oooo00<000000?ooo`3oool0FP3oool00`000000
oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo
00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`1J0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`050?oo
o`030000003oool0oooo05X0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo0@00000000030000
003oool0oooo00D0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`400000
00000`000000oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool01@3o
ool10000000000<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0
oooo00D0oooo0@00000000030000003oool0oooo00D0oooo00<000000?ooo`3oool0FP3oool00`00
0000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`050?ooo`030000003oool0oooo05X0
oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`1J0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`05
0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool01@3oool10000000000<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo0@0000000003
0000003oool0oooo00D0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`40
000000000`000000oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0
1@3oool10000000000<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1J0?ooo`030000003o
ool0oooo00D0oooo0@00000000030000003oool0oooo00D0oooo00<000000?ooo`3oool0FP3oool0
0`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`050?ooo`030000003oool0oooo
05X0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00D0oooo
00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?oo
o`050?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool01@3oool10000000000<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo0@000000
00030000003oool0oooo00D0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?oo
o`40000000000`000000oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3o
ool01@3oool10000000000<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1J0?ooo`030000
003oool0oooo00D0oooo0@00000000030000003oool0oooo00D0oooo00<000000?ooo`3oool0FP3o
ool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`050?ooo`030000003oool0
oooo05X0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00D0
oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo
0?ooo`050?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool01@3oool10000000000<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo0@00
000000030000003oool0oooo00D0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`05
0?ooo`40000000000`000000oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo00<000000?oo
o`3oool01@3oool10000000000<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1J0?ooo`03
0000003oool0oooo00D0oooo0@00000000030000003oool0oooo00D0oooo00<000000?ooo`3oool0
FP3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`050?ooo`030000003o
ool0oooo05X0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo
00D0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`40000000000`000000
oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool01@3oool100000000
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo
0@00000000030000003oool0oooo00D0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?oo
o`050?ooo`40000000000`000000oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo00<00000
0?ooo`3oool01@3oool10000000000<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1J0?oo
o`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0FP3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`050?ooo`030000
003oool0oooo05X0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0
oooo00D0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`40000000000`00
0000oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool01@3oool10000
000000<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0
oooo0@00000000030000003oool0oooo00D0oooo00<000000?ooo`3oool0FP3oool00`000000oooo
0?ooo`050?ooo`40000000000`000000oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo00<0
00000?ooo`3oool01@3oool10000000000<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1J
0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00D0oooo00<000000?oo
o`3oool0FP3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`050?ooo`03
0000003oool0oooo05X0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo0@00000000030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`4000000000
0`000000oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool01@3oool1
0000000000<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo
00D0oooo0@00000000030000003oool0oooo00D0oooo00<000000?ooo`3oool0FP3oool00`000000
oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo
00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`1J0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`050?oo
o`030000003oool0oooo05X0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo0@00000000030000
003oool0oooo00D0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`400000
00000`000000oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool01@3o
ool10000000000<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0
oooo00D0oooo0@00000000030000003oool0oooo00D0oooo00<000000?ooo`3oool0FP3oool00`00
0000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`050?ooo`030000003oool0oooo05X0
oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`1J0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`05
0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool01@3oool10000000000<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo0@0000000003
0000003oool0oooo00D0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`40
000000000`000000oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0
1@3oool10000000000<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1J0?ooo`030000003o
ool0oooo00D0oooo0@00000000030000003oool0oooo00D0oooo00<000000?ooo`3oool0FP3oool0
0`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`050?ooo`030000003oool0oooo
05X0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00D0oooo
00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?oo
o`050?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool01@3oool10000000000<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo0@000000
00030000003oool0oooo00D0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?oo
o`40000000000`000000oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3o
ool01@3oool10000000000<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1J0?ooo`030000
003oool0oooo00D0oooo0@00000000030000003oool0oooo00D0oooo00<000000?ooo`3oool0FP3o
ool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`050?ooo`030000003oool0
oooo05X0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00D0
oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo
0?ooo`050?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool01@3oool10000000000<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo0@00
000000030000003oool0oooo00D0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`05
0?ooo`40000000000`000000oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo00<000000?oo
o`3oool01@3oool10000000000<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1J0?ooo`03
0000003oool0oooo00D0oooo0@00000000030000003oool0oooo00D0oooo00<000000?ooo`3oool0
FP3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`050?ooo`030000003o
ool0oooo05X0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo
00D0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`40000000000`000000
oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool01@3oool100000000
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo
0@00000000030000003oool0oooo00D0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?oo
o`050?ooo`40000000000`000000oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo00<00000
0?ooo`3oool01@3oool10000000000<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1J0?oo
o`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0FP3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`050?ooo`030000
003oool0oooo05X0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0
oooo00D0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`40000000000`00
0000oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool01@3oool10000
000000<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0
oooo0@00000000030000003oool0oooo00D0oooo00<000000?ooo`3oool0FP3oool00`000000oooo
0?ooo`050?ooo`40000000000`000000oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo00<0
00000?ooo`3oool01@3oool10000000000<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1J
0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00D0oooo00<000000?oo
o`3oool0FP3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`050?ooo`03
0000003oool0oooo05X0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo0@00000000030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`4000000000
0`000000oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool01@3oool1
0000000000<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo
00D0oooo0@00000000030000003oool0oooo00D0oooo00<000000?ooo`3oool0FP3oool00`000000
oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo
00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`1J0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`050?oo
o`030000003oool0oooo05X0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo0@00000000030000
003oool0oooo00D0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`400000
00000`000000oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool01@3o
ool10000000000<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0
oooo00D0oooo0@00000000030000003oool0oooo00D0oooo00<000000?ooo`3oool0FP3oool00`00
0000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`050?ooo`030000003oool0oooo05X0
oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`1J0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`05
0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool01@3oool10000000000<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo0@0000000003
0000003oool0oooo00D0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`40
000000000`000000oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0
1@3oool10000000000<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1J0?ooo`030000003o
ool0oooo00D0oooo0@00000000030000003oool0oooo00D0oooo00<000000?ooo`3oool0FP3oool0
0`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`050?ooo`030000003oool0oooo
05X0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00D0oooo
00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?oo
o`050?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool01@3oool10000000000<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo0@000000
00030000003oool0oooo00D0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?oo
o`40000000000`000000oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3o
ool01@3oool10000000000<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1J0?ooo`030000
003oool0oooo00D0oooo0@00000000030000003oool0oooo00D0oooo00<000000?ooo`3oool0FP3o
ool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`050?ooo`030000003oool0
oooo05X0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00D0
oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo
0?ooo`050?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool01@3oool10000000000<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo0@00
000000030000003oool0oooo00D0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`05
0?ooo`40000000000`000000oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo00<000000?oo
o`3oool01@3oool10000000000<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1J0?ooo`03
0000003oool0oooo00D0oooo0@00000000030000003oool0oooo00D0oooo00<000000?ooo`3oool0
FP3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`050?ooo`030000003o
ool0oooo05X0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo
00D0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`40000000000`000000
oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool01@3oool100000000
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo
0@00000000030000003oool0oooo00D0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?oo
o`050?ooo`40000000000`000000oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo00<00000
0?ooo`3oool01@3oool10000000000<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1J0?oo
o`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0FP3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`050?ooo`030000
003oool0oooo05X0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0
oooo00D0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`40000000000`00
0000oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool01@3oool10000
000000<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0
oooo0@00000000030000003oool0oooo00D0oooo00<000000?ooo`3oool0FP3oool00`000000oooo
0?ooo`050?ooo`40000000000`000000oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo00<0
00000?ooo`3oool01@3oool10000000000<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1J
0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00D0oooo00<000000?oo
o`3oool0FP3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`050?ooo`03
0000003oool0oooo05X0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo0@00000000030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`4000000000
0`000000oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool01@3oool1
0000000000<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo
00D0oooo0@00000000030000003oool0oooo00D0oooo00<000000?ooo`3oool0FP3oool00`000000
oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo
00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`1J0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`050?oo
o`030000003oool0oooo05X0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo0@00000000030000
003oool0oooo00D0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`400000
00000`000000oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool01@3o
ool10000000000<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0
oooo00D0oooo0@00000000030000003oool0oooo00D0oooo00<000000?ooo`3oool0FP3oool00`00
0000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`050?ooo`030000003oool0oooo05X0
oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`1J0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`05
0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool01@3oool10000000000<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo0@0000000003
0000003oool0oooo00D0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`40
000000000`000000oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0
1@3oool10000000000<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1J0?ooo`030000003o
ool0oooo00D0oooo0@00000000030000003oool0oooo00D0oooo00<000000?ooo`3oool0FP3oool0
0`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`050?ooo`030000003oool0oooo
05X0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00D0oooo
00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?oo
o`050?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool01@3oool10000000000<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo0@000000
00030000003oool0oooo00D0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?oo
o`40000000000`000000oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3o
ool01@3oool10000000000<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1J0?ooo`030000
003oool0oooo00D0oooo0@00000000030000003oool0oooo00D0oooo00<000000?ooo`3oool0FP3o
ool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`050?ooo`030000003oool0
oooo05X0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00D0
oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo
0?ooo`050?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool01@3oool10000000000<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo0@00
000000030000003oool0oooo00D0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`05
0?ooo`40000000000`000000oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo00<000000?oo
o`3oool01@3oool10000000000<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1J0?ooo`03
0000003oool0oooo00D0oooo0@00000000030000003oool0oooo00D0oooo00<000000?ooo`3oool0
FP3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`050?ooo`030000003o
ool0oooo05X0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo
00D0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`40000000000`000000
oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool01@3oool100000000
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo
0@00000000030000003oool0oooo00D0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?oo
o`050?ooo`40000000000`000000oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo00<00000
0?ooo`3oool01@3oool10000000000<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1J0?oo
o`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0FP3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`050?ooo`030000
003oool0oooo05X0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0
oooo00D0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`050?ooo`40000000000`00
0000oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool01@3oool10000
000000<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0
oooo0@00000000030000003oool0oooo00D0oooo00<000000?ooo`3oool0FP3oool00`000000oooo
0?ooo`050?ooo`40000000000`000000oooo0?ooo`050?ooo`030000003oool0oooo05X0oooo00<0
00000?ooo`3oool01@3oool10000000000<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1J
0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00D0oooo00<000000?oo
o`3oool0FP3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`050?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo00D0oooo0@00000000030000003oool0oooo00D0oooo00<000000?ooo`3oool0
FP3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`050?ooo`030000003o
ool0oooo05X0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo
00D0oooo00<000000?ooo`3oool0;03oool@000001h0oooo00<000000?ooo`3oool01@3oool10000
000000<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0J0?oooa800000401Z0002000001`0
oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0D0?ooo`L00000100e^mP2000001`0JP001000000I0?ooo`030000003oool0oooo00D0oooo
0@00000000030000003oool0oooo00D0oooo00<000000?ooo`3oool0403oool?00000080X^Cl0P00
000N06X000<000005P3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00l0oooo00<000000:;To02Ri?`04@2Ri?`2000001l0JP000P00000D
0?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00D0oooo00<000000?oo
o`3oool03P3oool00`000000X^Cl0:;To00D0:;To08000006@1Z000800000180oooo00<000000?oo
o`3oool01@3oool10000000000<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0=0?ooo`03
0000002Ri?`0X^Cl01L0X^Cl0P00000906X000h00000202_@CL00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00D0oooo0@00000000030000003oool0oooo00D0oooo00<000000?ooo`3oool0
303oool00`000000X^Cl0:;To00I0:;To0X000005`2_@CL00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00D0oooo0@00000000030000003oool0oooo00D0oooo00<000000?ooo`3oool02`3o
ool00`000000X^Cl0:;To00H0:;To08000000`3oool00`000000[d4g0:m1=`0L0:m1=`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0:0?ooo`030000002Ri?`0X^Cl01P0X^Cl00<000000?ooo`3oool0103oool0
0`000000[d4g0:m1=`0K0:m1=`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool1
0000000000<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000002Ri?`0X^Cl
01P0X^Cl00<000000?ooo`3oool01P3oool00`000000[d4g0:m1=`0K0:m1=`030000003oool0oooo
00`0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`080?ooo`030000002Ri?`0X^Cl01P0X^Cl00<000000?ooo`3oool01`3oool00`000000
[d4g0:m1=`0L0:m1=`030000003oool0oooo00/0oooo00<000000?ooo`3oool01@3oool100000000
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000002Ri?`0X^Cl01P0X^Cl
00<000000?ooo`3oool02@3oool00`000000[d4g0:m1=`0L0:m1=`030000003oool0oooo00X0oooo
00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`060?ooo`030000002Ri?`0X^Cl00/0X^Cl3P00000=0?ooo`030000002_@CL0[d4g01`0[d4g00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo3`00000<0<?Hj@030000003oool0oooo00d0oooo00<00000
0:m1=`2_@CL0702_@CL00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo0@000000
00030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000`mSY0<?Hj@0I0<?H
j@030000003oool0oooo00h0oooo00<000000:m1=`2_@CL0702_@CL00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00D0oooo0@00000000030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0103oool00`000000`mSY0<?Hj@0H0<?Hj@030000003oool0oooo0100oooo00<000000:m1=`2_
@CL0702_@CL00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo0@00000000030000
003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000`mSY0<?Hj@0I0<?Hj@030000
003oool0oooo0140oooo00<000000:m1=`2_@CL06`2_@CL00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00D0oooo0@00000000030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3o
ool00`000000`mSY0<?Hj@0H0<?Hj@030000003oool0oooo0180oooo00<000000:m1=`2_@CL0702_
@CL00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo0@00000000030000003oool0
oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000`mSY0<?Hj@0I0<?Hj@030000003oool0
oooo01<0oooo00<000000:m1=`2_@CL0702_@CL00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00D0oooo0@00000000030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`00
0000`mSY0<?Hj@0H0<?Hj@030000003oool0oooo01D0oooo00<000000:m1=`2_@CL03P2_@CL?0000
00D0oooo00<000000?ooo`3oool01@3oool10000000000<000000?ooo`3oool01@3oool01@000000
oooo0?ooo`3oool0000001/0`mSY00<000000?ooo`3oool05P3oool@000000h0aW=`00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`050?ooo`05
0000003oool0oooo0?ooo`0000006P33f>T00`000000oooo0?ooo`0G0?ooo`0300000036Lg00aW=`
01`0aW=`00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`40000000000`000000
oooo0?ooo`060?ooo`030000003oool0000001/0`mSY00<000000?ooo`3oool0603oool00`000000
aW=`0<IcL00K0<IcL0050000003oool0oooo0?ooo`000000203oool10000000000<000000?ooo`3o
ool01P3oool00`000000oooo0000000J0<?Hj@030000003oool0oooo01T0oooo00<000000<IcL036
Lg007036Lg0010000000oooo0?ooo`0000080?ooo`40000000000`000000oooo0?ooo`060?ooo`80
00006`33f>T00`000000oooo0?ooo`0J0?ooo`0300000036Lg00aW=`01/0aW=`00@000000?ooo`3o
ool00000203oool10000000000<000000?ooo`3oool01P3oool2000001X0`mSY00<000000?ooo`3o
ool06`3oool00`000000aW=`0<IcL00L0<IcL0030000003oool0000000P0oooo0@00000000030000
003oool0oooo00H0oooo00<000000<?Hj@33f>T06@33f>T00`000000oooo0?ooo`0L0?ooo`030000
0036Lg00aW=`01/0aW=`00<000000?ooo`000000203oool10000000000<000000?ooo`3oool01P3o
ool00`000000`mSY0<?Hj@0H0<?Hj@030000003oool0oooo01d0oooo00<000000<IcL036Lg007036
Lg02000000P0oooo0@00000000030000003oool0oooo00D0oooo00<000000<?Hj@33f>T06@33f>T0
0`000000oooo0?ooo`0N0?ooo`0300000036Lg00aW=`01/0aW=`0P0000080?ooo`40000000000`00
0000oooo0?ooo`050?ooo`0300000033f>T0`mSY01P0`mSY00<000000?ooo`3oool07`3oool00`00
0000aW=`0<IcL00L0<IcL0030000003oool0oooo00H0oooo0@00000000030000003oool0oooo00@0
oooo00<000000<?Hj@33f>T03033f>T>00000280oooo00<000000<IcL036Lg006`36Lg000`000000
oooo0?ooo`060?ooo`40000000000`000000oooo0?ooo`040?ooo`l000003@3=am@00`000000oooo
0?ooo`0P0?ooo`0300000036Lg00aW=`01`0aW=`00<000000?ooo`3oool01@3oool10000000000<0
00000?ooo`3oool0103oool00`000000cLOD0<g7e00I0<g7e0030000003oool0oooo0200oooo00<0
00000<IcL036Lg007036Lg000`000000oooo0?ooo`050?ooo`40000000000`000000oooo0?ooo`03
0?ooo`030000003=am@0cLOD01T0cLOD00<000000?ooo`3oool08P3oool00`000000aW=`0<IcL00L
0<IcL0030000003oool0oooo00@0oooo0@00000000030000003oool0oooo00<0oooo00<000000<g7
e03=am@06@3=am@00`000000oooo0?ooo`0R0?ooo`0300000036Lg00aW=`01`0aW=`00<000000?oo
o`3oool0103oool10000000000<000000?ooo`3oool00`3oool00`000000cLOD0<g7e00I0<g7e003
0000003oool0oooo02<0oooo00<000000<IcL036Lg007036Lg000`000000oooo0?ooo`030?ooo`40
000000000`000000oooo0?ooo`030?ooo`030000003=am@0cLOD01T0cLOD00<000000?ooo`3oool0
8`3oool00`000000aW=`0<IcL00L0<IcL0030000003oool0oooo00<0oooo0@00000000030000003o
ool0oooo00<0oooo00<000000<g7e03=am@0603=am@00`000000oooo0?ooo`0U0?ooo`0300000036
Lg00aW=`01`0aW=`00<000000?ooo`3oool00P3oool10000000000<000000?ooo`3oool00`3oool0
0`000000cLOD0<g7e00H0<g7e0030000003oool0oooo02D0oooo00<000000<IcL036Lg007036Lg00
0`000000oooo0?ooo`020?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003=am@0cLOD
01P0cLOD00<000000?ooo`3oool09P3oool00`000000aW=`0<IcL00L0<IcL0040000003oool0oooo
0?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003=am@0cLOD01P0cLOD00<000000?oo
o`3oool09P3oool00`000000aW=`0<IcL00E0<IcL0P000000`3oool10000000000<000000?ooo`3o
ool00`3oool00`000000cLOD0<g7e00H0<g7e0030000003oool0oooo02L0oooo00<000000<IcL036
Lg001@36Lg0?000000P0ci6B0`3oool10000000000<000000?ooo`3oool00`3oool00`000000cLOD
0<g7e00G0<g7e0030000003oool0oooo02P0oooo2000000G0<nATP030000003oool0oooo00400000
00000`000000oooo0?ooo`040?ooo`030000003=am@0cLOD01H0cLOD00<000000?ooo`3oool0:03o
ool00`000000ci6B0<nATP0L0<nATP030000003oool0oooo0040000000000`000000oooo0?ooo`04
0?ooo`030000003=am@0cLOD01H0cLOD00<000000?ooo`3oool0:@3oool00`000000ci6B0<nATP0K
0<nATP030000003oool0oooo0040000000000`000000oooo0?ooo`040?ooo`030000003=am@0cLOD
01H0cLOD00<000000?ooo`3oool0:@3oool00`000000ci6B0<nATP0K0<nATP030000003oool00000
0040oooo00000`3oool000000?ooo`040?ooo`030000003=am@0cLOD01H0cLOD00<000000?ooo`3o
ool0:@3oool00`000000ci6B0<nATP0K0<nATP030000003oool000000040oooo00000`3oool00000
0?ooo`040?ooo`030000003=am@0cLOD01D0cLOD00<000000?ooo`3oool0:P3oool00`000000ci6B
0<nATP0K0<nATP030000003oool000000040oooo00000`3oool000000?ooo`040?ooo`030000003=
am@0cLOD01D0cLOD00<000000?ooo`3oool0:`3oool00`000000ci6B0<nATP0J0<nATP030000003o
ool000000040oooo00000`3oool000000?ooo`040?ooo`030000003=am@0cLOD01D0cLOD00<00000
0?ooo`3oool0:`3oool00`000000ci6B0<nATP0J0<nATP030000003oool000000040oooo00000`3o
ool000000?ooo`040?ooo`030000003=am@0cLOD01D0cLOD00<000000?ooo`3oool0:`3oool00`00
0000ci6B0<nATP0J0<nATP030000003oool000000040oooo00000`3oool000000?ooo`040?ooo`03
0000003=am@0cLOD01@0cLOD00<000000?ooo`3oool0;03oool00`000000ci6B0<nATP0J0<nATP03
0000003oool000000040oooo00000`3oool000000?ooo`040?ooo`030000003=am@0cLOD01@0cLOD
00<000000?ooo`3oool0;@3oool00`000000ci6B0<nATP0I0<nATP030000003oool000000040oooo
00000`3oool000000?ooo`040?ooo`030000003=am@0cLOD00T0cLOD3000000_0?ooo`030000003?
TI80ci6B01T0ci6B00<000000?ooo`0000000@3oool000030?ooo`000000oooo00@0oooo3000000;
0=2f`0030000003oool0oooo02d0oooo00<000000<nATP3?TI806@3?TI800`000000oooo00000001
0?ooo`0000<0oooo0000003oool0103oool00`000000d;K00=2f`00D0=2f`0030000003oool0oooo
02d0oooo00<000000<nATP3?TI806@3?TI800`000000oooo000000010?ooo`0000<0oooo0000003o
ool0103oool00`000000d;K00=2f`00D0=2f`0030000003oool0oooo02h0oooo00<000000<nATP3?
TI80603?TI800`000000oooo000000010?ooo`0000<0oooo0000003oool0103oool00`000000d;K0
0=2f`00D0=2f`0030000003oool0oooo02h0oooo00<000000<nATP3?TI80603?TI800`000000oooo
000000010?ooo`0000<0oooo0000003oool0103oool00`000000d;K00=2f`00D0=2f`0030000003o
ool0oooo02h0oooo00<000000<nATP3?TI80603?TI800`000000oooo000000010?ooo`0000<0oooo
0000003oool0103oool00`000000d;K00=2f`00D0=2f`0030000003oool0oooo02h0oooo00<00000
0<nATP3?TI80603?TI800`000000oooo000000010?ooo`0000<0oooo0000003oool0103oool00`00
0000d;K00=2f`00C0=2f`0030000003oool0oooo0300oooo00<000000<nATP3?TI805`3?TI800`00
0000oooo000000010?ooo`0000<0oooo0000003oool0103oool00`000000d;K00=2f`00C0=2f`003
0000003oool0oooo0300oooo00<000000<nATP3?TI805`3?TI800`000000oooo000000010?ooo`00
00<0oooo0000003oool0103oool00`000000d;K00=2f`00C0=2f`0030000003oool0oooo0300oooo
00<000000<nATP3?TI805`3?TI800`000000oooo000000010?ooo`0000<0oooo0000003oool0103o
ool00`000000d;K00=2f`00C0=2f`0030000003oool0oooo0300oooo00<000000<nATP3?TI805`3?
TI800`000000oooo000000010?ooo`0000<0oooo0000003oool0103oool00`000000d;K00=2f`00C
0=2f`0030000003oool0oooo0340oooo00<000000<nATP3?TI805P3?TI800`000000oooo00000001
0?ooo`0000<0oooo0000003oool0103oool00`000000d;K00=2f`00C0=2f`0030000003oool0oooo
0340oooo00<000000<nATP3?TI805P3?TI800`000000oooo000000010?ooo`0000<0oooo0000003o
ool0103oool00`000000d;K00=2f`00C0=2f`0030000003oool0oooo0340oooo00<000000<nATP3?
TI805P3?TI800`000000oooo000000010?ooo`0000<0oooo0000003oool0103oool00`000000d;K0
0=2f`00C0=2f`0030000003oool0oooo0340oooo00<000000<nATP3?TI804@3?TI8600000040oooo
0@0000010?ooo`0000<0oooo0000003oool0103oool00`000000d;K00=2f`00C0=2f`0030000003o
ool0oooo0380oooo00<000000<nATP3?TI80103?TI8<000000D0djN[00<000000?ooo`0000000@3o
ool000030?ooo`000000oooo00@0oooo00<000000=2f`03@]/004`3@]/000`000000oooo0?ooo`0b
0?ooo`L000004@3CYj/00`000000oooo000000010?ooo`0000<0oooo0000003oool0103oool00`00
0000d;K00=2f`00C0=2f`0030000003oool0oooo0380oooo00<000000=>WZ`3CYj/05@3CYj/00`00
0000oooo000000010?ooo`0000<0oooo0000003oool0103oool00`000000d;K00=2f`00C0=2f`003
0000003oool0oooo0380oooo00<000000=>WZ`3CYj/05@3CYj/00`000000oooo000000010?ooo`00
00<0oooo0000003oool0103oool00`000000d;K00=2f`00B0=2f`0030000003oool0oooo03<0oooo
00<000000=>WZ`3CYj/05@3CYj/00`000000oooo000000010?ooo`0000<0oooo0000003oool0103o
ool00`000000d;K00=2f`00B0=2f`0030000003oool0oooo03<0oooo00<000000=>WZ`3CYj/05@3C
Yj/00`000000oooo000000010?ooo`0000<0oooo0000003oool0103oool00`000000d;K00=2f`00B
0=2f`0030000003oool0oooo03<0oooo00<000000=>WZ`3CYj/05@3CYj/00`000000oooo00000001
0?ooo`0000<0oooo0000003oool0103oool00`000000d;K00=2f`00B0=2f`0030000003oool0oooo
03<0oooo00<000000=>WZ`3CYj/05@3CYj/00`000000oooo000000010?ooo`0000<0oooo0000003o
ool0103oool00`000000d;K00=2f`00B0=2f`0030000003oool0oooo03<0oooo00<000000=>WZ`3C
Yj/05@3CYj/00`000000oooo000000010?ooo`0000<0oooo0000003oool0103oool00`000000d;K0
0=2f`00B0=2f`0030000003oool0oooo03@0oooo00<000000=>WZ`3CYj/0503CYj/00`000000oooo
000000010?ooo`0000<0oooo0000003oool0103oool00`000000d;K00=2f`00=0=2f`0H00000=P3o
ool00`000000djN[0=>WZ`0D0=>WZ`030000003oool000000040oooo00000`3oool000000?ooo`04
0?ooo`030000003@]/00d;K000<0d;K02P0000050=2U[@030000003oool0oooo03@0oooo00<00000
0=>WZ`3CYj/0503CYj/00`000000oooo000000010?ooo`0000<0oooo0000003oool0103oool60000
00l0d:F]00<000000?ooo`3oool0=03oool00`000000djN[0=>WZ`0D0=>WZ`030000003oool00000
0040oooo00000`3oool000000?ooo`040?ooo`030000003@YJd0d:F]0180d:F]00<000000?ooo`3o
ool0=03oool00`000000djN[0=>WZ`0D0=>WZ`030000003oool000000040oooo00000`3oool00000
0?ooo`040?ooo`030000003@YJd0d:F]0180d:F]00<000000?ooo`3oool0=03oool00`000000djN[
0=>WZ`0D0=>WZ`030000003oool000000040oooo00000`3oool000000?ooo`040?ooo`030000003@
YJd0d:F]0180d:F]00<000000?ooo`3oool0=03oool00`000000djN[0=>WZ`0D0=>WZ`030000003o
ool000000040oooo00000`3oool000000?ooo`040?ooo`030000003@YJd0d:F]0180d:F]00<00000
0?ooo`3oool0=03oool00`000000djN[0=>WZ`0D0=>WZ`030000003oool000000040oooo00000`3o
ool000000?ooo`040?ooo`030000003@YJd0d:F]01<0d:F]00<000000?ooo`3oool0<`3oool00`00
0000djN[0=>WZ`0D0=>WZ`030000003oool000000040oooo00000`3oool000000?ooo`040?ooo`03
0000003@YJd0d:F]01<0d:F]00<000000?ooo`3oool0<`3oool00`000000djN[0=>WZ`0D0=>WZ`03
0000003oool000000040oooo00000`3oool000000?ooo`040?ooo`030000003@YJd0d:F]01<0d:F]
00<000000?ooo`3oool0<`3oool00`000000djN[0=>WZ`0D0=>WZ`030000003oool000000040oooo
00000`3oool000000?ooo`040?ooo`030000003@YJd0d:F]01<0d:F]00<000000?ooo`3oool0<`3o
ool00`000000djN[0=>WZ`0D0=>WZ`030000003oool000000040oooo00000`3oool000000?ooo`04
0?ooo`030000003@YJd0d:F]01<0d:F]00<000000?ooo`3oool0<`3oool00`000000djN[0=>WZ`0D
0=>WZ`030000003oool000000040oooo00000`3oool000000?ooo`040?ooo`030000003@YJd0d:F]
01<0d:F]00<000000?ooo`3oool0<`3oool00`000000djN[0=>WZ`0D0=>WZ`030000003oool00000
0040oooo00000`3oool000000?ooo`040?ooo`030000003@YJd0d:F]01<0d:F]00<000000?ooo`3o
ool0=03oool00`000000djN[0=>WZ`0C0=>WZ`030000003oool000000040oooo00000`3oool00000
0?ooo`040?ooo`030000003@YJd0d:F]01<0d:F]00<000000?ooo`3oool0=03oool00`000000djN[
0=>WZ`0C0=>WZ`030000003oool000000040oooo00000`3oool000000?ooo`040?ooo`030000003@
YJd0d:F]01<0d:F]00<000000?ooo`3oool0=03oool00`000000djN[0=>WZ`0C0=>WZ`030000003o
ool000000040oooo00000`3oool000000?ooo`040?ooo`030000003@YJd0d:F]01<0d:F]00<00000
0?ooo`3oool0=03oool00`000000djN[0=>WZ`0C0=>WZ`030000003oool000000040oooo00000`3o
ool000000?ooo`040?ooo`030000003@YJd0d:F]01<0d:F]00<000000?ooo`3oool0=03oool00`00
0000djN[0=>WZ`0C0=>WZ`030000003oool000000040oooo00000`3oool000000?ooo`040?ooo`03
0000003@YJd0d:F]01<0d:F]00<000000?ooo`3oool0=03oool00`000000djN[0=>WZ`0>0=>WZ`H0
00000@3oool100000040oooo00000`3oool000000?ooo`040?ooo`030000003@YJd0d:F]01<0d:F]
00<000000?ooo`3oool0=03oool00`000000djN[0=>WZ`030=>WZ`/000001@3C^/400`000000oooo
000000010?ooo`0000<0oooo0000003oool0103oool00`000000d:F]0=2U[@0C0=2U[@030000003o
ool0oooo03@0oooo1P00000@0=>j`@030000003oool000000040oooo00000`3oool000000?ooo`04
0?ooo`030000003@YJd0d:F]01@0d:F]00<000000?ooo`3oool0<`3oool00`000000dk[10=>j`@0C
0=>j`@030000003oool000000040oooo00000`3oool000000?ooo`040?ooo`030000003@YJd0d:F]
01@0d:F]00<000000?ooo`3oool0<`3oool00`000000dk[10=>j`@0C0=>j`@030000003oool00000
0040oooo00000`3oool000000?ooo`040?ooo`030000003@YJd0d:F]01@0d:F]00<000000?ooo`3o
ool0<`3oool00`000000dk[10=>j`@0C0=>j`@030000003oool000000040oooo00000`3oool00000
0?ooo`040?ooo`030000003@YJd0d:F]01@0d:F]00<000000?ooo`3oool0<`3oool00`000000dk[1
0=>j`@0C0=>j`@030000003oool000000040oooo00000`3oool000000?ooo`040?ooo`030000003@
YJd0d:F]01@0d:F]00<000000?ooo`3oool0<`3oool00`000000dk[10=>j`@0C0=>j`@030000003o
ool000000040oooo00000`3oool000000?ooo`040?ooo`030000003@YJd0d:F]01@0d:F]00<00000
0?ooo`3oool0<`3oool00`000000dk[10=>j`@0C0=>j`@030000003oool000000040oooo00000`3o
ool000000?ooo`040?ooo`030000003@YJd0d:F]00T0d:F]3000000d0?ooo`030000003C^/40dk[1
01@0dk[100<000000?ooo`0000000@3oool000030?ooo`000000oooo00@0oooo3000000;0<fBU`03
0000003oool0oooo0380oooo00<000000=>j`@3C^/404P3C^/401@000000dk[10000003oool00000
0040oooo00000`3oool000000?ooo`040?ooo`030000003=TYL0cI:G01@0cI:G00<000000?ooo`3o
ool0<P3oool00`000000dk[10=>j`@0B0=>j`@050000003C^/4000000?ooo`0000000@3oool00003
0?ooo`000000oooo00@0oooo00<000000<fBU`3=TYL05@3=TYL00`000000oooo0?ooo`0a0?ooo`03
0000003C^/40dk[10180dk[100D000000=>j`@000000oooo000000010?ooo`0000<0oooo0000003o
ool0103oool00`000000cI:G0<fBU`0E0<fBU`030000003oool0oooo0340oooo00<000000=>j`@3C
^/404@3C^/401P000000dk[10=>j`@000000oooo00000040oooo00000`3oool000000?ooo`040?oo
o`030000003=TYL0cI:G01D0cI:G00<000000?ooo`3oool0<@3oool00`000000dk[10=>j`@0A0=>j
`@060000003C^/40dk[10000003oool000000@3oool000030?ooo`000000oooo00@0oooo00<00000
0<fBU`3=TYL05@3=TYL00`000000oooo0?ooo`0a0?ooo`030000003C^/40dk[10140dk[100H00000
0=>j`@3C^/4000000?ooo`0000010?ooo`0000<0oooo0000003oool0103oool00`000000cI:G0<fB
U`0E0<fBU`030000003oool0oooo0340oooo00<000000=>j`@3C^/404@3C^/401P000000dk[10=>j
`@000000oooo00000040oooo00000`3oool000000?ooo`040?ooo`030000003=TYL0cI:G01H0cI:G
00<000000?ooo`3oool0<03oool00`000000dk[10=>j`@0@0=>j`@070000003C^/40dk[10=>j`@00
0000oooo000000010?ooo`0000<0oooo0000003oool0103oool00`000000cI:G0<fBU`0F0<fBU`03
0000003oool0oooo0300oooo00<000000=>j`@3C^/40403C^/401`000000dk[10=>j`@3C^/400000
0?ooo`0000000@3oool000030?ooo`000000oooo00@0oooo00<000000<fBU`3=TYL05P3=TYL00`00
0000oooo0?ooo`0`0?ooo`030000003C^/40dk[10100dk[100L000000=>j`@3C^/40dk[10000003o
ool000000040oooo00000`3oool000000?ooo`040?ooo`030000003=TYL0cI:G01H0cI:G00<00000
0?ooo`3oool0<03oool00`000000dk[10=>j`@0@0=>j`@070000003C^/40dk[10=>j`@000000oooo
000000010?ooo`0000<0oooo0000003oool0103oool00`000000cI:G0<fBU`0F0<fBU`030000003o
ool0oooo0300oooo00<000000=>j`@3C^/40403C^/401`000000dk[10=>j`@3C^/4000000?ooo`00
00000@3oool000030?ooo`000000oooo00@0oooo00<000000<fBU`3=TYL05`3=TYL00`000000oooo
0?ooo`0_0?ooo`030000003C^/40dk[100l0dk[100<000000=>j`@3C^/400P3C^/400`000000oooo
000000010?ooo`0000<0oooo0000003oool0103oool00`000000cI:G0<fBU`0G0<fBU`030000003o
ool0oooo02h0oooo00<000000=>j`@3C^/40403C^/400`000000dk[10=>j`@020=>j`@030000003o
ool000000040oooo00000`3oool000000?ooo`040?ooo`030000003=TYL0cI:G01L0cI:G00<00000
0?ooo`3oool0;P3oool00`000000dk[10=>j`@0@0=>j`@030000003C^/40dk[10080dk[100<00000
0?ooo`0000000@3oool000030?ooo`000000oooo00@0oooo00<000000<fBU`3=TYL05`3=TYL00`00
0000oooo0?ooo`0^0?ooo`030000003C^/40dk[10100dk[100<000000=>j`@3C^/400P3C^/400`00
0000oooo000000010?ooo`0000<0oooo0000003oool0103oool00`000000cI:G0<fBU`0G0<fBU`03
0000003oool0oooo02h0oooo00<000000=>j`@3C^/40403C^/400`000000dk[10=>j`@020=>j`@03
0000003oool000000040oooo00000`3oool000000?ooo`040?ooo`030000003=TYL0cI:G01P0cI:G
00<000000?ooo`3oool0;@3oool00`000000dk[10=>j`@0?0=>j`@030000003C^/40dk[100<0dk[1
00<000000?ooo`0000000@3oool000030?ooo`000000oooo00@0oooo00<000000<fBU`3=TYL0603=
TYL00`000000oooo0?ooo`0]0?ooo`030000003C^/40dk[100l0dk[11`0000010?ooo`4000000@3o
ool000030?ooo`000000oooo00@0oooo00<000000<fBU`3=TYL0603=TYL00`000000oooo0?ooo`0]
0?ooo`030000003C^/40dk[100@0dk[1300000050<o=e`030000003oool000000040oooo00000`3o
ool000000?ooo`040?ooo`030000003=TYL0cI:G01P0cI:G00<000000?ooo`3oool0;@3oool70000
00/0clgG00<000000<o=e`3?cML00`3?cML00`000000oooo000000010?ooo`0000<0oooo0000003o
ool0103oool00`000000cI:G0<fBU`0H0<fBU`030000003oool0oooo02d0oooo00<000000<o=e`3?
cML03P3?cML00`000000clgG0<o=e`040<o=e`030000003oool000000040oooo00000`3oool00000
0?ooo`040?ooo`030000003=TYL0cI:G01T0cI:G00<000000?ooo`3oool0:`3oool00`000000clgG
0<o=e`0?0<o=e`030000003?cML0clgG00@0clgG00<000000?ooo`0000000@3oool000030?ooo`00
0000oooo00@0oooo00<000000<fBU`3=TYL06@3=TYL00`000000oooo0?ooo`0[0?ooo`030000003?
cML0clgG00l0clgG00<000000<o=e`3?cML0103?cML00`000000oooo000000010?ooo`0000<0oooo
0000003oool0103oool00`000000cI:G0<fBU`0C0<fBU`L00000;@3oool00`000000clgG0<o=e`0?
0<o=e`030000003?cML0clgG00@0clgG00<000000?ooo`0000000@3oool000030?ooo`000000oooo
00@0oooo00<000000<fBU`3=TYL01@3=TYL>000000H0aGQj00<000000?ooo`3oool0:`3oool00`00
0000clgG0<o=e`0?0<o=e`030000003?cML0clgG00@0clgG00<000000?ooo`0000000@3oool00003
0?ooo`000000oooo00@0oooo2000000E0<EhNP030000003oool0oooo02T0oooo00<000000<o=e`3?
cML03`3?cML00`000000clgG0<o=e`050<o=e`030000003oool000000040oooo00000`3oool00000
0?ooo`040?ooo`0300000035N7X0aGQj01X0aGQj00<000000?ooo`3oool0:@3oool00`000000clgG
0<o=e`0?0<o=e`030000003?cML0clgG00D0clgG00<000000?ooo`0000000@3oool000030?ooo`00
0000oooo00D0oooo00<000000<EhNP35N7X06P35N7X00`000000oooo0?ooo`0X0?ooo`030000003?
cML0clgG00l0clgG00<000000<o=e`3?cML01@3?cML00`000000oooo000000010?ooo`0000<0oooo
0000003oool01@3oool00`000000aGQj0<EhNP0J0<EhNP030000003oool0oooo02L0oooo00<00000
0<o=e`3?cML0403?cML00`000000clgG0<o=e`040<o=e`040000003oool0oooo00000040oooo0000
0`3oool000000?ooo`060?ooo`0300000035N7X0aGQj01X0aGQj00<000000?ooo`3oool09P3oool0
0`000000clgG0<o=e`0@0<o=e`030000003?cML0clgG00@0clgG00@000000?ooo`3oool000000@3o
ool000030?ooo`000000oooo00H0oooo00<000000<EhNP35N7X06P35N7X00`000000oooo0?ooo`0V
0?ooo`030000003?cML0clgG00l0clgG00<000000<o=e`3?cML01@3?cML010000000oooo0?ooo`00
00010?ooo`0000<0oooo0000003oool01P3oool2000001/0aGQj00<000000?ooo`3oool09@3oool0
0`000000clgG0<o=e`0@0<o=e`030000003?cML0clgG00D0clgG00@000000?ooo`3oool000000@3o
ool000030?ooo`000000oooo00H0oooo0P00000L0<EhNP030000003oool0oooo02@0oooo00<00000
0<o=e`3?cML0403?cML00`000000clgG0<o=e`050<o=e`040000003oool0oooo00000040oooo0000
0`3oool000000?ooo`060?ooo`8000007035N7X00`000000oooo0?ooo`0T0?ooo`030000003?cML0
clgG0100clgG00<000000<o=e`3?cML01@3?cML010000000oooo0?ooo`0000010?ooo`0000<0oooo
0000003oool01P3oool00`000000oooo0000000L0<EhNP030000003oool0oooo02<0oooo00<00000
0<o=e`3?cML0403?cML00`000000clgG0<o=e`050<o=e`040000003oool0oooo00000040oooo0000
0`3oool000000?ooo`060?ooo`030000003oool0000001`0aGQj00<000000?ooo`3oool08P3oool0
0`000000clgG0<o=e`0@0<o=e`030000003?cML0clgG00H0clgG00@000000?ooo`3oool000000@3o
ool000030?ooo`000000oooo00H0oooo00@000000?ooo`3oool000007035N7X00`000000oooo0?oo
o`0Q0?ooo`030000003?cML0clgG0100clgG00<000000<o=e`3?cML01P3?cML010000000oooo0?oo
o`0000010?ooo`0000<0oooo0000003oool01P3oool010000000oooo0?ooo`00000L0<EhNP030000
003oool0oooo0240oooo00<000000<o=e`3?cML0403?cML00`000000clgG0<o=e`060<o=e`040000
003oool0oooo00000040oooo00000`3oool000000?ooo`060?ooo`050000003oool0oooo0?ooo`00
00006`35N7X00`000000oooo0?ooo`0P0?ooo`030000003?cML0clgG0140clgG00<000000<o=e`3?
cML01P3?cML010000000oooo0?ooo`0000010?ooo`0000<0oooo0000003oool01P3oool01@000000
oooo0?ooo`3oool0000001`0aGQj00<000000?ooo`3oool07`3oool00`000000clgG0<o=e`0A0<o=
e`030000003?cML0clgG00H0clgG00@000000?ooo`3oool000000@3oool000030?ooo`000000oooo
00H0oooo00D000000?ooo`3oool0oooo000000070<EhNP0300000035N7X0aGQj0180aGQj00<00000
0?ooo`3oool07`3oool00`000000clgG0<o=e`0@0<o=e`030000003?cML0clgG00<0clgG1@000002
0?ooo`4000000@3oool000030?ooo`000000oooo00H0oooo00<000000?ooo`3oool00P3oool00`00
0000aGQj0<EhNP0J0<EhNP030000003oool0oooo01h0oooo00<000000<o=e`3?cML0303?cML:0000
00<0`^3^00D000000?ooo`3oool0oooo000000010?ooo`0000<0oooo0000003oool01P3oool00`00
0000oooo0?ooo`020?ooo`0300000035N7X0aGQj01X0aGQj00<000000?ooo`3oool07@3oool00`00
0000clgG0<o=e`030<o=e`X000001032h>h00`000000`^3^0<;PkP060<;PkP050000003oool0oooo
0?ooo`0000000@3oool000030?ooo`000000oooo00H0oooo00<000000?ooo`3oool00`3oool00`00
0000aGQj0<EhNP0J0<EhNP030000003oool0oooo01`0oooo1P00000>0<;PkP0300000032h>h0`^3^
00D0`^3^00<000000?ooo`3oool00P3oool100000040oooo00000`3oool000000?ooo`060?ooo`03
0000003oool0oooo00<0oooo00<000000<EhNP35N7X05035N7X7000001d0oooo00<000000<;PkP32
h>h04P32h>h00`000000`^3^0<;PkP050<;PkP030000003oool0oooo0080oooo0@0000010?ooo`00
00<0oooo0000003oool01P3oool00`000000oooo0?ooo`040?ooo`0300000035N7X0aGQj00D0aGQj
3P0000070;A?C0030000003oool0oooo01X0oooo00<000000<;PkP32h>h04P32h>h00`000000`^3^
0<;PkP040<;PkP030000003oool0oooo00<0oooo0@0000010?ooo`0000<0oooo0000003oool01P3o
ool00`000000oooo0?ooo`040?ooo`P000005P2dCd`00`000000oooo0?ooo`0H0?ooo`0300000032
h>h0`^3^01<0`^3^00<000000<;PkP32h>h00`32h>h00`000000oooo0?ooo`040?ooo`4000000@3o
ool000030?ooo`000000oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000]4m<0;A?C00J
0;A?C0030000003oool0oooo01P0oooo00<000000<;PkP32h>h04`32h>h00`000000`^3^0<;PkP03
0<;PkP030000003oool0oooo00@0oooo0@0000010?ooo`0000<0oooo0000003oool01P3oool00`00
0000oooo0?ooo`050?ooo`030000002dCd`0]4m<01/0]4m<00<000000?ooo`3oool05P3oool00`00
0000`^3^0<;PkP0C0<;PkP0300000032h>h0`^3^00<0`^3^00<000000?ooo`3oool01@3oool10000
0040oooo00000`3oool000000?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000;A?C02d
Cd`06`2dCd`00`000000oooo0?ooo`0D0?ooo`0300000032h>h0`^3^01@0`^3^00<000000<;PkP32
h>h00`32h>h00`000000oooo0?ooo`050?ooo`4000000@3oool000030?ooo`000000oooo00H0oooo
00<000000?ooo`3oool01`3oool00`000000]4m<0;A?C00K0;A?C0030000003oool0oooo01<0oooo
00<000000<;PkP32h>h05032h>h00`000000`^3^0<;PkP020<;PkP8000001`3oool100000040oooo
00000`3oool000000?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000;A?C02dCd`0702d
Cd`00`000000oooo0?ooo`0A0?ooo`0300000032h>h0`^3^01D0`^3^00<000000<;PkP32h>h00P32
h>h2000000L0oooo0@0000010?ooo`0000<0oooo0000003oool01P3oool00`000000oooo0?ooo`08
0?ooo`030000002dCd`0]4m<01/0]4m<00<000000?ooo`3oool04@3oool00`000000`^3^0<;PkP0D
0<;PkP0300000032h>h0`^3^0080`^3^00<000000?ooo`0000001`3oool100000040oooo00000`3o
ool000000?ooo`060?ooo`030000003oool0oooo00T0oooo00<000000;A?C02dCd`06`2dCd`00`00
0000oooo0?ooo`0?0?ooo`0300000032h>h0`^3^01D0`^3^00D000000<;PkP32h>h0`^3^00000002
0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01P3oool00`00
0000oooo0?ooo`090?ooo`030000002dCd`0]4m<01`0]4m<00<000000?ooo`3oool03P3oool00`00
0000`^3^0<;PkP0E0<;PkP0500000032h>h0`^3^0<;PkP0000000P3oool00`000000oooo0?ooo`05
0?ooo`4000000@3oool000030?ooo`000000oooo00H0oooo00<000000?ooo`3oool02P3oool00`00
0000]4m<0;A?C00L0;A?C0030000003oool0oooo00`0oooo00<000000<;PkP32h>h05P32h>h01000
0000`^3^0<;PkP0000030?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000
003oool01P3oool00`000000oooo0?ooo`0;0?ooo`030000002dCd`0]4m<01`0]4m<00<000000?oo
o`3oool02P3oool00`000000`^3^0<;PkP0G0<;PkP0400000032h>h0`^3^000000<0oooo00<00000
0?ooo`3oool01@3oool100000040oooo00000`3oool000000?ooo`060?ooo`030000003oool0oooo
00`0oooo00<000000;A?C02dCd`06`2dCd`00`000000oooo0?ooo`0:0?ooo`0300000032h>h0`^3^
01D0`^3^1@0000040?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003o
ool01P3oool00`000000oooo0?ooo`0<0?ooo`030000002dCd`0]4m<01`0]4m<00<000000?ooo`3o
ool0203oool00`000000`^3^0<;PkP0<0<;PkPX0000000@0T>Oj0000002@ioX000001@3oool00`00
0000oooo0?ooo`050?ooo`4000000@3oool000030?ooo`000000oooo00H0oooo00<000000?ooo`3o
ool03@3oool00`000000]4m<0;A?C00H0;A?C0D000002@3oool00`000000`^3^0<;PkP020<;PkPX0
00002`2@ioX2000000H0oooo00<000000?ooo`3oool01@3oool100000040oooo00000`3oool00000
0?ooo`060?ooo`030000003oool0oooo00d0oooo0P00000?0;A?C0X000001@240002000000H0oooo
1P00000D093WnP8000001`3oool00`000000oooo0?ooo`050?ooo`4000000@3oool000030?ooo`00
0000oooo00H0oooo00<000000?ooo`3oool03@3oool2000000D0]4m<2P00000A08@0008000000`3o
ool00`000000T>Oj093WnP0G093WnP030000003oool0000000L0oooo00<000000?ooo`3oool01@3o
ool100000040oooo00000`3oool000000?ooo`060?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`0000001000000M08@000<00000602@ioX2000000030?ooo`000000oooo00L0oooo00<00000
0?ooo`3oool01@3oool100000040oooo00000`3oool000000?ooo`060?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool00P00000O08@000030000002@ioX0T>Oj01L0T>Oj00D000000?oo
o`3oool0oooo000000080?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000
003oool01P3oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo0?ooo`80000070240000
0`000000T>Oj093WnP0G093WnP030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`050?ooo`4000000@3oool000030?ooo`000000oooo00H0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`030?ooo`03000000240000Q00001L0Q0000P00000H093W
nP8000001@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo0@0000010?oo
o`0000<0oooo0000003oool01P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0
oooo0P00000F08@000030000002@ioX0T>Oj01L0T>Oj00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool0
1P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00H0oooo00<0000008@000240000
4P2400000`000000T>Oj093WnP0@093WnPP000001`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01P3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00L0oooo0P00000@08@0008000001@2@ioX>000000l0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`4000000@3oool000030?ooo`000000
oooo00H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`080?ooo`8000001@24000@
000001d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`4000000@3oool0
00030?ooo`000000oooo00H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0:0?oo
o`L00000:`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo0@0000010?oo
o`0000<0oooo0000003oool01P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo03/0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`4000000@3oool000030?oo
o`000000oooo00H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool100000040oooo00000`3oool000000?oo
o`060?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01P3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`050?ooo`4000000@3oool000030?ooo`000000oooo00H0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool01@3oool100000040oooo00000`3oool000000?ooo`060?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0
oooo0@0000010?ooo`0000<0oooo0000003oool01P3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo03T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`400000
0@3oool000030?ooo`000000oooo00H0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0i0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool100000040oooo0000
0`3oool000000?ooo`060?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0>@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000
003oool01P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`050?ooo`4000000@3oool000030?ooo`000000oooo00H0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool01@3oool100000040oooo00000`3oool000000?ooo`060?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01P3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`050?ooo`4000000@3oool000030?ooo`000000oooo00H0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool1
00000040oooo00000`3oool000000?ooo`060?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00D0oooo0@0000010?oo
o`0000<0oooo0000003oool01P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03D0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`050?ooo`4000000@3oool000030?oo
o`000000oooo00H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool01@3oool100000040oooo00000`3oool000000?oo
o`060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01P3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`050?ooo`4000000@3oool000030?ooo`000000oooo00H0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool01@3oool100000040oooo00000`3oool000000?ooo`060?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00D0
oooo0@0000010?ooo`0000<0oooo0000003oool01P3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo03<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`050?ooo`400000
0@3oool000030?ooo`000000oooo00H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`0c0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01@3oool100000040oooo0000
0`3oool000000?ooo`060?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0<P3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000
003oool01P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0340oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`050?ooo`4000000@3oool000030?ooo`000000oooo00H0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool01@3oool100000040oooo00000`3oool000000?ooo`060?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01P3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`050?ooo`4000000@3oool000030?ooo`000000oooo00H0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01@3oool1
00000040oooo00000`3oool000000?ooo`060?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool0;`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo0@0000010?oo
o`0000<0oooo0000003oool01P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02l0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`4000000@3oool000030?oo
o`000000oooo00H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0_0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool01@3oool100000040oooo00000`3oool000000?oo
o`060?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01P3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`050?ooo`4000000@3oool000030?ooo`000000oooo00H0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool01@3oool100000040oooo00000`3oool000000?ooo`060?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00D0
oooo0@0000010?ooo`0000<0oooo0000003oool01P3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`050?ooo`400000
0@3oool000030?ooo`000000oooo00H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`0/0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01@3oool100000040oooo0000
0`3oool000000?ooo`060?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000
003oool01P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02/0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`050?ooo`4000000@3oool000030?ooo`000000oooo00H0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool01@3oool100000040oooo00000`3oool000000?ooo`060?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01P3oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`050?ooo`4000000@3oool000030?ooo`000000oooo00H0oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool01@3oool1
00000040oooo00000`3oool000000?ooo`060?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00D0oooo0@0000010?oo
o`0000<0oooo0000003oool01P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`050?ooo`4000000@3oool000030?oo
o`000000oooo00H0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool01@3oool100000040oooo00000`3oool000000?oo
o`060?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01P3oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`050?ooo`4000000@3oool000030?ooo`000000oooo00H0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool01@3oool100000040oooo00000`3oool000000?ooo`060?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00D0
oooo0@0000010?ooo`0000<0oooo0000003oool01P3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`050?ooo`400000
0@3oool000030?ooo`000000oooo00H0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool01@3oool100000040oooo0000
0`3oool000000?ooo`060?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000
003oool01P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`050?ooo`4000000@3oool000030?ooo`000000oooo00H0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool01@3oool100000040oooo00000`3oool000000?ooo`060?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01P3oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`050?ooo`4000000@3oool000030?ooo`000000oooo00H0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool1
00000040oooo00000`3oool000000?ooo`060?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo0@0000010?oo
o`0000<0oooo0000003oool01P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`4000000@3oool000030?oo
o`000000oooo00H0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool01@3oool100000040oooo00000`3oool000000?oo
o`060?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01P3oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`050?ooo`4000000@3oool000030?ooo`000000oooo00H0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool01@3oool100000040oooo00000`3oool000000?ooo`060?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0
oooo0@0000010?ooo`0000<0oooo0000003oool01P3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`050?ooo`400000
0@3oool000030?ooo`000000oooo00H0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`0P0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01@3oool100000040oooo0000
0`3oool000000?ooo`060?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000
003oool01P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`050?ooo`4000000@3oool000030?ooo`000000oooo00H0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool01@3oool100000040oooo00000`3oool000000?ooo`060?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01P3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`050?ooo`4000000@3oool000030?ooo`000000oooo00H0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool1
00000040oooo00000`3oool000000?ooo`060?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo0@0000010?oo
o`0000<0oooo0000003oool01P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`4000000@3oool000030?oo
o`000000oooo00H0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool100000040oooo00000`3oool000000?oo
o`060?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01P3oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`050?ooo`4000000@3oool000030?ooo`000000oooo00H0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool01@3oool100000040oooo00000`3oool000000?ooo`060?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0
oooo0@0000010?ooo`0000<0oooo0000003oool01P3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`050?ooo`400000
0@3oool000030?ooo`000000oooo00H0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool100000040oooo0000
0`3oool000000?ooo`060?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000
003oool01P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`050?ooo`4000000@3oool000030?ooo`000000oooo00H0
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool01@3oool100000040oooo00000`3oool000000?ooo`060?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01P3oool00`000000oooo0?oo
o`0P0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`050?ooo`4000000@3oool000030?ooo`000000oooo00H0oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01@3oool1
00000040oooo00000`3oool000000?ooo`060?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo0@0000010?oo
o`0000<0oooo0000003oool01P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`050?ooo`4000000@3oool000030?oo
o`000000oooo00H0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool01@3oool100000040oooo00000`3oool000000?oo
o`060?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01P3oool0
0`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`050?ooo`4000000@3oool000030?ooo`000000oooo00H0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool01@3oool100000040oooo00000`3oool000000?ooo`060?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00D0
oooo0@0000010?ooo`0000<0oooo0000003oool01P3oool00`000000oooo0?ooo`060?ooodX00000
203oool00`000000oooo0?ooo`050?ooo`4000000@3oool000030?ooo`000000oooo00H0oooo00<0
00000?ooo`3oool01P3oool00`000000IP0006H0000I06H000030000001V0000IP0001<0IP0000<0
000006H0001V0000501V00000`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo0@00
00010?ooo`0000<0oooo0000003oool01P3oool00`000000oooo0?ooo`060?ooo`030000001V0000
IP0001T0IP0000<0000006H0001V00004`1V00000`000000IP0006H0000D06H000030000003oool0
oooo00H0oooo00<000000?ooo`3oool01@3oool100000040oooo00000`3oool000000?ooo`060?oo
o`030000003oool0oooo00H0oooo00<0000006H0001V00006@1V00000`000000IP0006H0000C06H0
00030000001V0000IP0001@0IP0000<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?oo
o`4000000@3oool000030?ooo`000000oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000
IP0006H0000K06H000030000001V0000IP000180IP0000<0000006H0001V0000501V00000`000000
oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool0
1P3oool00`000000oooo0?ooo`050?ooo`030000001V0000IP0001/0IP0000<0000006H0001V0000
4@1V00000`000000IP0006H0000F06H000030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool100000040oooo00000`3oool000000?ooo`060?ooo`030000003oool0oooo00D0oooo00<0
000006H0001V00006`1V00000`000000IP0006H0000A06H000030000001V0000IP0001H0IP0000<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`4000000@3oool000030?ooo`000000
oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000IP0006H0000_06H000030000001V0000
IP0001H0IP0000<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`4000000@3oool0
00030?ooo`000000oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000IP0006H0000_06H0
00030000001V0000IP0001H0IP0000<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?oo
o`4000000@3oool000030?ooo`000000oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000
IP0006H0000_06H000030000001V0000IP0001H0IP0000<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`050?ooo`4000000@3oool000030?ooo`000000oooo00H0oooo00<000000?ooo`3oool0
1@3oool00`000000IP0006H0000^06H000030000001V0000IP0001L0IP0000<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`4000000@3oool000030?ooo`000000oooo00H0oooo00<0
00000?ooo`3oool01@3oool00`000000IP0006H0000^06H000030000001V0000IP0001L0IP0000<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`4000000@3oool000030?ooo`000000
oooo00H0oooo00<000000?ooo`3oool0103oool00`000000IP0006H0000_06H000030000001V0000
IP0001L0IP0000<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`4000000@3oool0
00030?ooo`000000oooo00H0oooo00<000000?ooo`3oool0103oool00`000000IP0006H0000_06H0
00030000001V0000IP0001P0IP0000<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?oo
o`4000000@3oool000030?ooo`000000oooo00H0oooo00<000000?ooo`3oool0103oool00`000000
IP0006H0000^06H000030000001V0000IP0001T0IP0000<000000?ooo`3oool0103oool00`000000
oooo0?ooo`050?ooo`4000000@3oool000030?ooo`000000oooo00H0oooo00<000000?ooo`3oool0
103oool00`000000IP0006H0000^06H000030000001V0000IP0001T0IP0000<000000?ooo`3oool0
103oool00`000000oooo0?ooo`050?ooo`4000000@3oool000030?ooo`000000oooo00H0oooo00<0
00000?ooo`3oool0103ooom>000000H0oooo00<000000?ooo`3oool01@3oool100000040oooo0000
0`3oool000000?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000;BG^@2dUkT0;P2dUkT0
0`000000]9Ni0;BG^@0I0;BG^@030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool1
00000040oooo00000`3oool000000?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000;BG
^@2dUkT0;P2dUkT00`000000]9Ni0;BG^@0I0;BG^@030000003oool0oooo00@0oooo00<000000?oo
o`3oool01@3oool100000040oooo00000`3oool000000?ooo`060?ooo`030000003oool0oooo00@0
ooooCP0000060?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool0
1P3oool00`000000oooo0?ooo`040?ooo`030000001V0000IP0002d0IP0000<0000006H0001V0000
6P1V00000`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0
oooo0000003oool01P3oool00`000000oooo0?ooo`040?ooo`030000001V0000IP0002d0IP0000<0
000006H0001V00006P1V00000`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo0@00
00010?ooo`0000<0oooo0000003oool01P3oool8000002l0IP0000<0000006H0001V00006P1V0008
000000L0oooo0@0000010?ooo`0000<0oooo0000003oool01P3oool00`000000oooo0?ooo`040?oo
o`030000001V0000IP0002d0IP0000<0000006H0001V00006P1V00000`000000oooo0?ooo`040?oo
o`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool01P3oool00`000000
oooo0?ooo`030?ooo`030000001V0000IP0002d0IP0000<0000006H0001V0000701V00000`000000
oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0oooo0000003oool0
1P3oool00`000000oooo0?ooo`030?ooo`030000001V0000IP0002d0IP0000<0000006H0001V0000
701V00000`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000<0
oooo0000003oool01P3oool00`000000oooo0?ooo`030?ooo`030000001V0000IP0002d0IP0000<0
000006H0001V0000701V00000`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo0@00
00010?ooo`0000<0oooo0000003oool01@3oool00`000000oooo0?ooo`040?ooo`030000001V0000
IP0002d0IP0000<0000006H0001V0000701V00000`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo0@0000010?ooo`0000<0oooo0000003oool01@3oool00`000000oooo0?ooo`040?oo
o`030000001V0000IP0002`0IP0000<0000006H0001V00007@1V00000`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo0@0000010?ooo`0000<0oooo0000003oool01@3oool00`000000
oooo0?ooo`040?ooo`030000001V0000IP0002`0IP0000<0000006H0001V00007@1V00000`000000
oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo0@0000010?ooo`0000<0oooo0000003oool0
1@3oool00`000000oooo0?ooo`040?ooo`030000001V0000IP0002`0IP0000<0000006H0001V0000
7@1V00000`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo0@0000010?ooo`0000<0
oooo0000003oool01@3oool00`000000oooo0?ooo`040?ooo`030000001V0000IP0004`0IP0000<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`4000000@3oool000030?ooo`000000
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000IP0006H0001<06H000030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool100000040oooo00000`3oool000000?ooo`050?oo
o`030000003oool0oooo00<0oooo00<0000006H0001V0000CP1V00000`000000oooo0?ooo`030?oo
o`030000003oool0oooo00@0oooo0@0000010?ooo`0000<0oooo0000003oool01@3oool00`000000
oooo0?ooo`030?ooo`030000001V0000IP0004h0IP0000<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`040?ooo`4000000@3oool000030?ooo`000000oooo00D0oooo00<000000?ooo`3oool0
0`3oool00`000000IP0006H0001>06H000030000003oool0oooo00<0oooo00<000000?ooo`3oool0
103oool100000040oooo00000`3oool000000?ooo`040?ooo`030000003oool0oooo00@0oooo00<0
000006H0001V0000CP1V00000`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo0@00
00010?ooo`0000<0oooo0000003oool0103oool00`000000oooo0?ooo`040?oooe8000001P3oool0
0`000000oooo0?ooo`030?ooo`4000000@3oool000030?ooo`000000oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000]9Rj0;BH^P1>0;BH^P030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool100000040oooo00000`3oool000000?ooo`040?ooo`030000003oool0oooo00@0
oooo00<000000;BH^P2dV;X0CP2dV;X00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0
oooo0@0000010?ooo`0000<0oooo0000003oool0103oool00`000000oooo0?ooo`040?ooo`030000
002dV;X0]9Rj04h0]9Rj00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`400000
0@3oool000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool0103oool00`000000]9Rj0;BH
^P1>0;BH^P030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool100000040oooo0000
0`3oool000000?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000;BH^P2dV;X0CP2dV;X0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo0@0000010?ooo`0000<0oooo0000
003oool0103oool00`000000oooo0?ooo`040?ooo`030000002dV;X0]9Rj04h0]9Rj00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`4000000@3oool000030?ooo`000000oooo00@0
oooo00<000000?ooo`3oool0103oool00`000000]9Rj0;BH^P1>0;BH^P030000003oool0oooo00@0
oooo00<000000?ooo`3oool00`3oool100000040oooo00000`3oool000000?ooo`030?ooo`030000
003oool0oooo00D0oooo00<000000;BH^P2dV;X0CP2dV;X00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0080oooo0@0000010?ooo`0000<0oooo0000003oool00`3oool00`000000oooo0?oo
o`050?ooo`030000002dV;X0]9Rj04h0]9Rj00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`020?ooo`4000000@3oool000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool01@3oool0
0`000000]9Rj0;BH^P1>0;BH^P030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool1
00000040oooo00000`3oool000000?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000;BH
^P2dV;X0CP2dV;X00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo0@0000010?oo
o`0000<0oooo0000003oool00`3oool00`000000oooo0?ooo`050?ooo`030000002dV;X0]9Rj04h0
]9Rj00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`4000000@3oool000030?oo
o`000000oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000]9Rj0;BH^P1>0;BH^P030000
003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool100000040oooo00000`3oool000000?oo
o`030?ooo`030000003oool0oooo00D0oooo00<000000;BH^P2dV;X0CP2dV;X00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0080oooo0@0000010?ooo`0000<0oooo0000003oool00`3oool0
0`000000oooo0?ooo`050?ooo`030000002dV;X0]9Rj04h0]9Rj00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`020?ooo`4000000@3oool000030?ooo`000000oooo00<0oooo00<000000?oo
o`3oool01@3oool00`000000]9Rj0;BH^P1>0;BH^P030000003oool0oooo00D0oooo00<000000?oo
o`3oool00P3oool100000040oooo00000`3oool000000?ooo`020?ooo`030000003oool0oooo00H0
oooo00<000000;BH^P2dV;X0CP2dV;X00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?oo
o`0000000@3oool000030?ooo`000000oooo0080oooo00<000000?ooo`3oool01P3oool00`000000
]9Rj0;BH^P1>0;BH^P030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000010?oo
o`0000<0oooo0000003oool00P3oool00`000000oooo0?ooo`060?ooo`030000002dV;X0]9Rj04h0
]9Rj00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool000000040oooo00000`3oool0
00000?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000;BH^P2dV;X0CP2dV;X00`000000
oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000@3oool000030?ooo`000000oooo0080
oooo00<000000?ooo`3oool01P3oool00`000000]9Rj0;BH^P1>0;BH^P030000003oool0oooo00H0
oooo00D000000?ooo`3oool0oooo000000010?ooo`0000<0oooo0000003oool00P3oool00`000000
oooo0?ooo`060?ooo`030000002dV;X0]9Rj04h0]9Rj00<000000?ooo`3oool01P3oool01@000000
oooo0?ooo`3oool000000040oooo00000`3oool000000?ooo`020?ooo`030000003oool0oooo00H0
oooo00<000000;BH^P2dV;X0CP2dV;X00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?oo
o`0000000@3oool000030?ooo`000000oooo0080oooo00<000000?ooo`3oool01P3oool00`000000
]9Rj0;BH^P1>0;BH^P030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000010?oo
o`0000<0oooo0000003oool00P3oool00`000000oooo0?ooo`060?ooo`030000002dV;X0]9Rj04h0
]9Rj00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool000000040oooo00000`3oool0
00000?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000;BH^P2dV;X0CP2dV;X00`000000
oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000@3oool000050?ooo`000000oooo0?oo
o`0000002@3oool00`000000]9Rj0;BH^P1>0;BH^P030000003oool0oooo00L0oooo00@000000?oo
o`3oool000000@3oool000050?ooo`000000oooo0?ooo`0000002@3oool00`000000]9Rj0;BH^P1>
0;BH^P030000003oool0oooo00L0oooo00@000000?ooo`3oool000000@3oool000050?ooo`000000
oooo0?ooo`0000002@3oool00`000000]9Rj0;BH^P1>0;BH^P030000003oool0oooo00L0oooo00@0
00000?ooo`3oool000000@3oool000050?ooo`000000oooo0?ooo`0000002@3oool00`000000]9Rj
0;BH^P1>0;BH^P030000003oool0oooo00L0oooo00@000000?ooo`3oool000000@3oool000050?oo
o`000000oooo0?ooo`0000002@3oool00`000000]9Rj0;BH^P1>0;BH^P030000003oool0oooo00L0
oooo00@000000?ooo`3oool000000@3oool000050?ooo`000000oooo0?ooo`0000002@3oool00`00
0000]9Rj0;BH^P1>0;BH^P030000003oool0oooo00L0oooo00@000000?ooo`3oool000000@3oool0
00050?ooo`000000oooo0?ooo`0000002@3oool00`000000]9Rj0;BH^P1>0;BH^P030000003oool0
oooo00L0oooo00@000000?ooo`3oool000000@3oool000050?ooo`000000oooo0?ooo`0000002@3o
ool00`000000]9Rj0;BH^P1>0;BH^P030000003oool0oooo00L0oooo00@000000?ooo`3oool00000
0@3oool000050?ooo`000000oooo0?ooo`0000002@3oool00`000000]9Rj0;BH^P1>0;BH^P030000
003oool0oooo00L0oooo00@000000?ooo`3oool000000@3oool000040?ooo`000000oooo000000X0
oooo00<000000;BH^P2dV;X0CP2dV;X00`000000oooo0?ooo`080?ooo`030000003oool000000040
oooo0000103oool000000?ooo`00000:0?ooo`030000002dV;X0]9Rj04h0]9Rj00<000000?ooo`3o
ool0203oool00`000000oooo000000010?ooo`0000@0oooo0000003oool000002P3oool00`000000
]9Rj0;BH^P1>0;BH^P030000003oool0oooo00P0oooo00<000000?ooo`0000000@3oool000040?oo
o`000000oooo000000X0oooo00<000000;BH^P2dV;X0CP2dV;X00`000000oooo0?ooo`080?ooo`03
0000003oool000000040oooo0000103oool000000?ooo`00000:0?oooe8000002P3oool00`000000
oooo000000010?ooo`0000@0oooo0000003oool00000IP3oool00`000000oooo000000010?ooo`00
00@0oooo0000003oool00000IP3oool00`000000oooo000000010?ooo`0000@0oooo0000003oool0
0000IP3oool00`000000oooo000000010?ooo`0000@0oooo0000003oool00000IP3oool00`000000
oooo000000010?ooo`0000<0oooo000000000000J03oool200000040oooo00000`3oool000000000
001X0?ooo`8000000@3oool000030?ooo`000000000006P0oooo0P0000010?ooo`0000<0oooo0000
00000000J03oool200000040oooo00000`3oool000000000001X0?ooo`8000000@3oool000030?oo
o`000000000006P0oooo0P0000010?ooo`0000<0oooo000000000000J03oool200000040oooo0000
0`3oool000000000001X0?ooo`8000000@3oool000030?ooo`000000000006P0oooo0P0000010?oo
o`0000<0oooo0000003oool0J@3oool100000040oooo00000`3oool000000?ooo`1Y0?ooo`400000
0@3oool000030?ooo`000000oooo06T0oooo0@0000010?ooo`0000<0oooo0000003oool0J@3oool1
00000040oooo00000`3oool000000000001Z00000040oooo001^0?ooo`00KP3oool00001\
\>"],
  ImageRangeCache->{{{91.5625, 179.313}, {681.688, 159.75}} -> {0.244854, \
0.322277, 0.00150709, 0.00150709}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#5", "Text"],

Cell[CellGroupData[{

Cell["Hz2[[-5]]", "Input"],

Cell[BoxData[
    \(5.525695092690836`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pretty[Chop[e2ni . eigenvectors2[\([\(-5\)]\)], 10^\(-4\)]]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
          {"\<\"optic\"\>", "0", "0", \(-1.`\), "0", "0", "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Status["\<Plotting stage 2 mode 5\>"]\ ; 
    eigenplot[
      eigenvectors2[\([\(-5\)]\)], \(- .2\), {0, \(-1\), \(- .25\)}, \ 
      floatmatrix2]\ ; Done[]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 4.95269 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.04936 5.09872 2.49583e-016 5.09872 [
[ 0 0 0 0 ]
[ 1 4.95269 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
.1333 4.95269 L
s
.1333 4.95269 m
.26075 3.76924 L
s
.26075 3.76924 m
.21037 .65115 L
s
.21037 .65115 m
0 0 L
s
1 0 m
.78963 .65115 L
s
.78963 .65115 m
.73925 3.76924 L
s
.73925 3.76924 m
.8667 4.95269 L
s
.8667 4.95269 m
1 0 L
s
0 0 m
.1333 4.95269 L
s
.1333 4.95269 m
.8667 4.95269 L
s
.8667 4.95269 m
1 0 L
s
1 0 m
0 0 L
s
.21037 .65115 m
.78963 .65115 L
s
.78963 .65115 m
.73925 3.76924 L
s
.73925 3.76924 m
.26075 3.76924 L
s
.26075 3.76924 m
.21037 .65115 L
s
0 0 m
1 0 L
1 4.95269 L
0 4.95269 L
closepath
clip
newpath
.01 w
.4098 4.06034 Mdot
.5902 4.06034 Mdot
.39857 2.25228 Mdot
.60143 2.25228 Mdot
.3962 4.43924 Mdot
.6038 4.43924 Mdot
.38104 2.37406 Mdot
.61896 2.37406 Mdot
.25 Mabswid
0 0 m
.1333 4.95269 L
s
.1333 4.95269 m
.8667 4.95269 L
s
.8667 4.95269 m
1 0 L
s
1 0 m
0 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{133.688, 662.063},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000250002UR000`400?l00000o`00003oQ@3oool0
08D0oooo00250000000000<000000?ooo`3oool0P@3oool1000000000P0000210?ooo`8000000002
00000840oooo0P00000000800000P@3oool20000000000<000000?ooo`000000O`3oool100000040
oooo0@00000000030000003oool0000007l0oooo0@0000010?ooo`40000000000`000000oooo0000
001o0?ooo`4000000@3oool10000000000<000000?ooo`000000OP3oool00`000000oooo0?ooo`01
0000000000@000000?ooo`3oool00000O@3oool00`000000oooo0?ooo`010000000000@000000?oo
o`3oool00000O@3oool00`000000oooo0?ooo`010000000000@000000?ooo`3oool00000O03oool0
10000000oooo0?ooo`3oool10000000000D000000?ooo`3oool0oooo0000001k0?ooo`040000003o
ool0oooo0?ooo`40000000001@000000oooo0?ooo`3oool0000007/0oooo00@000000?ooo`3oool0
oooo0@00000000050000003oool0oooo0?ooo`000000NP3oool00`000000oooo0?ooo`020?ooo`40
000000000`000000oooo0?ooo`020?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0
0P3oool10000000000<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1g0?ooo`030000003o
ool0oooo0080oooo0@00000000030000003oool0oooo0080oooo00<000000?ooo`3oool0M`3oool0
0`000000oooo0?ooo`020?ooo`40000000000`000000oooo0?ooo`030?ooo`030000003oool0oooo
07D0oooo00<000000?ooo`3oool00`3oool10000000000<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`1e0?ooo`030000003oool0oooo00<0oooo0@00000000030?ooo`000000oooo00<0oooo
00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`020?ooo`4000000@3oool000030?ooo`00
0000oooo00@0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`030?ooo`4000000@3o
ool000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`03
0?ooo`4000000@3oool000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool0L`3oool00`00
0000oooo0?ooo`030?ooo`4000000@3oool000030?ooo`000000oooo00@0oooo00<000000?ooo`3o
ool0LP3oool00`000000oooo0?ooo`040?ooo`4000000@3oool000030?ooo`000000oooo00D0oooo
00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`040?ooo`4000000@3oool000030?ooo`00
0000oooo00D0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`040?ooo`4000000@3o
ool000030?ooo`000000oooo00D0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`05
0?ooo`4000000@3oool000030?ooo`000000oooo00H0oooo00<000000?ooo`3oool0K`3oool00`00
0000oooo0?ooo`050?ooo`4000000@3oool000030?ooo`000000oooo00H0oooo00<000000?ooo`3o
ool0K`3oool00`000000oooo0?ooo`050?ooo`4000000@3oool000030?ooo`000000oooo00H0oooo
00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`060?ooo`4000000@3oool000030?ooo`00
0000oooo00L0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`060?ooo`4000000@3o
ool000030?ooo`000000oooo00L0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`06
0?ooo`4000000@3oool000030?ooo`000000oooo00L0oooo00<000000?ooo`3oool0K03oool00`00
0000oooo0?ooo`070?ooo`4000000@3oool000030?ooo`000000oooo00P0oooo00<000000?ooo`3o
ool0J`3oool00`000000oooo0?ooo`070?ooo`4000000@3oool000030?ooo`000000oooo00P0oooo
00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`070?ooo`4000000@3oool000030?ooo`00
0000oooo00P0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`080?ooo`4000000@3o
ool000030?ooo`000000oooo00P0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`08
0?ooo`4000000@3oool000030?ooo`000000oooo00T0oooo00<000000?ooo`3oool0J@3oool00`00
0000oooo0?ooo`080?ooo`4000000@3oool000030?ooo`000000oooo00T0oooo00<000000?ooo`3o
ool0J03oool00`000000oooo0?ooo`090?ooo`4000000@3oool000030?ooo`000000oooo00T0oooo
00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`090?ooo`4000000@3oool000030?ooo`00
0000oooo00X0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`090?ooo`4000000@3o
ool000030?ooo`000000oooo00X0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0:
0?ooo`4000000@3oool000030?ooo`000000oooo00X0oooo00<000000?ooo`3oool0IP3oool00`00
0000oooo0?ooo`0:0?ooo`4000000@3oool000030?ooo`000000oooo00/0oooo00<000000?ooo`3o
ool0I@3oool00`000000oooo0?ooo`0:0?ooo`4000000@3oool000030?ooo`000000oooo00/0oooo
00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0:0?ooo`4000000@3oool000030?ooo`00
0000oooo00/0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0;0?ooo`4000000@3o
ool000030?ooo`000000oooo00`0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0;
0?ooo`4000000@3oool000030?ooo`000000oooo00`0oooo00<000000?ooo`3oool0H`3oool00`00
0000oooo0?ooo`0;0?ooo`4000000@3oool000030?ooo`000000oooo00`0oooo00<000000?ooo`3o
ool0HP3oool00`000000oooo0?ooo`0<0?ooo`4000000@3oool000030?ooo`000000oooo00d0oooo
00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0<0?ooo`4000000@3oool000030?ooo`00
0000oooo00d0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0<0?ooo`4000000@3o
ool000030?ooo`000000oooo00d0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0=
0?ooo`4000000@3oool000030?ooo`000000oooo00d0oooo00<000000?ooo`3oool0H03oool00`00
0000oooo0?ooo`0=0?ooo`4000000@3oool000030?ooo`000000oooo00h0oooo00<000000?ooo`3o
ool0G`3oool00`000000oooo0?ooo`0=0?ooo`4000000@3oool000030?ooo`000000oooo00h0oooo
00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0>0?ooo`4000000@3oool000030?ooo`00
0000oooo00h0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0>0?ooo`4000000@3o
ool000030?ooo`000000oooo00l0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`0>
0?ooo`4000000@3oool000030?ooo`000000oooo00l0oooo00<000000?ooo`3oool0G03oool00`00
0000oooo0?ooo`0?0?ooo`4000000@3oool00080oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`1L0?ooo`030000003oool0oooo00h0oooo0@0000010?ooo`40oooo00020?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0>0?ooo`400000
0@3oool10?ooo`000P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo05X0oooo00<0
00000?ooo`3oool03`3oool100000040oooo0@3oool00080oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00l0oooo0@0000010?ooo`40oooo00020?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0?0?oo
o`4000000@3oool10?ooo`000P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool0403oool100000040oooo0@3oool00080oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0100oooo0@0000010?ooo`40oooo
00020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`0@0?ooo`4000000@3oool10?ooo`000P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo05H0oooo00<000000?ooo`3oool04@3oool100000040oooo0@3oool00080oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0140oooo0@0000010?oo
o`40oooo00020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`0A0?ooo`4000000@3oool10?ooo`000P3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo05@0oooo00<000000?ooo`3oool04P3oool100000040oooo0@3oool00080oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo0@00
00010?ooo`40oooo00020?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0E03oool0
0`000000oooo0?ooo`0B0?ooo`4000000@3oool10?ooo`000P3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo05<0oooo00<000000?ooo`3oool04P3oool100000040oooo0@3oool00080
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo01<0
oooo0@0000010?ooo`40oooo00020?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
DP3oool00`000000oooo0?ooo`0C0?ooo`4000000@3oool10?ooo`000P3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool04`3oool100000040oooo0@3o
ool00080oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0
oooo01@0oooo0@0000010?ooo`40oooo00020?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0D03oool00`000000oooo0?ooo`0D0?ooo`4000000@3oool10?ooo`000P3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0503oool100000040
oooo0@3oool00080oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1>0?ooo`030000
003oool0oooo01D0oooo0@0000010?ooo`40oooo00020?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool0CP3oool00`000000oooo0?ooo`0E0?ooo`4000000@3oool10?ooo`000P3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool05@3oool1
00000040oooo0@3oool00080oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1<0?oo
o`030000003oool0oooo01H0oooo0@0000010?ooo`40oooo00020?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0F0?ooo`4000000@3oool10?ooo`00
0P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0
5P3oool100000040oooo0@3oool00080oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`1:0?ooo`030000003oool0oooo01L0oooo0@0000010?ooo`40oooo00020?ooo`030000003oool0
oooo01H0ooooCP00000I0?ooo`4000000@3oool10?ooo`000P3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo04X0oooo00<000000?ooo`3oool05`3oool100000040oooo0@3oool00080
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo01L0
oooo0@0000010?ooo`40oooo00020?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
BP3oool00`000000oooo0?ooo`0G0?ooo`4000000@3oool10?ooo`000P3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool05`3oool100000040oooo0@3o
ool00080oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0
oooo01L0oooo0@0000010?ooo`40oooo00020?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool0BP3oool00`000000oooo0?ooo`0G0?ooo`4000000@3oool10?ooo`000P3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool05`3oool100000040
oooo0@3oool00080oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1:0?ooo`030000
003oool0oooo01L0oooo0@0000010?ooo`40oooo00020?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool0BP3oool00`000000oooo0?ooo`0G0?ooo`4000000@3oool10?ooo`000`3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
04X0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`010?ooo`000`3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`010?ooo`000`3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`010?ooo`000`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04X0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo04X0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`010?oo
o`000`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo04X0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`010?ooo`000`3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo04X0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`010?ooo`000`3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04X0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`010?ooo`000`3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04X0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`01
0?ooo`000`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04X0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo04X0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`010?ooo`00
0`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo04X0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`010?ooo`000`3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
04T0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`010?ooo`000`3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04T0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`010?ooo`000`3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`010?ooo`000`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04P0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo04P0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`010?oo
o`000`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo04P0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`010?ooo`000`3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo04P0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`010?ooo`000`3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04P0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`010?ooo`000`3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04P0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`01
0?ooo`000`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04P0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`010?ooo`000`3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo04P0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`010?ooo`00
0`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`010?ooo`00103oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo04P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`00103oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
04P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04P0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`020?ooo`00103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04P0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo04P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`020?oo
o`00103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo04P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`00103o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo04P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`00103oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04P0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04P0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`02
0?ooo`00103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04P0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo04P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`00
103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo04P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`00103oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
04P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04P0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`020?ooo`00103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04P0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo04P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`020?oo
o`00103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo04P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`00103o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo04P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`00103oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04P0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04P0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`02
0?ooo`00103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04P0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`020?ooo`00103oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo04P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`00
1@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo04L0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`030?ooo`001@3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
04L0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`030?ooo`001@3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04L0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`030?ooo`001@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04L0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo04L0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`030?oo
o`001@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo04L0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`030?ooo`001@3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo04L0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`030?ooo`001@3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04L0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04H0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`03
0?ooo`001@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04H0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo04H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`030?ooo`00
1@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo04H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`030?ooo`001@3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
04H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`030?ooo`001@3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04H0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`030?ooo`001@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo04H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`030?oo
o`001@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo04H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`030?ooo`001@3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo04H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`030?ooo`001@3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04H0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04H0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`03
0?ooo`001P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04H0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo04H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`00
1P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo04H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`001P3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
04H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`040?ooo`001P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo04H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?oo
o`001P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo04H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`001P3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo04H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`001P3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04H0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04H0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`04
0?ooo`001P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04H0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo04H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`00
1P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo04D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`001P3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
04D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04D0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`040?ooo`001P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04D0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo04D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?oo
o`001P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo04D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`001P3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo04D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`001P3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04D0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`001P3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`040?ooo`001P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04D0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`001`3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`05
0?ooo`001`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04D0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo04D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00
1`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo04D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`001`3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
04D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04@0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`050?ooo`001`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo04@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?oo
o`001`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo04@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`001`3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo04@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04@0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04@0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`05
0?ooo`001`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04@0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo04@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`00
1`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo04@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`001`3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
04@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04@0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`050?ooo`001`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo04@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?oo
o`001`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo04@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`001`3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo04@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04@0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`050?ooo`00203oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo04@0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`060?ooo`00203oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`06
0?ooo`00203oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo04@0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`060?ooo`00203oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo04@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`060?ooo`00
203oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`060?ooo`00203oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo04<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`060?ooo`00203oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`060?ooo`00203oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool01P3oool000P0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`130?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01P3oool000P0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool01P3oool000P0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`130?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01P3oool000P0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool01P3oool000P0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`130?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool01P3oool000P0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool01P3oool000P0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`130?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool01P3oool000P0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`130?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01P3o
ool000P0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`130?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool01P3oool000P0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`130?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01P3oool000P0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool01P3oool000P0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`130?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01P3oool000P0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool01P3oool000P0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`13
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01P3oool000P0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool01P3oool000P0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`130?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool01P3oool000P0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00H0oooo00080?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00H0oooo00080?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0@`3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00H0oooo00080?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
00H0oooo00080?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0@`3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo00H0oooo00080?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00H0oooo
00080?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo00H0oooo00080?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00H0oooo00080?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo00H0oooo00080?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool0@`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00H0oooo00080?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo00H0oooo00080?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0@`3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00H0oooo00080?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo00H0oooo00080?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0@`3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo00H0oooo00080?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00L0
oooo00090?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0@P3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo00L0oooo00090?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0@P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00L0oooo0009
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo00L0oooo00090?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0@P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00L0oooo00090?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo00L0oooo00090?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
@P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00L0oooo00090?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00L0oooo00090?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0@P3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00L0oooo00090?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
00L0oooo00090?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0@P3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo00L0oooo00090?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00L0oooo
00090?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo00L0oooo00090?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0@P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00L0oooo00090?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo00L0oooo00090?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool0@P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00L0oooo00090?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo00L0oooo00090?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00L0oooo00090?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo00L0oooo00090?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo00L0oooo00090?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00L0
oooo00090?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0@P3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo00L0oooo00090?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0@P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00L0oooo0009
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo00L0oooo00090?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0@P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00L0oooo00090?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo00L0oooo00090?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
@@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00L0oooo00090?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00L0oooo00090?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0@@3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00L0oooo00090?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
00L0oooo00090?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo00L0oooo00090?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00L0oooo
00090?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo00L0oooo00090?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool0@@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00L0oooo00090?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo00L0oooo00090?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool0@@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00L0oooo00090?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo00L0oooo00090?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0@@3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00L0oooo00090?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo00L0oooo000:0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0@@3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo000:0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0
oooo000:0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0@@3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo00P0oooo000:0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0@@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo000:
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo00P0oooo000:0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0@@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo000:0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo00P0oooo000:0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
@@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo000:0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo00P0oooo000:0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0@@3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo000:0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
00P0oooo000:0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo000:0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo
000:0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo00P0oooo000:0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0@@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo000:0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo00P0oooo000:0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool0@@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo000:0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo00P0oooo000:0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0@@3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo000:0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo00P0oooo000:0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0@@3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo000:0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0
oooo000:0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0@@3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo00P0oooo000:0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0@@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo000:
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo00P0oooo000:0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0@@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo000:0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo00P0oooo000:0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
@@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo000:0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo00P0oooo000:0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0@@3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo000:0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
00P0oooo000:0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0@03oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo00P0oooo000:0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00P0oooo
000:0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo00P0oooo000:0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0@03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00P0oooo000:0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo00P0oooo000:0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool0@03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00P0oooo000:0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo00P0oooo000:0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00P0oooo000;0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo00T0oooo000;0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0@03oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo00T0oooo000;0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00T0
oooo000;0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0@03oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo00T0oooo000;0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00T0oooo000;
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo00T0oooo000;0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0?`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00T0oooo000;0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo00T0oooo000;0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00T0oooo000;0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo00T0oooo000;0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0?`3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00T0oooo000;0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
00T0oooo000;0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0?`3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo00T0oooo000;0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00T0oooo
000;0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo00T0oooo000;0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0?`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00T0oooo000;0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo00T0oooo000;0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool0?`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00T0oooo000;0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo00T0oooo000;0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00T0oooo000;0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo00T0oooo000;0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0?`3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo00T0oooo000;0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00T0
oooo000;0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo00T0oooo000;0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0?`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00T0oooo000;
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo00T0oooo000;0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0?`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00T0oooo000;0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo00T0oooo000;0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00T0oooo000;0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo00T0oooo000;0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0?`3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00T0oooo000;0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
00T0oooo000;0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0?`3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo00T0oooo000;0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00T0oooo
000;0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo00T0oooo000;0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0?`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00T0oooo000;0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo00T0oooo000;0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool0?`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00T0oooo000;0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo00T0oooo000<0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00X0oooo000<0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo00X0oooo000<0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0?`3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00X0oooo000<0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00X0
oooo000<0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0?`3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo00X0oooo000<0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0?`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00X0oooo000<
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo00X0oooo000<0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool0?`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00X0oooo000<0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo00X0oooo000<0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00X0oooo000<0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo00X0oooo000<0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0?`3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00X0oooo000<0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00X0oooo000<0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0?`3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo00X0oooo000<0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00X0oooo
000<0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo00X0oooo000<0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool0?`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00X0oooo000<0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo00X0oooo000<0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool0?`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00X0oooo000<0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo00X0oooo000<0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00X0oooo000<0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo00X0oooo000<0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0?P3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo00X0oooo000<0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00X0
oooo000<0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0?P3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo00X0oooo000<0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0?P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00X0oooo000<
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo00X0oooo000<0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0?@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00X0oooo000<0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo00X0oooo000<0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
?@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00X0oooo000<0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo00X0oooo000<0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0?@3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00X0oooo000<0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
00X0oooo000<0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0?@3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo00X0oooo000<0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00X0oooo
000<0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo00X0oooo000<0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0?@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00X0oooo000<0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo00X0oooo000=0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00/0oooo000=0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo00/0oooo000=0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0?@3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00/0oooo000=0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo00/0oooo000=0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0?@3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00/0oooo000=0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00/0
oooo000=0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0?@3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo00/0oooo000=0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0?@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00/0oooo000=
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo00/0oooo000=0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool0?@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00/0oooo000=0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo00/0oooo000=0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
?@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00/0oooo000=0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo00/0oooo000=0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0?@3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00/0oooo000=0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00/0oooo000=0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0?@3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo00/0oooo000=0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00/0oooo
000=0?ooo`030000003oool0oooo0180oooo@@00000D0?ooo`030000003oool0oooo00/0oooo000=
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo00/0oooo000=0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool0?@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00/0oooo000=0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo00/0oooo000=0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
?@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00/0oooo000=0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo00/0oooo000=0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0?`3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00/0oooo000=0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
00/0oooo000=0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0?`3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo00/0oooo000=0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00/0oooo
000=0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo00/0oooo000=0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0?`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00/0oooo000=0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo00/0oooo000=0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool0?`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00/0oooo000=0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo00/0oooo000=0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0@@3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00/0oooo000=0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo00/0oooo000=0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0@@3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo00/0oooo000=0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00/0
oooo000=0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0@@3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo00/0oooo000=0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0@@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00/0oooo000=
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00/0oooo000>0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0@@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00`0oooo000>0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00`0oooo000>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
@`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00`0oooo000>0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00`0oooo000>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0@`3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00`0oooo000>0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00`0oooo000>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0@`3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00`0oooo000>0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00`0oooo
000>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00`0oooo000>0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00`0oooo000>0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00`0oooo000>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo000>0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00`0oooo000>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0A@3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo000>0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00`0oooo000>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0<0?ooo`003P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04D0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`003P3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0<0?ooo`003P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04D0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`003P3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<
0?ooo`003P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo04L0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0<0?ooo`003P3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo04L0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`00
3P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0<0?ooo`003P3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo04L0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`003P3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0<0?ooo`003P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
04L0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`003P3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0<0?ooo`003P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo04L0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`003P3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0<0?ooo`003P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo04T0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`003P3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo04T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?oo
o`003P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0<0?ooo`003P3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo04T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`003P3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0<0?ooo`003P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo04T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`003P3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0<0?ooo`003P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo04T0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`003P3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0<0?ooo`003P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo04T0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`003`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0=
0?ooo`003`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo04/0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0=0?ooo`003`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo04/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0=0?ooo`00
3`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0=0?ooo`003`3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0=0?ooo`003`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0=0?ooo`003`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
04/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0=0?ooo`003`3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0=0?ooo`003`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo04/0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0=0?ooo`003`3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0=0?ooo`003`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo04d0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`003`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo04d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?oo
o`003`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0=0?ooo`003`3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo04d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`003`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0=0?ooo`003`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo04d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`003`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0=0?ooo`003`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo04d0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`003`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0=0?ooo`003`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`003`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=
0?ooo`003`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo04l0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`003`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`00
3`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0=0?ooo`003`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo04l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`003`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0=0?ooo`003`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
04l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`003`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool000l0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool03@3oool000l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`1A0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool000l0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool03@3oool000l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1A0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool000l0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool03@3oool000l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1A0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool000l0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3o
ool000l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool03@3oool000l0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`1C0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03@3oool000l0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool03@3oool00100oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`1C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03P3oool00100oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool03P3oool00100oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1C
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03P3oool00100oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool03P3oool00100oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1C0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool03P3oool00100oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
3P3oool00100oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1C0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool03P3oool00100oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`1C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03P3oool0
0100oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool03P3oool00100oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`1E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03P3oool00100oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool03P3oool00100oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`1E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03P3oool00100oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool03P3oool00100oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1E0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool03P3oool00100oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool03P3oool00100oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1E0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool03P3oool00100oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03P3o
ool00100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool03P3oool00100oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`1G0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03P3oool00100
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool03P3oool00100oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`1G0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03P3oool00100oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool03P3oool00100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03P3oool00100oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool03P3oool00100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool03P3oool00100oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
3P3oool00100oooo00D000000?ooo`3oool0oooo0000001K0?ooo`050000003oool0oooo0?ooo`00
0000403oool00100oooo00D000000?ooo`3oool0oooo0000001K0?ooo`050000003oool0oooo0?oo
o`000000403oool00100oooo00D000000?ooo`3oool0oooo0000001K0?ooo`050000003oool0oooo
0?ooo`000000403oool00100oooo00D000000?ooo`3oool0oooo0000001K0?ooo`050000003oool0
oooo0?ooo`000000403oool00100oooo00D000000?ooo`3oool0oooo0000001K0?ooo`050000003o
ool0oooo0?ooo`000000403oool00100oooo00D000000?ooo`3oool0oooo0000001K0?ooo`050000
003oool0oooo0?ooo`000000403oool00100oooo00D000000?ooo`3oool0oooo0000001K0?ooo`05
0000003oool0oooo0?ooo`000000403oool00100oooo00D000000?ooo`3oool0oooo0000001K0?oo
o`050000003oool0oooo0?ooo`000000403oool00100oooo00D000000?ooo`3oool0oooo0000001K
0?ooo`050000003oool0oooo0?ooo`000000403oool00100oooo00@000000?ooo`3oool00000G@3o
ool010000000oooo0?ooo`00000@0?ooo`00403oool010000000oooo0?ooo`00001M0?ooo`040000
003oool0oooo00000100oooo000@0?ooo`040000003oool0oooo000005d0oooo00@000000?ooo`3o
ool00000403oool00100oooo00@000000?ooo`3oool00000G@3oool010000000oooo0?ooo`00000@
0?ooo`004@3oool00`000000oooo0000001M0?ooo`030000003oool000000140oooo000A0?ooo`03
0000003oool0000005d0oooo00<000000?ooo`0000004@3oool00140oooo00<000000?ooo`000000
G@3oool00`000000oooo0000000A0?ooo`004@3oool00`000000oooo0000001M0?ooo`030000003o
ool000000140oooo000A0?ooo`030000003oool0000005d0oooo00<000000?ooo`0000004@3oool0
0140oooo00<000000?ooo`000000G@3oool00`000000oooo0000000A0?ooo`004@3oool2000005l0
oooo0P00000A0?ooo`004@3oool2000005l0oooo0P00000A0?ooo`004@3oool2000005l0oooo0P00
000A0?ooo`004@3oool2000005l0oooo0P00000A0?ooo`004@3oool2000005l0oooo0P00000A0?oo
o`004@3oool2000005l0oooo0P00000A0?ooo`004@3oool2000005l0oooo0P00000A0?ooo`004@3o
ool2000005l0oooo0P00000A0?ooo`004@3oool2000005l0oooo0P00000A0?ooo`004@3oool00`00
0000oooo0?ooo`1O0?ooo`030000003oool0oooo00l0oooo000A0?ooo`030000003oool0oooo05l0
oooo00<000000?ooo`3oool03`3oool00140oooo00<000000?ooo`3oool0G`3oool00`000000oooo
0?ooo`0?0?ooo`004@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo00l0oooo000A
0?ooof<000004@3oool008D0oooo0000\
\>"],
  ImageRangeCache->{{{91.5625, 197.5}, {753.5, 224.875}} -> {0.232419, \
0.412666, 0.0014811, 0.0014811}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["#6", "Text"],

Cell[CellGroupData[{

Cell["Hz2[[-6]]", "Input"],

Cell[BoxData[
    \(7.929884455271951`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pretty[Chop[e2ni . eigenvectors2[\([\(-6\)]\)], 10^\(-4\)]]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"x\"\>", "\<\"y\"\>", "\<\"z\"\>", "\<\"yaw\"\>", \
"\<\"pitch\"\>", "\<\"roll\"\>"},
          {"\<\"optic\"\>", "0", "0.004796342028408928`", "0", "0", 
            "0", \(-0.9999884974854193`\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Status["\<Plotting stage 2 mode 6\>"]\ ; 
    eigenplot[
      eigenvectors2[\([\(-6\)]\)], \(- .2\), {\(-1\), 0, \(- .25\)}, \ 
      floatmatrix2]\ ; Done[]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.71311 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.430632 1.86126 4.66207e-018 1.86126 [
[ 0 0 0 0 ]
[ 1 1.71311 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
1 0 m
.8868 1.71311 L
s
.8868 1.71311 m
.1132 1.71311 L
s
.1132 1.71311 m
0 0 L
s
0 0 m
1 0 L
s
.91844 .08415 m
.08156 .08415 L
s
.08156 .08415 m
.16388 1.55624 L
s
.16388 1.55624 m
.83612 1.55624 L
s
.83612 1.55624 m
.91844 .08415 L
s
1 0 m
.8868 1.71311 L
s
.8868 1.71311 m
.83612 1.55624 L
s
.83612 1.55624 m
.91844 .08415 L
s
.91844 .08415 m
1 0 L
s
0 0 m
.08156 .08415 L
s
.08156 .08415 m
.16388 1.55624 L
s
.16388 1.55624 m
.1132 1.71311 L
s
.1132 1.71311 m
0 0 L
s
0 0 m
1 0 L
1 1.71311 L
0 1.71311 L
closepath
clip
newpath
.5 Mabswid
.689 .691 .846 r
.44299 1.57093 m .48509 1.57093 L .485 1.5338 L p F P
0 g
s
.715 .584 .008 r
.485 1.5338 m .48509 1.57093 L .48379 1.66269 L p F P
0 g
s
.8 .653 .099 r
.2893 1.66269 m .30616 1.57093 L p .28201 1.65358 L F P
0 g
s
.8 .653 .099 r
.30616 1.57093 m .30496 1.5338 L .28201 1.65358 L p F P
0 g
s
.689 .691 .846 r
.30496 1.5338 m .30616 1.57093 L .44299 1.57093 L p F P
0 g
s
.689 .691 .846 r
.485 1.5338 m .30496 1.5338 L p .44299 1.57093 L F P
0 g
s
0 0 .099 r
.6978 1.44854 m .69384 1.57093 L .69873 1.59756 L p F P
0 g
s
.689 .691 .846 r
.51522 1.44854 m .51491 1.57093 L .55701 1.57093 L p F P
0 g
s
0 0 .008 r
.51529 1.59756 m .51491 1.57093 L p .51703 1.56002 L F P
0 g
s
0 0 .008 r
.51491 1.57093 m .51522 1.44854 L .51703 1.56002 L p F P
0 g
s
.689 .691 .846 r
.55701 1.57093 m .69384 1.57093 L .6978 1.44854 L p F P
0 g
s
.689 .691 .846 r
.6978 1.44854 m .51522 1.44854 L p .55701 1.57093 L F P
0 g
s
.421 0 0 r
.30496 1.5338 m .485 1.5338 L .48323 1.65358 L p F P
0 g
s
.421 0 0 r
.48323 1.65358 m .28201 1.65358 L .30496 1.5338 L p F P
0 g
s
.715 .584 .008 r
.48323 1.65358 m .485 1.5338 L p .48379 1.66269 L F P
0 g
s
0 0 .099 r
.72144 1.56002 m .6978 1.44854 L p .69873 1.59756 L F P
0 g
s
.393 0 0 r
.51522 1.44854 m .6978 1.44854 L .72144 1.56002 L p F P
0 g
s
.393 0 0 r
.72144 1.56002 m .51703 1.56002 L .51522 1.44854 L p F P
0 g
s
0 0 .099 r
.69873 1.59756 m .7165 1.69422 L .72144 1.56002 L p F P
0 g
s
0 0 .008 r
.51703 1.56002 m .51665 1.69422 L .51529 1.59756 L p F P
0 g
s
.61095 1.58547 m
.61823 1.56002 L
s
.715 .584 .008 r
.48379 1.66269 m .48335 1.69422 L .48323 1.65358 L p F P
0 g
s
.8 .653 .099 r
.28201 1.65358 m .2835 1.69422 L .2893 1.66269 L p F P
0 g
s
.287 0 0 r
.55289 1.29357 m .55034 1.25598 L .48097 1.25872 L p F P
0 g
s
.287 0 0 r
.48097 1.25872 m .48 1.29644 L .55289 1.29357 L p F P
0 g
s
.483 0 0 r
.48 1.29644 m .48097 1.25872 L .41386 1.24153 L p F P
0 g
s
.075 0 0 r
.62171 1.27009 m .61581 1.2335 L .55034 1.25598 L p F P
0 g
s
.075 0 0 r
.55034 1.25598 m .55289 1.29357 L .62171 1.27009 L p F P
0 g
s
.483 0 0 r
.41386 1.24153 m .40948 1.27847 L .48 1.29644 L p F P
0 g
s
.647 .091 0 r
.40948 1.27847 m .41386 1.24153 L .35504 1.20577 L p F P
0 g
s
0 0 0 r
.68026 1.22788 m .67146 1.19312 L .61581 1.2335 L p F P
0 g
s
0 0 0 r
.61581 1.2335 m .62171 1.27009 L .68026 1.22788 L p F P
0 g
s
.647 .091 0 r
.35504 1.20577 m .34762 1.2411 L .40948 1.27847 L p F P
0 g
s
.765 .293 0 r
.34762 1.2411 m .35504 1.20577 L .30999 1.15439 L p F P
0 g
s
0 0 0 r
.723 1.17041 m .71202 1.13819 L .67146 1.19312 L p F P
0 g
s
0 0 0 r
.67146 1.19312 m .68026 1.22788 L .723 1.17041 L p F P
0 g
s
.63509 1.50114 m
.71906 1.2078 L
s
.765 .293 0 r
.30999 1.15439 m .30017 1.18737 L .34762 1.2411 L p F P
0 g
s
.28188 1.23507 m
.37029 1.59036 L
s
.822 .481 0 r
.30017 1.18737 m .30999 1.15439 L .28323 1.09182 L p F P
0 g
s
0 0 0 r
.74551 1.10268 m .7333 1.07349 L .71202 1.13819 L p F P
0 g
s
0 0 0 r
.71202 1.13819 m .723 1.17041 L .74551 1.10268 L p F P
0 g
s
.71906 1.2078 m
.74526 1.11625 L
s
.684 .704 .862 r
.43633 1.69422 m .2835 1.69422 L p .48323 1.65358 L F P
0 g
s
.684 .704 .862 r
.2835 1.69422 m .28201 1.65358 L .48323 1.65358 L p F P
0 g
s
.684 .704 .862 r
.48323 1.65358 m .48335 1.69422 L .43633 1.69422 L p F P
0 g
s
.684 .704 .862 r
.56367 1.69422 m .51665 1.69422 L p .72144 1.56002 L F P
0 g
s
.684 .704 .862 r
.51665 1.69422 m .51703 1.56002 L .72144 1.56002 L p F P
0 g
s
.684 .704 .862 r
.72144 1.56002 m .7165 1.69422 L .56367 1.69422 L p F P
0 g
s
.822 .481 0 r
.28323 1.09182 m .27192 1.12187 L .30017 1.18737 L p F P
0 g
s
.25587 1.13052 m
.28188 1.23507 L
s
.808 .636 .081 r
.27192 1.12187 m .28323 1.09182 L .27786 1.02373 L p F P
0 g
s
0 0 .125 r
.74497 1.03091 m .73266 1.00502 L .7333 1.07349 L p F P
0 g
s
0 0 .125 r
.7333 1.07349 m .74551 1.10268 L .74497 1.03091 L p F P
0 g
s
.74526 1.11625 m
.76942 1.03186 L
s
.808 .636 .081 r
.27786 1.02373 m .26614 1.05052 L .27192 1.12187 L p F P
0 g
s
.719 .737 .222 r
.26614 1.05052 m .27786 1.02373 L .29507 .9567 L p F P
0 g
s
0 0 .264 r
.7207 .96213 m .7095 .93948 L .73266 1.00502 L p F P
0 g
s
0 0 .264 r
.73266 1.00502 m .74497 1.03091 L .7207 .96213 L p F P
0 g
s
.719 .737 .222 r
.29507 .9567 m .28414 .98021 L .26614 1.05052 L p F P
0 g
s
0 0 0 r
.28414 .98021 m .29507 .9567 L .33379 .8976 L p F P
0 g
s
.601 .139 0 r
.67445 .90354 m .66552 .88369 L .7095 .93948 L p F P
0 g
s
.601 .139 0 r
.7095 .93948 m .7207 .96213 L .67445 .90354 L p F P
0 g
s
0 0 0 r
.33379 .8976 m .32484 .91815 L .28414 .98021 L p F P
0 g
s
0 0 0 r
.32484 .91815 m .33379 .8976 L .39052 .8528 L p F P
0 g
s
.489 0 0 r
.61055 .86156 m .60486 .84376 L .66552 .88369 L p F P
0 g
s
.489 0 0 r
.66552 .88369 m .67445 .90354 L .61055 .86156 L p F P
0 g
s
0 0 0 r
.38458 .87107 m .39052 .8528 L .45958 .82736 L p F P
0 g
s
0 0 0 r
.39052 .8528 m .38458 .87107 L .32484 .91815 L p F P
0 g
s
.317 0 0 r
.53552 .84101 m .53368 .82422 L .60486 .84376 L p F P
0 g
s
.317 0 0 r
.60486 .84376 m .61055 .86156 L .53552 .84101 L p F P
0 g
s
0 0 0 r
.45958 .82736 m .45738 .84431 L .38458 .87107 L p F P
0 g
s
.104 0 0 r
.45738 .84431 m .45958 .82736 L .53368 .82422 L p F P
0 g
s
.104 0 0 r
.53368 .82422 m .53552 .84101 L .45738 .84431 L p F P
0 g
s
.01 w
.6325 .8227 Mdot
.3675 .8227 Mdot
.63972 .83941 Mdot
.36028 .83941 Mdot
.25 Mabswid
1 0 m
.8868 1.71311 L
s
.8868 1.71311 m
.1132 1.71311 L
s
.1132 1.71311 m
0 0 L
s
0 0 m
1 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{203.375, 348.375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003;0001G2000`400?l00000o`00003ob`000000
00800000a`3oool20000000000<000000?ooo`000000a@3oool100000040oooo0@00000000040000
003oool0oooo00000<<0oooo00<000000?ooo`3oool00@00000000050000003oool0oooo0?ooo`00
0000`@3oool010000000oooo0?ooo`3oool10000000000<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`2m0?ooo`030000003oool0oooo0080oooo0@00000000030000003oool0oooo00<0oooo
00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`030?ooo`40000000000`000000oooo0?oo
o`040?ooo`030000003oool0oooo0;T0oooo00<000000?ooo`3oool0103oool10000000000<0oooo
0000003oool01@3oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo00@0oooo0@000001
0?ooo`0000<0oooo0000003oool01@3oool00`000000oooo0?ooo`2f0?ooo`030000003oool0oooo
00D0oooo0@0000010?ooo`0000<0oooo0000003oool01P3oool00`000000oooo0?ooo`2d0?ooo`03
0000003oool0oooo00H0oooo0@0000010?ooo`0000<0oooo0000003oool01`3oool00`000000oooo
0?ooo`2b0?ooo`030000003oool0oooo00L0oooo0@0000010?ooo`0000<0oooo0000003oool0203o
ool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo00P0oooo0@0000010?ooo`0000<0oooo
0000003oool02@3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo00T0oooo0@000001
0?ooo`0000<0oooo0000003oool02P3oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo
00X0oooo0@0000010?ooo`0000<0oooo0000003oool02`3oool00`000000oooo0?ooo`2Z0?ooo`03
0000003oool0oooo00/0oooo0@0000010?ooo`0000<0oooo0000003oool0303oool00`000000oooo
0?ooo`2X0?ooo`030000003oool0oooo00`0oooo0@0000010?ooo`0000<0oooo0000003oool03@3o
oonZ000000l0oooo0@0000010?ooo`0000<0oooo0000003oool03@3oool00`000000oooo0?ooo`2V
0?ooo`030000003oool0oooo00d0oooo0@0000010?ooo`0000<0oooo0000003oool03@3oool00`00
0000oooo0?ooo`2V0?ooo`030000003oool0oooo00d0oooo0@0000010?ooo`0000<0oooo0000003o
ool03@3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo00d0oooo0@0000010?ooo`00
00<0oooo0000003oool03@3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo00d0oooo
0@0000010?ooo`0000<0oooo0000003oool03@3oool00`000000oooo0?ooo`2V0?ooo`030000003o
ool0oooo00d0oooo0@0000010?ooo`0000<0oooo0000003oool03@3oool00`000000oooo0?ooo`2V
0?ooo`030000003oool0oooo00`0oooo0@0000010?ooo`40oooo00020?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`0<0?ooo`4000000@3oool10?oo
o`000P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3o
ool0303oool100000040oooo0@3oool00080oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`2U0?ooo`030000003oool0oooo00`0oooo0@0000010?ooo`40oooo00020?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0=0?ooo`4000000@3o
ool10?ooo`000P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0:@0oooo00<00000
0?ooo`3oool03@3oool100000040oooo0@3oool00080oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo00d0oooo0@0000010?ooo`40oooo00020?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0=0?ooo`40
00000@3oool10?ooo`000P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0:@0oooo
00<000000?ooo`3oool03@3oool100000040oooo0@3oool00080oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo00d0oooo0@0000010?ooo`40oooo0002
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0=
0?ooo`4000000@3oool10?ooo`000P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
0:@0oooo00<000000?ooo`3oool03@3oool100000040oooo0@3oool00080oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo00d0oooo0@0000010?ooo`40
oooo00020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0Y03oool00`000000oooo
0?ooo`0=0?ooo`4000000@3oool10?ooo`000P3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo0:@0oooo00<000000?ooo`3oool03@3oool100000040oooo0@3oool00080oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool00@3oool00080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2T0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool00@3oool000<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2T0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00@3o
ool000<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2T0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`2S0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00@3oool000<0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00@3oool000<0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2R
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool00@3oool000<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2R0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
0@3oool000<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2R0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool00@3oool000<0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`2R0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool0
00<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool00P3oool000<0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`2R0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool000@0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`2R0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool000@0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2R0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool00P3oool000@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2Q0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00P3o
ool000@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`2P0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool000@0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2P0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`2P0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool000@0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`2P0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool00P3oool000@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2P
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool000@0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`2P0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool00`3oool000@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2P0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`2P0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
0`3oool000D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2P0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`2P0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool0
00D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2P0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`2P0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool000D0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2P0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`2P0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool000D0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`2P0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool00`3oool000D0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2O0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool00`3oool000D0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2O0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool000D0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3o
ool000D0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2N0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`2N0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0103oool000D0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0103oool000D0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`2N0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0103oool000H0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2N
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0103oool000H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2N0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
103oool000H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2N0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`2N0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0103oool0
00H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`2N0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0103oool000H0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`2M0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0103oool000H0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2M0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool01@3oool000H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2L0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01@3o
ool000L0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2L0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`2L0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01@3oool000L0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`2L0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01@3oool000L0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2L
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool01@3oool000L0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2L0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
1@3oool000L0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2L0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`2L0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01@3oool0
00L0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool01P3oool000L0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`2K0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool000L0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool01P3oool000L0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`2K0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool000L0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool01P3oool000P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2K0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool000P0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool01P3oool000P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2J0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool000P0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01P3o
ool000P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool01P3oool000P0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`2J0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool000P0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool01P3oool000P0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`2J0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool000P0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool01P3oool000P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2J
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool000P0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool01`3oool000P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2J0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
1`3oool000P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2I0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool01`3oool000P0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`2I0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool0
00P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool01`3oool000T0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`2I0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool000T0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool01`3oool000T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`2I0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool000T0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool01`3oool000T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2H0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool01`3oool000T0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool01`3oool000T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2H0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool01`3oool000T0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01`3o
ool000T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2H0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool01`3oool000T0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`2H0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool000T0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0203oool000T0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`2H0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool000T0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0203oool000T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2H
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool000T0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0203oool000X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2G0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool000X0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
203oool000X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2G0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0203oool000X0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`2G0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool0
00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0203oool000X0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`2G0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool000X0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool0203oool000X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`2F0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203oool000X0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0203oool000X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2F0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02@3oool000X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2F0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3o
ool000X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`2F0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool000X0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02@3oool000/0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0^0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0;`3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00T0oooo000;0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0I0?ooo`T000004@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool000/0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`100?ooo`T000001`0J00000`000000D@0000000003
000003l0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`090?ooo`002`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo03d0oooo1@00000>01X000030000001A0000D@00
00<0D@000`00000l0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool000/0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00`0
oooo1P00000?01X000030000001A0000D@0000H0D@00100000070?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`090?ooo`002`3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02@3ooolJ000000/0D@00
0P0000050?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`090?ooo`002`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03D0oooo2P00
000C0?ooo`@00000201A0003000003@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`090?ooo`002`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03<0oooo2P00000I
0?ooo`@00000101A000010000000O@0007d00000000c0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool02@3oool000/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0b
0?ooo`P00000803oool400000004054000000000O@0007d000800000<@3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00X0oooo000;0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0<03oool8000002H0oooo0P00000407d000030000003oool0oooo02h0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`002`3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo02l0oooo1P00000[0?ooo`8000000`1m0002000002d0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`002`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo02h0oooo1@00000_0?ooo`8000000`1m00000`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool000/0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0/0?ooo`D00000<`3oool010000000O@0007d0001m0002000002X0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`002`3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo02/0oooo1@00000e0?ooo`8000000`1m00000`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool000/0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0Z0?ooo`@00000>@3oool00`000000O@0007d0
0002000002P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`002`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02P0oooo1@00000k0?ooo`80000000<0O@00
0000003oool09`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo000<0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool09`3oool5000003h0oooo0`00000W0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool000`0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0V0?ooo`@00000@P3oool2000002H0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0:0?ooo`00303oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo02D0oooo0`0000140?ooo`8000009@3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00X0oooo000<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0903o
ool3000004D0oooo0P00000U0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3o
ool000`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0S0?ooo`800000B03oool2
000002@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`00303oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0B03oool20000
02<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`00303oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo0280oooo0P00001;0?ooo`8000008P3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo000<0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool08@3oool2000004`0oooo00<0000009TS003oool08@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00/0oooo000<0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool08@3oool2000004d0oooo00<0000009TS003oool0803oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00/0oooo000<0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0803oool2000004l0oooo0P00000P0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool02`3oool000`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0O0?oo
o`800000D@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool02`3oool000`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0O0?ooo`80
0000D@3oool2000001l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`00
303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01h0oooo0P00001C0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`00303o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0D`3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3o
ool000`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0M0?ooo`800000E@3oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool0
00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
05@0oooo0P00000L0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool000d0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0L0?ooo`800000E`3oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool000d0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0L0?ooo`800000E`3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool000d0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0L0?ooo`800000E`3oool2000001/0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`003@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo01/0oooo0P00001I0?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`003@3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo01X0oooo0P00001I0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`003@3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo01X0oooo0P00001J0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`003@3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo01X0oooo0P00001J0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo01T0oooo00<000000;Rl>0000000FP3oool2000001T0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo01T0oooo0P00001K0?ooo`8000006@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00`0oooo000=0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool06@3oool20000
05/0oooo0P00000I0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0303oool000d0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0H0?ooo`030000002h_3P0000005/0
oooo00<0000000007`000000603oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00`0
oooo000=0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0603oool3000005/0oooo
00<0000000007`000000103oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0303oool000d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0H0?ooo`<00000F`3oool00`000000000O000000040?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0<0?ooo`003@3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo01P0oooo00<000000<jR50000000F`3oool00`000000000O00000003
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0<
0?ooo`003@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01L0oooo0P0000000`3>
XQ@000000?ooo`1J0?ooo`030000000001l0000000<0oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00`0oooo000>0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool05`3oool010000000cZ8D0<jR5000001K0?ooo`030000000001l00000
00<0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00`0oooo000>0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool05`3oool010000000
cZ8D0<jR5000001K0?ooo`030000000001l0000000<0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo000>0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool05`3oool01@000000cZ8D0<jR503>XQ@0000005X0oooo00<000000000
7`0000000P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0303oool000h0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0G0?ooo`05
0000003>XQ@0cZ8D0<jR50000000FP3oool00`000000000O000000020?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`003P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo01P0oooo00@000000<jR503>XQ@00000FP3oool00`00
0000000O000000020?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0<0?ooo`003P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01P0
oooo00@000000<jR503>XQ@00000FP3oool01@000000000O0000003oool0000001D0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`003P3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo01L0oooo00@000000<jR503>XQ@00000FP3oool01@000000000O0000003o
ool0000001D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`003P3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01L0oooo00@000000<jR503>XQ@00000F@3o
ool4000000030?ooo`000000oooo01@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0=0?ooo`003P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01L0oooo00@00000
0<jR503>XQ@00000F@3oool5000001H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0=0?ooo`003P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01L0oooo00@00000
0<jR503>XQ@00000F@3oool5000001H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0=0?ooo`003P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01L0oooo00D00000
0<jR50000000dW/00000001G0?ooo`H000005P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00d0oooo000>0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool05`3oool0
1@000000cZ8D0000003BN`00000005L0oooo1P00000F0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool03@3oool000h0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0H
0?ooo`8000000P3BN`000`000000oooo0?ooo`1D0?ooo`D000005`3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00d0oooo000>0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0603oool200000080dW/000<000000?ooo`3oool0E03oool5000001L0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`003P3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo01P0oooo00D000000=9k003BN`00dW/00000001E0?ooo`H000005`3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00d0oooo000>0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0603oool00`000000dW/00=9k00020=9k00030000003oool0oooo0580
oooo1@00000H0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03@3oool000l0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0D0?ooo`050000003oool0oooo0?ooo`00
0000103BN`000`000000oooo0?ooo`1B0?ooo`D00000603oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00d0oooo000?0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`020?ooo`050000003BN`00dW/00=9k00000000D`3oool6000001P0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`003`3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo01D0oooo00D000000?ooo`3oool0oooo000000040=9k0003
0000003oool0oooo0500oooo1P00000H0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool03@3oool000l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo0080oooo00D000000=9k003BN`00dW/00000001A0?ooo`H00000603oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00d0oooo000?0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`020?ooo`030000003BN`00dW/00080dW/0
00<000000?ooo`3oool0C@3oool7000001P0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0=0?ooo`003`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool00P3oool00`000000dW/00=9k00020=9k00030000003oool0oooo04d0oooo1`00
000H0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03P3oool000l0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0080oooo00@00000
0=9k003BN`00dW/00P00001=0?ooo`P00000603oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00h0oooo000?0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`020?ooo`040000003BN`00dW/000000080`d/000<000000?ooo`3oool0B@3o
ool8000001T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0>0?ooo`003`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00P3oool0
10000000dW/00=9k000000030<=;00030000003oool0oooo04L0oooo2@00000I0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool03P3oool000l0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0080oooo00<000000=9k000000001033B`00
0`000000oooo0?ooo`150?ooo`P0000000<0oooo0000003oool0603oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00h0oooo000?0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`020?ooo`030000003BN`00000000@0`d/000<000000?oo
o`3oool0A03oool800000080oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00h0oooo000?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`030?ooo`0300000033B`00`d/000@0`d/000<000000?ooo`3o
ool0@`3oool8000000030?ooo`000000oooo01T0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0>0?ooo`003`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool00`3oool00`000000`d/00<=;00050<=;00030000003oool0oooo0440oooo
200000020?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0>0?ooo`003`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool00`3oool00`000000`d/00<=;00050<=;00030000003oool0oooo03l0oooo2000
00030?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0>0?ooo`003`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool0103oool00`000000`d/00<=;00050<=;00030000003oool0oooo03`0oooo2@000004
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0>
0?ooo`003`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool01@3oool00`000000`d/00<=;00050<=;00030000003oool0oooo03X0oooo2P0000030?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0>0?oo
o`00403oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool01@3oool00`000000`d/00<=;00040<=;00<00000>@3oool:000000@0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00h0oooo000@0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`060?ooo`030000
0033B`00`d/000<0`d/000@000000:DG002U5`000000=P3oool;000000D0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00h0oooo000@0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`060?ooo`030000
0033B`00`d/000<0`d/000@000000:DG002U5`00YAL00P00000c0?ooo`/000001@3oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03P3oool00100oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00L0oooo
00D000000<=;0033B`00`d/0000000060:DG00030000003oool0oooo02l0oooo300000050?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0>0?ooo`00
403oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
1`3oool010000000`d/00<=;000000070:DG00800000;@3oool=000000H0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00l0oooo000@0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`080?ooo`030000
0033B`00000000T0YAL000<000000?ooo`3oool0:03oool>000000L0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo000@0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`090?ooo`8000002P2U
5`02000002H0oooo0P0000000`0C0000000000000009000000P0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo000@0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0:0?ooo`030000002U5`00
YAL000X0YAL00`00000P0?ooo`<000000`0C000:000000T0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo000@0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0:0?ooo`8000002P2U5`000`00
0000N`0007/00004000001T0oooo0`00000601<000P000002`3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00100oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00`0oooo0P0000080:DG0003
0000001k0000N`0000@0N`001@00000B0?ooo`8000002P0C0006000000/0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo000@0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0>0?ooo`030000
002U5`00YAL000D0YAL000<0000007/0001k00002@1k000B000000`04`001000000=0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`00403o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool03`3o
ool2000000@0YAL000<0000007/0001k0000301k00000`000000B@0004T0000;04T000030000000C
00004`0000/04`000`00000>0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0?0?ooo`00403oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool0403oool200000080YAL000<0000007/0001k0000301k0000
0`000000B@0004T0000;04T000030000000C00004`0000X04`000P00000@0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?ooo`00403oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool04P3oool30000
00h0N`0000<0000004T0001900002`1900000`0000004`0001<0000701<000<000004@3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool00100
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01@0
oooo0P00000=07/00003000000190000B@0000/0B@0000<0000001<0000C00001@0C0002000001@0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0
oooo000@0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0F0?ooo`@000002@1k00000`000000B@0004T0000;04T000030000000C00004`0000804`00
0`00000F0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0?0?ooo`004@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool06@3oool4000000D0N`0000<0000004T0001900002`1900000`0000004`000000
0002000001P0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00l0oooo000A0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`0M0?ooo`@0000000<0N`000000001900001P190008000001/0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo000A0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0Q0?oo
o`T000008`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool03`3oool00140oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo04d0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00l0oooo000A0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0@0?ooo`004@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0403oool00140oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo0100oooo000A0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0@0?ooo`004@3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0BP3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0403oool00140oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo04T0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0100oooo
000A0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`190?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0@0?ooo`004@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool0B03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0403oool00140oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo04P0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo0100oooo000A0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0@0?ooo`004@3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0403oool00140oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0100oooo000B0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`160?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0@0?ooo`004P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0A03oool00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0403oool00180
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo04@0
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0100
oooo000B0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`140?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0A0?ooo`004P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool0A03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool04@3oool00180oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo0140oooo000B0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0A0?ooo`004P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool04@3oool00180oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0140oooo000B0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0A0?ooo`004P3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool04@3oool0
0180oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
0400oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
0140oooo000B0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`0o0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0A0?ooo`004P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool04@3oool00180oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0P0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo0140oooo000C0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo02@0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0A0?ooo`004`3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0T0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool04@3oool001<0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0280oooo9P00000L0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool04@3oool001<0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0240oooo00<0000006@0001T0000
601T00000`000000I00006@0000706@000030000003oool0oooo01X0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0B0?ooo`004`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo0240oooo00<000000?ooo`3oool08@3oool00`000000I00006@0000G06@000030000001T
0000I00000P0I00000<000000?ooo`3oool06P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo0180oooo000C0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`0Q0?ooo`030000001T0000I00001L0I00000<0000006@0001T00002@1T0000
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool04P3oool0
01<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
0240oooo00<0000006@0001T00005`1T00000`000000I00006@0000906@000030000003oool0oooo
01T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`004`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0803oool00`000000
I00006@0000F06@000030000001T0000I00000X0I00000<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo0180oooo000C0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0P0?ooo`030000001T0000I00001H0I000
00<0000006@0001T00002P1T00000`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool04P3oool001<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo0200oooo00<0000006@0001T00005P1T00000`000000I00006@0
000;06@000030000003oool0oooo01P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0B0?ooo`004`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool0803oool00`000000I00006@0000F06@000030000001T0000I00000/0I00000<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0180oooo000C0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0O0?oo
o`030000001T0000I00001D0I00000<0000006@0001T0000301T00000`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool04P3oool001<0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01l0oooo00<0000006@0001T
00005@1T00000`000000I00006@0000<06@000030000003oool0oooo01P0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0B0?ooo`004`3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool07`3oool00`000000I00006@0000T06@000030000
003oool0oooo01P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`004`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool07`3o
ool00`000000I00006@0000U06@000030000003oool0oooo01H0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0B0?ooo`004`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool07`3oool00`000000I00006@0000U06@000030000003oool0
oooo01H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0B0?ooo`00503oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool07P3oool00`00
0000I00006@0000U06@000030000003oool0oooo01H0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0B0?ooo`00503oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool07P3oool00`000000I00006@0000U06@000030000003oool0oooo01H0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0B0?ooo`00503oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool07P3oool00`000000I000
06@0000V06@000030000003oool0oooo01D0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0C0?ooo`00503oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01T0oooo9P00
00050?ooo`030000001T0000I00002H0I00000<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo01<0oooo000D0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool06@3oool00`000000J`0006/0000806/000030000001[0000J`0001L0J`0000<00000
0?ooo`3oool00`3oool00`000000I00006@0000V06@000030000003oool0oooo01D0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0C0?ooo`00503oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo01T0oooo00<0000006/0001[0000201[00000`000000J`0006/0000G06/0
00030000003oool0oooo00<0oooo00<0000006@0001T00009P1T00000`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool04`3oool001@0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0H0?ooo`030000001[0000J`0000T0J`0000<0000006/0001[
00005`1[00000`000000oooo0?ooo`030?ooo`030000001T0000I00002L0I00000<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01<0oooo000D0?ooo`030000
003oool0oooo00X0oooo7000000;06/000030000001[0000J`0001L0J`001`00000Y06@001P00000
2`3oool00`000000oooo0?ooo`0C0?ooo`00503oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo01P0oooo00<0000006/0001[00002P1[00000`000000J`0006/0000F06/000030000003o
ool0oooo00<0oooo:`00000F0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool04`3o
ool001@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0I0?ooo`030000001[0000
J`0000X0J`0000<0000006/0001[00005P1[00000`000000oooo0?ooo`030?ooo`030000002_]=`0
[kCL02L0[kCL00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo01<0oooo000D0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool06@3oool00`00
0000J`0006/0000:06/000030000001[0000J`0001H0J`0000<000000?ooo`3oool00`3oool00`00
0000[kCL0:ndg00W0:ndg0030000003oool0oooo01D0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0C0?ooo`00503oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01T0
oooo00<0000006/0001[00002P1[00000`000000J`0006/0000F06/000030000003oool0oooo00<0
oooo00<000000:ndg02_]=`09`2_]=`00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool04`3oool001@0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0I0?ooo`030000001[0000J`0000`0J`0000<0000006/0001[00005@1[00000`000000oooo
0?ooo`030?ooo`030000002_]=`0[kCL02L0[kCL00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo01<0oooo000D0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool06@3oool00`000000J`0006/0000<06/000030000001[0000J`0001D0J`0000<0
00000?ooo`3oool00`3oool00`000000[kCL0:ndg00W0:ndg0030000003oool0oooo01H0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0C0?ooo`00503oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo01T0oooo00<0000006/0001[0000301[00000`000000J`0006/0000E
06/000030000003oool0oooo00<0oooo00<000000:ndg02_]=`09`2_]=`00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04`3oool001@0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`030000001[0000J`0002<0J`000P0000050?oo
o`030000002_]=`0[kCL02L0[kCL00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo01<0oooo000E0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool06P3oool00`000000J`0006/0000S06/0008000001@3oool00`000000[kCL0:ndg00W0:ndg003
0000003oool0oooo01L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0C0?ooo`00
5@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01X0oooo00<0000006/0001[0000
8`1[0002000000D0oooo00<000000:ndg02_]=`09`2_]=`00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0503oool001D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0J0?ooo`030000001[0000J`0002@0J`000P0000050?ooo`030000002_
]=`0[kCL02L0[kCL00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo01@0oooo000E0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool06P3oool0
0`000000J`0006/0000T06/0008000001@3oool00`000000[kCL0:ndg00W0:ndg0030000003oool0
oooo01P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0D0?ooo`005@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo01X0oooo00<0000006/0001[0000901[00000`00
0000oooo0?ooo`040?ooo`030000002_]=`0[kCL02L0[kCL00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo01@0oooo000E0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool06`3oool00`000000J`0006/0000T06/000030000003oool0oooo00@0
oooo00<000000:ndg02_]=`09`2_]=`00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0503oool001D0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0K0?ooo`030000001[0000J`0002@0J`0000<000000?ooo`3oool0103oool00`000000[kCL
0:ndg00V0:ndg0030000003oool0oooo01X0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0D0?ooo`005@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01`0oooo00<0
000006/0001[0000901[00000`000000oooo0?ooo`040?ooo`030000002_]=`0[kCL02H0[kCL00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01@0oooo000E
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool06`3oool00`000000J`0006/0000U
06/000030000003oool0oooo00@0oooo00<000000:ndg02_]=`09P2_]=`00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0503oool001D0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0K0?ooo`030000001[0000J`0002D0J`0000<000000?oo
o`3oool0103oool00`000000[kCL0:ndg00V0:ndg0030000003oool0oooo01/0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0D0?ooo`005@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01`0oooo00<0000006/0001[00009@1[00000`000000oooo0?ooo`040?ooo`03
0000002_]=`0[kCL02H0[kCL00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01@0oooo000E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
703ooolY000000H0oooo00<000000:ndg02_]=`09P2_]=`00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0503oool001D0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0L0?ooo`030000002_]=`0[kCL02D0[kCL00<000000?ooo`3oool0103o
ool00`000000[kCL0:ndg00V0:ndg0030000003oool0oooo01`0oooo00D000000?ooo`3oool0oooo
0000000F0?ooo`005@3oool01@000000oooo0?ooo`3oool0000001l0oooo00<000000:ndg02_]=`0
9@2_]=`00`000000oooo0?ooo`040?ooo`030000002_]=`0[kCL02H0[kCL00<000000?ooo`3oool0
703oool01@000000oooo0?ooo`3oool0000001H0oooo000E0?ooo`050000003oool0oooo0?ooo`00
00007`3oool00`000000[kCL0:ndg00U0:ndg0030000003oool0oooo00@0oooo00<000000:ndg02_
]=`09P2_]=`00`000000oooo0?ooo`0L0?ooo`050000003oool0oooo0?ooo`0000005P3oool001D0
oooo00D000000?ooo`3oool0oooo0000000O0?ooo`030000002_]=`0[kCL02D0[kCL00<000000?oo
o`3oool0103oool00`000000[kCL0:ndg00V0:ndg0030000003oool0oooo01`0oooo00D000000?oo
o`3oool0oooo0000000F0?ooo`005P3oool00`000000oooo0000000P0?ooo`030000002_]=`0[kCL
02D0[kCL00<000000?ooo`3oool0103oool00`000000[kCL0:ndg00V0:ndg0030000003oool0oooo
01d0oooo00<000000?ooo`0000005`3oool001H0oooo00<000000?ooo`000000803oool00`000000
[kCL0:ndg00U0:ndg0030000003oool0oooo00@0oooo00<000000:ndg02_]=`09P2_]=`00`000000
oooo0?ooo`0M0?ooo`030000003oool0000001L0oooo000F0?ooo`030000003oool000000200oooo
00<000000:ndg02_]=`09@2_]=`00`000000oooo0?ooo`040?ooo`030000002_]=`0[kCL02H0[kCL
00<000000?ooo`3oool07@3oool00`000000oooo0000000G0?ooo`005P3oool200000240oooo:@00
00060?ooobX00000803oool2000001L0oooo000F0?ooo`800000VP3oool2000001L0oooo000F0?oo
o`800000VP3oool2000001L0oooo000F0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool05@3oool001H0ooooWP00000G0?ooo`00\
\>"],
  ImageRangeCache->{{{91.5625, 253.25}, {528.813, 251.125}} -> {-0.0728924, \
0.833304, 0.00265834, 0.00265834}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Export as a state-space to Matlab/Simulink", "Text"],

Cell[CellGroupData[{

Cell["Calculate[Stage2]", "Input"],

Cell[BoxData[
    \(Calculate[Stage2]\)], "Output"]
}, Open  ]],

Cell["domatlabexport = True;", "Input"],

Cell[CellGroupData[{

Cell[TextData[{
  "If[domatlabexport,\n\tMatlabExport[\n\t\t\"",
  StyleBox["twowiresimpleblades_\"<>modelcase<>\"",
    FontFamily->"Lucida Grande",
    FontWeight->"Plain"],
  ".m\",\n\t\t\
{\"mbtwsA\",ssAspoiler[potentialmatrices2,kineticmatrix,1.0,0]},\n\t\t\
{\"mbtwsB\",ssB[coupling2,kineticmatrix,1.0]},\n\t\t{\"mbtwsC\",ssC},\n\t\t\
{\"mbtwsD\",ssD}\n\t]\n]"
}], "Input"],

Cell[BoxData[
    RowBox[{\(StringJoin::"string"\), \(\(:\)\(\ \)\), "\<\"String expected \
at position \\!\\(2\\) in \\!\\(\\\"twowiresimpleblades_\\\" <> modelcase <> \
\\\".m\\\"\\). \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::string\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    \(MatlabExport[
      "twowiresimpleblades_" <> modelcase <> ".m", {"mbtwsbA", 
        ssAspoiler[potentialmatrices2, kineticmatrix, 1.`, 0]}, {"mbtwsbB", 
        ssB[coupling2, kineticmatrix, 1.`]}, {"mbtwsbC", ssC}, {"mbtwsbD", 
        ssD}]\)], "Output"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1152}, {0, 811}},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{935, 733},
WindowMargins->{{19, Automatic}, {Automatic, 7}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"]}, {None, Inherited, None}},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {36, 36}},
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False},
CellLabelAutoDelete->True,
DockedCells -> FEPrivate`FrontEndResource[ "FEExpressions", \
"CompatibilityToolbar"],
StyleDefinitions -> "Default.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 106, 3, 73, "Section"],

Cell[CellGroupData[{
Cell[1907, 60, 58, 0, 38, "Subsection"],
Cell[1968, 62, 118, 3, 33, "Text"],
Cell[2089, 67, 284, 8, 102, "Input"],

Cell[CellGroupData[{
Cell[2398, 79, 210, 4, 52, "Text"],
Cell[2611, 85, 106, 1, 30, "Input"],
Cell[2720, 88, 106, 3, 30, "Input"],
Cell[2829, 93, 1160, 22, 336, "Input"],
Cell[3992, 117, 45, 4, 66, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4074, 126, 193, 4, 52, "Text"],
Cell[4270, 132, 589, 10, 130, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[4896, 147, 174, 3, 49, "Text"],
Cell[5073, 152, 792, 13, 210, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[5902, 170, 43, 0, 30, "Text"],
Cell[5948, 172, 32, 0, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[6017, 177, 54, 0, 30, "Text"],
Cell[6074, 179, 40, 0, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[6151, 184, 61, 0, 30, "Text"],
Cell[6215, 186, 28, 0, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[6280, 191, 40, 0, 30, "Text"],
Cell[6323, 193, 220, 4, 70, "Input"],
Cell[6546, 199, 161, 3, 70, "Input"],
Cell[6710, 204, 109, 3, 70, "Input"],
Cell[6822, 209, 235, 4, 70, "Input"],
Cell[7060, 215, 151, 3, 70, "Input"],
Cell[7214, 220, 338, 6, 70, "Input"],
Cell[7555, 228, 299, 5, 70, "Input"],
Cell[7857, 235, 134, 3, 70, "Input"],
Cell[7994, 240, 155, 3, 70, "Input"],
Cell[8152, 245, 118, 3, 70, "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8319, 254, 37, 0, 38, "Subsection"],
Cell[8359, 256, 71, 0, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[8467, 261, 68, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[8560, 265, 45, 0, 70, "Subsubsection"],
Cell[8608, 267, 2240, 58, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10885, 330, 71, 0, 70, "Subsubsection"],
Cell[10959, 332, 1213, 25, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12209, 362, 86, 1, 70, "Subsubsection"],
Cell[12298, 365, 380, 7, 70, "Text"],
Cell[12681, 374, 2662, 68, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15380, 447, 52, 0, 70, "Subsubsection"],
Cell[15435, 449, 341, 6, 70, "Text"],
Cell[15779, 457, 1261, 30, 70, "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[17089, 493, 35, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[17149, 497, 136, 3, 33, "Text"],
Cell[17288, 502, 91, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17416, 508, 112, 3, 33, "Text"],
Cell[17531, 513, 939, 16, 210, "Input"],
Cell[18473, 531, 124, 2, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[18634, 538, 98, 2, 30, "Text"],
Cell[18735, 542, 86, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18858, 548, 171, 3, 33, "Text"],
Cell[19032, 553, 111, 3, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19180, 561, 59, 0, 33, "Text"],
Cell[19242, 563, 120, 6, 102, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[19399, 574, 114, 3, 30, "Text"],
Cell[19516, 579, 56, 0, 70, "Input"],
Cell[19575, 581, 58, 0, 70, "Input"],
Cell[19636, 583, 58, 0, 70, "Input"],
Cell[19697, 585, 58, 0, 70, "Input"],
Cell[19758, 587, 62, 0, 70, "Input"],
Cell[19823, 589, 56, 0, 70, "Input"],
Cell[19882, 591, 68, 0, 70, "Input"],
Cell[19953, 593, 60, 0, 70, "Input"],
Cell[20016, 595, 62, 0, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[20115, 600, 38, 0, 30, "Text"],
Cell[20156, 602, 57, 0, 30, "Input"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[20252, 607, 27, 0, 30, "Input"],

Cell[CellGroupData[{
Cell[20304, 611, 59, 0, 38, "Subsection"],
Cell[20366, 613, 35, 0, 30, "Input"],

Cell[CellGroupData[{
Cell[20426, 617, 74, 1, 33, "Text"],

Cell[CellGroupData[{
Cell[20525, 622, 136, 4, 30, "Input"],
Cell[20664, 628, 205, 3, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[20918, 637, 54, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[20997, 641, 196, 12, 210, "Input"],
Cell[21196, 655, 582, 15, 135, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[21827, 676, 47, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[21899, 680, 214, 12, 70, "Input"],
Cell[22116, 694, 293, 9, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[22458, 709, 34, 0, 30, "Text"],

Cell[CellGroupData[{
Cell[22517, 713, 108, 3, 70, "Input"],
Cell[22628, 718, 50, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22715, 724, 108, 3, 70, "Input"],
Cell[22826, 729, 50, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22913, 735, 94, 2, 70, "Input"],
Cell[23010, 739, 42, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23089, 745, 96, 2, 70, "Input"],
Cell[23188, 749, 42, 1, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[23279, 756, 51, 0, 30, "Text"],

Cell[CellGroupData[{
Cell[23355, 760, 58, 0, 30, "Input"],
Cell[23416, 762, 76, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23529, 768, 58, 0, 30, "Input"],
Cell[23590, 770, 75, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23702, 776, 46, 0, 30, "Input"],
Cell[23751, 778, 54, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23842, 784, 48, 0, 30, "Input"],
Cell[23893, 786, 54, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[23996, 793, 50, 0, 33, "Text"],
Cell[24049, 795, 168, 6, 70, "Input"],
Cell[24220, 803, 129, 3, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[24386, 811, 41, 0, 30, "Text"],

Cell[CellGroupData[{
Cell[24452, 815, 18, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[24495, 819, 27, 0, 30, "Input"],
Cell[24525, 821, 53, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24615, 827, 93, 1, 30, "Input"],
Cell[24711, 830, 465, 12, 55, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25213, 847, 245, 4, 30, "Input"],
Cell[25461, 853, 27838, 671, 233, 6792, 407, "GraphicsData", "PostScript", \
"Graphics"],
Cell[53302, 1526, 243, 5, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[53594, 1537, 18, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[53637, 1541, 27, 0, 30, "Input"],
Cell[53667, 1543, 53, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[53757, 1549, 93, 1, 30, "Input"],
Cell[53853, 1552, 467, 12, 55, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[54357, 1569, 363, 6, 70, "Input"],
Cell[54723, 1577, 36466, 774, 247, 6646, 401, "GraphicsData", "PostScript", \
"Graphics"],
Cell[91192, 2353, 243, 5, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[91484, 2364, 18, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[91527, 2368, 27, 0, 30, "Input"],
Cell[91557, 2370, 53, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[91647, 2376, 93, 1, 30, "Input"],
Cell[91743, 2379, 460, 12, 55, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[92240, 2396, 184, 3, 50, "Input"],
Cell[92427, 2401, 9830, 444, 67, 6816, 402, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[102306, 2851, 18, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[102349, 2855, 27, 0, 30, "Input"],
Cell[102379, 2857, 52, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[102468, 2863, 93, 1, 30, "Input"],
Cell[102564, 2866, 413, 11, 55, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[103014, 2882, 184, 3, 50, "Input"],
Cell[103201, 2887, 10010, 483, 70, 7734, 451, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[113260, 3376, 18, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[113303, 3380, 27, 0, 30, "Input"],
Cell[113333, 3382, 52, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[113422, 3388, 93, 1, 30, "Input"],
Cell[113518, 3391, 413, 11, 55, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[113968, 3407, 196, 4, 50, "Input"],
Cell[114167, 3413, 6241, 262, 67, 3341, 222, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[120457, 3681, 18, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[120500, 3685, 27, 0, 30, "Input"],
Cell[120530, 3687, 52, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[120619, 3693, 93, 1, 30, "Input"],
Cell[120715, 3696, 465, 12, 55, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[121217, 3713, 196, 4, 50, "Input"],
Cell[121416, 3719, 12035, 468, 69, 6563, 396, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[133524, 4195, 58, 0, 38, "Subsection"],
Cell[133585, 4197, 34, 0, 30, "Input"],

Cell[CellGroupData[{
Cell[133644, 4201, 74, 1, 33, "Text"],

Cell[CellGroupData[{
Cell[133743, 4206, 133, 3, 30, "Input"],
Cell[133879, 4211, 206, 3, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[134134, 4220, 54, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[134213, 4224, 194, 12, 210, "Input"],
Cell[134410, 4238, 583, 15, 135, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[135042, 4259, 47, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[135114, 4263, 212, 12, 210, "Input"],
Cell[135329, 4277, 293, 9, 43, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[135671, 4292, 34, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[135730, 4296, 107, 3, 70, "Input"],
Cell[135840, 4301, 50, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[135927, 4307, 107, 3, 70, "Input"],
Cell[136037, 4312, 50, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[136124, 4318, 93, 2, 70, "Input"],
Cell[136220, 4322, 42, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[136299, 4328, 95, 2, 70, "Input"],
Cell[136397, 4332, 42, 1, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[136488, 4339, 51, 0, 30, "Text"],

Cell[CellGroupData[{
Cell[136564, 4343, 57, 0, 70, "Input"],
Cell[136624, 4345, 76, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[136737, 4351, 57, 0, 70, "Input"],
Cell[136797, 4353, 75, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[136909, 4359, 45, 0, 70, "Input"],
Cell[136957, 4361, 55, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[137049, 4367, 47, 0, 70, "Input"],
Cell[137099, 4369, 54, 1, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[137202, 4376, 41, 0, 30, "Text"],

Cell[CellGroupData[{
Cell[137268, 4380, 18, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[137311, 4384, 26, 0, 30, "Input"],
Cell[137340, 4386, 53, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[137430, 4392, 92, 1, 30, "Input"],
Cell[137525, 4395, 464, 12, 55, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[138026, 4412, 171, 3, 50, "Input"],
Cell[138200, 4417, 79470, 1294, 662, 6482, 389, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[217719, 5717, 18, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[217762, 5721, 26, 0, 30, "Input"],
Cell[217791, 5723, 53, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[217881, 5729, 92, 1, 30, "Input"],
Cell[217976, 5732, 467, 12, 55, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[218480, 5749, 171, 3, 50, "Input"],
Cell[218654, 5754, 50306, 944, 349, 6650, 401, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[269009, 6704, 18, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[269052, 6708, 26, 0, 30, "Input"],
Cell[269081, 6710, 53, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[269171, 6716, 92, 1, 30, "Input"],
Cell[269266, 6719, 462, 12, 55, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[269765, 6736, 179, 3, 50, "Input"],
Cell[269947, 6741, 100277, 1583, 671, 7436, 432, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[370273, 8330, 18, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[370316, 8334, 26, 0, 30, "Input"],
Cell[370345, 8336, 53, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[370435, 8342, 92, 1, 30, "Input"],
Cell[370530, 8345, 413, 11, 55, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[370980, 8361, 179, 3, 50, "Input"],
Cell[371162, 8366, 88259, 1449, 662, 7734, 451, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[459470, 9821, 18, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[459513, 9825, 26, 0, 30, "Input"],
Cell[459542, 9827, 52, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[459631, 9833, 92, 1, 30, "Input"],
Cell[459726, 9836, 416, 11, 55, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[460179, 9852, 191, 4, 50, "Input"],
Cell[460373, 9858, 75214, 1025, 671, 1376, 109, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[535636, 10889, 18, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[535679, 10893, 26, 0, 30, "Input"],
Cell[535708, 10895, 52, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[535797, 10901, 92, 1, 30, "Input"],
Cell[535892, 10904, 465, 12, 55, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[536394, 10921, 191, 4, 50, "Input"],
Cell[536588, 10927, 60144, 1062, 357, 6545, 396, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[596805, 11997, 58, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[596888, 12001, 34, 0, 30, "Input"],
Cell[596925, 12003, 51, 1, 29, "Output"]
}, Open  ]],
Cell[596991, 12007, 39, 0, 30, "Input"],

Cell[CellGroupData[{
Cell[597055, 12011, 379, 9, 174, "Input"],
Cell[597437, 12022, 351, 5, 22, "Message"],
Cell[597791, 12029, 278, 5, 48, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

